Package: AeRobiology
Type: Package
Title: A Computational Tool for Aerobiological Data
Version: 2.0.4
Authors@R: c(
    person(given = "Jesus",
           family = "Rojo",
           role = "aut",
           email = "Jesus.Rojo@uclm.es"),
    person(given = "Antonio",
           family = "Picornell",
           role = "aut",
           email = "picornell@uma.es"),
    person(given = "Jose",
           family = "Oteros",
           role = c("aut", "cre"),
           email = "OterosJose@gmail.com")
 )
Author: Jesus Rojo [aut],
  Antonio Picornell [aut],
  Jose Oteros [aut, cre]
Maintainer: Jose Oteros <OterosJose@gmail.com>
Description: Different tools for managing databases of airborne particles, elaborating the main calculations and visualization of results. In a first step, data are checked using tools for quality control and all missing gaps are completed. Then, the main parameters of the pollen season are calculated and represented graphically. Multiple graphical tools are available: pollen calendars, phenological plots, time series, tendencies, interactive plots, abundance plots...
License: GPL-3
Depends: R (>= 2.10)
Imports: dplyr, writexl, ggvis, lubridate, plotly, ggplot2, tidyr,
        circular, scales, grDevices, zoo, grid, data.table
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Suggests: testthat, knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-07-09 17:29:26 UTC; CodexSandboxOnline
Repository: CRAN
Date/Publication: 2026-07-09 22:10:19 UTC

# Generated by roxygen2: do not edit by hand

export(analyse_trend)
export(calculate_ps)
export(credits)
export(interpollen)
export(iplot_abundance)
export(iplot_pheno)
export(iplot_pollen)
export(iplot_years)
export(ma)
export(plot_heathour)
export(plot_hour)
export(plot_normsummary)
export(plot_ps)
export(plot_monthly_heatmap)
export(plot_summary)
export(plot_trend)
export(pollen_calendar)
export(quality_control)
importFrom(circular,circular)
importFrom(circular,mean.circular)
importFrom(data.table,data.table)
importFrom(dplyr,"%>%")
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,summarise)
importFrom(dplyr,summarise_all)
importFrom(dplyr,ungroup)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_area)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_errorbar)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,geom_violin)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,position_dodge)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_fill_brewer)
importFrom(ggplot2,scale_fill_discrete)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_fill_gradientn)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_x_date)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,scale_y_date)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_classic)
importFrom(ggplot2,theme_dark)
importFrom(ggplot2,theme_set)
importFrom(ggplot2,ylab)
importFrom(ggvis,"%>%")
importFrom(ggvis,add_axis)
importFrom(ggvis,axis_props)
importFrom(ggvis,ggvis)
importFrom(ggvis,input_checkboxgroup)
importFrom(ggvis,input_slider)
importFrom(ggvis,layer_lines)
importFrom(ggvis,layer_points)
importFrom(ggvis,scale_numeric)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.copy)
importFrom(grDevices,dev.off)
importFrom(grDevices,graphics.off)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grDevices,rainbow)
importFrom(grDevices,recordPlot)
importFrom(graphics,abline)
importFrom(graphics,barplot)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(grid,grid.layout)
importFrom(grid,pushViewport)
importFrom(grid,viewport)
importFrom(lubridate,hour)
importFrom(lubridate,is.POSIXt)
importFrom(lubridate,yday)
importFrom(lubridate,year)
importFrom(plotly,ggplotly)
importFrom(plotly,layout)
importFrom(scales,date_format)
importFrom(scales,pretty_breaks)
importFrom(stats,SSlogis)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,cor.test)
importFrom(stats,getInitial)
importFrom(stats,lm)
importFrom(stats,na.omit)
importFrom(stats,nls)
importFrom(stats,pf)
importFrom(stats,predict)
importFrom(stats,predict.lm)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,smooth.spline)
importFrom(stats,stl)
importFrom(stats,ts)
importFrom(stats,window)
importFrom(tidyr,"%>%")
importFrom(tidyr,gather)
importFrom(tidyr,spread)
importFrom(utils,data)
importFrom(utils,globalVariables)
importFrom(utils,head)
importFrom(writexl,write_xlsx)
importFrom(zoo,na.approx)

## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(echo = FALSE, warning = FALSE, fig.width = 7)
Sys.setlocale(locale="english")

## ----echo=FALSE---------------------------------------------------------------
library ("knitr")

## -----------------------------------------------------------------------------
library ("AeRobiology")

## ----eval=FALSE, echo = TRUE--------------------------------------------------
# install.packages("AeRobiology")
# library (AeRobiology)

## ----echo = TRUE--------------------------------------------------------------
data("munich_pollen")

## ----eval=FALSE, echo = TRUE--------------------------------------------------
# install.packages("readxl")
# library (readxl)

## ----eval=FALSE, echo = TRUE--------------------------------------------------
# Mydata<-read_xlsx("C:/Users/Antonio/Desktop/Prueba Markdown/mydata.xlsx")
# 

## ----eval=FALSE, echo = TRUE--------------------------------------------------
# Mydata<-read_xlsx("C:/Users/Antonio/Desktop/Prueba Markdown/mydata.xlsx", sheet=2)
# 

## ----echo=TRUE, results='hold'------------------------------------------------
str(munich_pollen)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
QualityControl<-quality_control(munich_pollen, result = "table")

## ----echo=TRUE, results='hold'------------------------------------------------

head(QualityControl)

## ----echo=TRUE,  fig.keep='first', results='hide'-----------------------------
quality_control(munich_pollen, result = "plot")

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
quality_control(munich_pollen, int.window = 4, perc.miss = 50, ps.method = "percentage", perc = 80)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
Interpolated<-interpollen(munich_pollen[,c(1,6)], method="lineal", plot = TRUE, result = "long")


## ----echo=TRUE, results='hold'------------------------------------------------
head(Interpolated)

## ----echo=TRUE, results='hide'------------------------------------------------
CompleteData<-interpollen(munich_pollen[,c(1,6)], method="lineal", plot = FALSE, result = "wide")

## ----echo=TRUE, eval=FALSE----------------------------------------------------
# calculate_ps(munich_pollen, method="percentage", interpolation=TRUE, int.method = "lineal", plot = F)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
i<-interpollen(munich_pollen[,c(1,6)], method="movingmean", factor = 2, plot = TRUE)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
i2<-interpollen(munich_pollen[,c(1,6)], method="spline", ndays=3, spar=0.7, plot = FALSE)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
i3<-interpollen(munich_pollen[,c(1,6)], method="spline", ndays=5, spar=0.2, plot = TRUE)

## ----echo=TRUE, results='hide', fig.keep='last'-------------------------------
i4<-interpollen(munich_pollen, method="tseries", plot = TRUE)

## ----echo = TRUE, results='hide', fig.keep='last', warning=FALSE--------------
pollen_season <- calculate_ps(munich_pollen)

## ----echo = FALSE, fig.keep='all', warning=FALSE------------------------------
knitr::kable(pollen_season[24:31, ] , format = "html", booktabs = TRUE)

## ----echo = TRUE, fig.keep='last', warning=FALSE------------------------------
calculate_ps(munich_pollen[,c(1,6)], plot = TRUE)

## ----echo=TRUE, results='hide', fig.keep='first', eval=FALSE------------------
# calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc = 90, export.result = FALSE)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc = 90, export.result = FALSE, int.method = "spline")

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc = 75, export.result = FALSE, interpolation = FALSE)

## ----echo=TRUE, results='hide', fig.keep='first', warning=FALSE---------------
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "logistic", derivative = 5, reduction=FALSE)

## ----echo = FALSE, fig.keep='all', warning=FALSE------------------------------
knitr::kable(pollen_season, format = "html", booktabs = TRUE )

## ----echo=TRUE, results='hide', fig.keep='first', warning=FALSE---------------
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "logistic", derivative = 6, reduction=FALSE, red.level = 0.8)

## ----echo = FALSE, fig.keep='all', warning=FALSE------------------------------
knitr::kable(pollen_season, format = "html", booktabs = TRUE)

## ----echo=TRUE, results='hide', fig.keep='first', warning=FALSE---------------
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "clinical", type = "birch")

## ----echo = FALSE, fig.keep='all', warning=FALSE------------------------------
knitr::kable(pollen_season, format = "html", booktabs = TRUE)

## ----echo=TRUE, results='hide', fig.keep='first', warning=FALSE---------------
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "clinical", n.clinical = 5, window.clinical = 7, th.pollen = 10, th.sum = 100, th.day = 100)

## ----echo = FALSE, fig.keep='all', warning=FALSE------------------------------
knitr::kable(pollen_season, format = "html", booktabs = TRUE)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
calculate_ps(munich_pollen[,c(1,6)], method = "grains", window.grains = 3, th.pollen = 2 )

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
calculate_ps(munich_pollen[,c(1,6)], method = "moving", man = 7, th.ma = 4)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
calculate_ps(munich_pollen[,c(1,3)], method = "moving", man = 7, th.ma = 4, def.season = "interannual")

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc=95, def.season = "peak")

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
CompleteData<-interpollen(munich_pollen, method="spline", ndays=3, spar=0.7, plot = TRUE, maxdays = 3, result = "wide")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_ps(CompleteData, pollen.type="Alnus", year=2013, fill.col = "orange", axisname = "AeRobiology custom units")

## ----echo = TRUE, results='hide',fig.keep='all', warning=FALSE----------------
pollen_calendar(munich_pollen, method = "heatplot", period = "daily", color = "green", interpolation = FALSE)

## ----echo = TRUE, fig.keep='all', warning=FALSE-------------------------------
average_values<-pollen_calendar(munich_pollen, method = "heatplot", period = "daily", color = "green", interpolation = FALSE, result = "table")
knitr::kable(average_values[82:90, ], format = "html", booktabs = TRUE)

## ----echo = TRUE, results='hide',fig.keep='all', warning=FALSE----------------
pollen_calendar(data = munich_pollen, method = "heatplot", period = "daily", color = "red", method.classes = "custom", n.classes = 5, classes = c(5, 25, 50, 200), interpolation = FALSE)

## ----echo = TRUE, results='hide',fig.keep='all', warning=FALSE----------------
pollen_calendar(data = munich_pollen, method = "heatplot", period = "daily", color = "purple", method.classes = "custom", n.classes = 5, classes = c(5, 25, 50, 200), start.month = 11, na.remove = FALSE, interpolation = FALSE)

## ----echo = TRUE, results='hide',fig.keep='all', warning=FALSE----------------
pollen_calendar(data = munich_pollen, method = "heatplot", period = "weekly", color = "blue", method.classes = "exponential", n.types = 4, y.start = 2011, y.end = 2014, interpolation = FALSE)

## ----echo = TRUE, results='hide',fig.keep='all', warning=FALSE----------------
pollen_calendar(data = munich_pollen, method = "phenological", n.types = 5, y.start = 2011, y.end = 2014, interpolation = FALSE)

## ----echo = TRUE, results='hide',fig.keep='all', warning=FALSE----------------
pollen_calendar(data = munich_pollen,  method = "phenological", perc1 = 90, perc2 = 95, th.pollen = 5, interpolation = FALSE)

## ----echo = TRUE, results='hide', fig.keep='all', warning=FALSE---------------
pollen_calendar(data = munich_pollen, method = "violinplot", y.start = 2012, y.end = 2015, interpolation = FALSE)

## ----echo = TRUE, results='hide', fig.keep='all', warning=FALSE---------------
pollen_calendar(data = munich_pollen, method = "violinplot", th.pollen = 10, na.rm = FALSE, interpolation = FALSE)

## ----echo = TRUE, results='hide',fig.keep='all', eval=FALSE-------------------
# iplot_pollen(munich_pollen, year = 2012)
# iplot_years(munich_pollen, pollen = "Betula")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_summary(munich_pollen, pollen = "Betula")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_summary(munich_pollen, pollen = "Betula", mave = 5)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_summary(munich_pollen, pollen = "Betula", mave = 5, normalized = TRUE)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_normsummary(munich_pollen, pollen = "Betula", color.plot = "red")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_normsummary(munich_pollen, pollen = "Betula", color.plot = "green", mave = 5, normalized = TRUE)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, result="plot")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, split = FALSE, quantil = 1, result="plot")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, split=FALSE, quantil = 0.5, result="plot")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, significant = 1, result = "plot")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, significant = 1, result="table")

## ----echo = TRUE, results='hide',fig.keep='all', eval=FALSE-------------------
# plot_trend(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE, n.types = 3)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE, n.types = 3, y.start = 2011, y.end = 2011, col.bar = "#d63131")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE, n.types = 3, y.start = 2011, y.end = 2011, col.bar = "#d63131", type.plot = "dynamic")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
iplot_pheno(munich_pollen, method= "percentage", perc=80, int.method="spline", n.types = 8)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
iplot_pheno(munich_pollen, method= "clinical", n.clinical = 3, int.method="spline", n.types = 4)

## ----echo = TRUE, results='hide',fig.keep='all', eval=FALSE-------------------
# iplot_pheno(munich_pollen, method= "clinical", n.clinical = 3, int.method="spline", n.types = 4, type.plot = "dynamic")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_ps(munich_pollen, pollen.type="Alnus", year=2011)

## ----echo = TRUE, results='hold', error=TRUE----------------------------------
try({
plot_ps(munich_pollen, pollen.type="Alnuscdscscr", year=2011)
})

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, method= "percentage", perc=95 ,int.method = "lineal")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, method= "percentage", perc=95 ,int.method = "movingmean")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, days = 90)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, fill.col = "orange", axisname = "AeRobiology custom units")

## ----echo = FALSE, warning=FALSE, message=FALSE-------------------------------
library(ggplot2)
library(dplyr)

## ----echo = TRUE--------------------------------------------------------------
data("POMO_pollen")

## ----echo = TRUE, message=FALSE-----------------------------------------------
plot_hour(POMO_pollen)

## ----message=FALSE------------------------------------------------------------
TO<-plot_hour(POMO_pollen, result ="table")
knitr::kable(TO[1:10,], caption = "3-Hourly patterns", row.names = FALSE, digits = 1, format = "html", booktabs = TRUE)

## ----message=FALSE, echo=TRUE-------------------------------------------------
plot_hour(POMO_pollen, locations = TRUE)

## ----message=FALSE, echo=TRUE-------------------------------------------------
plot_heathour(POMO_pollen)

## ----message=FALSE, echo=TRUE-------------------------------------------------
plot_heathour(POMO_pollen, low.col = "darkgreen", mid.col = "moccasin", high.col = "brown")

## ----message=FALSE, echo=TRUE-------------------------------------------------
plot_heathour(POMO_pollen, locations = TRUE)

#' Plotting Several Pollen Seasons.
#'
#' Function to plot the pollen data during several seasons. Also plots the averaged pollen season over the study period. It is possible to plot the relative abundance per day and smoothing the pollen season by calculating a moving average.
#'
#' @param data A \code{data.frame} object. This \code{data.frame} should include a first column in format \code{Date} and the rest of columns in format \code{numeric} belonging to each pollen type by column.
#' @param pollen A \code{character} string with the name of the particle to show. This \code{character} must match with the name of a column in the input database. This is a mandatory argument.
#' @param mave An \code{integer} value specifying the order of the moving average applied to the data. By default, \code{mave = 1}.
#' @param normalized A \code{logical} value specifying if the visualization shows real pollen data (\code{normalized = FALSE}) or the percentage of every day over the whole pollen season (\code{normalized = TRUE}). By default, \code{normalized = FALSE}.
#' @param interpolation A \code{logical} value specifying if the visualization shows the gaps in the inputs data (\code{interpolation = FALSE}) or if an interpolation method is used for filling the gaps (\code{interpolation = TRUE}). By default, \code{interpolation = TRUE}.
#' @param int.method A \code{character} string with the name of the interpolation method to be used. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"tseries"} or \code{"spline"}. By default, \code{int.method = "lineal"}.
#' @param export.plot A \code{logical} value specifying if a plot will be exported or not. If \code{FALSE} graphical results will only be displayed in the active graphics window. If \code{TRUE} graphical results will be displayed in the active graphics window and also one pdf/png file will be saved within the \emph{plot_AeRobiology} directory automatically created in the working directory. By default, \code{export.plot = FALSE}.
#' @param export.format A \code{character} string specifying the format selected to save the plot. The implemented formats that may be used are: \code{"pdf"} or \code{"png"}. By default, \code{export.format = "pdf"}.
#' @param axisname A \code{character} string specifying the title of the y axis. By default, \code{axisname =  "Pollen grains / m3"}.
#' @param ... Other additional arguments may be used to customize the exportation of the plots using \code{"pdf"} or \code{"png"} files and therefore arguments from functions \code{\link[grDevices]{pdf}} and \code{\link[grDevices]{png}} may be implemented. For example, for pdf files the user may custom the arguments: width, height, family, title, fonts, paper, bg, fg, pointsize...; and for png files the user may custom the arguments: width, height, units, pointsize, bg, res...
#'
#' @details This function allows to summarize the pollen season by a simple plot. Even though the package was originally designed to treat aeropalynological data, it can be used to study many other atmospheric components (e.g., bacteria in the air, fungi, insects ...) \emph{(Buters et al., 2018; Oteros et al., 2019)}.
#' @return This function returns plot of class \pkg{ggplot2}. User are able to customize the output as a \pkg{ggplot2} object.
#' @references Buters, J. T. M., Antunes, C., Galveias, A., Bergmann, K. C., Thibaudon, M., Galan, C. & Oteros, J. (2018). Pollen and spore monitoring in the world. \emph{Clinical and translational allergy}, 8(1), 9.
#' @references Oteros, J., Bartusel, E., Alessandrini, F., Nunez, A., Moreno, D. A., Behrendt, H., ... & Buters, J. (2019). Artemisia pollen is the main vector for airborne endotoxin. \emph{Journal of Allergy and Clinical Immunology}.
#' @seealso \code{\link{calculate_ps}}; \code{\link{plot_normsummary}}
#' @examples  data("munich_pollen")
#' @examples  plot_summary(munich_pollen, pollen = "Betula", export.plot = FALSE, interpolation = FALSE)
#' @importFrom graphics plot
#' @importFrom utils data
#' @importFrom ggplot2 aes element_text geom_area geom_line ggplot ggtitle labs theme theme_bw theme_classic theme_set
#' @importFrom grDevices dev.off pdf png
#' @importFrom lubridate is.POSIXt yday year
#' @importFrom stats aggregate
#' @importFrom tidyr %>%
#' @export
plot_summary<-function (data,
                      pollen,
                      mave=1,
                      normalized=FALSE,
                      interpolation = TRUE,
                      int.method = "lineal",
                      export.plot = FALSE,
                      export.format = "pdf",
                      axisname="Pollen grains / m3",
                      ...){

  # Sys.setlocale(category = "LC_ALL", locale="english")

  #############################################    CHECK THE ARGUMENTS       #############################

  if(export.plot == TRUE){ifelse(!dir.exists(file.path("plot_AeRobiology")), dir.create(file.path("plot_AeRobiology")), FALSE)}
  data<-data.frame(data)
  if(!is.data.frame(data)) stop ("Please include a data.frame: first column with date, and the rest with pollen types")

  if(!is.character(pollen)) stop ("Please include only charactr values for 'pollen'")

  if(!is.logical(export.plot)) stop ("Please include only logical values for export.plot argument")

  if(export.format != "pdf" & export.format != "png") stop ("Please export.format only accept values: 'pdf' or 'png'")

  if(class(data[,1])[1]!="Date" & !is.POSIXt(data[,1])) {stop("Please the first column of your data must be the date in 'Date' format")}
  data[,1]<-as.Date(data[,1])


  if(!is.character(axisname)) stop ("Please include only character values for 'axisname'")

  # if(!is.logical(interpolation)) stop ("Please include only logical values for interpolation argument")
  #
  # if(int.method != "lineal" & int.method != "movingmean" & int.method != "tseries" &  int.method != "spline") stop ("Please int.method only accept values: 'lineal', 'movingmean', 'tseries' or 'spline'")
  #


  ncolpollen<-which( colnames(data)==pollen)
  data<-data[,c(1,ncolpollen)]


if(interpolation == TRUE){data <- interpollen(data, method = int.method)}

  data[, 1] <- as.Date(data[, 1])
  colnames(data)[1]<-"Date"
  data$DOY<-yday(data[, 1] )
  data$Year<-year(data[, 1] )
  data[,2]<-ma(data[,2],man=mave)

  if (normalized==T){
    sum<-aggregate(data[,pollen], by=list(data[,"Year"]), FUN=sum, na.rm=T)
    colnames(sum)[1]<-"Year"
    data<-merge(data,sum,by="Year")
    colnames(data)[length(data)]<-"sum"

    data$percent<-data[,pollen]*100/data[,"sum"]
    data<-data[which(data$sum!=0),]
    meant<-aggregate(data[,"percent"], by=list(data[,"DOY"]), FUN=mean, na.rm=T)
    colnames(meant)[1]<-"DOY"
    data_pollen<-merge(data, meant, by ="DOY")
    data_pollen$Year<-as.character(year(data_pollen[,"Date"]))
    # data_pollen<-data_pollen[,c(colnames(data_pollen)[1:2],pollen,"Year","x")]


    plot.summary<-ggplot(data_pollen, aes(x=DOY, y=data_pollen[,"percent"],fill=Year)) +
      theme_set(theme_bw()) +
      geom_area(position = "identity", alpha=0.3)+
      geom_line(data=data_pollen, aes(y=x), size=1)+
      labs(x="Day of the year", y="percentage (%)") +
      theme(axis.text=element_text(size=10), axis.title=element_text(size=10)) +
      ggtitle(pollen) +
      theme_classic()+
      theme(plot.title=element_text( face="bold.italic", size=13))


  }else{

    sum<-aggregate(data[,pollen], by=list(data[,"Year"]), FUN=sum, na.rm=T)
    colnames(sum)[1]<-"Year"
    data<-merge(data,sum,by="Year")
    colnames(data)[length(data)]<-"sum"

    data$percent<-data[,pollen]*100/data[,"sum"]
    data<-data[which(data$sum!=0),]
    meant<-aggregate(data[,pollen], by=list(data[,"DOY"]), FUN=mean, na.rm=T)
    colnames(meant)[1]<-"DOY"
    data_pollen<-merge(data, meant, by ="DOY")
    data_pollen$Year<-as.character(year(data_pollen[,"Date"]))
    data_pollen<-data_pollen[,c(colnames(data_pollen)[1:2],pollen,"Year","x")]


    plot.summary<-ggplot(data_pollen, aes(x=DOY, y=data_pollen[,pollen],fill=Year)) +
      theme_set(theme_bw()) +
      geom_area(position = "identity", alpha=0.3)+
      geom_line(data=data_pollen, aes(y=x), size=1)+
      labs(x="Day of the year", y=axisname) +
      theme(axis.text=element_text(size=10), axis.title=element_text(size=10)) +
      ggtitle(pollen) +
      theme_classic()+
      theme(plot.title=element_text(face="bold.italic", size=13))

  }




if(export.plot == TRUE  & export.format == "png") {
  png(paste0("plot_AeRobiology/plot_summary_", pollen,".png"), ...)
  plot(plot.summary)
  dev.off()
  png(paste0("plot_AeRobiology/credits.png"))

  dev.off()
}

if(export.plot == TRUE  & export.format == "pdf") {
  pdf(paste0("plot_AeRobiology/plot_summary_",  pollen, ".pdf"), ...)
  plot(plot.summary)

  dev.off()
}

return(plot.summary)

}

#' Pollen Calendar by Different Methods from a Historical Pollen Database
#'
#' Function to calculate the pollen calendar from a historical database of several pollen types and using the most commonly used methods in the generation of the pollen calendars in the aerobiology field.
#'
#' @param data A \code{data.frame} object including the general database where calculation of the pollen calendar must be applied. This \code{data.frame} must include a first column in \code{Date} format and the rest of columns in \code{numeric} format belonging to each pollen type by column.
#' @param method A \code{character} string specifying the method applied to calculate and generate the pollen calendar. The implemented methods that can be used are: \code{"heatplot"}, \code{"violinplot"} or \code{"phenological"}. A more detailed information about the different methods for defining the pollen season may be consulted in \strong{Details}. The \code{method} argument will be \code{heatplot} by default.
#' @param n.types A \code{numeric} (\code{integer}) value specifying the number of the most abundant pollen types that must be represented in the pollen calendar. A more detailed information about the selection of the considered pollen types may be consulted in \strong{Details}. The \code{n.types} argument will be \code{15} types by default.
#' @param start.month A \code{numeric} (\code{integer}) value ranging \code{1_12} specifying the number of the month (January_December) when the beginning of the pollen calendar must be considered. This argument is only applicable for the \code{"heatplot"} method with \code{"daily"} period, for the \code{"phenological"} method with \code{"avg_before"} \code{average.method}, and for the \code{"violinplot"} method, and the rest of methods only may be generated from the January (\code{start.month = 1}). The \code{start.month} argument will be \code{1} (month of January) by default.
#' @param y.start,y.end A \code{numeric} (\code{integer}) value specifying the period selected to calculate the pollen calendar (start year _ end year). If \code{y.start} and \code{y.end} are not specified (\code{NULL}), the entire database will be used to generate the pollen calendar. The \code{y.start} and \code{y.end} arguments will be \code{NULL} by default.
#' @param perc1,perc2 A \code{numeric} value ranging \code{0_100}. These arguments are valid only for the \code{"phenological"} method. These values represent the percentage of the total annual pollen included in the pollen season, removing \code{(100_percentage)/2\%} of the total pollen before and after of the pollen season. Two percentages must be specified because of the definition of the "main pollination period" (\code{perc1}) and "early/late pollination" (\code{perc2}) based on the \code{"phenological"} method proposed by \emph{Werchan et al. (2018)}. The \code{perc1} argument will be \code{80} and \code{perc2} argument will be \code{99} by default. A more detailed information about the \code{phenological} method to generate the pollen calendar may be consulted in \strong{Details}.
#' @param th.pollen A \code{numeric} value specifying the minimum threshold of the average pollen concentration which will be used to generate the pollen calendar. Days below this threshold will not be considered. For the \code{"phenological"} method this value limits the "possible occurrence" period as proposed by \emph{Werchan et al. (2018)}. The \code{th.pollen} argument will be \code{1} by default. A more detailed information about the methods to generate the pollen calendar may be consulted in \emph{Details}.
#' @param average.method A \code{character} string specifying the moment of the application of the average. This argument is valid only for the \code{"phenological"} method. The implemented methods that can be used are: \code{"avg_before"} or \code{"avg_after"}. \code{"avg_before"} produces the average to the daily concentrations and then pollen season are calculated for all pollen types, this method is recommended as it is a more concordant method with respect to the rest of implemented methods. Otherwise, \code{"avg_after"} determines the pollen season for all years and all pollen types, and then a circular average is calculated for the start_dates and end_dates. The \code{average.method} argument will be \code{"avg_before"} by default.
#' @param period A \code{character} string specifying the interval time considered to generate the pollen calendar. This argument is valid only for the \code{"heatplot"} method. The implemented periods that can be used are: \code{"daily"} or \code{"weekly"}. \code{"daily"} selection produces a pollen calendar using daily averages during the year and \code{"weekly"} selection produces a pollen calendar using weekly averages during the year. The \code{period} argument will be \code{"daily"} by default.
#' @param method.classes A  \code{character} string specifying the method to define the classes used for classifying the average pollen concentrations to generate the pollen calendar. This argument is valid only for the  \code{"heatplot"} method. The implemented methods for defining classes are:  \code{"exponential"} and  \code{"custom"}. The  \code{method.classes} argument will be  \code{"exponential"} by default. A more detailed information about the methods to classify the average pollen concentrations to generate the pollen calendar may be consulted in \strong{Details}.
#' @param n.classes A \code{numeric} (\code{integer}) value specifying the number of classes that will be used for classifying the average pollen concentrations to generate the pollen calendar. This argument is valid only for the \code{"heatplot"} method and the classification by \code{method.classes = "custom"}. The \code{n.classes} argument will be \code{5} by default. A more detailed information about the methods to classify the average pollen concentrations to generate the pollen calendar may be consulted in \strong{Details}.
#' @param classes A \code{numeric} vector specifying the threshold established to define the different classes that will be used for classifying the average pollen concentrations to generate the pollen calendar. This argument is valid only for the \code{"heatplot"} method and the classification by \code{method.classes = "custom"}. The \code{classes} argument will be \code{c(25, 50, 100, 300)} by default. The number of specified classes must be equal to \code{n.classes _ 1} because of the maximum threshold will be automatically specified by the maximum value. A more detailed information about the methods to classify the average pollen concentrations to generate the pollen calendar may be consulted in \strong{Details}.
#' @param color A \code{character} string specifying the color to generate the graph showing the pollen calendar. This argument is valid only for the \code{"heatplot"} method. The implemented color palettes to generate the pollen calendar are: \code{"green"}, \code{"red"}, \code{"blue"}, \code{"purple"} or \code{"black"}. The \code{color} argument will be \code{"green"} by default.
#' @param interpolation A \code{logical} value. If \code{FALSE} the interpolation of the pollen data is not applicable. If \code{TRUE} an interpolation of the pollen series will be applied to complete the gaps before the calculation of the pollen calendar. The \code{interpolation} argument will be \code{TRUE} by default. A more detailed information about the interpolation method may be consulted in \strong{Details}.
#' @param int.method A \code{character} string specifying the method selected to apply the interpolation method in order to complete the pollen series. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"spline"} or \code{"tseries"}. The \code{int.method} argument will be \code{"lineal"} by default.
#' @param na.remove A \code{logical} value specifying if \code{na} values must be remove for the pollen calendar or not. \code{n.remove = TRUE} by default.
#' @param legendname A \code{character} string specifying the title of the legend. By default is \code{"Pollen / m3"}.
#' @param result A \code{character} string specifying the output for the function. The implemented outputs that may be obtained are: \code{"plot"} and \code{"table"}. The argument \code{result} will be \code{"plot"} by default.
#' @param export.plot A \code{logical} value specifying if a plot with the pollen calendar saved in the working directory will be required or not. If \code{FALSE} graphical results will only be displayed in the active graphics window. If \code{TRUE} graphical results will be displayed in the active graphics window and also a \emph{pdf} file will be saved within the \emph{plot_AeRobiology} directory automatically created in the working directory. The \code{export.plot} will be \code{FALSE} by default.
#' @param export.format A \code{character} string specifying the format selected to save the pollen calendar plot. The implemented formats that may be used are: \code{"pdf"} and \code{"png"}. The \code{export.format} will be \code{"pdf"} by default.
#' @param ... Other additional arguments may be used to customize the exportation of the plots using \code{"pdf"} or \code{"png"} files and therefore arguments from \emph{pdf} and \emph{png} functions (\pkg{grDevices} package) may be implemented. For example, for \emph{pdf} files the user may custom the arguments: \code{width}, \code{height}, \code{family}, \code{title}, \code{fonts}, \code{paper}, \code{bg}, \code{fg}, \code{pointsize...}; and for \emph{png} files the user may custom the arguments: \code{width}, \code{height}, \code{units}, \code{pointsize}, \code{bg}, \code{res...}
#' @details This function allows to calculate and generate the pollen calendar using three different methods which are described below. The pollen calendar will be calculated and generated only for the period specified by the user using the \code{y.start} and \code{y.end} arguments, and for the specified number of the most abundant pollen types using the \code{n.types} argument by the user. The most abundant pollen types will be selected according to the highest average annual amounts of pollen registered by the pollen types during the considered period.
#' \itemize{
#' \item \code{"heatplot"} method. This pollen calendar is constructed based on the daily or weekly average of pollen concentrations, depending of the preferences of the user that may select \code{"daily"} or \code{"weekly"} as \code{period} argument. Then, these averages may be classified in different categories following different methods selected by the user according to the \code{method.classes} argument. If \code{method.classes = "exponential"} the user will apply the classification based on exponential classes proposed by \emph{Stix and Ferreti (1974)}, which has been commonly used in aerobiology for the generation of pollen calendars. The classification based on exponential method considers 11 classes (\code{1_2, 3_5, 6_11, 12_24, 25_49, 50_99, 100_199, 200_399, 400_799, 800_1600, >1600}). An example of this pollen calendar may be consulted in \emph{Rojo et al. (2016)}. This method to design pollen calendars is an adaptation from the pollen calendar proposed by \emph{Spieksma (1991)} who considered 10_day periods instead of daily or weekly periods. Otherwise, if \code{method.classes  = "custom"} the user may customize the classification according to the number of classes selected (\code{n.classes} argument) and the thresholds of the pollen concentrations used to define the classes (\code{classes} argument). Average values below the level of the \code{th.pollen} argument will be removed from the pollen calendar.
#' \item \code{"phenological"} method. This pollen calendar is based on phenological definition of the pollen season and adapted from the methodology proposed by \emph{Werchan et al. (2018)}. After to obtain daily average pollen concentrations for the most abundant pollen types different pollination periods were calculated using the daily averages. The main pollination period was calculated based on the percentage defined by \code{perc1} argument (selected by the user, 80\% by default) of the annual total pollen. For example, if \code{perc1 = 80} the beginning of the high season was marked when 10\% of the annual value was reached and the end was selected when 90\% was reached. In the case of the early/late pollination a total of the percentage defined by \code{perc2} argument (selected by the user, 99\% by default) of the annual total pollen will be registered during this period. For this kind of pollen calendar the \code{th.pollen} argument will define the "possible occurrence" period as adapted by \emph{Werchan et al. (2018)}, considering the entire period between the first and the last day when this pollen level is reached. In an alternative way the average may be carried out after to define the pollen seasons using \code{method_average = "avg_after"} (instead of \code{"avg_before"} by default). \code{"avg_after"} determines the pollen season for all years and all pollen types, and then an average for circular data is calculated from the start_dates and end_dates.
#' \item \code{"violinplot"} method. This pollen calendar is based on the pollen intensity and adapted from the pollen calendar published by \emph{ORourke (1990)}. In first time the daily averages of the pollen concentrations are calculated and then these averages are represented using the \emph{violin plot} graph. The shape of the \emph{violin plot} display the pollen intensity of the pollen types in a relative way i.e. the values will be calculated as relative measurements regarding to the most abundant pollen type in annual amounts. Therefore, this pollen calendar shows a relative comparison between the pollen intensity of the pollen types but without scales and units. Average values below the level of the \code{th.pollen} argument will be removed from the pollen calendar.
#' }
#' Pollen time series frequently have different gaps with no data and this fact could be a problem for the calculation of specific methods for defining the pollen season even providing incorrect results. In this sense by default a linear interpolation will be carried out to complete these gaps before to generate the pollen calendar. For more information to see the \code{\link{interpollen}} function.
#' @return This function returns different results:\cr
#' \code{plot} in the active graphics window displaying the pollen calendar generated by the user when \code{result = "plot"}. This plot may be included in an object by assignment operators.\cr
#' \code{data.frame} including the daily or weekly average pollen concentrations (according to the selection of the user) used to generate the pollen calendar. This \code{data.frame} will be returned when \code{result = "table"}.\cr
#' If \code{export.plot = TRUE} this plot displaying the pollen calendar will also be exported as file within the \emph{Plot_AeRobiology}" directory created in the working directory.\cr
#' If \code{export.plot = TRUE} and \code{export.format = pdf} a \emph{pdf} file of the pollen calendar will be saved within the \emph{plot_AeRobiology} directory created in the working directory. Additional characteristics may be incorporated to the exportation as \emph{pdf} file (see \pkg{grDevices} package)\cr
#' If \code{export.plot = TRUE} and \code{export.format = png} a \emph{png} file of the pollen calendar will be saved within the \emph{plot_AeRobiology} directory created in the working directory. Additional characteristics may be incorporated to the exportation as \emph{png} file (see \pkg{grDevices} package).
#' @references ORourke, M.K., 1990. Comparative pollen calendars from Tucson, Arizona: Durhamvs. Burkard samplers. \emph{Aerobiologia}, 6(2), p.136_140.
#' @references Rojo, J., Rapp, A., Lara, B., Sabariego, S., Fernandez_Gonzalez, F. and Perez_Badia, R., 2016. Characterisation of the airborne pollen spectrum in Guadalajara (central Spain) and estimation of the potential allergy risk. \emph{Environmental Monitoring and Assessment}, 188(3), p.130.
#' @references Spieksma, F.T.M., 1991. \emph{Regional European pollen calendars. Allergenic pollen and pollinosis in Europe}, pp.49_65.
#' @references Stix, E. and Ferretti, M.L., 1974. \emph{Pollen calendars of three locations in Western Germany. Atlas European des Pollens Allergisants}, pp.85_94.
#' @references Werchan, M., Werchan, B. and Bergmann, K.C., 2018. German pollen calendar 4.0_update based on 2011_2016 pollen data. \emph{Allergo Journal International}, 27, pp.69_71.
#' @seealso \code{\link{interpollen}}, \code{\link{calculate_ps}}
#' @examples data("munich_pollen")
#' @examples pollen_calendar(munich_pollen, method = "heatplot", interplation = FALSE)
#' @importFrom dplyr ungroup group_by mutate summarise_all
#' @importFrom circular circular mean.circular
#' @importFrom ggplot2 aes coord_flip element_text geom_tile geom_violin ggplot labs scale_fill_manual scale_x_continuous scale_x_date scale_y_date theme theme_bw theme_dark
#' @importFrom graphics abline barplot legend lines mtext par plot
#' @importFrom grDevices colorRampPalette dev.off pdf png recordPlot
#' @importFrom lubridate is.POSIXt
#' @importFrom scales date_format
#' @importFrom stats na.omit
#' @importFrom tidyr gather %>%
#' @export
pollen_calendar <- function (data,
          method = "heatplot", # "phenological" "violinplot" "heatplot"
          n.types = 15,
          start.month = 1,
          y.start = NULL,
          y.end = NULL,
          perc1 = 80,
          perc2 = 99,
          th.pollen = 1,
          average.method = "avg_before", # "avg_before" "avg_after"
          period = "daily", # "daily"  "weekly
          method.classes = "exponential", # "custom" "exponential"
          n.classes = 5,
          classes = c(25,50,100,300),
          color = "green", # "red" "green" "blue" "purple" "black"
          interpolation = TRUE,
          int.method = "lineal",
          na.remove = TRUE,
          result = "plot",
          export.plot = FALSE,
          export.format = "pdf",
          legendname = "Pollen grains / m3",...){
  
  base_dir <- if (nzchar(Sys.getenv("_R_CHECK_PACKAGE_NAME_"))) tempdir() else "."
  plot_dir <- file.path(base_dir, "plot_AeRobiology")
  
#############################################    CHECK THE ARGUMENTS       #############################

if(export.plot == TRUE){ifelse(!dir.exists(file.path("plot_AeRobiology")),dir.create(plot_dir, recursive = TRUE, showWarnings = FALSE), FALSE)}
  data<-data.frame(data)
if(!is.data.frame(data)) stop ("Please include a data.frame: first column with date, and the rest with pollen types")

if(method != "phenological" & method != "violinplot" & method != "heatplot") stop ("Please 'method' argument only accept values: 'phenological', 'violinplot' or 'heatplot'")

if(!is.numeric(n.types)) stop ("Please include only numeric values for 'n.types' argument indicating the number of pollen types which will be displayed")

if(!is.numeric(start.month) | ((start.month %in% c(1,2,3,4,5,6,7,8,9,10,11,12)) == FALSE)) stop ("Please include only numeric integer values between 1-12 for 'start.month' argument indicating the start month for the pollen calendar")

if(average.method == "avg_after" & start.month != 1) stop ("'avg_after' only can be calculate when 'start.month' argument is equal to 1")

if(!is.numeric(y.start) & !is.null(y.start)) stop ("Please include only numeric values for y.start argument indicating the start year considered")

if(!is.numeric(y.end) & !is.null(y.end)) stop ("Please include only numeric values for 'y.end' argument indicating the end year considered")

if(!is.numeric(perc1) | perc1 < 0 | perc1 > 100) stop ("Please include only numeric values between 0-100 for 'perc1' argument")

if(!is.numeric(perc2) | perc2 < 0 | perc2 > 100) stop ("Please include only numeric values between 0-100 for 'perc2' argument")

if(perc1 > perc2) stop ("Please should be perc 1 < perc2")

if(!is.numeric(th.pollen)) stop ("Please include only numeric values for 'th.pollen' argument indicating the minimum averaged pollen concentration to be considered")

if(average.method != "avg_before" & average.method != "avg_after") stop ("Please average.method only accept values: 'avg_before' or 'avg_after'")

if(period != "daily" & period != "weekly") stop ("Please period only accept values: 'daily' or 'weekly'")

if(method.classes != "custom" & method.classes != "exponential") stop ("Please method.classes only accept values: 'custom' or 'exponential'")

if(!is.numeric(n.classes)) stop ("Please include only numeric values for n.classes argument indicating the number of classes which will be used for the plots")

if(!is.numeric(classes)) stop ("Please include only numeric values for classes argument indicating the thresholds used for classifying the average pollen concentration for the plots")

if ((length(classes) + 1) != n.classes) stop ("The number of specified classes must be equal to 'n.classes - 1' because of the maximum threshold will be automatically specified by the maximum value")

if(color != "red" & color != "blue" & color != "green" & color != "purple" & color != "black") stop ("Please 'color' argument only accept values: 'red', 'blue', 'green', 'purple' or 'black'")

if(!is.logical(interpolation)) stop ("Please include only logical values for interpolation argument")

if(int.method != "lineal" & int.method != "movingmean" & int.method != "spline" & int.method != "tseries") stop ("Please int.method only accept values: 'lineal', 'movingmean', 'spline' or 'tseries'")

if(result != "plot" & result != "table") stop ("Please result only accept values: 'plot' or 'table'")

if(!is.logical(export.plot)) stop ("Please include only logical values for export.plot argument")

  if(class(data[,1])[1]!="Date" & !is.POSIXt(data[,1])) {stop("Please the first column of your data must be the date in 'Date' format")}
  data[,1]<-as.Date(data[,1])

if(ncol(data) - 1 == 1) stop ("The number of pollen types must be 2 at least")

if(ncol(data)-1 < n.types) {
  n.types = ncol(data)-1
  warning(paste("WARNING: the number of columns is smaller than 'n.types' argument. 'n.types' adjusted to", n.types))}

#############################################    MANAGEMENT OF THE DATABASE       #############################
  average_values<-data.frame()
perc1 <- 100 - perc1; perc2 <- 100 - perc2

if(interpolation == TRUE){data <- interpollen(data, method = int.method, plot = F)}

jd.month <- c(1, 32, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335)

seasons <- unique(as.numeric(strftime(data[, 1], "%Y")))
if(is.null(y.start)){y.start <- min(seasons)}; if(is.null(y.end)){y.end <- max(seasons)}

data <- data[which(as.numeric(strftime(data[ ,1], "%Y")) >= y.start & as.numeric(strftime(data[ ,1], "%Y")) <= y.end), ]
data <- data.frame(date = data[ ,1], year = as.numeric(strftime(data[ ,1], "%Y")), jd = as.numeric(strftime(data[ ,1], "%j")), week = as.numeric(strftime(data[ ,1], "%W")), data[ ,-1])

#types <- ddply(data[ ,-c(1,3,4)], "year", function(x) colSums(x[-1], na.rm = T)) [-1] %>%
#  apply(., 2, function(x) mean(x, na.rm = T)) %>% .[order(., decreasing = TRUE)] %>%
#  names(.) %>%
#  .[1:n.types]
types <- data.frame(data[ ,-c(1,3,4)] %>%
  group_by(year) %>%
  summarise_all(sum, na.rm = TRUE))[-1] %>%
  apply(., 2, function(x) mean(x, na.rm = T)) %>% .[order(., decreasing = TRUE)] %>%
  names(.) %>%
  .[1:n.types]

#############################################    ORDER      ######################################################

  data.or <- data[ ,which(colnames(data) %in% c("jd", types))]

  #data.or <- ddply(data.or, "jd", function(x) colMeans(x[-1], na.rm = T)) %>%
  #.[ ,colnames(.) %in% c("jd", types)]
  data.or <- data.frame(data.or %>%
    group_by(jd) %>%
    summarise_all(mean, na.rm = T))

  data.or <- data.or[which(data.or$jd != 366), ]

  data.or[is.na(data.or)] <- NA #data <- data[-nrow(data), ]

  pc.df1 <- data.frame(type = NA, start = NA, end = NA)
  pc.df2 <- data.frame(type = NA, start = NA, end = NA)
  pc.df3 <- data.frame(type = NA, start = NA, end = NA)

  for (t in 1:length(types)){

    pollen.s <- na.omit(data.or[ ,which(colnames(data.or) %in% c("jd",types[t]))]) # Pollen data without NAs

    pollen.s$acum1 <- NA
    for (i in 1:nrow(pollen.s)) {
      if (i == 1) {
        pollen.s$acum1[i] = pollen.s[i, types[t]]
      }  else {
        pollen.s$acum1[i] = pollen.s[i, types[t]] + pollen.s$acum1[i-1]
      }
    }

    pollen.s$acum2 <- NA
    for (i in nrow(pollen.s):1) {
      if (i == nrow(pollen.s)) {
        pollen.s$acum2[i] = pollen.s[i, types[t]]
      }  else {
        pollen.s$acum2[i] = pollen.s[i, types[t]] + pollen.s$acum2[i+1]
      }
    }

    lim1 <- sum(pollen.s[types[t]])/100*(perc1/2)
    lim2 <- sum(pollen.s[types[t]])/100*(perc2/2)

    pc.df1[t,"type"] <- types[t]
    pc.df1[t,"start"] <- pollen.s$jd[which(pollen.s$acum1 >= lim1)][1]
    pc.df1[t,"end"] <- pollen.s$jd[which(pollen.s$acum2 < lim1)][1] - 1; pc.df1[t,"end"] <- pc.df1[t,"end"] - pc.df1[t,"start"] + 1

    pc.df2[t,"type"] <- types[t]
    pc.df2[t,"start"] <- pollen.s$jd[which(pollen.s$acum1 >= lim2)][1]
    pc.df2[t,"end"] <- pollen.s$jd[which(pollen.s$acum2 < lim2)][1] - 1; pc.df2[t,"end"] <- pc.df2[t,"end"] - pc.df2[t,"start"] + 1

    pc.df3[t,"type"] <- types[t]
    pc.df3[t,"start"] <- pollen.s$jd[which(pollen.s[ ,types[t]] >= th.pollen)][1]
    pc.df3[t,"end"] <- pollen.s$jd[which(pollen.s[ ,types[t]] >= th.pollen)][length(pollen.s$jd[which(pollen.s[ ,types[t]] >= th.pollen)])]; pc.df3[t,"end"] <- pc.df3[t,"end"] - pc.df3[t,"start"] + 1
  }

type.or <- pc.df2$type[order(pc.df2$start, decreasing = T)]

#############################################    METHODS OF CALENDAR      ###########################

if (method == "phenological" & average.method == "avg_before"){

  data <- data[ ,which(colnames(data) %in% c("jd", types))]

  #data <- ddply(data, "jd", function(x) colMeans(x[-1], na.rm = T)) %>%
  #  .[ ,colnames(.) %in% c("jd", types)]
  data <- data.frame(data %>%
        group_by(jd) %>%
          summarise_all(mean, na.rm = T))

  data <- data[which(data$jd != 366), ]

  if(start.month != 1){data <- rbind(data[which(data$jd == jd.month[start.month]):nrow(data), ], data[1:(which(data$jd == jd.month[start.month])-1), ])}

  data$jd1 <- 1:nrow(data)

  data[is.na(data)] <- NA #data <- data[-nrow(data), ]

  pc.df1 <- data.frame(type = NA, start = NA, end = NA)
  pc.df2 <- data.frame(type = NA, start = NA, end = NA)
  pc.df3 <- data.frame(type = NA, start = NA, end = NA)

  for (t in 1:length(types)){

  pollen.s <- na.omit(data[ ,which(colnames(data) %in% c("jd1",types[t]))]) # Pollen data without NAs

  pollen.s$acum1 <- NA
  for (i in 1:nrow(pollen.s)) {
    if (i == 1) {
      pollen.s$acum1[i] = pollen.s[i, types[t]]
    }  else {
      pollen.s$acum1[i] = pollen.s[i, types[t]] + pollen.s$acum1[i-1]
    }
  }

  pollen.s$acum2 <- NA
  for (i in nrow(pollen.s):1) {
    if (i == nrow(pollen.s)) {
      pollen.s$acum2[i] = pollen.s[i, types[t]]
    }  else {
      pollen.s$acum2[i] = pollen.s[i, types[t]] + pollen.s$acum2[i+1]
    }
  }

  lim1 <- sum(pollen.s[types[t]])/100*(perc1/2)
  lim2 <- sum(pollen.s[types[t]])/100*(perc2/2)


  pc.df1[t,"type"] <- types[t]
  pc.df1[t,"start"] <- pollen.s$jd1[which(pollen.s$acum1 >= lim1)][1]
  pc.df1[t,"end"] <- pollen.s$jd1[which(pollen.s$acum2 < lim1)][1] - 1; pc.df1[t,"end"] <- pc.df1[t,"end"] - pc.df1[t,"start"] + 1

  pc.df2[t,"type"] <- types[t]
  pc.df2[t,"start"] <- pollen.s$jd1[which(pollen.s$acum1 >= lim2)][1]
  pc.df2[t,"end"] <- pollen.s$jd1[which(pollen.s$acum2 < lim2)][1] - 1; pc.df2[t,"end"] <- pc.df2[t,"end"] - pc.df2[t,"start"] + 1

  pc.df3[t,"type"] <- types[t]
  pc.df3[t,"start"] <- pollen.s$jd1[which(pollen.s[ ,types[t]] >= th.pollen)][1]
  pc.df3[t,"end"] <- pollen.s$jd1[which(pollen.s[ ,types[t]] >= th.pollen)][length(pollen.s$jd[which(pollen.s[ ,types[t]] >= th.pollen)])]; pc.df3[t,"end"] <- pc.df3[t,"end"] - pc.df3[t,"start"] + 1
  }
}

######################################################################################################

if (method == "phenological" & average.method == "avg_after"){
  data <- data[ ,which(colnames(data) %in% c("date", types))]

  pc.df1 <- data.frame(type = NA, start = NA, end = NA)
  pc.df2 <- data.frame(type = NA, start = NA, end = NA)
  pc.df3 <- data.frame(type = NA, start = NA, end = NA)

  pollen.ps1 <- calculate_ps(data = data, method = "percentage", perc = (100 - perc1), plot = F, export.result = F, interpolation = F)
  pollen.ps2 <- calculate_ps(data = data, method = "percentage", perc = (100 - perc2), plot = F, export.result = F, interpolation = F)


  list.results <- list()

  for (t in 1:length(types)){

    seasons <- unique(as.numeric(strftime(data[, 1], "%Y")))

    st.ps <-NA; mx.ps <- NA; en.ps <- NA

    result.ps <- data.frame(seasons, st.jd = NA, en.jd = NA)

    for (j in 1:length(seasons)) {
      tryCatch({
      ye <- seasons[j]

      pollen.s <- na.omit(data[which(as.numeric(strftime(data[, 1], "%Y"))==ye), which(colnames(data) %in% c("date",types[t]))]) # Pollen data without NAs
      pollen.s$jdays <- as.numeric(strftime(pollen.s[, 1], "%j"))

      st.ps <- pollen.s$jdays[which(pollen.s[ ,types[t]] > 0)][1]
      en.ps <- pollen.s$jdays[which(pollen.s[ ,types[t]] > 0)][length(pollen.s$jdays[which(pollen.s[ ,types[t]] > 0)])]

      result.ps[j,"st.jd"] <- pollen.s$jdays[pollen.s$jdays == st.ps] # Start-date of PS (JD)
      result.ps[j,"en.jd"] <- pollen.s$jdays[pollen.s$jdays == en.ps] # End-date of PS (JD)

      print(paste(ye, types[t]))
      }, error = function(e){
        print(paste("Year", ye, types[t], ". Try to check the aerobiological data for this year"))})

    }
    list.results[[types[t]]] <- result.ps

  }

  nam.list <- names(list.results)
  for(l in 1:length(nam.list)){
    if(l == 1) {df.results <- data.frame(type = nam.list[l], list.results[[l]])
    } else {
      df.results <- rbind(df.results, data.frame(type = nam.list[l], list.results[[l]]))
    }
  }
  pollen.ps3 <- df.results

  for (t in 1:length(types)){
    tryCatch({
      pc.df1[t,"type"] <- types[t]
      st <- na.omit(pollen.ps1$st.jd[pollen.ps1$type == types[t]]) * 360 / 365
      pc.df1[t,"start"] <- round((as.numeric(mean.circular(circular(st, units = "degrees")))) * 365 / 360); if(pc.df1[t,"start"] <= 0) {pc.df1[t,"start"] <- pc.df1[t,"start"] + 365}
      en <- na.omit(pollen.ps1$en.jd[pollen.ps1$type == types[t]]) * 360 / 365
      pc.df1[t,"end"] <- round((as.numeric(mean.circular(circular(en, units = "degrees")))) * 365 / 360); if(pc.df1[t,"end"] <= 0) {pc.df1[t,"end"] <- pc.df1[t,"end"] + 365}; pc.df1[t,"end"] <- pc.df1[t,"end"] - pc.df1[t,"start"] + 1

      pc.df2[t,"type"] <- types[t]
      st <- na.omit(pollen.ps2$st.jd[pollen.ps2$type == types[t]]) * 360 / 365
      pc.df2[t,"start"] <- round((as.numeric(mean.circular(circular(st, units = "degrees")))) * 365 / 360); if(pc.df2[t,"start"] <= 0) {pc.df2[t,"start"] <- pc.df2[t,"start"] + 365}
      en <- na.omit(pollen.ps2$en.jd[pollen.ps2$type == types[t]]) * 360 / 365
      pc.df2[t,"end"] <- round((as.numeric(mean.circular(circular(en, units = "degrees")))) * 365 / 360); if(pc.df2[t,"end"] <= 0) {pc.df2[t,"end"] <- pc.df2[t,"end"] + 365}; pc.df2[t,"end"] <- pc.df2[t,"end"] - pc.df2[t,"start"] + 1

      pc.df3[t,"type"] <- types[t]
      st <- na.omit(pollen.ps3$st.jd[pollen.ps3$type == types[t]]) * 360 / 365
      pc.df3[t,"start"] <- round((as.numeric(mean.circular(circular(st, units = "degrees")))) * 365 / 360); if(pc.df3[t,"start"] <= 0) {pc.df3[t,"start"] <- pc.df3[t,"start"] + 365}
      en <- na.omit(pollen.ps3$en.jd[pollen.ps3$type == types[t]]) * 360 / 365
      pc.df3[t,"end"] <- round((as.numeric(mean.circular(circular(en, units = "degrees")))) * 365 / 360); if(pc.df3[t,"end"] <= 0) {pc.df3[t,"end"] <- pc.df3[t,"end"] + 365}; pc.df3[t,"end"] <- pc.df3[t,"end"] - pc.df3[t,"start"] + 1
    }, error = function(e){})
  }

}

######################################################################################################

if (method == "violinplot" | (method == "heatplot" & period == "daily")){

  data <- data[ ,which(colnames(data) %in% c("jd", types))]

  #data <- ddply(data, "jd", function(x) colMeans(x[-1], na.rm = T)) %>%
  #  .[ ,colnames(.) %in% c("jd", types)]
  data <- data.frame(data %>%
                       group_by(jd) %>%
                       summarise_all(mean, na.rm = T))

  data <- data[which(data$jd != 366), ]

  if(start.month != 1){data <- rbind(data[which(data$jd == jd.month[start.month]):nrow(data), ], data[1:(which(data$jd == jd.month[start.month])-1), ])}

  if(start.month != 1){data$jd <- seq(as.Date(strptime(paste0(as.character(data$jd),"-2017"), format = "%j-%Y"))[1], as.Date(strptime(paste0(as.character(data$jd),"-2018"), format = "%j-%Y"))[nrow(data)], by = "days")
  } else {
    data$jd <- seq(as.Date(strptime(paste0(as.character(data$jd),"-2017"), format = "%j-%Y"))[1], as.Date(strptime(paste0(as.character(data$jd),"-2017"), format = "%j-%Y"))[nrow(data)], by = "days")
  }

  #violin_data <- gather(data, key = variable, value = value, -jd, na.rm = TRUE)
  violin_data <- gather(data, key = variable, value = value, -jd)
  violin_data$value[violin_data$value < th.pollen] <- NA

  #if (method == "heatplot" & period == "daily"){violin_data <- na.omit(violin_data)}

  # create a weight variable for each variable.  dplyr will make this easy.
  violin_data <-
    violin_data %>%
    group_by(value) %>%
    mutate(wt = value / max(colSums(data[,-1], na.rm = TRUE))) %>%
    ungroup()

  data[ ,1] <- as.numeric(strftime(data[ ,1], "%j"))
}

######################################################################################################

if (method == "heatplot" & period == "weekly"){
  #data <- ddply(data[ ,-c(1:3)], "week", function(x) colMeans(x[-1], na.rm = TRUE)) %>%
  #  .[ ,colnames(.) %in% c("week", types)]
  data <- data.frame(data[ ,-c(1:3)] %>%
                          group_by(week) %>%
                          summarise_all(mean, na.rm = T)) %>%
    .[ ,colnames(.) %in% c("week", types)]

  heat.data <- gather(data, key = variable, value = value, -week)
  heat.data$value[heat.data$value < th.pollen] <- NA
  heat.data <- na.omit(heat.data)

  heat.data$variable <- factor(heat.data$variable, levels = as.character(pc.df2$type), ordered = TRUE)

}


#################################################################   PLOTS   ##########################


if (method == "phenological"){
  #ORDER

  pc.df3$type <- factor(pc.df3$type, levels = as.character(type.or), ordered = T); pc.df3 <- pc.df3[order(pc.df3$type), ]
  pc.df2$type <- factor(pc.df2$type, levels = as.character(type.or), ordered = T); pc.df2 <- pc.df2[order(pc.df2$type), ]
  pc.df1$type <- factor(pc.df1$type, levels = as.character(type.or), ordered = T); pc.df1 <- pc.df1[order(pc.df1$type), ]

  pc.df1 <- pc.df1[which(pc.df1$type %in% pc.df2$type & pc.df1$type %in% pc.df3$type), ]
  pc.df2 <- pc.df2[which(pc.df2$type %in% pc.df1$type & pc.df2$type %in% pc.df3$type), ]
  pc.df3 <- pc.df3[which(pc.df3$type %in% pc.df1$type & pc.df3$type %in% pc.df2$type), ]


  #PLOT

  par(mar = c(5,7,3,1), xpd = F)

  barplot(`colnames<-`(t(pc.df3[-1]), pc.df3[,1]), width = 1, space = 0, horiz = T, col=c("transparent","yellow"), border = NA, las = 2, xlim = c(1, 365), axes = F, main = paste0("Pollen calendar (Period ",y.start,"-",y.end, ")"), cex.main = 1.8, font.axis = 3)
  barplot(`colnames<-`(t(pc.df2[-1]), pc.df2[,1]), width = 1, space = 0, horiz = T, col=c("transparent","orange"), border = NA, add = T, las = 2, axes = F, font.axis = 3)
  barplot(`colnames<-`(t(pc.df1[-1]), pc.df1[,1]), width = 1, space = 0, horiz = T, col=c("transparent","red"), border = NA, add = T, las = 2, axes = F, font.axis = 3)

  abline (h=0:n.types, lwd = 1, col = "gray")

  lines(x = c(1,1) , y = c(0,nrow(pc.df1)), lwd = 3, col = 1); lines(x = c(365,365) , y = c(0,nrow(pc.df1)), lwd = 3, col = 1)
  lines(x = c(1,365) , y = c(0,0), lwd = 2, col = 1); lines(x = c(1,365) , y = c(nrow(pc.df1),nrow(pc.df1)), lwd = 2, col = 1)

  nam.mo <- c("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec")
  len.mo <- c(31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31)

  if(start.month == 1){
    for(m in c(start.month:12,1:(start.month-1))){
      if(m <= 11) {lines(x = c(sum(len.mo[1:m]),sum(len.mo[1:m])) , y = c(-1,n.types), lwd = 1, col = "gray", lty = 2)}
      if(m <= 11) {lines(x = c(sum(len.mo[1:m]),sum(len.mo[1:m])) , y = c(-1,0), lwd = 2, col = "black", lty = 1)}
      if(m == 1) {mtext (side = 1, adj = 0.028, text = nam.mo[m], cex = 1.2)}
      if(m > 1) {mtext (side = 1, adj = 0.028 + (0.086*(m-1)), text = nam.mo[m], cex = 1.2)}
    }
  } else {
    cont <- as.numeric()
    for(m in c(start.month:12,1:(start.month-1))){
      cont <-c(cont, m)
      if(length(cont) <= 11) {lines(x = c(sum(len.mo[cont]),sum(len.mo[cont])) , y = c(-1,n.types), lwd = 1, col = "gray", lty = 2)}
      if(length(cont) <= 11) {lines(x = c(sum(len.mo[cont]),sum(len.mo[cont])) , y = c(-1,0), lwd = 2, col = "black", lty = 1)}
      if(length(cont) == 1) {mtext (side = 1, adj = 0.028, text = nam.mo[m], cex = 1.2)}
      if(length(cont) > 1) {mtext (side = 1, adj = 0.028 + (0.086*(length(cont)-1)), text = nam.mo[m], cex = 1.2)}
    }
  }


  # legend("bottomleft", legend = c("Main pollination period", "Early/late pollination", "Possible occurrence"), col = c("red", "orange", "yellow"), pch = 15, bty = "n", cex = 1, x.intersp = 0.6, y.intersp = 0.5, inset = c(0.55,-0.2), xpd = TRUE)

plot.calendar <- recordPlot()

}

######################################################################################################

if (method == "violinplot"){

violin_data$variable <- factor(violin_data$variable, levels = as.character(type.or), ordered = T)

violin_data <- data.frame(violin_data)

if (na.remove == TRUE) {violin_data <- na.omit(violin_data)}

plot.calendar <- ggplot(violin_data) +
    aes(x = variable, y = jd, weight = wt) +
    geom_violin(fill = "yellow", colour = "yellow", size = 1)+
    coord_flip()+
    theme_dark()+
    labs(y = "", x = "", title = paste0("Pollen calendar (Period ",y.start,"-",y.end,")"))+
    scale_y_date(limits = c(min(violin_data[ ,1])[1], max(violin_data[ ,1])[1]), breaks = "1 month", labels = date_format("%b"))+
    theme(axis.text.y = element_text(size = 12, face = "bold.italic"), axis.text.x = element_text(size = 14, face = "bold"), title = element_text(size = 14, face = "bold"))
}

######################################################################################################

if (method == "heatplot" & period == "daily"){

violin_data$variable <- factor(violin_data$variable, levels = as.character(type.or), ordered = T)

if (color == "red") {colmin = "#fc9272"; colmax = "#67000d"}
if (color == "green") {colmin = "#c7e9c0"; colmax = "#00441b"}
if (color == "black") {colmin = "#d9d9d9"; colmax = "#000000"}
if (color == "blue") {colmin = "#d0d1e6"; colmax = "#023858"}
if (color == "purple") {colmin = "#dadaeb"; colmax = "#3f007d"}

if(method.classes == "custom"){
  classes = c(0, classes, max(violin_data$value, na.rm = TRUE)+100)
  lab.classes <- as.character()
  for (l in 2:length(classes)){
    if(l == 2) {lab.classes <- c(paste0("<",classes[l]))}
    if(l != 2 & l != length(classes)) {lab.classes <- c(lab.classes, paste0(classes[l-1],"-",classes[l]))}
    if(l == length(classes)) {lab.classes <- c(lab.classes, paste0(">",classes[l-1]))}
  }
}

if(method.classes == "exponential"){
  if (max(violin_data$value, na.rm = TRUE) > 1600 ) {n.classes = 11
  classes = c(0,2,5,11,24,49,99,199,399,799,1600,(max(violin_data$value, na.rm = TRUE)+100))
  lab.classes = c("1-2","3-5","6-11","12-24","25-49", "50-99", "100-199", "200-399", "400-799", "800-1600", ">1600")}

  if (max(violin_data$value, na.rm = TRUE) <= 1600 ) {n.classes = 10
  classes = c(0,2,5,11,24,49,99,199,399,799,1600)
  lab.classes = c("1-2","3-5","6-11","12-24","25-49", "50-99", "100-199", "200-399", "400-799", "800-1600")}

}

#violin_data <- data.frame(violin_data)
if (na.remove == TRUE) {violin_data <- na.omit(violin_data)}

plot.calendar <- ggplot(violin_data, aes(jd, variable)) +
    geom_tile(aes(fill = cut(value, breaks = classes, labels = lab.classes)))+
    scale_fill_manual(drop=FALSE, values=colorRampPalette(c(colmin, colmax))(n.classes), name = legendname, na.translate = F)+
    theme_bw()+
    labs(y = "", x = "", title = paste0("Pollen calendar (Period ",y.start,"-",y.end,")"))+
    #scale_x_date(limits = c(min(violin_data[ ,1], na.rm = T)[1], max(violin_data[ ,1], na.rm = T)[1]), breaks = "1 month", labels = date_format("%b"))+
    scale_x_date(breaks = "1 month", labels = date_format("%b"))+
    theme(axis.text.y = element_text(size = 12, face = "bold.italic"), axis.text.x = element_text(size = 14, face = "bold"), title = element_text(size = 14, face = "bold"))

}

######################################################################################################

if (method == "heatplot" & period == "weekly"){

heat.data$variable <- factor(heat.data$variable, levels = as.character(type.or), ordered = T)

if (color == "red") {colmin = "#fc9272"; colmax = "#67000d"}
if (color == "green") {colmin = "#c7e9c0"; colmax = "#00441b"}
if (color == "black") {colmin = "#d9d9d9"; colmax = "#000000"}
if (color == "blue") {colmin = "#d0d1e6"; colmax = "#023858"}
if (color == "purple") {colmin = "#dadaeb"; colmax = "#3f007d"}

if(method.classes == "custom"){
  classes = c(0, classes, max(heat.data$value, na.rm = TRUE)+100)
  lab.classes <- as.character()
  for (l in 2:length(classes)){
    if(l == 2) {lab.classes <- c(paste0("<",classes[l]))}
    if(l != 2 & l != length(classes)) {lab.classes <- c(lab.classes, paste0(classes[l-1],"-",classes[l]))}
    if(l == length(classes)) {lab.classes <- c(lab.classes, paste0(">",classes[l-1]))}
  }
}

if(method.classes == "exponential"){
  if (max(heat.data$value, na.rm = TRUE) > 1600 ) {n.classes = 11
  classes = c(0,2,5,11,24,49,99,199,399,799,1600,(max(heat.data$value, na.rm = TRUE)+100))
  lab.classes = c("1-2","3-5","6-11","12-24","25-49", "50-99", "100-199", "200-399", "400-799", "800-1600", ">1600")}

  if (max(heat.data$value, na.rm = TRUE) <= 1600 ) {n.classes = 10
  classes = c(0,2,5,11,24,49,99,199,399,799,1600)
  lab.classes = c("1-2","3-5","6-11","12-24","25-49", "50-99", "100-199", "200-399", "400-799", "800-1600")}

}

if (na.remove == TRUE) {heat.data <- na.omit(heat.data)}

plot.calendar <- ggplot(heat.data, aes(week, variable)) +
    geom_tile(aes(fill = cut(value, breaks = classes, labels = lab.classes)), colour = "white")+
    scale_fill_manual(drop=FALSE, values=colorRampPalette(c(colmin, colmax))(n.classes), name = legendname)+
    theme_bw()+
    labs(y = "", x = "Week of the year", title = paste0("Pollen calendar (Period ",y.start,"-",y.end,")"))+
    scale_x_continuous(breaks = seq(0,50,5), limits = c(0,53))+
    theme(axis.text.y = element_text(size = 12, face = "bold.italic"), axis.text.x = element_text(size = 14), axis.title.x = element_text(size = 16, face = "bold"), title = element_text(size = 14, face = "bold"))
}

#############################################    EXPORT RESULTS       #############################

if(export.plot == TRUE & export.format == "pdf") {
  pdf(file.path(plot_dir, paste0("pollen_calendar_", method, ".pdf")), ...)
    if(method == "phenological"){print(plot.calendar)
      } else {
        plot(plot.calendar)
      }

  dev.off()}

if(export.plot == TRUE & export.format == "png") {
  png(file.path(plot_dir, paste0("pollen_calendar_", method, ".png")), ...)
  if(method == "phenological"){print(plot.calendar)
  } else {
    plot(plot.calendar)
  }
  dev.off()
  png(file.path(plot_dir, "credits.png"))

  dev.off()
  }

if (result == "plot") return(plot.calendar)
if (result == "table") {return(data)}

}

#' A view of the creators
#'
#' Credits
#'
#' @export
credits <- function() {
  print("")
  print("                     .vu5SdXUi                                                                      ")
  print("                   JBQgBBBBBQBQB:           .ZI       :7            UD.                             ")
  print("      BBBi       .QQvQB57.   .7SBB          IQB       BQB           BQu                             ")
  print("     uQBBB       gb BI  MZdBBMP5 Bg         7BB       rI.           QBr                             ")
  print("     QBYQB:    iER5QI  iBIBLsqbBE B rZBQQr  rQQ:DQg.  LI:  .PQBQK   BQr  .EQBQ5   .IBQqSdvMP   uB1  ")
  print("    rBE 5Bd   KBQBbRq  rQgM  iPgQ IEZL:i2Bs iBZBPBBB  QBj :BdLrsQB  RBi rBXvrUBB .BB71BBKiBBi  BQY  ")
  print("    dBi .gB. .BE:dXUB. :BugMEggQ :DI .:: 7B :MQ   gQ7 EQ7 R7 .. .Qi DQ: Q: .: :B.:BX  bB  KQZ rBQ   ")
  print("   :dP7rrKb5 rdKJUIDDM.ig1gjqBQ.s7i7.v7Yi.Q .Dd   XgL 5Rr P ivrs.Sv KR: S r77v gi XdLsDE  .gE:sQ7   ")
  print("   1PI2XIUId .bK.  :MQBQPXBiBRdB. i5.:7i.rQ :SP   SEr 5b7 E:.r7:.E: KEi Z.:77..g..X1r7:    UKI1Z    ")
  print("  :qD:    XKJ 2Ks:..Y.:qQDQ2:PQBQ  bji::rRi iqbqi7IM  2dL rdii:iUE  IZr LPii:iXK iULrr:r.  .IvUu    ")
  print("  r1J     7sU  ijU5u7  :BQK   BgBv  7j1Ju.  :u7:Iuj   L1i  :uYuu7   JU:  :uY1Jr  .vu::jJE   vrq     ")
  print("                                                                                 j7i  .7K   :7J     ")
  print("                                                                                 :ririrr   :7Y.     ")
  print("")
  print("")
  print("")
  print("The creators:")
  print("")
  print(":.:::::.:::::.:::::...............:.:...::i:iiiiiii:iiiiiiri")
  print(".:.:.:::.:.:.:.:....::..:iiPXKL1KMRRDg5v::.::i:i:iii:iiiiiii")
  print(":.:.:.:.:.:.:....isXMQRPBBBBBQBQBQBQBQBQQqr::.::iiiii:iii:ii")
  print("...:.:.:.:...:.ijXdQgRRQgQMQgQQQgQRQMQggRBQBqr.::i:iii:i:i:i")
  print(".............:rUX5PKPPqUK5qgQbbdRDRZZEQggPQBBBP:..i:i:iii:i:")
  print("........... .uEgbE5Sj7i7jSgRPdKK5KIjYu7JKPbQgQBB2i.::i:i:i:i")
  print(".......... .EMgbbIX1LrL5MgqjU77vuiirriivbZggDDQMBQj..:i:i:i:")
  print(".........  EQgdPKPS22EMMX7i7irir:7vsJKPRgEqdKPgRgBQQi.:i:i:i")
  print(". . . . . iQgEdPPJu5KLr.  .......::.::i:rr7712qgQgQBg.::i:i:")
  print(" . . . .  2QPPXRJi:.           . . .   ....ir12PMQMBB5.:::::")
  print(".......  .BDD2MM:     ....:..............:::r712ZMRMBs..::::")
  print(" . . .  .RRMdZQr .i72gMBQBQgUjY7i::::J2bKgEESUL1bBgRBi :::::")
  print("        LBRMQg7 :YUvL777XdEXPUYi.:rLdDQMQMQMBQgSgQggB:..:.::")
  print("        bBDBQ7 ..:rsssdBRPEDSY:  .1QMMDRDEXK5qPEqQgQBi :.:::")
  print("  .   .ZBQBQJ     ..i:rLs7sr. .  .PBQMgPQBQZRdSU2gQRBPi:::::")
  print("      uBBPXb.        ....:.. ... .sD2vriiLjXEMKKjdQQgBQv:i:i")
  print("      72XivEi .             ...  .PKJ:::ii7vsLussSBQg5Lirir:")
  print("       i:.LZ7. ...         ....  :SdUi:::i:i::rJvqQBgv7777ri")
  print("        . ::u:. . .      ..       7SUri:::i:irYuuDQQX7Jvv77r")
  print("            7Y.  .   . :ii...    .iJ75Lrirr77J11PBEPrvvv7L77")
  print("          . rvi     . ...  :dPY:rLDggPviii77JuU2QPPsYvYLsvLr")
  print("           .7j::.... :irir71KggQQBQBBBDurrrssSUEgILJYjYJYjvv")
  print("            :qv::.::iugQMv72II2LsbQEDDQQBbIUKPdgP7vvuJjLJvsv")
  print("             rDr.i:r5QBqi::i:::i:YXDbEdggQEEdPbgsssuJ1sjLsvs")
  print("              jgr77:Kg7       ..::vJ5Xq5dEEPDEM1Jj2jUJuJuYJL")
  print("               Kg2YYIZ:. ..:YXXZdZ521ISEEgEMMgUU1Uj2j1suJ1LJ")
  print("              .rEMEKSIv7i...r7ssEPKIUYKEMgRMbJUUSUI1UJus1JjY")
  print("    .i72qgQBBB::7PgMZdXPLJY7rvY1ss55U5dMgggQ5ujI1UJUu1j2JUYJ")
  print(".1BBBQBBBQQqsi..i7dQBMMqqXXYIKRPq2PbZEQgQgQRBgqIKPbXIj2jUJ1s")
  print("RBQBRgi.      ....:YXMQQQRDgdMZgDZbgRQQQKZRQMQMQRBQBgqu21Uju")
  print("gBurL        .:.. ..:iJKgQBQBQBRQRQMQgZSSPQgRgRgQgQgQQdJ2U2u")
  print("Dgi2         ..:.....:.rvLvIKbqEdREZPPIKKggQgMgMgQgRgQRMddXX")
  print("MQXj         .....:.:...::iivY25qXq5K5PKEDMgRDMgRgRDQZUsuLsv")
  print(":7rvi.       ........:...::7J55S2KSKSqSPbMSOFIA_&_ABRILgPPI2")
  print("")
  print("---- Jesus Rojo ----")
  print("")
  print("")
  print("")
  print("iiiiiriririririririririi:i:i:i:r:i:ii7r7r77v7v7L7L7L7L7L7L7Y")
  print("iiiiriiiiiiiriririi:i:::7sU1X5qPKsv7iii:i:ir77v7v7v7Lvv7v7L7")
  print("i:i:i:i:i:i:i:...rqgBQBRQdEERMRgMgQQBBBQBQBg7:rr77v7v7v7L7v7")
  print(":i:i:i:i:i:i..iuMBBBdEKUsUuqSbPdqdPgDRgRRBBBRLrrrv7v7v7v7vvL")
  print("::::i:i::::.:SBQBgSvsLYYY7suS2UJj1XKDZRZDZBBBQBJii7rv7v7v7vr")
  print("::::::::::. 2BBBgL:i:i:7ri:..irv7LLJuPdBgddBBBQQviirr7r77vrr")
  print(":::::::::..:2BBEY::.:.:.. ....ii77LvJJXDQDbPQQBBBPr:rr7r7rrr")
  print("::.:::.:.:2XdBRr.:.:::.......::ir7rJsuj5DgDZdBBBQBQqiiirr7r7")
  print(":::.:...iXBBBQj...:::.:.......::i:ii77sY25DMZgBBBBBBRr7r7r7r")
  print(".:.:.:.:rgBBDgi..:.:....   . ..:.::i:rr7rvLPZQMBRBQBQYirr7rr")
  print(":.:....7PDBEdg7.... .       ......::iii:rr7JbgBQQQBBB1ri7r7r")
  print(".......1RRRDQB:. ....:.....::i:i:rvISEZDdPj1IPRBQBQBB1r7r7r7")
  print(".......:RBBMB5:rXPQBBQBgqvrirrYubQBQBBBQQQBQQPKQBQBQBs77v77r")
  print("....... rBQBQijE5IISXQQBQQvi:7uMQBMQQQqEqZdgZg2KBBBBgs7L7v77")
  print(".......  iMQR irXPjSRQMQBZU..:JRBQBQPdQQggBggdPugBBQXLJvL7vr")
  print("........  :BU .rs5iv5SYIYrr: .LBgbI27LIX5gQMX522KBBQUUJ1Ysvv")
  print("......... 2Q2 . .:Lsu1Ivi:i. .7PXUsv11XPZPXjY7JudQBgKUUj1YJ7")
  print("......... .BR........:...:::  iPU2vr:::::::irvLUEBQESXUUJjYs")
  print("... .....   S.... .     :.::  7XPSIi:...:::i77uIQQZXPXX12Jsv")
  print(" . .......  .r....     .::.: .isYIX2i:.::iir72KEMRPdPPSS1UsJ")
  print("........... .Lr::...::rri.    .:i7dP7rri77YY5PMDMKbPEqP5Ij1L")
  print(" . ........  KL7rr:::i:..7i. .:YqRQP777vLI5EdgDBDbPEbdKXU2Js")
  print(". . .......  JgL7vriri:.iIBQPPQBBBBDPUI12SbgQgQQDPEPEqP5511Y")
  print(" . . . .....  DZYLvLvs7vuS5gBBBBQBgDdMMDZQPZgQQRPEPdbdKKUIsj")
  print(". . . . . .   rBZ72XgbX2U2u7juSXgEgZRQBRBgPZBQQdZPEbEPq55uUY")
  print(" . . . . . .   sBP7uJriJUUsujS5PSbEQMMqPZZPQQBEZEZPEPPXX2UJJ")
  print(". . . . . . .   vQdvL...::i::iir7sIIKuUqgRBBBggEgEDbdXK22Jjv")
  print("   . . . . . .   :gQIv:::ii7rv7J1XXZX2qQQBQQggDgEgEDPPSSuUss")
  print("    . . . . . . .  EBbv::ruIPdDbgEDqPXMQBQQEggMDgZgEZqK2Ijuv")
  print("   . . . . . .     :QBdui::vJZDZKKUXPQQBQQDgERDMDgDgPbXSU2sJ")
  print("                 rQqrMBESsjvsIqU1IPPRQBQQDMbEQBggZgEZqq55u1L")
  print("            .7UPDBBv.iKBQMdPbZPPSgMRQBRQZggDKdBBQREDPdXXU2Jj")
  print("     .:rjSgMBBQEgRE..:ivSDQgBQBQQQBQQggDDZgdEPERBBBgESXIX1Us")
  print("rXERRBBBQBggZbKdPQP..::i:irs2qdgEgZgdEdDEgdDdDdEZBBBQgS2j1Ju")
  print("QgMZgdDdEPbPZPEPPgBi.:iiiirrYsX5EdDPdPZdgdDdDEZqXPBQBBBgPuY7")
  print("PdqZPEbbqPSZEgPdKZQD..irir71U5SPPEbdPdbZbDdEPZKXLdQQQBQBQBZX")
  print("bSPbDdPKbIbPgbPXbXQRP .irY2sISPXdPZPZZgdZbEPbSSLS8=DQMQgQMBQ")
  print("")
  print("---- Antonio Picornell ----")
  print("")
  print("")
  print("")
  print("777r7r7r7r77v777Y7IjU7r7BUirL5X1SPD1LiLuJ7L7v7v7Yvv7L7LvY7L7")
  print("r7r7r7r7r7r7r7r7v5PKPP5SEQUY21UUXDdBDgP5X2JLr77LvsvYvsvsvsvY")
  print("7r7r7r7r7r7rrir7SqKKDQBQBQBQBgQQBRQMQQDvIKPUjvY7LvsvsLsvsvYv")
  print("rrrrr7rri777YIs21EZRQQMBQBBBQBQBQBBBQBQQQgPDEgK5JvvsvYvsvYvY")
  print("rrrrrirrYLYuZ2PEDgBBBQBQBgMgRggRBQQBBBBQBbd1I5ZU2Y77LvL7v7v7")
  print("irrrrrirLYJIUPEBQBQZ2Yri....:::rrss5KZDBQBBBgDZguLrLvYvYvLvY")
  print("riririiiv7XI2RBBI:...   . . ..:.::::rr7ruPQQBBBQg7v7LvsvY7L7")
  print("iiii::7QQRgBBDi. . . . . ... ........::iirijDBBBQQL7rv7L7v7v")
  print("i:i:::MQQQBB7  .. .             ......::ii7r75BBBBQ7rr77v777")
  print(":i:i:rrqDBg: ...                 . ..::iirr77vuBQBQM7rr777r7")
  print("::::i:.SBQr ...                 .  .::iirr77LLsSBQBQPrrr7r7r")
  print("::::.::KQE ...                     ..::iirr77uu2DBQBQMLririr")
  print(":.:.:.:SBi ..                         ....:iY1IjgBBBBX7:riri")
  print("......:BQ. ..rIZPMgMP5vi..   .     ..:rJu1UXuU2UbBQBQD:iiiii")
  print("..... iQB. .Y2Yir7uXDQBQBEJiiir:vsdQBQBQBQBBBP5sZBBQBUi:iii:")
  print(".......KBi :rr:i:i:rYPqPKZXLi7L1ZQQBMgqUvJu5XDIjZBQBRJii:i:i")
  print(".....:LJB:..:iUPgqBQBQBQgDK...rZBBBQBQBMMgREEPXuRBBQDirii:i:")
  print(".... .7QQr . :iLL7YjLYjj:...  :EddED2XPQgQQQdSu5QBQdv7rririi")
  print(".....  JBi    ..irv77:.       .vr.::rjqPDggqYrLLBQUr7777vr7r")
  print(" . .    Pr                .   .sv:.    ..::::irvggvJL7rY7vrr")
  print("  . .   ::. .         :....   :72Jv:.   . ..:rsLDq1Ju7s7vrri")
  print("       .ii....   ..r5Q:       .:i.:RPv:i:iirrJUIZgU1J7r7r7ir")
  print("        r:.::...rUgQDr:2U.   .irJ5DDggPYL7Ju22S2D2IUuvLvvrri")
  print("        ri.7v7ruPQE5:.iqQBqIXZQBQBBQ2EgMPKIKPdqPZ52IYjsJvv77")
  print("        rr:7IrudQRgIjYvvXEBBBQBQBQBMgZQQBBRbdZddDUS1Usjvv77r")
  print("        .Si7IrsRBBBBQBKKXPXbgZEDPZgBQBQBBQPPdDKgPX5I1UYY7v77")
  print("         2U:LriJQqi.iSDu:.::irP2PgBBgKKMPrIbRZMZPSXUUJuLL77r")
  print("         .MKUUiLU:     .  ...7LJISuYr77PujPQQQMbXKIIuuLs7vr7")
  print("          :g51JJs.  . . ....:::i7L1sYsX2K5QMQRbXP551Ussvv77r")
  print("            KSJuv:   ::7JqqgZRKbKbUY72qddRQBgKIP55u1LYvv77rr")
  print("           vBZPXIv:     ::vs5Ljr7r:.rUgQBQRRBbX2S22JuLY7vrri")
  print("         .KBBruBQPjr..    .:.:.::i:iIgMBQRPBBQgP2Uj1YsvL77rr")
  print("        JgZgQ .7QQBDur7r::riir7r7sXPBQBRgbQQQgBQQIS21YY77rri")
  print("      .EZS2ZX ...LdBBRPqrjuv7Y1EZQBBBBZZZQBBgRgBQESqIS22JYrr")
  print("  ..i2RqIj1ZD .::.:7PMBQQMBQBQBQBQBgZPDgQQBMRgRgQgXIIuSuI25j")
  print("ii.7Kd22jusDQ....::ir7v5KbbgdgEZPPXPPDgQQBMgDMgMDQX1J2j1YuJu")
  print(":.rXS12uUJu5B:..::ii7r77sjIIS2qSqKPPgDQQBMDEMDMZggZvjsjLL7vv")
  print(".7K5juJ1JUJuM2.:::.:irrvLuuX2KIS5PqDZMARCOKdEgMArCOJvY7v7v7v")
  print("")
  print("---- Jose Oteros ----")
  print("")
  print("")
  print("                     .vu5SdXUi                                                                      ")
  print("                   JBQgBBBBBQBQB:           .ZI       :7            UD.                             ")
  print("      BBBi       .QQvQB57.   .7SBB          IQB       BQB           BQu                             ")
  print("     uQBBB       gb BI  MZdBBMP5 Bg         7BB       rI.           QBr                             ")
  print("     QBYQB:    iER5QI  iBIBLsqbBE B rZBQQr  rQQ:DQg.  LI:  .PQBQK   BQr  .EQBQ5   .IBQqSdvMP   uB1  ")
  print("    rBE 5Bd   KBQBbRq  rQgM  iPgQ IEZL:i2Bs iBZBPBBB  QBj :BdLrsQB  RBi rBXvrUBB .BB71BBKiBBi  BQY  ")
  print("    dBi .gB. .BE:dXUB. :BugMEggQ :DI .:: 7B :MQ   gQ7 EQ7 R7 .. .Qi DQ: Q: .: :B.:BX  bB  KQZ rBQ   ")
  print("   :dP7rrKb5 rdKJUIDDM.ig1gjqBQ.s7i7.v7Yi.Q .Dd   XgL 5Rr P ivrs.Sv KR: S r77v gi XdLsDE  .gE:sQ7   ")
  print("   1PI2XIUId .bK.  :MQBQPXBiBRdB. i5.:7i.rQ :SP   SEr 5b7 E:.r7:.E: KEi Z.:77..g..X1r7:    UKI1Z    ")
  print("  :qD:    XKJ 2Ks:..Y.:qQDQ2:PQBQ  bji::rRi iqbqi7IM  2dL rdii:iUE  IZr LPii:iXK iULrr:r.  .IvUu    ")
  print("  r1J     7sU  ijU5u7  :BQK   BgBv  7j1Ju.  :u7:Iuj   L1i  :uYuu7   JU:  :uY1Jr  .vu::jJE   vrq     ")
  print("                                                                                 j7i  .7K   :7J     ")
  print("                                                                                 :ririrr   :7Y.     ")
  print("")
  }

#' Estimation of the Main Parameters of the Pollen Season
#'
#' Function to calculate the main parameters of the pollen season with regard to phenology and pollen intensity from a historical database of several pollen types. The function can use the most common methods in the definition of the pollen season.
#'
#' @param data A \code{data.frame} object including the general database where calculation of the pollen season must be applied. This \code{data.frame} must include a first column in \code{Date} format and the rest of columns in \code{numeric} format belonging to each pollen type by column.
#' @param method A \code{character} string specifying the method applied to calculate the pollen season and the main parameters. The implemented methods that can be used are: \code{"percentage"}, \code{"logistic"}, \code{"moving"}, \code{"clinical"} or \code{"grains"}. A more detailed information about the different methods for defining the pollen season may be consulted in \strong{Details}.
#' @param th.day A \code{numeric} value. The number of days whose pollen concentration is bigger than this threshold is calculated for each year and pollen type. This value will be obtained in the results of the function. The \code{th.day} argument will be \code{100} by default.
#' @param perc A \code{numeric} value ranging \code{0_100}. This argument is valid only for \code{method = "percentage"}. This value represents the percentage of the total annual pollen included in the pollen season, removing \code{(100_perc)/2\%} of the total pollen before and after of the pollen season. The \code{perc} argument will be \code{95} by default.
#' @param def.season A \code{character} string specifying the method for selecting the best annual period to calculate the pollen season. The pollen seasons may occur within the natural year between two years. The implemented options that can be used are: \code{"natural"}, \code{"interannual"} or \code{"peak"}. The \code{def.season} argument will be \code{"natural"} by default. A more detailed information about the different methods for selecting the best annual period to calculate the pollen season may be consulted in \strong{Details}.
#' @param reduction A \code{logical} value. This argument is valid only for the \code{"logistic"} method. If \code{FALSE} the reduction of the pollen data is not applicable. If \code{TRUE} a reduction of the peaks above a certain level (\code{red.level} argument) will be carried out before the definition of the pollen season. The \code{reduction} argument will be \code{FALSE} by default. A more detailed information about the reduction process may be consulted in \strong{Details}.
#' @param red.level A \code{numeric} value ranging \code{0_1} specifying the percentile used as level to reduce the peaks of the pollen series before the definition of the pollen season. This argument is valid only for the \code{"logistic"} method. The \code{red.level} argument will be \code{0.90} by default, specifying the percentile 90.
#' @param derivative A \code{numeric} (\code{integer}) value belonging to options of \code{4}, \code{5} or \code{6} specifying the derivative that will be applied to calculate the asymptotes which determines the pollen season using the \code{"logistic"} method. This argument is valid only for the \code{"logistic"} method. The \code{derivative} argument will be \code{5} by default. More information may be consulted in \strong{Details}.
#' @param man A \code{numeric} (\code{integer}) value specifying the order of the moving average applied to calculate the pollen season using the \code{"moving"} method. This argument is valid only for the \code{"moving"} method. The \code{man} argument will be \code{11} by default.
#' @param th.ma A \code{numeric} value specifying the threshold used for the \code{"moving"} method for defining the beginning and the end of the pollen season. This argument is valid only for the \code{"moving"} method. The \code{th.ma} argument will be \code{5} by default.
#' @param n.clinical A \code{numeric} (\code{integer}) value specifying the number of days which must exceed a given threshold (\code{th.pollen} argument) for defining the beginning and the end of the pollen season. This argument is valid only for the \code{"clinical"} method. The \code{n.clinical} argument will be \code{5} by default.
#' @param window.clinical A \code{numeric} (\code{integer}) value specifying the time window during which the conditions must be evaluated for defining the beginning and the end of the pollen season using the \code{"clinical"} method. This argument is valid only for the \code{"clinical"} method. The \code{window.clinical} argument will be \code{7} by default.
#' @param window.grains A \code{numeric} (\code{integer}) value specifying the time window during which the conditions must be evaluated for defining the beginning and the end of the pollen season using the \code{"grains"} method. This argument is valid only for the \code{"grains"} method. The \code{window.grains} argument will be \code{5} by default.
#' @param th.pollen A \code{numeric} value specifying the threshold that must be exceeded during a given number of days (\code{n.clinical} or \code{window.grains} arguments) for defining the beginning and the end of the pollen season using the \code{"clinical"} or \code{"grains"} methods. This argument is valid only for the \code{"clinical"} or \code{"grains"} methods. The \code{th.pollen} argument will be \code{10} by default.
#' @param th.sum A \code{numeric} value specifying the pollen threshold that must be exceeded by the sum of daily pollen during a given number of days (\code{n.clinical} argument) exceeding a given daily threshold (\code{th.pollen} argument) for defining the beginning and the end of the pollen season using the \code{"clinical"} method. This argument is valid only for the \code{"clinical"} method. The \code{th.sum} argument will be \code{100} by default.
#' @param type A \code{character} string specifying the parameters considered according to a specific pollen type for calculating the pollen season using the \code{"clinical"} method. The implemented pollen types that may be used are: \code{"birch"}, \code{"grasses"}, \code{"cypress"}, \code{"olive"} or \code{"ragweed"}. As result for selecting any of these pollen types the parameters \code{n.clinical}, \code{window.clinical}, \code{th.pollen} and \code{th.sum} will be automatically adjusted for the \code{"clinical"} method. If no pollen types are specified (\code{type = "none"}), these parameters will be considered by the user. This argument is valid only for the \code{"clinical"} method. The \code{type} argument will be \code{"none"} by default.
#' @param interpolation A \code{logical} value. If \code{FALSE} the interpolation of the pollen data is not applicable. If \code{TRUE} an interpolation of the pollen series will be applied to complete the gaps with no data before the calculation of the pollen season. The \code{interpolation} argument will be \code{TRUE} by default. A more detailed information about the interpolation method may be consulted in \strong{Details}.
#' @param int.method A \code{character} string specifying the method selected to apply the interpolation method in order to complete the pollen series. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"spline"} or \code{"tseries"}. The \code{int.method} argument will be \code{"lineal"} by default.
#' @param maxdays A \code{numeric} (\code{integer} value) specifying the maximum number of consecutive days with missing data that the algorithm is going to interpolate. If the gap is bigger than the argument value, the gap will not be interpolated. Not valid with \code{int.method = "tseries"}. The \code{maxdays} argument will be \code{30} by default.
#' @param result A \code{character} string specifying the output for the function. The implemented outputs that may be obtained are: \code{"table"} and \code{"list"}. The argument \code{result} will be \code{"table"} by default.
#' @param plot A \code{logical} value specifying if a set of plots based on the definition of the pollen season will be shown in the plot history or not. If \code{FALSE} graphical results will not be shown. If \code{TRUE} a set of plots will be shown in the plot history. The \code{plot} argument will be \code{TRUE} by default.
#' @param export.plot A \code{logical} value specifying if a set of plots based on the definition of the pollen season will be saved in the workspace. If \code{TRUE} a \emph{pdf} file for each pollen type showing graphically the definition of the pollen season for each studied year will be saved within the \emph{plot_AeRobiology} directory created in the working directory. The \code{plot} argument will be \code{FALSE} by default.
#' @param export.result A \code{logical} value specifying if a excel file including all parameters for the definition of the pollen season saved in the working directoty will be required or not. If \code{FALSE} the results will not exported. If \code{TRUE} the results will be exported as \emph{xlsx} file including all parameters calculated from the definition of the pollen season within the \emph{table_AeRobiology} directory created in the working directory. The \code{export.result} argument will be \code{FALSE} by default.
#' @details This function allows to calculate the pollen season using five different methods which are described below. After calculating the start_date, end_date and peak_date for the pollen season all rest of parameters have been calculated as detailed in \strong{Value} section.
#' \itemize{
#'   \item \code{"percentage"} method. This is a commonly used method for defining the pollen season based on the elimination of a certain percentage in the beginning and the end of the pollen season \emph{(Nilsson and Persson, 1981; Andersen, 1991)}. For example if the pollen season is based on the 95\% of the total annual pollen (\code{"perc" = 95}), the start_date of the pollen season is marked as the day in which 2.5\% of the total pollen is registered and the end_date of the pollen season is marked as the day in which 97.5\% of the total pollen is registered.
#'   \item \code{"logistic"} method. This method was developed by \emph{Ribeiro et al. (2007)} and modified by \emph{Cunha et al. (2015)}. It is based on fitting annually a non_linear logistic regression model to the daily accumulated curve for each pollen type. This logistic function and the different derivatives were considered to calculate the start_date and end_date of the pollen season, based on the asymptotes when pollen amounts are stabilized on the beginning and the end of the accumulated curve. For more information about the method to see \emph{Ribeiro et al. (2007)} and \emph{Cunha et al. (2015)}. Three different derivatives may be used (\code{derivative} argument) \code{4}, \code{5} or \code{6} that represent from higher to lower restrictive criterion for defining the pollen season. This method may be complemented with an optional method for reduction the peaks values (\code{reduction = TRUE}), thus avoiding the effect of the great influence of extreme peaks. In this sense, peaks values will be cut below a certain level that the user may select based on a percentile analysis of peaks. For example, \code{red.level = 0.90} will cut all peaks above the percentile \code{90}.
#'   \item \code{"moving"} method. This method is proposed the first time by the authors of this package. The definition of the pollen season is based on the application of a moving average to the pollen series in order to obtain the general seasonality of the pollen curve avoiding the great variability of the daily fluctuations. Thus, the start_date and the end_date will be established when the curve of the moving average reaches a given pollen threshold (\code{th.ma} argument). Also the order of the moving average may be customized by the user (\code{man} argument). By default, \code{man} = 11 and \code{th.ma} = 5.
#'   \item \code{"clinical"} method. This method was proposed by \emph{Pfaar et al. (2017)}. It is based on the expert consensus in relation to pollen exposure and the relationship with allergic symptoms derived of the literature. Different periods may be defined by this method: the pollen season, the high pollen season and the high pollen days. The start_date and end_date of the pollen season were defined as a certain number of days (\code{n.clinical} argument) within a time window period (\code{window.clinical} argument) exceeding a certain pollen threshold (\code{th.pollen} argument) which summation is above a certain pollen sum (\code{th.sum} argument). All these parameters are established for each pollen type according to \emph{Pfaar et al. (2017)} and using the \code{type} argument these parameters may be automatically adjusted for the specific pollen types (\code{"birch"}, \code{"grasses"}, \code{"cypress"}, \code{"olive"} or \code{"ragweed"}). Furthermore, the user may change all parameters to do a customized definition of the pollen season. The start_date and end_date of the high pollen season were defined as three consecutive days exceeding a certain pollen threshold (\code{th.day} argument). The number of high pollen days will also be calculated exceeding this pollen threshold (\code{th.day}). For more information about the method to see \emph{Pfaar et al. (2017)}.
#' \item \code{"grains"} method. This method was proposed by \emph{Galan et al. (2001)} originally in olive pollen but after also applied in other pollen types. The start_date and end_date of the pollen season were defined as a certain number of days (\code{window.grains} argument) exceeding a certain pollen threshold (\code{th.pollen} argument). For more information about the method to see \emph{Galan et al. (2001)}.
#' }
#' The pollen season of the species may occur during the natural year (Calendar year: from 1. January to 31. December) or the start_date and the end_date of the pollen season may happen in two different natural years (or calendar years). This consideration has been taken into account and in this package different method for defining the period for calculating the pollen season have been implemented. In this sense, the \code{def.season} argument has been incorporated in three options:
#' \itemize{
#' \item \code{"natural"}: considering the pollination year as natural year from 1st January to 31th December for defining the start_dates and end_dates of the pollen season for each pollen types.
#' \item \code{"interannual"}: considering the pollination year from 1st June to 31th May for defining the start_dates and end_dates of the pollen season for each pollen types.
#' \item \code{"peak"}: considering a customized pollination year for each pollen types calculated as 6 previous months and 6 later months from the average peak_date.
#' }
#' Pollen time series frequently have different gaps with no data and this fact could be a problem for the calculation of specific methods for defining the pollen season even providing incorrect results. In this sense by default a linear interpolation will be carried out to complete these gaps before to define the pollen season (\code{interpolation = TRUE}). Additionally, the users may select other interpolation methods using the \code{int.method} argument, as \code{"lineal"}, \code{"movingmean"}, \code{"spline"} or \code{"tseries"}. For more information to see the \code{\link{interpollen}} function.
#' @return This function returns different results:\cr
#' \code{data.frame} when \code{result = "table"} including the main parameters of the pollen season with regard to phenology and pollen intensity as:
#' \itemize{
#'    \item \strong{type}: pollen type
#'    \item \strong{seasons}: year of the beginning of the season
#'    \item \strong{st.dt}: start_date (date)
#'    \item \strong{st.jd}: start_date (day of the year)
#'    \item \strong{en.dt}: end_date (date)
#'    \item \strong{en.jd}: end_date (day of the year)
#'    \item \strong{ln.ps}: length of the season
#'    \item \strong{sm.tt}: total sum
#'    \item \strong{sm.ps}: pollen integral
#'    \item \strong{pk.val}: peak value
#'    \item \strong{pk.dt}: peak_date (date)
#'    \item \strong{pk.jd}: peak_date (day of year)
#'    \item \strong{ln.prpk}: length of the pre_peak period
#'    \item \strong{sm.prpk}: pollen integral of the pre_peak period
#'    \item \strong{ln.pspk}: length of the post_peak period
#'    \item \strong{sm.pspk}: pollen integral of the post_peak period
#'    \item \strong{daysth}: number of days with more than 100 pollen grains
#'    \item \strong{st.dt.hs}: start_date of the High pollen season (date, only for clinical method)
#'    \item \strong{st.jd.hs}: start_date of the High pollen season (day of the year, only for clinical method)
#'    \item \strong{en.dt.hs}: end_date of the High pollen season (date, only for clinical method)
#'    \item \strong{en.jd.hs}: end_date of the High pollen season (day of the year, only for clinical method)
#' }
#' \code{list} when \code{result = "list"} including the main parameters of the pollen season, one pollen type by element
#' \code{plots} when \code{plot = TRUE} showing graphically the definition of the pollen season for each studied year in the plot history.
#' If \code{export.result = TRUE} this \code{data.frame} will also be exported as \emph{xlsx} file within the \emph{table_AeRobiology} directory created in the working directory. If \code{export.result = FALSE} the results will also be showed as list object named \code{list.ps}. \cr
#' If \code{export.plot = TRUE} a \emph{pdf} file for each pollen type showing graphically the definition of the pollen season for each studied year will be saved within the \emph{plot_AeRobiology} directory created in the working directory.
#' @references Andersen, T.B., 1991. A model to predict the beginning of the pollen season. \emph{Grana}, 30(1), pp.269_275.
#' @references Cunha, M., Ribeiro, H., Costa, P. and Abreu, I., 2015. A comparative study of vineyard phenology and pollen metrics extracted from airborne pollen time series. \emph{Aerobiologia}, 31(1), pp.45_56.
#' @references  Galan, C., Garcia_Mozo, H., Carinanos, P., Alcazar, P. and Dominguez_Vilches, E., 2001. The role of temperature in the onset of the \emph{Olea europaea} L. pollen season in southwestern Spain. \emph{International Journal of Biometeorology}, 45(1), pp.8_12.
#' @references Nilsson, S. and Persson, S., 1981. Tree pollen spectra in the Stockholm region (Sweden), 1973_1980. \emph{Grana}, 20(3), pp.179_182.
#' @references Pfaar, O., Bastl, K., Berger, U., Buters, J., Calderon, M.A., Clot, B., Darsow, U., Demoly, P., Durham, S.R., Galan, C., Gehrig, R., Gerth van Wijk, R., Jacobsen, L., Klimek, L., Sofiev, M., Thibaudon, M. and Bergmann, K.C., 2017. Defining pollen exposure times for clinical trials of allergen immunotherapy for pollen_induced rhinoconjunctivitis_an EAACI position paper. \emph{Allergy}, 72(5), pp.713_722.
#' @references Ribeiro, H., Cunha, M. and Abreu, I., 2007. Definition of main pollen season using logistic model. \emph{Annals of Agricultural and Environmental Medicine}, 14(2), pp.259_264.
#' @seealso \code{\link{interpollen}}, \code{\link{plot_ps}}
#' @examples data("munich_pollen")
#' @examples calculate_ps(munich_pollen, plot = TRUE, result = "table")
#' @importFrom circular circular mean.circular
#' @importFrom graphics abline lines  par plot
#' @importFrom grDevices dev.copy dev.off graphics.off recordPlot
#' @importFrom lubridate is.POSIXt yday
#' @importFrom stats aggregate coef complete.cases getInitial na.omit nls quantile SSlogis
#' @importFrom utils data head globalVariables
#' @importFrom writexl write_xlsx
#' @importFrom tidyr %>%
#' @export
calculate_ps <- function(data,
                          method = "percentage",
                          th.day = 100,
                          perc = 95,
                          def.season = "natural",
                          reduction = FALSE,
                          red.level = 0.90,
                          derivative = 5,
                          man = 11,
                          th.ma = 5,
                          n.clinical = 5,
                          window.clinical = 7,
                          window.grains = 5,
                          th.pollen = 10,
                          th.sum = 100,
                          type = "none",
                          interpolation = TRUE,
                          int.method = "lineal",
                          maxdays = 30,
                          result = "table",
                          plot = TRUE,
                          export.plot = FALSE,
                          export.result = FALSE) {

  ######################################################################################################

  if(!is.logical(export.plot)) stop ("Please include only logical values for export.plot argument")

  if(!is.logical(export.result)) stop ("Please include only logical values for export.result argument")
  
  in_check <- nzchar(Sys.getenv("_R_CHECK_PACKAGE_NAME_"))
  base_dir <- if (in_check) tempdir() else getwd()
  
  if (isTRUE(export.plot)) {
    plot_dir <- file.path(base_dir, "plot_AeRobiology")
    if (!dir.exists(plot_dir)) {
      dir.create(plot_dir, recursive = TRUE, showWarnings = FALSE)
    }
    plot <- TRUE
  }
  
  if (isTRUE(export.result)) {
    table_dir <- file.path(base_dir, "table_AeRobiology")
    if (!dir.exists(table_dir)) {
      dir.create(table_dir, recursive = TRUE, showWarnings = FALSE)
    }
  }
  
  

  data<-data.frame(data)
  if(!is.data.frame(data)) stop ("Please include a data.frame: first column with date, and the rest with pollen types")

  if(!is.numeric(th.day) | th.day < 0) stop ("Please include only numeric values >= 0 for th.day argument")

  if(!is.numeric(perc) | perc < 0 | perc > 100) stop ("Please include only numeric values between 0-100 for perc argument")

  if(!is.logical(reduction)) stop ("Please include only logical values for reduction argument")

  if(!is.numeric(red.level) | red.level < 0 | red.level > 1) stop ("Please include only numeric values between 0-1 for red.level argument")

  if(derivative != 4 & derivative != 5 & derivative != 6) stop ("Please derivative only accept values: 4, 5 or 6")

  if(!is.numeric(man) | man < 0) stop ("Please include only numeric values > 0 for man argument")

  if(!is.numeric(th.ma) | th.ma < 0) stop ("Please include only numeric values > 0 for th.ma argument")

  if(result != "table" & result != "list") stop ("Please result only accept values: 'table' or 'list'")

  if(!is.logical(plot)) stop ("Please include only logical values for plot argument")

  if(!is.numeric(n.clinical) | n.clinical < 0) stop ("Please include only numeric values >= 0 for n.clinical argument")

  if(!is.numeric(window.clinical) | window.clinical < 0) stop ("Please include only numeric values >= 0 for window.clinical argument")

  if(!is.numeric(window.grains) | window.grains < 0) stop ("Please include only numeric values >= 0 for window.grains argument")

  if(!is.numeric(th.pollen) | th.pollen < 0) stop ("Please include only numeric values >= 0 for th.pollen argument")

  if(!is.numeric(th.sum) | th.sum < 0) stop ("Please include only numeric values >= 0 for th.sum argument")

  if(!is.logical(interpolation)) stop ("Please include only logical values for interpolation argument")

  if(int.method != "lineal" & int.method != "movingmean" & int.method != "spline" & int.method != "tseries") stop ("Please int.method only accept values: 'lineal', 'movingmean', 'spline' or 'tseries'")

  if(def.season != "natural" & def.season != "interannual" & def.season != "peak") stop ("Please def.season only accept values: 'natural', 'interannual' or 'peak'")

  if(method != "percentage" & method != "logistic" & method != "moving" & method != "clinical" & method != "grains") stop ("Please method only accept values: 'percentage', 'logistic', 'moving', 'clinical' or 'grains'")

  if(type != "none" & type != "birch" & type != "grasses" & type != "cypress" & type != "olive" & type != "ragweed") stop ("Please def.season only accept values: 'none', 'birch', 'grasses', 'cypress', 'olive' or 'ragweed'")

  if(class(data[,1])[1]!="Date" & !is.POSIXt(data[,1])) {stop("Please the first column of your data must be the date in 'Date' format")}
  data[,1]<-as.Date(data[,1])

  ######################################################################################################
  SS<-c()
  a<-c()
  g<-c()
  b<-c()
  list.ps<-c()
  if(method == "clinical" & type == "birch") {n.clinical = 5; window.clinical = 7; th.pollen = 10; th.sum = 100; th.day = 100}
  if(method == "clinical" & type == "grasses") {n.clinical = 5; window.clinical = 7; th.pollen = 3; th.sum = 30; th.day = 50}
  if(method == "clinical" & type == "cypress") {n.clinical = 5; window.clinical = 7; th.pollen = 20; th.sum = 200; th.day = 100}
  if(method == "clinical" & type == "olive") {n.clinical = 5; window.clinical = 7; th.pollen = 20; th.sum = 200; th.day = 100}
  if(method == "clinical" & type == "ragweed") {n.clinical = 5; window.clinical = 7; th.pollen = 3; th.sum = 30; th.day = 50}

  th.rem = 100 - perc
  if(method == "clinical") {window.clinical <- window.clinical - 1}
  if(method == "grains") {window.grains <- window.grains - 1}

  if(interpolation == TRUE){data <- interpollen(data, method = int.method, maxdays = maxdays, plot = F)}

  type.name <- colnames(data)

  cols <- ncol(data)

  list.results <- list()

  for (t in 2: cols){

    ####################################################################################################
    ################################## Definition of the season ########################################

    if (def.season == "interannual"){

      n.year <- rep(NA, nrow(data))
      for(y in 1:length(n.year)){
        if (data[y, 1] <= as.Date(paste0(strftime(data[y, 1], "%Y"),"-05-31"))) {n.year[y] <- as.numeric(strftime(data[y, 1], "%Y"))-1} else {n.year[y] <- as.numeric(strftime(data[y, 1], "%Y"))}}
      data$n.year <- n.year

    } else if (def.season == "peak") {

      peaks <- (aggregate(data[ ,type.name[t]] ~ strftime(data[ ,1], "%Y"), FUN = max)) %>%
      .[which(.[ ,2] != 0), ]


      date.peak <- rep(NA, nrow(peaks))
      for (p in 1:nrow(peaks)){
        date.peak[p] <- data[which(strftime(data[ ,1], "%Y") == peaks[p,1] & data[ , type.name[t]] == peaks[p,2]), 1][1]}
      date.peak <- as.Date(date.peak, origin = "1970-01-01")
      date.peak <- as.numeric(strftime(date.peak, "%j")) * 360 / 365
      mean.cir <- round((as.numeric(mean.circular(circular(date.peak, units = "degrees")))) * 365 / 360)
      if(mean.cir <= 0) {mean.cir <- mean.cir + 365}

      date.year <- c(mean.cir - 182, mean.cir + 182); date.year <- date.year[date.year > 0 & date.year <= 365]
      n.year <- rep(NA, nrow(data))
      for(y in 1:length(n.year)){
        if (data[y, 1] <= as.Date(paste0(strftime(data[y, 1], "%Y"),substring(as.Date(strptime(date.year, "%j")), 5)))) {n.year[y] <- as.numeric(strftime(data[y, 1], "%Y")) - 1} else {n.year[y] <- as.numeric(strftime(data[y, 1], "%Y"))}}
      data$n.year <- n.year

    } else if (def.season == "natural") {
      n.year <- as.numeric(strftime(data[, 1], "%Y"))
      data$n.year <- n.year}

    ####################################################################################################

    seasons <- unique(data$n.year)

    st.ps <-NA; mx.ps <- NA; en.ps <- NA; st.hs <- NA; en.hs <- NA

    result.ps <- data.frame(seasons, st.dt = NA, st.jd = NA, en.dt = NA, en.jd = NA, ln.ps = NA, sm.tt = NA, sm.ps = NA, pk.val = NA, pk.dt = NA, pk.jd = NA, ln.prpk = NA, sm.prpk = NA, ln.pspk = NA, sm.pspk = NA, daysth = NA)

    if(method == "clinical") {result.ps <- data.frame(seasons, st.dt = NA, st.jd = NA, en.dt = NA, en.jd = NA, ln.ps = NA, sm.tt = NA, sm.ps = NA, pk.val = NA, pk.dt = NA, pk.jd = NA, ln.prpk = NA, sm.prpk = NA, ln.pspk = NA, sm.pspk = NA, daysth = NA, st.dt.hs = NA, st.jd.hs = NA, en.dt.hs = NA, en.jd.hs = NA)}

    #if(plot == TRUE){graphics.off()}
    #if(plot == TRUE){par(mfrow = c(ceiling(length(seasons)/4),4), mar = c(0.5,0.5,1,0.5))}
    par(mfrow = c(ceiling(length(seasons)/4),4), mar = c(0.5,0.5,1,0.5))

    for (j in 1:length(seasons)) {
      tryCatch({

        ye <- seasons[j]

        if(length(which(complete.cases(data[which(data$n.year==ye), c(1,t)]))) == 0 | sum(data[which(data$n.year==ye), type.name[t]], na.rm = T) == 0) {print(paste("Error: Year", ye, type.name[t], ". The entire aerobiological data are NA or 0")); next()}

        pollen.s <- na.omit(data[which(data$n.year==ye), c(1,t)]) # Pollen data without NAs
        #pollen.s <- data[which(data$n.year==ye), c(1,t)]
        pollen.s$jdays <- as.numeric(strftime(pollen.s[, 1], "%j"))
        
        pollen.s3 <- pollen.s

        if (method == "moving") { ### Method using the moving average limited by a threshold

          pollen.s1 <- data.frame(Date = seq(from = pollen.s[, 1][1], to = pollen.s[, 1][nrow(pollen.s)], by = "day"), pollen = 0, jdays = 0)
          colnames(pollen.s1) <- colnames(pollen.s)
          pollen.s1$jdays <- as.numeric(strftime(pollen.s1[, 1], "%j"))
          pollen.s1[which(pollen.s1[, 1] %in% pollen.s[, 1]), 2] <- pollen.s[which(pollen.s[, 1] %in% pollen.s1[, 1]), 2]
          pollen.s <- pollen.s1

              pollen.s$ma <- ma(pollen.s[, 2], man=man)
              pollen.s[which(is.nan(pollen.s[, "ma"])), "ma"] <- NA
              Peakmod <- pollen.s[which(pollen.s[, "ma"] == max(pollen.s[, "ma"], na.rm = T)), 1][1]

              if (is.na(Peakmod)|max(pollen.s[, "ma"], na.rm = T)<th.ma) {
                mx.ps <- NA
                st.ps <- NA
                en.ps <- NA

                #if(is.na(mx.ps) | is.na(st.ps) | is.na(en.ps)) {print(paste("Error: Year", ye, type.name[t], ". Try to check the aerobiological data for this year")); next()}

              } else{
                mx.ps <- pollen.s[which(pollen.s[, 2] == max(pollen.s[, 2], na.rm = T)), 1][1]%>%yday(.)
                #st.ps <- pollen.s[which((pollen.s[, "ma"] <= th.ma) & (yday(pollen.s[, 1]) < yday(Peakmod))), 1] %>% .[length(.)]%>%yday(.)
                st.ps <- pollen.s[which((pollen.s[, "ma"] < th.ma) & (pollen.s[, 1] < Peakmod)), 1] %>% .[length(.)]%>%yday(.)+1
                #en.ps <- pollen.s[which((pollen.s[, "ma"] <= th.ma) & (yday(pollen.s[, 1]) > yday(Peakmod))), 1] %>% .[1]%>%yday(.)
                en.ps <- pollen.s[which((pollen.s[, "ma"] < th.ma) & (pollen.s[, 1] > Peakmod)), 1] %>% .[1]%>%yday(.)-1

                if (is.numeric(st.ps) &
                    length(st.ps) >=1){} else{
                      st.ps <- NA }
                if (is.numeric(mx.ps) &
                    length(mx.ps) >=1) {} else{
                      mx.ps <- NA }
                if (is.numeric(en.ps) &
                    length(en.ps) >=1) {} else{
                      en.ps <- NA }

                #if(is.na(mx.ps) | is.na(st.ps) | is.na(en.ps)) {print(paste("Error: Year", ye, type.name[t], ". Try to check the aerobiological data for this year")); next()}
              }
  }

        if (method == "percentage") { ### Method using the percentage for removing data (Andersen et al. 1991)

          pollen.s$ndays <- 1:nrow(pollen.s)
          lim <- sum(pollen.s[type.name[t]])/100*(th.rem/2)

          pollen.s$acum1 <- NA
          for (i in 1:nrow(pollen.s)) {
            if (i == 1) {
              pollen.s$acum1[i] = pollen.s[i, type.name[t]]
            }  else {
              pollen.s$acum1[i] = pollen.s[i, type.name[t]] + pollen.s$acum1[i-1]
            }
          }

          pollen.s$acum2 <- NA
          for (i in nrow(pollen.s):1) {
            if (i == nrow(pollen.s)) {
              pollen.s$acum2[i] = pollen.s[i, type.name[t]]
            }  else {
              pollen.s$acum2[i] = pollen.s[i, type.name[t]] + pollen.s$acum2[i+1]
            }
          }

          st.ps <- pollen.s$jdays[which(pollen.s$acum1 >= lim)][1]
          en.ps <- pollen.s$jdays[which(pollen.s$acum2 < lim)][1] - 1
          mx.ps <- pollen.s$jdays[which(pollen.s[type.name[t]] == max(pollen.s[type.name[t]]))[1]]
        }


        if (method == "clinical"){ ### Method using the clinical method (Pfaar et al. 2017)

          #for (f in 1: (nrow(pollen.s) - window.clinical)){
          #  if(pollen.s[f, type.name[t]] >= th.pollen &
          #    length(which(pollen.s[f:(f + window.clinical), type.name[t]] >= th.pollen)) >= n.clinical &
          #    sum(head(sort(pollen.s[f:(f + window.clinical), type.name[t]][which(pollen.s[f:(f + window.clinical), type.name[t]] >= th.pollen)], decreasing = TRUE), n.clinical)) >= th.sum){
          #    st.ps <- pollen.s$jdays[f]; break()}
          #}
          
          for (f in 1: nrow(pollen.s)){
          if((nrow(pollen.s) - (f + window.clinical)) <= 0){
            if(pollen.s[f, type.name[t]] >= th.pollen &
               length(which(pollen.s[f:nrow(pollen.s), type.name[t]] >= th.pollen)) >= n.clinical &
               sum(head(sort(pollen.s[f:nrow(pollen.s), type.name[t]][which(pollen.s[f:nrow(pollen.s), type.name[t]] >= th.pollen)], decreasing = TRUE), n.clinical)) >= th.sum){
              st.ps <- pollen.s$jdays[f]; break()}
          } else {
            if(pollen.s[f, type.name[t]] >= th.pollen &
               length(which(pollen.s[f:(f + window.clinical), type.name[t]] >= th.pollen)) >= n.clinical &
               sum(head(sort(pollen.s[f:(f + window.clinical), type.name[t]][which(pollen.s[f:(f + window.clinical), type.name[t]] >= th.pollen)], decreasing = TRUE), n.clinical)) >= th.sum){
              st.ps <- pollen.s$jdays[f]; break()}
          }
          }
          
          #for (f in (1 + window.clinical) : nrow(pollen.s)){
          #    if(pollen.s[f, type.name[t]] >= th.pollen &
          #       length(which(pollen.s[f:(f - window.clinical), type.name[t]] >= th.pollen)) >= n.clinical &
          #       sum(head(sort(pollen.s[f:(f - window.clinical), type.name[t]][which(pollen.s[f:(f - window.clinical), type.name[t]] >= th.pollen)], decreasing = TRUE), n.clinical)) >= th.sum) {
          #      en.ps <- pollen.s$jdays[f]}
          #  }          
          
          for (f in 1 : nrow(pollen.s)){
            if((f - window.clinical) <= 0){
              
              if(pollen.s[f, type.name[t]] >= th.pollen &
                 length(which(pollen.s[f:1, type.name[t]] >= th.pollen)) >= n.clinical &
                 sum(head(sort(pollen.s[f:1, type.name[t]][which(pollen.s[f:1, type.name[t]] >= th.pollen)], decreasing = TRUE), n.clinical)) >= th.sum) {
                en.ps <- pollen.s$jdays[f]}
              
            } else {
              
              if(pollen.s[f, type.name[t]] >= th.pollen &
                 length(which(pollen.s[f:(f - window.clinical), type.name[t]] >= th.pollen)) >= n.clinical &
                 sum(head(sort(pollen.s[f:(f - window.clinical), type.name[t]][which(pollen.s[f:(f - window.clinical), type.name[t]] >= th.pollen)], decreasing = TRUE), n.clinical)) >= th.sum) {
                en.ps <- pollen.s$jdays[f]}
            }
          }

          
          for (h in 1: (nrow(pollen.s) - 2)){
            if(pollen.s[h, type.name[t]] >= th.day &
              length(which(pollen.s[h:(h + 2), type.name[t]] >= th.day)) == 3) {
              st.hs <- pollen.s$jdays[h]; break()}
          }

          for (h in (1 + 2) : nrow(pollen.s)){
            if(pollen.s[h, type.name[t]] >= th.day &
              length(which(pollen.s[h:(h - 2), type.name[t]] >= th.day)) == 3) {
              en.hs <- pollen.s$jdays[h]}

          }

          mx.ps <- pollen.s$jdays[which(pollen.s[type.name[t]] == max(pollen.s[type.name[t]]))[1]]
        }


        if (method == "grains"){ ### Method using the grains method (Galan et al. 1991)
          
          #for (f in 1: (nrow(pollen.s) - window.grains)){
          #  if(pollen.s[f, type.name[t]] >= th.pollen & length(which(pollen.s[f:(f + window.grains), type.name[t]] >= th.pollen)) >= (window.grains+1)) {st.ps <- pollen.s$jdays[f]; break()}
          #}
          
          for (f in 1: nrow(pollen.s)){
            if((nrow(pollen.s) - (f + window.grains)) <= 0){
              if(pollen.s[f, type.name[t]] >= th.pollen & length(which(pollen.s[f:nrow(pollen.s), type.name[t]] >= th.pollen)) >= (window.grains+1)) {st.ps <- pollen.s$jdays[f]; break()}
              
            } else {
              
              if(pollen.s[f, type.name[t]] >= th.pollen & length(which(pollen.s[f:(f + window.grains), type.name[t]] >= th.pollen)) >= (window.grains+1)) {st.ps <- pollen.s$jdays[f]; break()}
            }
              
          }
          
          #for (f in (1 + window.grains) : nrow(pollen.s)){
          #  if(pollen.s[f, type.name[t]] >= th.pollen & length(which(pollen.s[f:(f - window.grains), type.name[t]] >= th.pollen)) >= (window.grains+1)) {en.ps <- pollen.s$jdays[f]}
          #}
          
          for (f in 1 : nrow(pollen.s)){
            if((f - window.grains) <= 0){
              if(pollen.s[f, type.name[t]] >= th.pollen & length(which(pollen.s[f:1, type.name[t]] >= th.pollen)) >= (window.grains+1)) {en.ps <- pollen.s$jdays[f]}
            
            } else {
              
              if(pollen.s[f, type.name[t]] >= th.pollen & length(which(pollen.s[f:(f - window.grains), type.name[t]] >= th.pollen)) >= (window.grains+1)) {en.ps <- pollen.s$jdays[f]}
            }  
            
          }
          
          mx.ps <- pollen.s$jdays[which(pollen.s[type.name[t]] == max(pollen.s[type.name[t]]))[1]]
        }


        if (method == "logistic"){ ### Method using the accumulated curve (Ribeiro et al. 2004)

          pollen.s1 <- data.frame(Date = seq(from = pollen.s[, 1][1], to = pollen.s[, 1][nrow(pollen.s)], by = "day"), pollen = 0, jdays = 0)
          colnames(pollen.s1) <- colnames(pollen.s)
          pollen.s1$jdays <- as.numeric(strftime(pollen.s1[, 1], "%j"))
          pollen.s1[which(pollen.s1[, 1] %in% pollen.s[, 1]), 2] <- pollen.s[which(pollen.s[, 1] %in% pollen.s1[, 1]), 2]
          pollen.s <- pollen.s1

          pollen.s2 <- pollen.s

          if(reduction == TRUE){
            pollen.s[which( pollen.s[, type.name[t]] >= quantile(data[data[ ,type.name[t]] > 0, type.name[t]], red.level, na.rm = TRUE)), type.name[t]] <- quantile(data[data[ ,type.name[t]] > 0, type.name[t]], red.level, na.rm = TRUE)}

          #pollen.s[ , type.name[t]] <- round(ma(pollen.s[ , type.name[t]], order = 5))
          pollen.s <- na.omit(pollen.s)
          pollen.s$ndays <- 1:nrow(pollen.s)

          pollen.s$acum <- NA
          for (i in 1:nrow(pollen.s)) {
            if (i==1) {
              pollen.s$acum[i] = pollen.s[i, type.name[t]]
            }  else {
              pollen.s$acum[i] = pollen.s[i, type.name[t]] + pollen.s$acum[i-1]
            }
          }

          tryCatch({
            tryCatch({model.acum <- nls(acum~a*(1+exp(-(b+g*ndays)))^-1, start=list(a = max(pollen.s$acum),g = 1,b = -2), data=pollen.s)}, error = function(e){})
            tryCatch({
              SS <- getInitial(acum ~ SSlogis(ndays,alpha,xmid,scale), data = pollen.s)
              a <- SS["alpha"]
              g <- 1/SS["scale"]
              b <- SS["alpha"]/(exp(SS["xmid"]/SS["scale"])+1)
              model.acum <- nls(acum~a*(1+exp(-(b+g*ndays)))^-1, start=list(a = a, g = g, b = b), data=pollen.s)
            }, error = function(e){})
          }, error = function(e){print(paste("Error:", "Year:", ye, type.name[t]))})

          tryCatch({
            #summary(model.acum)
            c <- coef(model.acum) # a es c[1], g es c[2] y b es c[3]
            aj.acum <- function(t){c[1]*(1+exp(-(c[3]+c[2]*t)))^-1}
            pollen.s$model <- aj.acum(pollen.s$ndays)

            x2 <- -c[3]/c[2]; x2 <- round(x2)

            if(x2==0){
              SS <- getInitial(acum ~ SSlogis(ndays,alpha,xmid,scale), data = pollen.s)
              a <- SS["alpha"]
              g <- 1/SS["scale"]
              b <- SS["alpha"]/(exp(SS["xmid"]/SS["scale"])+1)
              model.acum <- nls(acum~a*(1+exp(-(b+g*ndays)))^-1, start=list(a = a, g = g, b = b), data=pollen.s)
              c <- coef(model.acum) # a es c[1], g es c[2] y b es c[3]
              aj.acum <- function(t){c[1]*(1+exp(-(c[3]+c[2]*t)))^-1}
              pollen.s$model <- aj.acum(pollen.s$ndays)
              x2 <- -c[3]/c[2]; x2 <- round(x2)
            }

            if (derivative == 4){
              # Resultados de la cuarta derivada
              x1 <- -(log(5+2*sqrt(6))+c[3])/c[2]; x1 <- floor(x1)
              x3 <- -(log(5-2*sqrt(6))+c[3])/c[2]; x3 <- ceiling(x3)
            } else if (derivative == 5) {
              # Resultados de la quinta derivada
              x1 <- -(c[3]+(log((sqrt(26*sqrt(105)+270)/2)+(sqrt(105)/2)+(13/2))))/c[2]; x1 <- floor(x1)
              x3 <- -(c[3]+(log(+(sqrt(105)/2)-(sqrt(26*sqrt(105)+270)/2)+(13/2))))/c[2]; x3 <- ceiling(x3)
            } else if (derivative == 6){
              # Resultados de la sexta derivada
              x1 <- -(c[3]+log(sqrt(336*sqrt(15)+1320)/2+3*sqrt(15)+14))/c[2]; x1 <- floor(x1)
              x3 <- -(c[3]+log((-sqrt(336*sqrt(15)+1320)/2)+3*sqrt(15)+14))/c[2]; x3 <- ceiling(x3)
            }

            st.ps <- pollen.s$jdays[which(pollen.s$ndays == x1)]
            en.ps <- pollen.s$jdays[which(pollen.s$ndays == x3)]
            mx.ps <- pollen.s2$jdays[which(pollen.s2[type.name[t]] == max(pollen.s2[type.name[t]]))[1]]

            if(reduction == TRUE){pollen.s <- pollen.s2}
            
          }, error = function(e){
            print(paste("Error: Year", ye, type.name[t], ". This method can not parametrize the model for this aerobiological data"))
          })
        }

        # Characteristics of the pollen season (PS)
        result.ps[j,"st.dt"] <- as.character(pollen.s[pollen.s$jdays == st.ps, 1]) # Start-date of PS
        result.ps[j,"st.jd"] <- pollen.s$jdays[pollen.s$jdays == st.ps] # Start-date of PS (JD)
        result.ps[j,"en.dt"] <- as.character(pollen.s[pollen.s$jdays == en.ps, 1]) # End-date of PS
        result.ps[j,"en.jd"] <- pollen.s$jdays[pollen.s$jdays == en.ps] # End-date of PS (JD)
        result.ps[j,"ln.ps"] <- round(as.numeric(pollen.s[pollen.s$jdays == en.ps, 1] - pollen.s[pollen.s$jdays == st.ps, 1])) + 1 # Length of PS
        result.ps[j,"sm.tt"] <- sum(pollen.s[type.name[t]]) # Total sum
        result.ps[j,"sm.ps"] <- sum(pollen.s[which(pollen.s$jdays == st.ps) : which(pollen.s$jdays == en.ps), type.name[t]]) # Pollen Index
        result.ps[j,"pk.val"] <- max(pollen.s[type.name[t]]) # Peak value
        result.ps[j,"pk.dt"] <- as.character(pollen.s[pollen.s$jdays == mx.ps, 1]) # Peak date
        result.ps[j,"pk.jd"] <- pollen.s$jdays[pollen.s$jdays == mx.ps] # Peak date (JD)
        result.ps[j,"ln.prpk"] <- round(as.numeric(pollen.s[pollen.s$jdays == mx.ps, 1] - pollen.s[pollen.s$jdays == st.ps, 1]))+1 # Lengh of pre-peak period
        result.ps[j,"sm.prpk"] <- sum(pollen.s[which(pollen.s$jdays == st.ps) : which(pollen.s$jdays == mx.ps), type.name[t]]) # Pre-peak sum
        result.ps[j,"ln.pspk"] <- round(as.numeric(pollen.s[pollen.s$jdays == en.ps, 1] - pollen.s[pollen.s$jdays == mx.ps, 1])) # Lengh of post-peak period
        result.ps[j,"sm.pspk"] <- sum(pollen.s[(which(pollen.s$jdays == mx.ps)+1) : which(pollen.s$jdays == en.ps), type.name[t]]) # Post-peak sum
        result.ps[j,"daysth"] <- length(which(pollen.s[type.name[t]] >= th.day))
        if (method == "clinical" & is.numeric(st.hs)){result.ps[j,"st.dt.hs"] <- as.character(pollen.s[pollen.s$jdays == st.hs, 1])} # Start-date of HPS
        if (method == "clinical" & is.numeric(st.hs)){result.ps[j,"st.jd.hs"] <- pollen.s$jdays[pollen.s$jdays == st.hs]} # Start-date of HPS (JD)
        if (method == "clinical" & is.numeric(en.hs)){result.ps[j,"en.dt.hs"] <- as.character(pollen.s[pollen.s$jdays == en.hs, 1])} # End-date of HPS
        if (method == "clinical" & is.numeric(en.hs)){result.ps[j,"en.jd.hs"] <- pollen.s$jdays[pollen.s$jdays == en.hs]} # End-date of HPS (JD)

        if (which(pollen.s$jdays == st.ps)-20 > 1) {pollen.s <- pollen.s[-(1:(which(pollen.s$jdays == st.ps)-20)), ]}
        if (which(pollen.s$jdays == en.ps)+20 < nrow(pollen.s)) {pollen.s <- pollen.s[-((which(pollen.s$jdays == en.ps)+20):nrow(pollen.s)), ]}

        if(plot == TRUE){

          if(method == "percentage" | method == "logistic" | method == "clinical" | method == "grains"){
          plot(y = pollen.s[ ,type.name[t]], x = 1:length(pollen.s$jdays), type = "l", main = paste(toupper(type.name[t]), ye), ylab = expression(paste("Granos de polen/m"^"3")), xlab = "Julian days", xaxt = "n", yaxt = "n", lwd = 1.5)
          #plot(y = pollen.s[ ,type.name[t]], x = pollen.s$jdays, type = "l", main = paste(toupper(type.name[t]), ye), ylab = expression(paste("Granos de polen/m"^"3")), xlab = "Julian days", xaxt = "n", yaxt = "n", lwd = 1.5)
          par(new=T)
          #plot(pollen.s$acum, x = pollen.s$ndays, type="l", col="red")
          #plot(pollen.s$acum, type="l", col="red")
          #lines(pollen.s$ndays, aj.acum(pollen.s$ndays), col="blue")
          ymax <- max(pollen.s[ ,type.name[t]])+100
          #lines(x = c(result.ps[j,"st.jd"], result.ps[j,"st.jd"]), y = c(0,ymax), col = 2, lty = 2, lwd = 2)
          lines(x = c(which(pollen.s$jdays == result.ps[j,"st.jd"]), which(pollen.s$jdays == result.ps[j,"st.jd"])), y = c(0,ymax), col = 2, lty = 2, lwd = 2)
          #lines(x=c(mx.ps, mx.ps), y=c(0,ymax), col=2, lty=2, lwd=2)
          #lines(x = c(result.ps[j,"en.jd"], result.ps[j,"en.jd"]), y = c(0,ymax), col = 2, lty = 2, lwd = 2)
          lines(x = c(which(pollen.s$jdays == result.ps[j,"en.jd"]), which(pollen.s$jdays == result.ps[j,"en.jd"])), y = c(0,ymax), col = 2, lty = 2, lwd = 2)
          #lines(x = c(result.ps[j,"pk.jd"], result.ps[j,"pk.jd"]), y = c(0,ymax), col = 3, lty = 2, lwd = 2)
          lines(x = c(which(pollen.s$jdays == result.ps[j,"pk.jd"]), which(pollen.s$jdays == result.ps[j,"pk.jd"])), y = c(0,ymax), col = 3, lty = 2, lwd = 2)
          } else {

            #plot(y = pollen.s[ ,2], x = yday(pollen.s[ ,1]), type = "l", main = paste(toupper(type.name[t])," ", ye), xaxt = "n", yaxt = "n", lwd = 1.5)
            plot(y = pollen.s[ ,2], x = 1:length(yday(pollen.s[ ,1])), type = "l", main = paste(toupper(type.name[t])," ", ye), xaxt = "n", yaxt = "n", lwd = 1.5)
            #lines(pollen.s[ ,"ma"], x = yday(pollen.s[ ,1]), col="red")
            lines(pollen.s[ ,"ma"], x = 1:length(yday(pollen.s[ ,1])), col="red")
            #abline(v = c(st.ps,en.ps), col = 4, lty = 2, lwd = 2)
            abline(v = c(which(yday(pollen.s[ ,1]) == st.ps), which(yday(pollen.s[ ,1]) == en.ps)), col = 4, lty = 2, lwd = 2)
            abline(h = th.ma, col = 3, lty = 2, lwd = 2)
          }

          #plot.season <- recordPlot()
        }

        print(paste(ye, type.name[t]))
      }, error = function(e){
        print(paste("Year", ye, type.name[t], ". Try to check the aerobiological data for this year"))
      })
        result.ps[j,"sm.tt"] <- sum(pollen.s3[type.name[t]])
        result.ps[j,"pk.val"] <- max(pollen.s3[type.name[t]])
        result.ps[j,"pk.dt"] <- as.character(pollen.s3[which(pollen.s3[type.name[t]] == max(pollen.s3[type.name[t]]))[1], 1]) # Peak date
        result.ps[j,"pk.jd"] <- pollen.s3$jdays[which(pollen.s3[type.name[t]] == max(pollen.s3[type.name[t]]))[1]] # Peak date (JD)


      st.ps <-NA; mx.ps <- NA; en.ps <- NA; st.hs <- NA; en.hs <- NA
    }
    result.ps$st.dt <- as.Date(strptime(result.ps$st.dt, "%Y-%m-%d"))
    result.ps$en.dt <- as.Date(strptime(result.ps$en.dt, "%Y-%m-%d"))
    result.ps$pk.dt <- as.Date(strptime(result.ps$pk.dt, "%Y-%m-%d"))

    if (isTRUE(export.plot)){plot.season <- recordPlot()}

    list.results[[type.name[t]]] <- result.ps

    par(mfrow = c(1,1), mar = c(5.1, 4.1, 4.1, 2.1))

    if (isTRUE(export.plot)) {
      if (method == "percentage") {
        dev.copy(pdf, file.path(plot_dir, paste0("plot_", type.name[t], "_", method, perc, ".pdf")))
        plot.season; dev.off()
      }
      if (method == "logistic") {
        dev.copy(pdf, file.path(plot_dir, paste0("plot_", type.name[t], "_", method, derivative, ".pdf")))
        plot.season; dev.off()
      }
      if (method == "moving") {
        dev.copy(pdf, file.path(plot_dir, paste0("plot_", type.name[t], "_", method, man, "_", th.ma, ".pdf")))
        plot.season; dev.off()
      }
      if (method == "clinical") {
        dev.copy(pdf, file.path(plot_dir, paste0("plot_", type.name[t], "_", method, n.clinical, "_", window.clinical + 1, "_", th.pollen, "_", th.sum, ".pdf")))
        plot.season; dev.off()
      }
      if (method == "grains") {
        dev.copy(pdf, file.path(plot_dir, paste0("plot_", type.name[t], "_", method, window.grains + 1, "_", th.pollen, ".pdf")))
        plot.season; dev.off()
      }
    }
  }
    

  par(mfrow = c(1,1), mar = c(5.1, 4.1, 4.1, 2.1))
  #if(plot == TRUE){graphics.off()}

  nam.list <- names(list.results)

  for(l in 1:length(nam.list)){
      if(l == 1) {df.results <- data.frame(type = nam.list[l], list.results[[l]])
    } else {
      df.results <- rbind(df.results, data.frame(type = nam.list[l], list.results[[l]]))
    }
  }

  list.ps <- list.results

  list.results [["Information"]] <- data.frame(
        Attributes = c("Pollen type", "seasons", "st.dt", "st.jd", "en.dt", "en.jd", "ln.ps", "sm.tt", "sm.ps", "pk.val", "pk.dt", "pk.jd", "ln.prpk", "sm.prpk", "ln.pspk", "sm.pspk", "daysth", "st.dt.hs", "st.jd.hs", "en.dt.hs", "en.jd.hs", "", "", "Method of the pollen season", "Interpolation", "Interpolation method", "Method for defining period", "", "Aditional arguments", "perc", "th.day", "reduction", "red.level", "derivative", "man", "th.ma", "n.clinical", "window.clinical", "window.grains", "th.pollen", "th.sum", "type", "", "", "Package", "Authors"),
        Description = c("Pollen type", "Year of the beginning of the season", "Start-date (date)", "Start-date (day of the year)", "End-date (date)", "End-date (day of the year)", "Length of the season", "Total sum", "Pollen integral", "Peak value", "Peak-date (date)", "Peak-date (day of year)", "Length of the pre-peak period", "Pollen integral of the pre-peak period", "Length of the post-peak period", "Pollen integral of the post-peak period", paste0("Number of days with more than ", th.day, " pollen grains"), "Start-date of the High pollen season (date, only for clinical method)", "Start-date of the High pollen season (day of the year, only for clinical method)", "End-date of the High pollen season (date, only for clinical method)", "End-date of the High pollen season (day of the year, only for clinical method)", "", "", method, interpolation, int.method, def.season, "", "", perc, th.day, reduction, red.level, derivative, man, th.ma, n.clinical, window.clinical, window.grains, th.pollen, th.sum, type,  "", "", "AeRobiology", "Jesus Rojo, Antonio Picornell & Jose Oteros"))

  if (isTRUE(export.result)) {
    if (method == "percentage") {
      write_xlsx(list.results, file.path(table_dir, paste0("table_ps_", method, perc, ".xlsx")))
    }
    if (method == "logistic") {
      write_xlsx(list.results, file.path(table_dir, paste0("table_ps_", method, derivative, ".xlsx")))
    }
    if (method == "moving") {
      write_xlsx(list.results, file.path(table_dir, paste0("table_ps_", method, man, "_", th.ma, ".xlsx")))
    }
    if (method == "clinical") {
      write_xlsx(list.results, file.path(table_dir, paste0("table_ps_", method, n.clinical, "_", window.clinical + 1, "_", th.pollen, "_", th.sum, ".xlsx")))
    }
    if (method == "grains") {
      write_xlsx(list.results, file.path(table_dir, paste0("table_ps_", method, window.grains + 1, "_", th.pollen, ".xlsx")))
    }
  }
  

  par(mfrow = c(1,1), mar = c(5.1, 4.1, 4.1, 2.1))

  if (result == "table") {return(df.results)}
  if (result == "list") {return(list.ps)}
}

context("calculate_ps")

test_that("calculate_ps returns all pollen types", {
  dates <- seq(as.Date("2025-01-01"), as.Date("2025-01-20"), by = "day")
  pollen_data <- data.frame(
    date = dates,
    pollen_a = c(rep(0, 4), 1, 3, 8, 10, 8, 3, 1, rep(0, 9)),
    pollen_b = c(rep(0, 9), 2, 4, 9, 12, 9, 4, 2, rep(0, 4))
  )

  result <- calculate_ps(
    pollen_data,
    method = "percentage",
    perc = 90,
    interpolation = FALSE,
    plot = FALSE,
    export.result = FALSE
  )

  expect_equal(unique(result$type), c("pollen_a", "pollen_b"))
  expect_equal(nrow(result), 2)
})

#' Plot of the Relative Abundance of the Pollen Types
#'
#' Generates a barplot based on the relative abundance (as percentage) in the air of the pollen types with respect to the total amounts
#'
#' @param data A \code{data.frame} object including the general database where calculation of the pollen season must be applied. This \code{data.frame} must include a first column in \code{Date} format and the rest of columns in \code{numeric} format belonging to each pollen type by column.
#' @param n.types A \code{numeric} (\code{integer}) value specifying the number of the most abundant pollen types that must be represented in the plot of the relative abundance. A more detailed information about the selection of the considered pollen types may be consulted in \strong{Details}. The \code{n.types} argument will be \code{15} types by default.
#' @param y.start,y.end A \code{numeric} (\code{integer}) value specifying the period selected to calculate relative abundances of the pollen types (\code{start year _ end year}). If \code{y.start} and \code{y.end} are not specified (\code{NULL}), the entire database will be used to generate the pollen calendar. The \code{y.start} and \code{y.end} arguments will be \code{NULL} by default.
#' @param interpolation A \code{logical} value. If \code{FALSE} the interpolation of the pollen data is not applicable. If \code{TRUE} an interpolation of the pollen series will be applied to complete the gaps with no data before the calculation of the pollen season. The \code{interpolation} argument will be \code{TRUE} by default. A more detailed information about the interpolation method may be consulted in \strong{Details}.
#' @param int.method A \code{character} string specifying the method selected to apply the interpolation method in order to complete the pollen series. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"spline"} or \code{"tseries"}. The \code{int.method} argument will be \code{"lineal"} by default.
#' @param col.bar A \code{character} string specifying the color of the bars to generate the graph showing the relative abundances of the pollen types. The \code{color} argument will be \code{#E69F00} by default, but any color may be selected.
#' @param type.plot A \code{character} string specifying the type of plot selected to show the plot showing the relative abundance of the pollen types. The implemented types that may be used are: \code{static} generates a static \strong{ggplot} object and \code{dynamic} generates a dynamic \strong{plotly} object.
#' @param result A \code{character} string specifying the output for the function. The implemented outputs that may be obtained are: \code{"plot"} and \code{"table"}. The argument \code{result} will be \code{"plot"} by default.
#' @param export.plot A \code{logical} value specifying if a plot saved in the working directory will be required or not. If \code{FALSE} graphical results will only be displayed in the active graphics window. If \code{TRUE} graphical results will be displayed in the active graphics window and also a \emph{pdf} or \emph{png} file (according to the \code{export.format} argument) will be saved within the \emph{plot_AeRobiology} directory automatically created in the working directory. This argument is applicable only for \code{"static"} plots. The \code{export.plot} will be \code{FALSE} by default.
#' @param export.format A \code{character} string specifying the format selected to save the plot showing the relative abundance of the pollen types. The implemented formats that may be used are: \code{"pdf"} and \code{"png"}. This argument is applicable only for \code{"static"} plots. The \code{export.format} will be \code{"pdf"} by default.
#' @param exclude A \code{character} string vector with the names of the pollen types to be excluded from the plot.
#' @param ... Other additional arguments may be used to customize the exportation of the plots using \code{"pdf"} or \code{"png"} files and therefore arguments from \code{\link[grDevices]{pdf}} and \code{\link[grDevices]{png}} functions (\pkg{grDevices} package) may be implemented. For example, for \emph{pdf} files the user may custom the arguments: \code{width}, \code{height}, \code{family}, \code{title}, \code{fonts}, \code{paper}, \code{bg}, \code{fg}, \code{pointsize...}; and for \emph{png} files the user may custom the arguments: \code{width}, \code{height}, \code{units}, \code{pointsize}, \code{bg}, \code{res...}
#' @details This function allows to calculate the relative abundance of the pollen types in the air from a database and to display a barplot with the percentage representation of the main pollen types as the graph reported by \emph{Rojo et al. (2016)}. This plot will be generated only for the specified number of the most abundant pollen types using the \code{n.types} argument by the user.\cr
#' \cr
#' Pollen time series frequently have different gaps with no data and this fact could be a problem for the calculation of specific methods for defining the pollen season even providing incorrect results. In this sense by default a linear interpolation will be carried out to complete these gaps before to define the pollen season (\code{interpolation = TRUE}). Additionally, the users may select other interpolation methods using the \code{int.method} argument, as \code{"lineal"}, \code{"movingmean"}, \code{"spline"} or \code{"tseries"}. For more information to see the \code{\link{interpollen}} function.
#' @return This function returns different results:\cr
#' \cr
#' \code{plot} in the active graphics window displaying the pollen calendar generated by the user when \code{result = "plot"}. This \code{plot} may be included in an object by assignment operators.\cr
#' \cr
#' \code{data.frame} including the yearly average pollen amounts for each pollen types used to generate the pollen of the relative abundance when \code{result = "table"}. This \code{data.frame} will be included in an object named \code{annual.sum.data}.\cr
#' \cr
#' If \code{export.plot = FALSE} graphical results will only be displayed in the active graphics window as \strong{ggplot} graph. Additional characteristics may be incorporated to the plot by \code{\link[ggplot2]{ggplot}} syntax (see \pkg{ggplot2} package).\cr
#' \cr
#' If \code{export.plot = TRUE} and \code{export.format = pdf} a \emph{pdf} file with the plot will be saved within the \emph{plot_AeRobiology} directory created in the working directory. This option is applicable only for \code{"static"} plots. Additional characteristics may be incorporated to the exportation as \emph{pdf} file (see \pkg{grDevices} package).\cr
#' \cr
#' If \code{export.plot = TRUE} and \code{export.format = png} a \emph{png} file with the plot will be saved within the \emph{plot_AeRobiology} directory created in the working directory. This option is applicable only for \code{"static"} plots. Additional characteristics may be incorporated to the exportation as \emph{png} file (see \pkg{grDevices} package).\cr
#' \cr
#' If \code{type.plot = dynamic} graphical results will be displayed in the active Viewer window as \strong{plotly} graph. Additional characteristics may be incorporated to the plot by \code{\link[plotly]{plotly}} syntax (see \pkg{plotly} package).
#' @references Rojo, J., Rapp, A., Lara, B., Sabariego, S., Fernandez_Gonzalez, F. and Perez_Badia, R., 2016. Characterisation of the airborne pollen spectrum in Guadalajara (central Spain) and estimation of the potential allergy risk. \emph{Environmental Monitoring and Assessment}, 188(3), p.130.
#' @seealso \code{\link{interpollen}}
#' @examples data("munich_pollen")
#' @examples iplot_abundance (munich_pollen, interpolation = FALSE, export.plot = FALSE)
#' @importFrom utils data
#' @importFrom lubridate is.POSIXt
#' @importFrom dplyr group_by summarise_all
#' @importFrom plotly ggplotly
#' @importFrom ggplot2 aes coord_flip element_blank element_text geom_bar geom_errorbar ggplot labs position_dodge theme theme_classic
#' @importFrom graphics plot
#' @importFrom grDevices dev.off pdf png
#' @importFrom stats sd
#' @importFrom tidyr %>%
#' @export
iplot_abundance <- function (data,
                             n.types = 15,
                             y.start = NULL,
                             y.end = NULL,
                             interpolation = TRUE,
                             int.method = "lineal",
                             col.bar = "#E69F00",
                             type.plot = "static",
                             result = "plot",
                             export.plot = FALSE,
                             export.format = "pdf",
                             exclude = NULL,
                             ...){

  base_dir <- if (nzchar(Sys.getenv("_R_CHECK_PACKAGE_NAME_"))) tempdir() else "."
  plot_dir <- file.path(base_dir, "plot_AeRobiology")
  
#############################################    CHECK THE ARGUMENTS       #############################

  if (isTRUE(export.plot)) dir.create(plot_dir, recursive = TRUE, showWarnings = FALSE)

  data<-data.frame(data)
  if(!is.data.frame(data)) stop ("Please include a data.frame: first column with date, and the rest with pollen types")

  if(!is.numeric(n.types)) stop ("Please include only numeric values for 'n.types' argument indicating the number of pollen types which will be displayed")

  if(!is.numeric(y.start) & !is.null(y.start)) stop ("Please include only numeric values for y.start argument indicating the start year considered")

  if(!is.numeric(y.end) & !is.null(y.end)) stop ("Please include only numeric values for 'y.end' argument indicating the end year considered")

  if(!is.logical(interpolation)) stop ("Please include only logical values for interpolation argument")

  if(int.method != "lineal" & int.method != "movingmean" & int.method != "spline" & int.method != "tseries") stop ("Please int.method only accept values: 'lineal', 'movingmean', 'spline' or 'tseries'")

  if(!is.character(col.bar)) stop ("Please include only character values indicating the color selected in the bars for generating the plot")

  if(type.plot != "static" & type.plot != "dynamic") stop ("Please type.plot only accept values: 'static' or 'dynamic'")

  if(result != "plot" & result != "table") stop ("Please result only accept values: 'plot' or 'table'")

  if(!is.logical(export.plot)) stop ("Please include only logical values for export.plot argument")

  if(export.format != "pdf" & export.format != "png") stop ("Please export.format only accept values: 'pdf' or 'png'")

  if(!is.character(exclude) & !is.null(exclude)) stop ("Please include only character values for exclude argument indicating the pollen type to be excluded")

  if(class(data[,1])[1]!="Date" & !is.POSIXt(data[,1])) {stop("Please the first column of your data must be the date in 'Date' format")}
  data[,1]<-as.Date(data[,1])

if(interpolation == TRUE){data <- interpollen(data, method = int.method, plot = FALSE)}

#############################################    SELECT ABUNDANT TYPES       #############################
  #annual.sum.data<-data.frame()
data <- data.frame(date = data[ ,1], year = as.numeric(strftime(data[ ,1], "%Y")), data[ ,-1])

#types <- ddply(data[ ,-1], "year", function(x) colSums(x[-1], na.rm = T)) [-1] %>%
#  apply(., 2, function(x) mean(x, na.rm = T)) %>% .[order(., decreasing = TRUE)] %>%
#  names(.) %>%
#  .[1:n.types]
types <- data.frame(data[ ,-1] %>%
                      group_by(year) %>%
                      summarise_all(sum, na.rm = TRUE))[-1] %>%
  apply(., 2, function(x) mean(x, na.rm = T)) %>% .[order(., decreasing = TRUE)] %>%
  names(.) %>%
  .[1:n.types]

#data <- data[ ,which(colnames(data) %in% c("date", "year", types))]

#############################################    SELECT PERIOD       #############################

seasons <- unique(as.numeric(strftime(data[, 1], "%Y")))

if(is.null(y.start)){y.start <- min(seasons)}; if(is.null(y.end)){y.end <- max(seasons)}

data <- data[which(as.numeric(strftime(data[ ,1], "%Y")) >= y.start & as.numeric(strftime(data[ ,1], "%Y")) <= y.end), ]

##############################################################################

#sum.data <- ddply(data, c("year"), function(x) colSums(x[ ,-which(colnames(x) %in% c("date", "year"))], na.rm = T))
sum.data <- data.frame(data[ ,-1] %>%
                      group_by(year) %>%
                      summarise_all(sum, na.rm = TRUE))

sum.data$Total <- apply(sum.data[ ,-which(colnames(sum.data) %in% c("year"))], 1, sum, na.rm = T)

perc.df <- sum.data[ ,-which(colnames(sum.data) == "year")]
for (r in 1:nrow(perc.df)){
  for(c in c(1:ncol(perc.df))){
    perc.df[r,c] <- perc.df[r,c]*100/perc.df$Total[r]
  }
}

perc.df <- perc.df[which(colnames(perc.df) %in% types)]

mean.perc <- data.frame(types = colnames(perc.df),
        mean = apply(perc.df, 2, FUN = function(x) mean(x, na.rm=T)),
        sd = apply(perc.df, 2, FUN = function(x) sd(x, na.rm=T)))

mean.perc$types <- factor(mean.perc$types, levels = mean.perc$types[order(mean.perc$mean)])

if (!is.null(exclude)){
  mean.perc<-mean.perc[!(as.character(mean.perc$types)%in%exclude),]}

plot.abundance <- ggplot(mean.perc, aes(x = types, y = mean)) +
  geom_bar(stat = "identity", position = position_dodge(), color = "black", fill = col.bar) +
  geom_errorbar(aes(ymin = mean - sd, ymax = mean + sd), width=.2,position=position_dodge(.9))+
  coord_flip()+
  theme_classic()+
  labs(y="Relative abundance (%)", title = paste0("Relative Abundance in the Air (", y.start, "-", y.end, ")"), size = 14)+
  theme(axis.title.y = element_blank(), axis.title.x = element_text(size=10, face="bold"), axis.text.y = element_text(size=10, face="bold.italic"), axis.text = element_text(size=10), title=element_text(size=10, face="bold"), plot.title = element_text(hjust = 0.5, size = 16))

if(export.plot == TRUE & type.plot == "static" & export.format == "png") {
  png(file.path(plot_dir, paste0("abundance_plot", y.start, "-", y.end, ".png")), ...)
    plot(plot.abundance)
  dev.off()
  png(file.path(plot_dir, "credits.png"))

  dev.off()
}

if(export.plot == TRUE & type.plot == "static" & export.format == "pdf") {
  pdf(file.path(plot_dir, paste0("abundance_plot", y.start, "-", y.end, ".pdf")), ...)
    plot(plot.abundance)

  dev.off()
}

if (result == "plot" & type.plot == "static") {return(plot.abundance)}
if (result == "plot" & type.plot == "dynamic") {return(ggplotly(plot.abundance))}

if (result == "table") {return(sum.data)}

}

#' Phenological Plot
#'
#' Generates a boxplot based on phenological parameters (start_dates and end_dates) that are calculated by the estimation of the main parameters of the pollen season
#'
#' @param data A \code{data.frame} object including the general database where calculation of the pollen season must be applied in order to generate the phenological plot based on the start_dates and end_dates. This \code{data.frame} must include a first column in \code{Date} format and the rest of columns in \code{numeric} format belonging to each pollen type by column.
#' @param method A \code{character} string specifying the method applied to calculate the pollen season and the main parameters. The implemented methods that can be used are: \code{"percentage"}, \code{"logistic"}, \code{"moving"}, \code{"clinical"} or \code{"grains"}. A more detailed information about the different methods for defining the pollen season may be consulted in \code{\link{calculate_ps}} function.
#' @param n.types A \code{numeric} (\code{integer}) value specifying the number of the most abundant pollen types that must be represented in the pollen calendar. A more detailed information about the selection of the considered pollen types may be consulted in \strong{Details}. The \code{n.types} argument will be \code{15} types by default.
#' @param th.day A \code{numeric} value in order to calculate the number of days when this level is exceeded for each year and each pollen type. This value will be obtained in the results of the function. The \code{th.day} argument will be \code{100} by default.
#' @param perc A \code{numeric} value ranging \code{0_100}. This argument is valid only for \code{method = "percentage"}. This value represents the percentage of the total annual pollen included in the pollen season, removing \code{(100_perc)/2\%} of the total pollen before and after of the pollen season. The \code{perc} argument will be \code{95} by default.
#' @param def.season A \code{character} string specifying the method for selecting the best annual period to calculate the pollen season. The pollen seasons may occur within the natural year or otherwise may occur between two years which determines the best annual period considered. The implemented options that can be used are: \code{"natural"}, \code{"interannual"} or \code{"peak"}. The \code{def.season} argument will be \code{"natural"} by default. A more detailed information about the different methods for selecting the best annual period to calculate the pollen season may be consulted in \code{\link{calculate_ps}} function.
#' @param reduction A \code{logical} value. This argument is valid only for the \code{"logistic"} method. If \code{FALSE} the reduction of the pollen data is not applicable. If \code{TRUE} a reduction of the peaks above a certain level (\code{red.level} argument) will be carried out before the definition of the pollen season. The \code{reduction} argument will be \code{FALSE} by default. A more detailed information about the reduction process may be consulted in \code{\link{calculate_ps}} function.
#' @param red.level A \code{numeric} value ranging \code{0_1} specifying the percentile used as level to reduce the peaks of the pollen series before the definition of the pollen season. This argument is valid only for the \code{"logistic"} method. The \code{red.level} argument will be \code{0.90} by default, specifying the percentile 90.
#' @param derivative A \code{numeric} (\code{integer}) value belonging to options of \code{4}, \code{5} or \code{6} specifying the derivative that will be applied to calculate the asymptotes which determines the pollen season using the \code{"logistic"} method. This argument is valid only for the \code{"logistic"} method. The \code{derivative} argument will be \code{5} by default.
#' @param man A \code{numeric} (\code{integer}) value specifying the order of the moving average applied to calculate the pollen season using the \code{"moving"} method. This argument is valid only for the \code{"moving"} method. The \code{man} argument will be \code{11} by default.
#' @param th.ma A \code{numeric} value specifying the threshold used for the \code{"moving"} method for defining the beginning and the end of the pollen season. This argument is valid only for the \code{"moving"} method. The \code{th.ma} argument will be \code{5} by default.
#' @param n.clinical A \code{numeric} (\code{integer}) value specifying the number of days which must exceed a given threshold (\code{th.pollen} argument) for defining the beginning and the end of the pollen season. This argument is valid only for the \code{"clinical"} method. The \code{n.clinical} argument will be \code{5} by default.
#' @param window.clinical A \code{numeric} (\code{integer}) value specifying the time window during which the conditions must be evaluated for defining the beginning and the end of the pollen season using the \code{"clinical"} method. This argument is valid only for the \code{"clinical"} method. The \code{window.clinical} argument will be \code{7} by default.
#' @param window.grains A \code{numeric} (\code{integer}) value specifying the time window during which the conditions must be evaluated for defining the beginning and the end of the pollen season using the \code{"grains"} method. This argument is valid only for the \code{"grains"} method. The \code{window.grains} argument will be \code{5} by default.
#' @param th.pollen A \code{numeric} value specifying the threshold that must be exceeded during a given number of days (\code{n.clinical} or \code{window.grains} arguments) for defining the beginning and the end of the pollen season using the \code{"clinical"} or \code{"grains"} methods. This argument is valid only for the \code{"clinical"} or \code{"grains"} methods. The \code{th.pollen} argument will be \code{10} by default.
#' @param th.sum A \code{numeric} value specifying the pollen threshold that must be exceeded by the sum of daily pollen during a given number of days (\code{n.clinical} argument) exceeding a given daily threshold (\code{th.pollen} argument) for defining the beginning and the end of the pollen season using the \code{"clinical"} method. This argument is valid only for the \code{"clinical"} method. The \code{th.sum} argument will be \code{100} by default.
#' @param type A \code{character} string specifying the parameters considered according to a specific pollen type for calculating the pollen season using the \code{"clinical"} method. The implemented pollen types that may be used are: \code{"birch"}, \code{"grasses"}, \code{"cypress"}, \code{"olive"} or \code{"ragweed"}. As result for selecting any of these pollen types the parameters \code{n.clinical}, \code{window.clinical}, \code{th.pollen} and \code{th.sum} will be automatically adjusted for the \code{"clinical"} method. If no pollen types are specified (\code{type = "none"}), these parameters will be considered by the user. This argument is valid only for the \code{"clinical"} method. The \code{type} argument will be \code{"none"} by default.
#' @param interpolation A \code{logical} value. If \code{FALSE} the interpolation of the pollen data is not applicable. If \code{TRUE} an interpolation of the pollen series will be applied to complete the gaps with no data before the calculation of the pollen season. The \code{interpolation} argument will be \code{TRUE} by default. A more detailed information about the interpolation method may be consulted in \strong{Details}.
#' @param int.method A \code{character} string specifying the method selected to apply the interpolation method in order to complete the pollen series. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"spline"} or \code{"tseries"}. The \code{int.method} argument will be \code{"lineal"} by default.
#' @param type.plot A \code{character} string specifying the type of plot selected to show the phenological plot. The implemented types that may be used are: \code{"static"} generates a static \strong{ggplot} object and \code{"dynamic"} generates a dynamic \strong{plotly} object.
#' @param export.plot A \code{logical} value specifying if a phenological plot saved in the working directory will be required or not. If \code{FALSE} graphical results will only be displayed in the active graphics window. If \code{TRUE} graphical results will be displayed in the active graphics window and also a \emph{pdf} or \emph{png} file (according to the \code{export.format} argument) will be saved within the \emph{plot_AeRobiology} directory automatically created in the working directory. This argument is applicable only for \code{"static"} plots. The \code{export.plot} will be \code{FALSE} by default.
#' @param export.format A \code{character} string specifying the format selected to save the phenological plot. The implemented formats that may be used are: \code{"pdf"} and \code{"png"}. This argument is applicable only for \code{"static"} plots. The \code{export.format} will be \code{"pdf"} by default.
#' @param ... Other additional arguments may be used to customize the exportation of the plots using \emph{pdf} or \emph{png} files and therefore arguments from \code{\link[grDevices]{pdf}} and \code{\link[grDevices]{png}} functions (\pkg{grDevices} package) may be implemented. For example, for \emph{pdf} files the user may custom the arguments: \code{width}, \code{height}, \code{family}, \code{title}, \code{fonts}, \code{paper}, \code{bg}, \code{fg}, \code{pointsize...}; and for \emph{png} files the user may custom the arguments: \code{width}, \code{height}, \code{units}, \code{pointsize}, \code{bg}, \code{res...}
#'
#' @details This function allows to calculate the pollen season using five different methods which are described in \code{\link{calculate_ps}} function. After calculating the start_date and end_date for each pollen type and each year a phenological plot will be generated using the boxplot approach where axis x represents the time (Day of the Year) and axis y includes the considered pollen types. The phenological plot will be generated only for the specified number of the most abundant pollen types using the \code{n.types} argument by the user. The implemented methods for defining the pollen season includes the most commonly used methodologies (\emph{Nilsson and Persson, 1981}; \emph{Andersen, 1991}; \emph{Galan et al., 2001}; \emph{Ribeiro et al., 2007}; \emph{Cunha et al., 2015}, \emph{Pfaar et al., 2017}) and a new implemented method (see \code{\link{calculate_ps}} function).\cr
#' Pollen time series frequently have different gaps with no data and this fact could be a problem for the calculation of specific methods for defining the pollen season even providing incorrect results. In this sense by default a linear interpolation will be carried out to complete these gaps before to define the pollen season (\code{interpolation = TRUE}). Additionally, the users may select other interpolation methods using the \code{int.method} argument, as \code{"lineal"}, \code{"movingmean"}, \code{"spline"} or \code{"tseries"}. For more information to see the \code{\link{interpollen}} function.
#'
#' @return This function returns different results:\cr
#' If \code{export.plot = FALSE} graphical results will only be displayed in the active graphics window as \strong{ggplot} graph. Additional characteristics may be incorporated to the plot by \code{\link[ggplot2]{ggplot}} syntax (see \pkg{ggplot2} package).\cr
#' If \code{export.plot = TRUE} and \code{export.format = pdf} a \emph{pdf} file of the phenological plot will be saved within the \emph{plot_AeRobiology} directory created in the working directory. This option is applicable only for \code{"static"} plots. Additional characteristics may be incorporated to the exportation as \emph{pdf} file (see \pkg{grDevices} package).\cr
#' If \code{export.plot = TRUE} and \code{export.format = png} a \emph{png} file of the phenological plot will be saved within the \emph{plot_AeRobiology} directory created in the working directory. This option is applicable only for \code{"static"} plots. Additional characteristics may be incorporated to the exportation \emph{png} file (see \pkg{grDevices} package).\cr
#' If \code{type.plot = dynamic} graphical results will be displayed in the active Viewer window as \strong{plotly} graph. Additional characteristics may be incorporated to the plot \code{\link[plotly]{plotly}} syntax (see \pkg{plotly} package).
#' @references Andersen, T.B., 1991. A model to predict the beginning of the pollen season. \emph{Grana}, 30(1), pp.269_275.
#' @references Cunha, M., Ribeiro, H., Costa, P. and Abreu, I., 2015. A comparative study of vineyard phenology and pollen metrics extracted from airborne pollen time series. \emph{Aerobiologia}, 31(1), pp.45_56.
#' @references  Galan, C., Garcia_Mozo, H., Carinanos, P., Alcazar, P. and Dominguez_Vilches, E., 2001. The role of temperature in the onset of the \emph{Olea europaea} L. pollen season in southwestern Spain. \emph{International Journal of Biometeorology}, 45(1), pp.8_12.
#' @references Nilsson, S. and Persson, S., 1981. Tree pollen spectra in the Stockholm region (Sweden), 1973_1980. \emph{Grana}, 20(3), pp.179_182.
#' @references Pfaar, O., Bastl, K., Berger, U., Buters, J., Calderon, M.A., Clot, B., Darsow, U., Demoly, P., Durham, S.R., Galan, C., Gehrig, R., Gerth van Wijk, R., Jacobsen, L., Klimek, L., Sofiev, M., Thibaudon, M. and Bergmann, K.C., 2017. Defining pollen exposure times for clinical trials of allergen immunotherapy for pollen_induced rhinoconjunctivitis_an EAACI position paper. \emph{Allergy}, 72(5), pp.713_722.
#' @references Ribeiro, H., Cunha, M. and Abreu, I., 2007. Definition of main pollen season using logistic model. \emph{Annals of Agricultural and Environmental Medicine}, 14(2), pp.259_264.
#' @seealso \code{\link{calculate_ps}}, \code{\link{interpollen}}
#' @examples data("munich_pollen")
#' @examples iplot_pheno (munich_pollen, interpolation = FALSE)
#' @importFrom plotly layout
#' @importFrom ggplot2 aes coord_flip element_text geom_boxplot ggplot labs position_dodge scale_fill_manual scale_y_continuous theme theme_bw
#' @importFrom graphics plot
#' @importFrom grDevices dev.off pdf png
#' @importFrom lubridate is.POSIXt
#' @importFrom plotly ggplotly
#' @importFrom dplyr group_by summarise_all
#' @importFrom stats na.omit
#' @importFrom utils data
#' @importFrom tidyr %>%
#' @export
iplot_pheno <- function(data,
                        method = "percentage",
                        n.types = 15,
                        th.day = 100,
                        perc = 95,
                        def.season = "natural",
                        reduction = FALSE,
                        red.level = 0.90,
                        derivative = 5,
                        man = 11,
                        th.ma = 5,
                        n.clinical = 5,
                        window.clinical = 7,
                        window.grains = 5,
                        th.pollen = 10,
                        th.sum = 100,
                        type = "none",
                        interpolation = TRUE,
                        int.method = "lineal",
                        type.plot = "static",
                        export.plot = FALSE,
                        export.format = "pdf",...){
  
  base_dir <- if (nzchar(Sys.getenv("_R_CHECK_PACKAGE_NAME_"))) tempdir() else "."
  plot_dir <- file.path(base_dir, "plot_AeRobiology")
  
#############################################    CHECK THE ARGUMENTS       #############################

  if (isTRUE(export.plot)) {
    dir.create(plot_dir, recursive = TRUE, showWarnings = FALSE)
  }

  data<-data.frame(data)
  if(!is.data.frame(data)) stop ("Please include a data.frame: first column with date, and the rest with pollen types")

  if(method != "percentage" & method != "logistic" & method != "moving" & method != "clinical" & method != "grains") stop ("Please method only accept values: 'percentage', 'logistic', 'moving', 'clinical' or 'grains'")

  if(!is.numeric(n.types)) stop ("Please include only numeric values for 'n.types' argument indicating the number of pollen types which will be displayed")

  if(!is.numeric(th.day) | th.day < 0) stop ("Please include only numeric values >= 0 for th.day argument")

  if(!is.numeric(perc) | perc < 0 | perc > 100) stop ("Please include only numeric values between 0-100 for perc argument")

  if(def.season != "natural" & def.season != "interannual" & def.season != "peak") stop ("Please def.season only accept values: 'natural', 'interannual' or 'peak'")

  if(!is.logical(reduction)) stop ("Please include only logical values for reduction argument")

  if(!is.numeric(red.level) | red.level < 0 | red.level > 1) stop ("Please include only numeric values between 0-1 for red.level argument")

  if(derivative != 4 & derivative != 5 & derivative != 6) stop ("Please derivative only accept values: 4, 5 or 6")

  if(!is.numeric(man) | man < 0) stop ("Please include only numeric values > 0 for man argument")

  if(!is.numeric(th.ma) | th.ma < 0) stop ("Please include only numeric values > 0 for th.ma argument")

  if(!is.numeric(n.clinical) | n.clinical < 0) stop ("Please include only numeric values >= 0 for n.clinical argument")

  if(!is.numeric(window.clinical) | window.clinical < 0) stop ("Please include only numeric values >= 0 for window.clinical argument")

  if(!is.numeric(window.grains) | window.grains < 0) stop ("Please include only numeric values >= 0 for window.grains argument")

  if(!is.numeric(th.pollen) | th.pollen < 0) stop ("Please include only numeric values >= 0 for th.pollen argument")

  if(!is.numeric(th.sum) | th.sum < 0) stop ("Please include only numeric values >= 0 for th.sum argument")

  if(type != "none" & type != "birch" & type != "grasses" & type != "cypress" & type != "olive" & type != "ragweed") stop ("Please def.season only accept values: 'none', 'birch', 'grasses', 'cypress', 'olive' or 'ragweed'")

  if(!is.logical(interpolation)) stop ("Please include only logical values for interpolation argument")

  if(int.method != "lineal" & int.method != "movingmean" & int.method != "spline" & int.method != "tseries") stop ("Please int.method only accept values: 'lineal', 'movingmean', 'spline' or 'tseries'")

  if(type.plot != "static" & type.plot != "dynamic") stop ("Please type.plot only accept values: 'static' or 'dynamic'")

  if(!is.logical(export.plot)) stop ("Please include only logical values for export.plot argument")

  if(export.format != "pdf" & export.format != "png") stop ("Please export.format only accept values: 'pdf' or 'png'")

  if(class(data[,1])[1]!="Date" & !is.POSIXt(data[,1])) {stop("Please the first column of your data must be the date in 'Date' format")}
  data[,1]<-as.Date(data[,1])

options(warn = -1)

#############################################    SELECT ABUNDANT TYPES       #############################

data <- data.frame(date = data[ ,1], year = as.numeric(strftime(data[ ,1], "%Y")), data[ ,-1])

#types <- ddply(data[ ,-1], "year", function(x) colSums(x[-1], na.rm = T)) [-1] %>%
  #apply(., 2, function(x) mean(x, na.rm = T)) %>% .[order(., decreasing = TRUE)] %>%
  #names(.) %>%
  #.[1:n.types]
types <- data.frame(data[ ,-1] %>%
                      group_by(year) %>%
                      summarise_all(sum, na.rm = TRUE))[-1] %>%
  apply(., 2, function(x) mean(x, na.rm = T)) %>% .[order(., decreasing = TRUE)] %>%
  names(.) %>%
  .[1:n.types]

data <- data[ ,which(colnames(data) %in% c("date", types))]

#############################################    CALCULATION OF THE POLLEN SEASON       #############################

list.ps <- calculate_ps(data = data, method = method, th.day = th.day, perc = perc, def.season = def.season, reduction = reduction, red.level = red.level, derivative = derivative, man = man, th.ma = th.ma, n.clinical = n.clinical, window.clinical = window.clinical, window.grains = window.grains, th.pollen = th.pollen, th.sum = th.sum, type = type, interpolation = interpolation, int.method = int.method, result = "list", plot = FALSE, export.plot = FALSE, export.result = FALSE)

season.data <- list.ps
type.name <- colnames(data)[-1]

dat.plot <- data.frame(); mean.st <- data.frame()

for(t in 1:(length(type.name))){
  dat.type <- season.data[[type.name[t]]]

  n <- NROW(dat.type)
  if (!is.finite(n) || n < 1) next
  n <- as.integer(n)
  
  dat.plot <- rbind(
    dat.plot,
    data.frame(
      phen  = c(rep.int(0, n), rep.int(1, n)),
      j.days = c(dat.type$st.jd, dat.type$en.jd),
      type  = type.name[t]
    )
  )
  

  mean.st <- rbind(mean.st, data.frame(type = type.name[t], mean.st = mean(dat.type$st.jd, na.rm = TRUE)))

}

  mean.st$mean.st[is.nan(mean.st$mean.st)] <- NA; mean.st <- na.omit(mean.st)#; mean.st <- mean.st[order(mean.st$mean.st), 1]

  dat.plot$type <- factor(dat.plot$type, levels = as.character(mean.st[order(mean.st$mean.st), 1]), ordered = T)

  dat.plot$phen[dat.plot$phen == 0] <- "Start-date"; dat.plot$phen[dat.plot$phen == 1] <- "End-date"

  dat.plot$phen <- factor(dat.plot$phen, levels = c("Start-date", "End-date"), ordered = T)

pheno.plot <- ggplot(data = na.omit(dat.plot), aes(y = j.days, x = type)) +
  #stat_boxplot(geom = "errorbar", width = 0.2)+
  geom_boxplot(aes(fill = phen), width = 1, varwidth = TRUE, position = position_dodge(width = 0))+
  labs(y = "Day of the year", x = "", title = "Phenological parameters", fill = "Phenophase")+
  scale_fill_manual(labels = c("Start-date", "End-date"), values = c("tan1", "lightskyblue")) +
  scale_y_continuous(breaks = seq(0,365,25))+
  coord_flip()+
  theme_bw()+
  theme(text = element_text(size = 14), legend.position = "bottom", axis.text.y = element_text(face="italic"))

if(export.plot == TRUE & type.plot == "static" & export.format == "png") {
  if(method == "percentage") {png(file.path(plot_dir, paste0("pheno_plot_", method, perc, ".png")), ...); plot(pheno.plot); dev.off(); png(file.path(plot_dir, "credits.png")); dev.off()}
  if(method == "logistic") {png(paste0("plot_AeRobiology/pheno_plot_",method,derivative,".png"), ...); plot(pheno.plot); dev.off(); png(file.path(plot_dir, "credits.png")); dev.off()}
  if(method == "moving") {png(paste0("plot_AeRobiology/pheno_plot_",method,man,"_",th.ma,".png"), ...); plot(pheno.plot); dev.off(); png(file.path(plot_dir, "credits.png")); dev.off()}
  if(method == "clinical") {png(paste0("plot_AeRobiology/pheno_plot_",method,n.clinical,"_",window.clinical+1,"_",th.pollen,"_",th.sum,".png"), ...); plot(pheno.plot); dev.off(); png(file.path(plot_dir, "credits.png")); dev.off()}
  if(method == "grains") {png(paste0("plot_AeRobiology/pheno_plot_",method,window.grains+1,"_",th.pollen,".png"), ...); plot(pheno.plot); dev.off(); png(file.path(plot_dir, "credits.png")); dev.off()}
}

if(export.plot == TRUE & type.plot == "static" & export.format == "pdf") {
  if(method == "percentage") {pdf(file.path(plot_dir, paste0("pheno_plot_", method, perc, ".pdf")), ...); plot(pheno.plot); dev.off()}
  if(method == "logistic") {pdf(paste0("plot_AeRobiology/pheno_plot_",method,derivative,".pdf"), ...); plot(pheno.plot); dev.off()}
  if(method == "moving") {pdf(paste0("plot_AeRobiology/pheno_plot_",method,man,"_",th.ma,".pdf"), ...); plot(pheno.plot); dev.off()}
  if(method == "clinical") {pdf(paste0("plot_AeRobiology/pheno_plot_",method,n.clinical,"_",window.clinical+1,"_",th.pollen,"_",th.sum,".pdf"), ...); plot(pheno.plot); dev.off()}
  if(method == "grains") {pdf(paste0("plot_AeRobiology/pheno_plot_",method,window.grains+1,"_",th.pollen,".pdf"), ...); plot(pheno.plot); dev.off()}
}

if (type.plot == "static") {return(pheno.plot)}

options(warn = 0)

if (type.plot == "dynamic") {
  ggplotly(pheno.plot) %>%
  layout(legend = list(orientation = 'v', x = -0.2, y = -0.3))
  }
}

#'Plotting hourly patterns with heatplot
#'
#'Function to plot pollen data expressed in concentrations with time resolution higher than 1 day (e.g. hourly, bi-hourly concentrations). As heatplot.
#'
#'@param data A \code{data.frame} object with the structure \code{long}. Where the first two columns are \code{factors} indicating the \code{pollen} and the \code{location}. The 3 and 4 columns are \code{POSIXct}, showing the hour. Where the third column is the beguinning of the concentration \code{from} and the fourth column is the end time of the concentrtion data \code{to}. The fifth column shows the concentrations of the different pollen types as \code{numeric}. Please see the example 3-hourly data from the automatic pollen monitor BAA500 from Munich and Viechtach in Bavaria (Germany) \code{data("POMO_pollen")}, supplied by ePIN Network supported by the Bavarian Government.
#'@param locations A \code{logical} object with the specification if the different locations will be displayed in the plot. Argument only used when \code{result == "plot"}. By default, \code{locations = FALSE}.
#'@param low.col A \code{character} object with the specification of the color of the lowest value for the scale. By default, \code{low.col = "blue"}.
#'@param mid.col A \code{character} object with the specification of the color of the medium value for the scale. By default, \code{mid.col = "white"}.
#'@param high.col A \code{character} object with the specification object with the specification of the color of the highest value for the scale. By default, \code{high.col = "red"}.
#'@return The function returns an object or a list of objects of class \pkg{ggplot2}.
#'@references Oteros, J., Pusch, G., Weichenmeier, I., Heimann, U., Mueller, R., Roeseler, S., ... & Buters, J. T. (2015). Automatic and online pollen monitoring. \emph{International archives of allergy and immunology}, 167(3), 158-166.
#'@examples data("POMO_pollen")
#'@examples plot_heathour(POMO_pollen)
#'@importFrom ggplot2 ggplot scale_fill_brewer geom_tile scale_fill_gradientn
#'@importFrom dplyr %>%
#'@export
plot_heathour <-
  function (data,
            locations = FALSE,
            low.col = "blue",
            mid.col = "white",
            high.col = "red") {
    data <- data.frame(data)
    if (!is.data.frame(data)){
      stop (
        "Please include a data.frame: first column with factor indicating the pollen, second column with factor indicating the locaiton, third column with POSIXct indicating the (from), fourth column with POSIXct indicating the (to) and fifth column with numbers indicating the concentration"
      )}

    if (!is.logical(locations)){
      stop ("Please include only logical values for locations argument")}
    if (!is.character(low.col)){
      stop ("Please include only character values for low.col argument, introduce valid color names.")}
    if (!is.character(mid.col)){
      stop ("Please include only character values for mid.col argument, introduce valid color names.")}
    if (!is.character(high.col)){
      stop ("Please include only character values for high.col argument, introduce valid color names.")}

    frame3 <- plot_hour(data, result = "table", locations = locations)

    frame3$location <- as.character(frame3$location)

    summaryhour <-
      frame3 %>% group_by(pollen, location, Hour) %>% summarise(percent = mean(percent, na.rm = TRUE))


    if (locations == TRUE) {
      pollenlist2 <- list()
      for (loca in 1:length(unique(summaryhour$location))) {
        locat <- unique(summaryhour$location)[loca]
        temp <- summaryhour[which(summaryhour$location == locat), ]
        plo <- ggplot(temp, aes(x = Hour, y = pollen, fill = percent)) +
          geom_tile() +
          scale_fill_gradientn(colours = c(low.col, mid.col, high.col),
                               limits = c(0, NA)) +
          labs(x = "", y = "", title = locat) +
          theme(axis.text.y = element_text(face = "italic")) +
          theme(axis.text.x = element_text(angle = 45, hjust = 1))
        pollenlist2[[loca]] <- plo
      }
      return(pollenlist2)
    } else{
      temp<-summaryhour
      plott <- ggplot(temp, aes(x = Hour, y = pollen, fill = percent)) +
        geom_tile() +
        scale_fill_gradientn(colours = c(low.col, mid.col, high.col),
                             limits = c(0, NA)) +
        labs(x = "", y = "", title = "") +
        theme(axis.text.y = element_text(face = "italic")) +
        theme(axis.text.x = element_text(angle = 45, hjust = 1))
      return(plott)
    }
  }

#' Plotting the Amplitude of Several Pollen Seasons.
#'
#' Function to plot the pollen data amplitude during several seasons: daily average pollen concentration over the study period, maximum pollen concentration of each day over the study period and minimum pollen concentration of each day value over the study period. It is possible to plot the relative abundance per day and smoothing the pollen season by calculating a moving average.
#'
#' @param data A \code{data.frame} object. This \code{data.frame} should include a first column in format \code{Date} and the rest of columns in format \code{numeric} belonging to each pollen type by column.
#' @param pollen A \code{character} string with the name of the particle to show. This \code{character} must match with the name of a column in the input database. This is a mandatory argument.
#' @param mave An \code{integer} value specifying the order of the moving average applied to the data. By default, \code{mave = 1}.
#' @param normalized A \code{logical} value specifying if the visualization shows real pollen data (\code{normalized = FALSE}) or the percentage of every day over the whole pollen season (\code{normalized = TRUE}). By default, \code{normalized = FALSE}.
#' @param interpolation A \code{logical} value specifying if the visualization shows the gaps in the inputs data (\code{interpolation = FALSE}) or if an interpolation method is used for filling the gaps (\code{interpolation = TRUE}). By default, \code{interpolation = TRUE}.
#' @param int.method A \code{character} string with the name of the interpolation method to be used. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"tseries"} or \code{"spline"}. By default, \code{int.method = "lineal"}.
#' @param export.plot A \code{logical} value specifying if a plot will be exported or not. If \code{FALSE} graphical results will only be displayed in the active graphics window. If \code{TRUE} graphical results will be displayed in the active graphics window and also one pdf/png file will be saved within the \emph{plot_AeRobiology} directory automatically created in the working directory. By default, \code{export.plot = FALSE}.
#' @param export.format A \code{character} string specifying the format selected to save the plot. The implemented formats that may be used are: \code{"pdf"} or \code{"png"}. By default, \code{export.format = "pdf"}.
#' @param axisname A \code{character} string specifying the title of the y axis. By default, \code{axisname =  "Pollen grains / m3"}.
#' @param color.plot A \code{character} string. The argument defines the color to fill the plot. Will be \code{"orange2"} by default.
#' @param ... Other additional arguments may be used to customize the exportation of the plots using \code{"pdf"} or \code{"png"} files and therefore arguments from functions \code{\link[grDevices]{pdf}} and  \code{\link[grDevices]{png}} may be implemented. For example, for pdf files the user may custom the arguments: width, height, family, title, fonts, paper, bg, fg, pointsize...; and for png files the user may custom the arguments: width, height, units, pointsize, bg, res...
#' @return This function returns plot of class \pkg{ggplot2}. User are able to customize the output as a \pkg{ggplot2} object.
#' @seealso \code{\link{calculate_ps}}; \code{\link{plot_summary}}
#' @examples data("munich_pollen")
#' @examples plot_normsummary(munich_pollen, pollen = "Betula", interpolation = FALSE, export.plot = FALSE)
#' @importFrom graphics plot
#' @importFrom utils data
#' @importFrom ggplot2 aes element_text geom_line geom_ribbon ggplot labs scale_colour_manual scale_x_date theme theme_classic
#' @importFrom grDevices dev.off pdf png
#' @importFrom lubridate is.POSIXt yday year
#' @importFrom scales date_format
#' @importFrom stats aggregate
#' @importFrom tidyr %>%
#' @export
plot_normsummary<-function (data,
                        pollen,
                        mave=1,
                        normalized=FALSE,
                        interpolation = TRUE,
                        int.method = "lineal",
                        export.plot = FALSE,
                        export.format = "pdf",
                        color.plot="orange2",
                        axisname="Pollen grains / m3",
                        ...){

  # Sys.setlocale(category = "LC_ALL", locale="english")

  #############################################    CHECK THE ARGUMENTS       #############################

  if(export.plot == TRUE){ifelse(!dir.exists(file.path("plot_AeRobiology")), dir.create(file.path("plot_AeRobiology")), FALSE)}
  data<-data.frame(data)
  if(!is.data.frame(data)) stop ("Please include a data.frame: first column with date, and the rest with pollen types")

  if(!is.character(pollen)) stop ("Please include only character values for 'pollen'")

  if(!is.logical(export.plot)) stop ("Please include only logical values for export.plot argument")

  if(export.format != "pdf" & export.format != "png") stop ("Please export.format only accept values: 'pdf' or 'png'")

  if(class(data[,1])[1]!="Date" & !is.POSIXt(data[,1])) {stop("Please the first column of your data must be the date in 'Date' format")}
  data[,1]<-as.Date(data[,1])

  if(!is.logical(interpolation)) stop ("Please include only logical values for interpolation argument")

  if(!is.character(axisname)) stop ("Please include only character values for 'axisname'")

  if(!is.character(color.plot)) stop ("Please include only character values indicating the name of a colour for 'color.plot'")

  # if(int.method != "lineal" & int.method != "movingmean" & int.method != "spline") stop ("Please int.method only accept values: 'lineal', 'movingmean' or 'spline'")

  ncolpollen<-which( colnames(data)==pollen)
  data<-data[,c(1,ncolpollen)]


  if(interpolation == TRUE){data <- interpollen(data, method = int.method)}
  data[, 1] <- as.Date(data[, 1])
  colnames(data)[1]<-"Date"
  data$DOY<-yday(data[, "Date"])
  data$Year<-year(data[, "Date"])

  sum<-aggregate(data[,pollen], by=list(data[,"Year"]), FUN=sum, na.rm=T)
  colnames(sum)[1]<-"Year"
  data<-merge(data,sum,by="Year")
  colnames(data)[length(data)]<-"sum"

  max<-aggregate(data[,pollen], by=list(data[,"Year"]), FUN=max, na.rm=T)
  colnames(max)[1]<-"Year"
  data<-merge(data,max,by="Year")
  colnames(data)[length(data)]<-"max"

  min<-aggregate(data[,pollen], by=list(data[,"Year"]), FUN=min, na.rm=T)
  colnames(min)[1]<-"Year"
  data<-merge(data,min,by="Year")
  colnames(data)[length(data)]<-"min"

  data$Norm<-data[,pollen]*100/data$sum
  data$noNorm<-data[,pollen]


  if (normalized == TRUE){
    meant<-aggregate(data[,"Norm"], by=list(data[,"DOY"]), FUN=mean, na.rm=T)

    mint<-aggregate(data[,"Norm"], by=list(data[,"DOY"]), FUN=min, na.rm=T)
    maxt<-aggregate(data[,"Norm"], by=list(data[,"DOY"]), FUN=max, na.rm=T)

    frame<-data.frame(DOY=meant$Group.1,Mean=meant$x,Min=mint$x,Max=maxt$x, date=as.Date(meant$Group.1, origin = "2000-01-01"))

    frame<-frame[!is.infinite(frame[,3]),]
    frame$Mean<-ma(frame$Mean,man=mave)
    frame$Min<-ma(frame$Min,man=mave)
    frame$Max<-ma(frame$Max,man=mave)

    plot.summary.norm<-ggplot(data = frame, aes(x = date, y = Mean)) +
      labs(x="", y="percentage (%)", title=pollen) +
      geom_ribbon(aes(ymin=Min,ymax=Max),alpha=0.3,fill=color.plot)+
      geom_line(size = 0.8)+
      scale_colour_manual("Parameters",values=c("black"))+
      theme_classic()+
      theme(text = element_text(size = 13), axis.text.x = element_text(size = 13), axis.text.y = element_text(size = 13))+
      scale_x_date(labels=date_format("%b"), date_breaks = "1 month")+
      theme(plot.title=element_text(face="bold.italic", size=13))


  } else {
    meant<-aggregate(data[,"noNorm"], by=list(data[,"DOY"]), FUN=mean, na.rm=T)
    mint<-aggregate(data[,"noNorm"], by=list(data[,"DOY"]), FUN=min, na.rm=T)
    maxt<-aggregate(data[,"noNorm"], by=list(data[,"DOY"]), FUN=max, na.rm=T)

    frame<-data.frame(DOY=meant$Group.1,Mean=meant$x,Min=mint$x,Max=maxt$x, date=as.Date(meant$Group.1, origin = "2000-01-01"))

    frame<-frame[!is.infinite(frame[,3]),]
    frame$Mean<-ma(frame$Mean,man=mave)
    frame$Min<-ma(frame$Min,man=mave)
    frame$Max<-ma(frame$Max,man=mave)

    plot.summary.norm<-ggplot(data = frame, aes(x = date, y = Mean)) +
      labs(x="", y=axisname, title=pollen) +
      geom_ribbon(aes(ymin=Min,ymax=Max),alpha=0.3,fill=color.plot)+
      geom_line(size = 0.8)+
      scale_colour_manual("Parameters",values=c("black"))+
      theme_classic()+
      theme(text = element_text(size = 13), axis.text.x = element_text(size = 13), axis.text.y = element_text(size = 13))+
      scale_x_date(labels=date_format("%b"), date_breaks = "1 month")+
      theme(plot.title=element_text(face="bold.italic", size=13))


  }




  if(export.plot == TRUE  & export.format == "png") {
    png(paste0("plot_AeRobiology/plot_normsummary_", pollen,".png"), ...)
    plot(plot.summary.norm)
    dev.off()
    png(paste0("plot_AeRobiology/credits.png"))

    dev.off()
  }

  if(export.plot == TRUE  & export.format == "pdf") {
    pdf(paste0("plot_AeRobiology/plot_normsummary_", pollen,".pdf"), ...)
    plot(plot.summary.norm)

    dev.off()
  }

  return(plot.summary.norm)

}

#'Monthly Pollen Heatmap
#'
#'Function to plot monthly sums of daily pollen concentrations as a heatmap. Months
#'are displayed in the x axis and years in the y axis for one selected pollen type.
#'
#'@param data A \code{data.frame} object. The first column must be in \code{Date}
#'format and pollen types must be provided as numeric columns. If the data include
#'several locations, one column can identify the location.
#'@param pollen.type A \code{character} string with the name of the pollen type to
#'be plotted. This name must match one numeric column in \code{data}.
#'@param location A \code{character} string with the location to be selected. If
#'\code{NULL} and a location column is detected, the first location in the data is
#'used. If the data do not include a location column, this argument is ignored.
#'@param location.col A \code{character} string with the name of the column
#'containing the locations. If \code{NULL}, common names such as \code{"location"},
#'\code{"city"} or \code{"station"} are automatically detected.
#'@param start.month A \code{numeric} value ranging \code{1_12} specifying the
#'first month shown in the x axis. The \code{start.month} argument will be
#'\code{1} by default.
#'@param color.A A \code{character} object with the specification of the color of
#'the lowest value for the scale. By default, \code{color.A = "yellow"}.
#'@param color.B A \code{character} object with the specification of the color of
#'the highest value for the scale. By default, \code{color.B = "red"}.
#'@param result A \code{character} object with the definition of the object to be
#'produced by the function. If \code{result == "plot"}, the function returns an
#'object of class \pkg{ggplot2}; if \code{result == "table"}, the function returns
#'a \pkg{data.frame} with the monthly sums. By default, \code{result = "plot"}.
#'@return If \code{result == "plot"}, the function returns an object of class
#'\pkg{ggplot2}; if \code{result == "table"}, the function returns a
#'\pkg{data.frame} with the monthly sums.
#'@examples data("munich_pollen")
#'@examples plot_monthly_heatmap(munich_pollen, pollen.type = "Betula")
#'@examples plot_monthly_heatmap(munich_pollen, pollen.type = "Poaceae", start.month = 6)
#'@importFrom ggplot2 aes element_text geom_tile ggplot labs scale_fill_gradient scale_x_discrete scale_y_continuous theme theme_bw
#'@importFrom lubridate is.POSIXt
#'@export
plot_monthly_heatmap <- function(data,
                                 pollen.type,
                                 location = NULL,
                                 location.col = NULL,
                                 start.month = 1,
                                 color.A = "yellow",
                                 color.B = "red",
                                 result = "plot") {

  data <- data.frame(data)

  if(!is.data.frame(data)) stop ("Please include a data.frame: first column with date, and the rest with pollen types")
  if(missing(pollen.type)) stop ("Please include one pollen type as character value for pollen.type argument")
  if(!is.character(pollen.type) | length(pollen.type) != 1) stop ("Please include one pollen type as character value for pollen.type argument")
  if(!is.null(location) & (!is.character(location) | length(location) != 1)) stop ("Please include one location as character value for location argument")
  if(!is.null(location.col) & (!is.character(location.col) | length(location.col) != 1)) stop ("Please include one column name as character value for location.col argument")
  if(!is.numeric(start.month) | length(start.month) != 1 | start.month < 1 | start.month > 12) stop ("Please include only numeric values between 1-12 for start.month argument")
  if(!is.character(color.A) | length(color.A) != 1) stop ("Please include only character values for color.A argument, introduce valid color names.")
  if(!is.character(color.B) | length(color.B) != 1) stop ("Please include only character values for color.B argument, introduce valid color names.")
  if(result != "plot" & result != "table") stop ("Please result only accept values: 'table' or 'plot'")
  if(class(data[,1])[1]!="Date" & !is.POSIXt(data[,1])) {stop("Please the first column of your data must be the date in 'Date' format")}
  if(!pollen.type %in% colnames(data)) stop ("Please pollen.type must match one column name in data")
  if(!is.numeric(data[, pollen.type])) stop ("Please pollen.type must match a numeric column in data")

  tryCatch(grDevices::col2rgb(color.A), error = function(e) stop("Please introduce a valid color name for color.A argument"))
  tryCatch(grDevices::col2rgb(color.B), error = function(e) stop("Please introduce a valid color name for color.B argument"))

  data[,1] <- as.Date(data[,1])

  if(is.null(location.col)){
    location.candidates <- c("location", "Location", "city", "City", "station", "Station", "site", "Site")
    location.col <- location.candidates[location.candidates %in% colnames(data)][1]
  } else if(!location.col %in% colnames(data)){
    stop("Please location.col must match one column name in data")
  }

  selected.location <- NA
  if(!is.na(location.col)){
    data[, location.col] <- as.character(data[, location.col])
    if(is.null(location)){
      selected.location <- unique(data[, location.col])[1]
    } else {
      selected.location <- location
    }
    if(!selected.location %in% data[, location.col]) stop ("Please location must match one value in the location column")
    data <- data[which(data[, location.col] == selected.location), ]
  }

  if(nrow(data) == 0) stop("No data available for the selected location")

  month.order <- c(start.month:12, 1:(start.month - 1))
  if(start.month == 1) month.order <- 1:12

  heat.data <- data.frame(
    date = data[,1],
    pollen = data[, pollen.type],
    year = as.numeric(strftime(data[,1], "%Y")),
    month = as.numeric(strftime(data[,1], "%m"))
  )

  sum_fun <- function(x) {
    if(all(is.na(x))) return(NA)
    sum(x, na.rm = TRUE)
  }

  monthly <- aggregate(pollen ~ year + month, data = heat.data, FUN = sum_fun, na.action = stats::na.pass)
  colnames(monthly) <- c("year", "month", "sum.pollen")
  monthly$month.label <- factor(month.abb[monthly$month], levels = month.abb[month.order])
  monthly$year <- as.numeric(monthly$year)
  monthly <- monthly[order(monthly$year, match(monthly$month, month.order)), ]
  rownames(monthly) <- NULL

  if(!is.na(selected.location)){
    monthly$location <- selected.location
  }

  if(result == "table"){
    return(monthly)
  }

  plot.title <- pollen.type
  if(!is.na(selected.location)){
    plot.title <- paste(pollen.type, selected.location, sep = " - ")
  }

  ggplot(monthly, aes(x = month.label, y = year, fill = sum.pollen)) +
    geom_tile(color = "white") +
    scale_fill_gradient(low = color.A, high = color.B, na.value = "grey90") +
    scale_x_discrete(drop = FALSE) +
    scale_y_continuous(breaks = sort(unique(monthly$year))) +
    labs(x = "", y = "", fill = "Monthly sum", title = plot.title) +
    theme_bw() +
    theme(axis.text.x = element_text(angle = 45, hjust = 1))
}

context("plot_monthly_heatmap")

test_that("plot_monthly_heatmap aggregates monthly sums for selected location", {
  dates <- seq(as.Date("2025-01-01"), as.Date("2025-02-03"), by = "day")
  heat_data <- rbind(
    data.frame(date = dates, location = "A", Betula = 1),
    data.frame(date = dates, location = "B", Betula = 2)
  )

  default_table <- plot_monthly_heatmap(
    heat_data,
    pollen.type = "Betula",
    result = "table"
  )

  selected_table <- plot_monthly_heatmap(
    heat_data,
    pollen.type = "Betula",
    location = "B",
    result = "table"
  )

  expect_true(all(default_table$location == "A"))
  expect_true(all(selected_table$location == "B"))
  expect_equal(default_table$sum.pollen[default_table$month == 1], 31)
  expect_equal(default_table$sum.pollen[default_table$month == 2], 3)
  expect_equal(selected_table$sum.pollen[selected_table$month == 1], 62)
  expect_equal(selected_table$sum.pollen[selected_table$month == 2], 6)
})

test_that("plot_monthly_heatmap uses the selected first month", {
  dates <- seq(as.Date("2025-01-01"), as.Date("2025-12-31"), by = "day")
  heat_data <- data.frame(date = dates, Betula = 1)

  result <- plot_monthly_heatmap(
    heat_data,
    pollen.type = "Betula",
    start.month = 6,
    result = "table"
  )

  expect_equal(as.character(result$month.label[1]), "Jun")
  expect_equal(result$year[result$month == 1], 2025)
})

#'Pollen Season Plot
#'
#'Function to plot the main pollen season of a single pollen type.
#'
#'@param data A \code{data.frame} object including the general database where interpollation must be performed. This \code{data.frame} must include a first column in \code{Date} format and the rest of columns in \code{numeric} format. Each column must contain information of one pollen type. It is not necessary to insert missing gaps; the function will automatically detect them.
#'@param pollen.type A \code{character} string specifying the name of the pollen type which will be plotted. The name must be exactly the same that appears in the column name. Mandatory argument with no default.
#'@param year A \code{numeric (interger)} value specifying the season to be plotted. The season does not necessary fit a natural year. See \code{\link{calculate_ps}} for more details. Mandatory argument with no default.
#'@param days A \code{numeric (interger)} specifying the number of days beyond each side of the main pollen season that will be represented. The \code{days} argument will be \code{30} by default.
#'@param fill.col A \code{character} string specifying the name of the color to fill the main pollen season (Galan et al., 2017) in the plot. See \code{\link[ggplot2]{ggplot}} function for more details. The \code{fill.col} argument will be \code{"turquoise4"} by default.
#'@param int.method A \code{character} string specifying the method selected to apply the interpolation method in order to complete the pollen series. The implemented methods that may be used are: \code{"lineal"},  \code{"movingmean"}, \code{"spline"} or  \code{"tseries"}. See \code{\link{interpollen}} function for more details. The \code{int.method} argument will be \code{"lineal"} by default.
#'@param axisname A \code{character} string or an expression specifying the y axis title of the plot. The \code{axisname} argument will be \code{expression(paste("Pollen grains / m" ^ "3"))} by default.
#'@param ... Other arguments passed on to the pollen season calculation as specified in \code{\link{calculate_ps}} function.
#'@details \code{plot_ps} function is designed to easily plot the main pollen season (Galan et al., 2017). The pre_peak period and the post_peak period are marked with different color intensity in the graph. The user must choose a single pollen type and season to plot.
#'@return The function returns an object of class \code{\link[ggplot2]{ggplot}} with a graphical representation of the main pollen season of the selected pollen type. The pre_peak and post_peak periods are marked with different color intensity.
#'@references Galan, C., Ariatti, A., Bonini, M., Clot, B., Crouzy, B., Dahl, A., Fernandez_Gonzalez, D., Frenguelli, G., Gehrig, R., Isard, S., Levetin, E., Li, D.W., Mandrioli, P., Rogers, C.A., Thibaudon, M., Sauliene, I., Skjoth, C., Smith, M., Sofiev, M., 2017. Recommended terminology for aerobiological studies. Aerobiologia (Bologna). 293_295.
#'@seealso \code{\link{calculate_ps}}, \code{\link{interpollen}}, \code{\link[ggplot2]{ggplot}}.
#'@examples data("munich_pollen")
#'@examples plot_ps(munich_pollen, year = 2013, pollen.type = "Betula")
#'@importFrom utils data
#'@importFrom scales date_format
#'@importFrom lubridate is.POSIXt year
#'@importFrom ggplot2 aes element_blank element_text geom_area geom_line ggplot labs scale_x_date theme theme_classic ylab
#'@importFrom graphics plot
#'@importFrom grDevices dev.off png
#'@importFrom tidyr %>%
#'@export
plot_ps <- function(data,
           pollen.type = NULL ,
           year = NULL ,
           days = 30,
           fill.col = "turquoise4",
           int.method="lineal",
           axisname= expression(paste("Pollen grains / m" ^ "3")),
           ...) {
    if(!inherits(axisname, "expression") & !inherits(axisname, "character")){stop("axisname: Please, insert only a character string or an expression")}
    if (!is.character(fill.col)) {
      stop("fill.col: Please, insert only a character string defining an existing color")
    }
  data<-data.frame(data)
    if (!is.data.frame(data) &
        !is.null(data)) {
      stop ("Please include a data.frame: first column with date, and the rest with pollen types")
    }
    if (is.null(year)) {
      stop("Please, select a year to plot")
    }
    if (is.null(pollen.type)) {
      stop("Please, select a pollen.type to plot")
    }
    if (!is.character(pollen.type)) {
      stop("pollen.type: Please, insert only a character string")
    }
    if (!is.numeric(year)) {
      stop("year: Please, insert only a number")
    }
    if (!is.numeric(days)) {
      stop("days: Please, insert only a number bigger than 1")
    }
    if (days < 1 | days %% 1 != 0 ) {
      stop("days: Please, insert only an entire number bigger than 1")
    }
    if(class(data[,1])[1]!="Date" & !is.POSIXt(data[,1])) {stop("Please the first column of your data must be the date in 'Date' format")}
    data[,1]<-as.Date(data[,1])
    namecolumn <- colnames(data)[-1]
    years <- unique(year(data[, 1]))
    if (!(pollen.type %in% namecolumn)) {
      stop(
        "pollen.type: Please, insert only a pollen type which is in your database (type the exact name)"
      )
    }
    if (!(year %in% years)) {
      stop("pollen.type: Please, insert only a year which is in your database")
    }
    datename <- colnames(data)[1]
    dataframe <- data[, c(datename, pollen.type)]
    referencetable <-
      calculate_ps(data = dataframe,
                   plot = FALSE,
                   export.result = FALSE,
                   int.method = int.method,
                   interpolation = TRUE, ...)
    dataframe <- interpollen(data = dataframe, method=int.method, plot = FALSE)

    Start <-
      referencetable[which(referencetable$seasons == year), 3] - (days)
    End <-
      referencetable[which(referencetable$seasons == year), 5] + (days)

    StartMPS <-
      referencetable[which(referencetable$seasons == year), 3]
    EndMPS <-
      referencetable[which(referencetable$seasons == year), 5]
    Peak <-
      referencetable[which(referencetable$seasons == year), 11]

    dataplot <-
      dataframe[which(dataframe[, 1] >= Start &
                        dataframe[, 1] <= End),]
    colnames(dataplot) <- c("date", "pollen")
    Preframe <- dataplot
    Postframe <- dataplot
    Preframe[which(Preframe$date < StartMPS |
                     Preframe$date > Peak), 2] <- NA
    Postframe[which(Postframe$date < Peak |
                      Preframe$date > EndMPS), 2] <- NA
    graph <- ggplot() +
      geom_area(data = dataplot,
                aes(date, pollen),
                color = "grey90",
                fill = "grey90") +
      geom_area(data = Preframe, aes(date, pollen), fill = fill.col) +
      geom_area(data = Postframe,
                aes(date, pollen),
                fill = fill.col,
                alpha = 0.5) +
      geom_line(data = dataplot,
                aes(date, pollen),
                color = "grey10",
                size = 0.3) +
      scale_x_date(labels = date_format("%d-%b"), breaks = '7 days') +
      theme_classic() +
      labs(title = paste(pollen.type, year)) +
      ylab(axisname) +
      theme(
        plot.title = element_text(face = "bold.italic", size = 16),
        axis.title.y = element_text(size = 12),
        axis.title.x = element_blank(),
        axis.text = element_text(size = 10, color = "black"),
        axis.text.x = element_text(angle = 45, hjust = 1)
      )
    return(graph)
  }

## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(echo = FALSE, warning = FALSE, fig.width = 7)
Sys.setlocale(locale="english")

## ----echo=FALSE---------------------------------------------------------------
library ("knitr")

## -----------------------------------------------------------------------------
library ("AeRobiology")

## ----eval=FALSE, echo = TRUE--------------------------------------------------
# install.packages("AeRobiology")
# library (AeRobiology)

## ----echo = TRUE--------------------------------------------------------------
data("munich_pollen")

## ----eval=FALSE, echo = TRUE--------------------------------------------------
# install.packages("readxl")
# library (readxl)

## ----eval=FALSE, echo = TRUE--------------------------------------------------
# Mydata<-read_xlsx("C:/Users/Antonio/Desktop/Prueba Markdown/mydata.xlsx")
# 

## ----eval=FALSE, echo = TRUE--------------------------------------------------
# Mydata<-read_xlsx("C:/Users/Antonio/Desktop/Prueba Markdown/mydata.xlsx", sheet=2)
# 

## ----echo=TRUE, results='hold'------------------------------------------------
str(munich_pollen)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
QualityControl<-quality_control(munich_pollen, result = "table")

## ----echo=TRUE, results='hold'------------------------------------------------

head(QualityControl)

## ----echo=TRUE,  fig.keep='first', results='hide'-----------------------------
quality_control(munich_pollen, result = "plot")

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
quality_control(munich_pollen, int.window = 4, perc.miss = 50, ps.method = "percentage", perc = 80)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
Interpolated<-interpollen(munich_pollen[,c(1,6)], method="lineal", plot = TRUE, result = "long")


## ----echo=TRUE, results='hold'------------------------------------------------
head(Interpolated)

## ----echo=TRUE, results='hide'------------------------------------------------
CompleteData<-interpollen(munich_pollen[,c(1,6)], method="lineal", plot = FALSE, result = "wide")

## ----echo=TRUE, eval=FALSE----------------------------------------------------
# calculate_ps(munich_pollen, method="percentage", interpolation=TRUE, int.method = "lineal", plot = F)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
i<-interpollen(munich_pollen[,c(1,6)], method="movingmean", factor = 2, plot = TRUE)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
i2<-interpollen(munich_pollen[,c(1,6)], method="spline", ndays=3, spar=0.7, plot = FALSE)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
i3<-interpollen(munich_pollen[,c(1,6)], method="spline", ndays=5, spar=0.2, plot = TRUE)

## ----echo=TRUE, results='hide', fig.keep='last'-------------------------------
i4<-interpollen(munich_pollen, method="tseries", plot = TRUE)

## ----echo = TRUE, results='hide', fig.keep='last', warning=FALSE--------------
pollen_season <- calculate_ps(munich_pollen)

## ----echo = FALSE, fig.keep='all', warning=FALSE------------------------------
knitr::kable(pollen_season[24:31, ] , format = "html", booktabs = TRUE)

## ----echo = TRUE, fig.keep='last', warning=FALSE------------------------------
calculate_ps(munich_pollen[,c(1,6)], plot = TRUE)

## ----echo=TRUE, results='hide', fig.keep='first', eval=FALSE------------------
# calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc = 90, export.result = FALSE)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc = 90, export.result = FALSE, int.method = "spline")

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc = 75, export.result = FALSE, interpolation = FALSE)

## ----echo=TRUE, results='hide', fig.keep='first', warning=FALSE---------------
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "logistic", derivative = 5, reduction=FALSE)

## ----echo = FALSE, fig.keep='all', warning=FALSE------------------------------
knitr::kable(pollen_season, format = "html", booktabs = TRUE )

## ----echo=TRUE, results='hide', fig.keep='first', warning=FALSE---------------
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "logistic", derivative = 6, reduction=FALSE, red.level = 0.8)

## ----echo = FALSE, fig.keep='all', warning=FALSE------------------------------
knitr::kable(pollen_season, format = "html", booktabs = TRUE)

## ----echo=TRUE, results='hide', fig.keep='first', warning=FALSE---------------
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "clinical", type = "birch")

## ----echo = FALSE, fig.keep='all', warning=FALSE------------------------------
knitr::kable(pollen_season, format = "html", booktabs = TRUE)

## ----echo=TRUE, results='hide', fig.keep='first', warning=FALSE---------------
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "clinical", n.clinical = 5, window.clinical = 7, th.pollen = 10, th.sum = 100, th.day = 100)

## ----echo = FALSE, fig.keep='all', warning=FALSE------------------------------
knitr::kable(pollen_season, format = "html", booktabs = TRUE)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
calculate_ps(munich_pollen[,c(1,6)], method = "grains", window.grains = 3, th.pollen = 2 )

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
calculate_ps(munich_pollen[,c(1,6)], method = "moving", man = 7, th.ma = 4)

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
calculate_ps(munich_pollen[,c(1,3)], method = "moving", man = 7, th.ma = 4, def.season = "interannual")

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc=95, def.season = "peak")

## ----echo=TRUE, results='hide', fig.keep='first'------------------------------
CompleteData<-interpollen(munich_pollen, method="spline", ndays=3, spar=0.7, plot = TRUE, maxdays = 3, result = "wide")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_ps(CompleteData, pollen.type="Alnus", year=2013, fill.col = "orange", axisname = "AeRobiology custom units")

## ----echo = TRUE, results='hide',fig.keep='all', warning=FALSE----------------
pollen_calendar(munich_pollen, method = "heatplot", period = "daily", color = "green", interpolation = FALSE)

## ----echo = TRUE, fig.keep='all', warning=FALSE-------------------------------
average_values<-pollen_calendar(munich_pollen, method = "heatplot", period = "daily", color = "green", interpolation = FALSE, result = "table")
knitr::kable(average_values[82:90, ], format = "html", booktabs = TRUE)

## ----echo = TRUE, results='hide',fig.keep='all', warning=FALSE----------------
pollen_calendar(data = munich_pollen, method = "heatplot", period = "daily", color = "red", method.classes = "custom", n.classes = 5, classes = c(5, 25, 50, 200), interpolation = FALSE)

## ----echo = TRUE, results='hide',fig.keep='all', warning=FALSE----------------
pollen_calendar(data = munich_pollen, method = "heatplot", period = "daily", color = "purple", method.classes = "custom", n.classes = 5, classes = c(5, 25, 50, 200), start.month = 11, na.remove = FALSE, interpolation = FALSE)

## ----echo = TRUE, results='hide',fig.keep='all', warning=FALSE----------------
pollen_calendar(data = munich_pollen, method = "heatplot", period = "weekly", color = "blue", method.classes = "exponential", n.types = 4, y.start = 2011, y.end = 2014, interpolation = FALSE)

## ----echo = TRUE, results='hide', fig.keep='all', warning=FALSE---------------
plot_monthly_heatmap(munich_pollen, pollen.type = "Betula")

## ----echo = TRUE, results='hide', fig.keep='all', warning=FALSE---------------
plot_monthly_heatmap(munich_pollen, pollen.type = "Poaceae", start.month = 6, color.A = "white", color.B = "darkgreen")

## ----echo = TRUE, results='hide',fig.keep='all', warning=FALSE----------------
pollen_calendar(data = munich_pollen, method = "phenological", n.types = 5, y.start = 2011, y.end = 2014, interpolation = FALSE)

## ----echo = TRUE, results='hide',fig.keep='all', warning=FALSE----------------
pollen_calendar(data = munich_pollen,  method = "phenological", perc1 = 90, perc2 = 95, th.pollen = 5, interpolation = FALSE)

## ----echo = TRUE, results='hide', fig.keep='all', warning=FALSE---------------
pollen_calendar(data = munich_pollen, method = "violinplot", y.start = 2012, y.end = 2015, interpolation = FALSE)

## ----echo = TRUE, results='hide', fig.keep='all', warning=FALSE---------------
pollen_calendar(data = munich_pollen, method = "violinplot", th.pollen = 10, na.rm = FALSE, interpolation = FALSE)

## ----echo = TRUE, results='hide',fig.keep='all', eval=FALSE-------------------
# iplot_pollen(munich_pollen, year = 2012)
# iplot_years(munich_pollen, pollen = "Betula")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_summary(munich_pollen, pollen = "Betula")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_summary(munich_pollen, pollen = "Betula", mave = 5)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_summary(munich_pollen, pollen = "Betula", mave = 5, normalized = TRUE)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_normsummary(munich_pollen, pollen = "Betula", color.plot = "red")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_normsummary(munich_pollen, pollen = "Betula", color.plot = "green", mave = 5, normalized = TRUE)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, result="plot")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, split = FALSE, quantil = 1, result="plot")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, split=FALSE, quantil = 0.5, result="plot")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, significant = 1, result = "plot")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, significant = 1, result="table")

## ----echo = TRUE, results='hide',fig.keep='all', eval=FALSE-------------------
# plot_trend(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE, n.types = 3)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE, n.types = 3, y.start = 2011, y.end = 2011, col.bar = "#d63131")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE, n.types = 3, y.start = 2011, y.end = 2011, col.bar = "#d63131", type.plot = "dynamic")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
iplot_pheno(munich_pollen, method= "percentage", perc=80, int.method="spline", n.types = 8)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
iplot_pheno(munich_pollen, method= "clinical", n.clinical = 3, int.method="spline", n.types = 4)

## ----echo = TRUE, results='hide',fig.keep='all', eval=FALSE-------------------
# iplot_pheno(munich_pollen, method= "clinical", n.clinical = 3, int.method="spline", n.types = 4, type.plot = "dynamic")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_ps(munich_pollen, pollen.type="Alnus", year=2011)

## ----echo = TRUE, results='hold', error=TRUE----------------------------------
try({
plot_ps(munich_pollen, pollen.type="Alnuscdscscr", year=2011)
})

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, method= "percentage", perc=95 ,int.method = "lineal")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, method= "percentage", perc=95 ,int.method = "movingmean")

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, days = 90)

## ----echo = TRUE, results='hide',fig.keep='all'-------------------------------
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, fill.col = "orange", axisname = "AeRobiology custom units")

## ----echo = FALSE, warning=FALSE, message=FALSE-------------------------------
library(ggplot2)
library(dplyr)

## ----echo = TRUE--------------------------------------------------------------
data("POMO_pollen")

## ----echo = TRUE, message=FALSE-----------------------------------------------
plot_hour(POMO_pollen)

## ----message=FALSE------------------------------------------------------------
TO<-plot_hour(POMO_pollen, result ="table")
knitr::kable(TO[1:10,], caption = "3-Hourly patterns", row.names = FALSE, digits = 1, format = "html", booktabs = TRUE)

## ----message=FALSE, echo=TRUE-------------------------------------------------
plot_hour(POMO_pollen, locations = TRUE)

## ----message=FALSE, echo=TRUE-------------------------------------------------
plot_heathour(POMO_pollen)

## ----message=FALSE, echo=TRUE-------------------------------------------------
plot_heathour(POMO_pollen, low.col = "darkgreen", mid.col = "moccasin", high.col = "brown")

## ----message=FALSE, echo=TRUE-------------------------------------------------
plot_heathour(POMO_pollen, locations = TRUE)

#' Moving Average Calculator
#'
#' Function to calculate the moving average of a given numeric vector. The order of the moving average may be customized by the user (\code{man} argument).
#'
#' @param data A \code{numeric} vector (e.g. a \code{numeric} column of a \code{dataframe}).
#' @param man An \code{integer} value specifying the order of the moving average applied to the data. By default, \code{man = 10}.
#' @param warnings A \code{logical} value specifying the show of warning messages. By default, \code{warnings = FALSE}.
#' @return This function returns a vector with the moving average of the input data.
#' @examples data("munich_pollen")
#' @examples ma(data = munich_pollen$Betula, man = 10, warnings = FALSE)
#' @export
ma <- function(data, man = 10, warnings = FALSE) {
  if (man %% 2 == 0) {
    man = man + 1
    try(if (warnings == TRUE)
      warning (paste("WARNING! moving average is calculated for man:", man)))
  }
  temp  <-  data
  for (i in 1:length(data)) {
    if (i  <=  (man  -  1)  /  2) {
      init  <-  1
    } else{
      init <- i - (man - 1) / 2
    }
    if (i > length(data) - (man - 1) / 2) {
      end <- length(data)
    } else{
      end <- i + (man - 1) / 2
    }

    temp[i] = mean(data[init:end], na.rm = T)
  }
  return(temp)
}

#' Quality Control of a Pollen Database
#'
#' Function to check the quality of an historical database of several pollen types.
#'@param data A \code{data.frame} object including the general database where quality must be checked. This data.frame must include a first column in \code{Date} format and the rest of columns in \code{numeric} format belonging to each pollen type by column. It is not necessary to insert the missing gaps; the function will automatically detect them.
#'@param int.window A  \code{numeric (interger)}value bigger or equal to \code{1}. The argument specifies the number of days of each side of the start, peak or end date of the main pollen season which will be checked during the quality control. If any of these days has been interpolated, the current season will not pass the quality control. The \code{int.window} argument will be \code{2} by default.
#'@param perc.miss A \code{numeric (interger)} value between \code{0} and \code{100}. The argument specifies the maximal percentage of interpolated days which is allowed inside the main pollen season to pass the quality control. The \code{perc.miss} argument will be \code{20} by default.
#'@param ps.method A \code{character} string specifying the method applied to calculate the pollen season and the main parameters. The implemented methods that can be used are: \code{"percentage"}, \code{"logistic"}, \code{"moving"}, \code{"clinical"} or \code{"grains"}. A more detailed information about the different methods for defining the pollen season may be consulted in \code{\link{calculate_ps}} function. The \code{ps.method} argument will be \code{"percentage"} by default.
#'@param result A \code{character} string specifying the format of the results. Only \code{"plot"} or \code{"table"} available. If \code{"plot"}, graphical resume of the quality control will be plotted. If \code{"table"}, a \code{data.frame} will be created indicating the filters passed by each pollen type and season. Consult 'Return' for more information .The \code{result} argument will be \code{"plot"} by default.
#'@param th.day See \code{\link{calculate_ps}} for more details.
#'@param perc See \code{\link{calculate_ps}} for more details.
#'@param def.season See \code{\link{calculate_ps}} for more details.
#'@param reduction See \code{\link{calculate_ps}} for more details.
#'@param red.level See \code{\link{calculate_ps}} for more details.
#'@param derivative See \code{\link{calculate_ps}} for more details.
#'@param man See \code{\link{calculate_ps}} for more details.
#'@param th.ma See \code{\link{calculate_ps}} for more details.
#'@param n.clinical See \code{\link{calculate_ps}} for more details.
#'@param window.clinical See \code{\link{calculate_ps}} for more details.
#'@param window.grains See \code{\link{calculate_ps}} for more details.
#'@param th.pollen See \code{\link{calculate_ps}} for more details.
#'@param th.sum See \code{\link{calculate_ps}} for more details.
#'@param type See \code{\link{calculate_ps}} for more details.
#'@param int.method See \code{\link{calculate_ps}} for more details.
#'@param ... Other arguments passed on to the pollen season calculation as specified in \code{\link{calculate_ps}} function.
#'@details Quality control is a relevant topic for aerobiology (Oteros et al., 2013). This function is another approach to improve the quality control management in the field. \cr\code{quality_control} function checks the quality of the pollen data of each pollen type and season. The filters applied by the function are: \cr
#'\itemize{
#'\item If the main pollen season (Galan et al., 2017) cannot be calculated according to \code{\link{calculate_ps}} function minimal requirements (lack of data for these pollen type and year). Filter named \code{"Complete"} in the \code{"quality_control"} \code{data.frame}.
#'\item If the start, end or peak date of the main pollen season has been interpolated or a day near to it (number of days specified by \code{int.window} argument). If a day near to these dates is missing, the selected date could not be the right one. Filters named \code{"Start"}, \code{"Peak"} and \code{"End"} in the \code{"quality_control"} \code{data.frame}.
#'\item The percentage of missing data inside the main pollen season. It calculates the number of days which have been interpolated by the algorithm and their percentage inside the main pollen season. If a high percentage of the main pollen season has been interpolated, the information of these season could not be reliable. Filter named \code{"Comp.MPS"} in the \code{"quality_control"} \code{data.frame}.
#'}
#'@return This function can return different results: \cr
#'\itemize{
#'\item If \code{result = "plot"}: Graphical resume of the Quality Control results showing the seasons of each pollen type and their quality (the risk assumed if they are included in further studies). The legend indicates the number of filter that have been unsuccessfully passed for each case. Object of class \code{\link[ggplot2]{ggplot}}. For graphical customization, see \code{\link[ggplot2]{ggplot}} function.
#'\item If \code{result = "table"}: \code{data.frame} with \code{logical} values for each pollen type and season. If \code{TRUE}, the filter has been successfully passed for this case. If FALSE, this case does not fit the minimal requirements of this filter.
#'}
#'@references Galan, C., Ariatti, A., Bonini, M., Clot, B., Crouzy, B., Dahl, A., Fernandez_Gonzalez, D., Frenguelli, G., Gehrig, R., Isard, S., Levetin, E., Li, D.W., Mandrioli, P., Rogers, C.A., Thibaudon, M., Sauliene, I., Skjoth, C., Smith, M., Sofiev, M., 2017. Recommended terminology for aerobiological studies. Aerobiologia (Bologna). 293_295.
#'@references Oteros, J., Galan, C., Alcazar, P., & Dominguez_Vilches, E. (2013). Quality control in bio_monitoring networks, Spanish Aerobiology Network. Science of the Total Environment, 443, 559_565.
#'@seealso \code{\link{calculate_ps}}, \code{\link{interpollen}}, \code{\link[ggplot2]{ggplot}}, \code{\link[ggplot2]{ggsave}}
#' @examples data("munich_pollen")
#' @examples quality_control(munich_pollen[,c(1:4)])
#' @importFrom utils data
#' @importFrom lubridate is.POSIXt
#' @importFrom ggplot2 aes element_blank element_text geom_tile ggplot ggsave labs scale_fill_gradient scale_x_discrete theme theme_classic
#' @importFrom graphics plot
#' @importFrom grDevices dev.off png
#' @importFrom tidyr %>%
#' @export
quality_control<-function(data,
                         int.window=2,
                         perc.miss=20,
                         ps.method="percentage",
                         result = "plot",
                         th.day=100,
                         perc = 95,
                         def.season = "natural",
                         reduction = FALSE,
                         red.level = 0.90,
                         derivative = 5,
                         man = 11,
                         th.ma = 5,
                         n.clinical = 5,
                         window.clinical = 7,
                         window.grains = 5,
                         th.pollen = 10,
                         th.sum = 100,
                         type = "none",
                         int.method = "lineal",
                         ...){
  data<-data.frame(data)
  if (!is.data.frame(data)& !is.null(data)){
    stop ("Please include a data.frame: first column with date, and the rest with pollen types")}
  if(class(data[,1])[1]!="Date" & !is.POSIXt(data[,1])) {stop("Please the first column of your data must be the date in 'Date' format")}
  data[,1]<-as.Date(data[,1])
  if(is.numeric(int.window)!="numeric" | int.window %% 1 != 0){warning("int.window adjusted to 2 (must be an integer > 1)."); int.window <- 2}
  if(int.window<1){stop("int.window: Please, insert only an entire number bigger or equal to 1")}
  if(!is.numeric(perc.miss)){stop("perc.miss: Please, insert a number between 0 and 100")}
  if(perc.miss<0 | perc.miss > 100){stop("perc.miss: Please, insert a number between 0 and 100")}
  if(result!="plot" & result!="table"){stop("result: Please, insert only 'plot' or 'table'.")}

  Pollen<-calculate_ps(data=data, method=ps.method, th.day=th.day, perc=perc, def.season=def.season, reduction=reduction, red.level=red.level, derivative=derivative, man=man, th.ma=th.ma, n.clinical=n.clinical, window.clinical=window.clinical, window.grains=window.grains, th.pollen=th.pollen, th.sum=th.sum, type=type, interpolation=TRUE, int.method=int.method, plot=FALSE, maxdays = 300 )
  Interpolated<-interpollen(data=data, method=int.method, maxdays = 300, plot=FALSE, result="long")
  Qualitycontrol<-data.frame()
  Dataframe<-Pollen[,c(1,2)]
  Dataframe$Complete<-TRUE
  Dataframe$Start<-TRUE
  Dataframe$Peak<-TRUE
  Dataframe$End<-TRUE
  Dataframe$Comp.MPS<-TRUE
  nrow<-nrow(Dataframe)
  for(a in 1:nrow){
    if(any(is.na(Pollen[a,]))){
      Dataframe[a,-c(1,2)]<-FALSE
    }else{
      #Start
      Interpolated$Type<-as.character(Interpolated$Type)
      Interwindow<-Interpolated[which(Interpolated$Type==as.character(Pollen[a,1]) & Interpolated$Date>=(Pollen[a,3]-int.window) & Interpolated$Date<=(Pollen[a,3]+int.window) ),]
      if(sum(Interwindow[,4],na.rm = T)!=0){
        Dataframe[a,4]<-FALSE
      }
      #Peak
      Interwindow2<-Interpolated[which(Interpolated$Type==as.character(Pollen[a,1]) & Interpolated$Date>=(Pollen[a,11]-int.window) & Interpolated$Date<=(Pollen[a,11]+int.window) ),]
      if(sum(Interwindow2[,4],na.rm = T)!=0){
        Dataframe[a,5]<-FALSE
      }
      #End
      Interwindow3<-Interpolated[which(Interpolated$Type==as.character(Pollen[a,1]) & Interpolated$Date>=(Pollen[a,5]-int.window) & Interpolated$Date<=(Pollen[a,5]+int.window) ),]
      if(sum(Interwindow3[,4],na.rm = T)!=0){
        Dataframe[a,6]<-FALSE
      }
      MPS<-Interpolated[which(Interpolated$Type==as.character(Pollen[a,1]) & Interpolated$Date>=Pollen[a,3] & Interpolated$Date<=Pollen[a,5]),]
      Day.dif<-as.numeric(Pollen[a,5]-Pollen[a,3])
      if(sum(MPS[,4],na.rm=T)>round(Day.dif*(perc.miss/100))){
        Dataframe[a,7]<-FALSE
      }
    }
  }
  Dataframe$Risk<-apply(Dataframe[,-c(1,2)], 1, function(x) length(x[x==FALSE]) )
  graph<-ggplot(Dataframe, aes(seasons, type))+
    geom_tile(aes(fill=Risk), colour="grey")+
    scale_fill_gradient(low="white", high="#cb181d", limits=c(0,5))+
    scale_x_discrete(limits = unique(Dataframe$seasons))+
    theme_classic()+
    labs(title="Quality Control")+
    theme(plot.title = element_text(hjust=0.5), title = element_text(size = 16, face="bold"),axis.title=element_blank(), axis.text = element_text(size = 12, face="bold", colour= "black"), axis.text.y = element_text(face="bold.italic"), legend.title = element_text(size = 14), legend.text = element_text(size = 12))
  if(result=="plot"){
    return(graph)
  }
  if(result=="table"){
    return(Dataframe)
  }
}

#' Interactive Plotting Pollen Data (one pollen type).
#'
#' Function to plot the pollen data of a pollen type during several seasons. The plots are fully interactive.
#'
#' @param data A \code{data.frame} object. This \code{data.frame} should include a first column in format \code{Date} and the rest of columns in format \code{numeric} belonging to each pollen type by column.
#' @param pollen A \code{character} string with the name of the particle to show. This \code{character} must match with the name of a column in the input database. This is a mandatory argument.
#' @return An interactive plot of the class \pkg{ggvis}.
#' @seealso \code{\link{iplot_pollen}}
#' @examples data("munich_pollen")
#' @examples iplot_years(data = munich_pollen, pollen = "Betula")
#' @importFrom dplyr filter
#' @importFrom ggvis add_axis axis_props ggvis input_checkboxgroup input_slider layer_lines layer_points scale_numeric %>%
#' @importFrom lubridate is.POSIXt yday year
#' @importFrom tidyr gather
#' @importFrom stats complete.cases
#' @export
iplot_years<-function(data, pollen){

  data<-data.frame(data)
  if(!is.data.frame(data)) stop ("Please include a data.frame: first column with date, and the rest with pollen types")

  if(!is.character(pollen)) stop ("Please include only character values for 'pollen' (including only pollen types in your database)")
  if(class(data[,1])[1]!="Date" & !is.POSIXt(data[,1])) {stop("Please the first column of your data must be the date in 'Date' format")}
  data[,1]<-as.Date(data[,1])
  colnames(data)[1]<-"date"

datalong <-
  gather(
    data,
    colnames(data[2:length(data)]),
    key = "variable",
    value = "value"
  )



## Compare_year
datalong_year <- datalong[which(datalong[, 2] == pollen), ]
datalong_year$year <- as.character(year(datalong_year$date))
datalong_year$date <- yday(datalong_year$date)
datalong_year <-
  datalong_year[which(complete.cases(datalong_year)), ]

iplot_year <- datalong_year %>%
  ggvis(x =  ~ date,
        y =  ~ value,
        stroke = ~ year) %>%
  filter(year %in% eval(input_checkboxgroup(unique(datalong_year$year)))) %>%
  layer_lines(opacity := 0.6, strokeWidth := 1) %>%
  layer_points(size := 20, opacity := 0.8, strokeWidth := 5) %>%
  add_axis("y", title = "Pollen concentration", title_offset = 50) %>%
  scale_numeric("x", domain = input_slider(1, 365, c(1, 365)), clamp = T) %>%
  add_axis("x", title = "Day of the year") %>%
  add_axis("x", orient = "top", ticks = 0, title = paste("Pollen",pollen),
           properties = axis_props(
             axis = list(stroke = "white"),
             labels = list(fontSize = 0)))

return(iplot_year)
}

#' \code{AeRobiology} package
#'
#' AeRobiology computational tool
#'
#' @docType package
#' @name AeRobiology
NULL

## quiets concerns of R CMD check re: the .'s that appear in pipelines
if(getRversion() >= "2.15.1")  utils::globalVariables(c(".", ":=", "DOY", "Max", "Mean", "Min", "Risk", "Year", "en.jd", "j.days", "jd", "opacity", "phen", "pk.jd", "pollen", "seasons", "size", "sm.ps", "st.jd", "strokeWidth", "value", "week", "wt", "x", "variable", "Hour", "location", "percent", "month.label", "sum.pollen"),add=TRUE)

#' Interpolation of Missing Data in a Pollen Database by Different Methods
#'
#' Function to simultaneously replace all missing data of an historical database of several pollen types by using different methods of interpolation.
#'
#' @param data A \code{data.frame} object including the general database where interpollation must be performed. This \code{data.frame} must include a first column in \code{Date} format and the rest of columns in \code{numeric} format. Each column must contain information of one pollen type. It is not necessary to insert missing gaps; the function will automatically detect them.
#' @param method A \code{character} string specifying the method applied to calculate and generate the pollen missing data. The implemented methods that can be used are: \code{"lineal"}, \code{"movingmean"}, \code{"spline"}, \code{"tseries"} or \code{"neighbour"}. A more detailed information about the different methods may be consulted in Details. The \code{method} argument will be \code{"lineal"} by default.
#' @param maxdays A \code{numeric (interger)} value specifying the maximum number of consecutive days with missing data that the algorithm is going to interpolate. If the gap is bigger than the argument value, the gap will not be interpolated. Not valid with \code{"tseries"} method. The \code{maxdays} argument will be \code{30} by default.
#' @param plot A \code{logical} argument. If \code{TRUE}, graphical previews of the input database will be plot at the end of the interpolation process. All the interpolated gaps will be marked in red. The \code{plot} argument will be \code{TRUE} by default.
#' @param factor A \code{numeric (interger)} value bigger than \code{1}. Only valid if the \code{"movingmean"} method is chosen. The argument specifies the factor which will multiply the gap size to stablish the range of the moving mean that will fulfill the gap. A more detailed information about the selection of the factor may be consulted in Details. The argument \code{factor} will be \code{1} by default.
#' @param ndays A \code{numeric (interger)} value bigger than \code{1}. Only valid if the \code{"spline"} method is chosen. Specifies the number of days beyond each side of the gap which are used to perform the spline regression. The argument \code{ndays} will be \code{3} by default.
#' @param spar A \code{numeric (double)} value ranging \code{0_1} specifying the degree of smoothness of the spline regression adjustment. As smooth as the adjustment is, more data are considered as outliers for the spline regression. Only valid if the \code{"spline"} method is chosen. The argument \code{"spar"} will be \code{0.5} by default.
#' @param data2,data3,data4,data5 A \code{data.frame} object (each one) including database of a neighbour pollen station which will be used to interpolate missing data in the target station. Only valid if the "neighbour" method is chosen. This \code{data.frame} must include a first column in \code{Date} format and the rest of columns in \code{numeric} format belonging to each pollen type by column. It is not necessary to insert the missing gaps; the function will automatically detect them. The arguments will be \code{NULL} by default.
#' @param mincorr A \code{numeric (double)} value ranging \code{0_1}. It specifies the minimal correlation coefficient (Spearman correlations) that neighbour stations must have with the target station to be taken into account for the interpolation. Only valid if the \code{"neighbour"} method is chosen. The argument \code{"mincorr"} will be \code{0.6} by default.
#' @param result A \code{character} string specifying the format of the resulting \code{data.frame}. Only \code{"wide"} or \code{"long"}. The \code{result} argument will be \code{"wide"} by default.
#' @details This function allows to interpolate missing data in a pollen database using 4 different methods which are described below. Interpolation for each pollen type will be automatically done for gaps smaller than the \code{"maxdays"} argument. \cr
#' \itemize{
#' \item \code{"lineal"} method. The interpolation will be carried out by tracing a straight line between the gap extremes.
#' \item \code{"movingmean"} method. It calculates the moving mean of the pollen daily concentrations with a window size of the gap size multiplicated by the \code{factor} argument and replace the missing data with the moving mean for these days. It is a dynamic function and for each gap of the database, the window size of the moving mean changes depending of each gap size.
#' \item \code{"spline"} method. The interpolation will be carried out by performing a spline regression with the previous and following days to the gap. The number of days of each side of the gap that will be taken into account for calculating the spline regression are specified by \code{ndays} argument. The smoothness of the adjustment of the spline regression can be specified by the \code{spar} argument.
#' \item \code{"tseries"} method. The interpolation will be carried out by analysing the time series of pollen database. It performs a seasonal_trend decomposition based on LOESS (Cleveland et al., 1990). The seasonality of the historical database is extracted and used to predict the missing data by performing a linear regression with the target year.
#' \item \code{"neighbour"} method. Other near stations provided by the user are used to interpolate the missing data of the target station. First of all, a Spearman correlation is performed between the target station and the neighbour stations to discard the neighbour stations with a correlation coefficient smaller than \code{mincorr} value. For each gap, a linear regression is performed between the neighbour stations and the target stations to determine the equation which converts the pollen concentrations of the neighbour stations into the pollen concentration of the target station. Only neighbour stations without any missing data during the gap period are taken into account for each gap.
#' }
#' @return This function returns different results:
#' \itemize{
#' \item If \code{result = "wide"}, returns a \code{data.frame} including the original data and completed with the interpolated data.
#' \item If \code{result = "long"}, returns a \code{data.frame} containing your data in long format (the first column for date, the second for pollen type, the third for concentration and an additional fourth column with \code{1} if this data has been interpolated or \code{0} if not).
#' \item If \code{plot = TRUE}, plots for each year and pollen type with daily values are represented in the active graphic window. Interpolated values are marked in red. If \code{method} argument is \code{"tseries"}, the seasonality is also represented in grey.
#' }
#' @references Cleveland RB, Cleveland WS, McRae JE, Terpenning I (1990) STL: a seasonal_trend decomposition procedure based on loess. J Off Stat 6(1):3_33.
#' @seealso \code{\link{ma}}
#' @examples data("munich_pollen")
#' @examples interpollen(munich_pollen, method = "lineal", plot = FALSE)
#' @importFrom lubridate is.POSIXt
#' @importFrom graphics legend lines par plot points
#' @importFrom stats aggregate cor.test lm na.omit predict predict.lm smooth.spline stl ts window
#' @importFrom zoo na.approx
#' @importFrom tidyr %>% gather spread
#' @export
interpollen <-
  function(data,
           method = "lineal" ,
           maxdays = 30,
           plot = TRUE,
           factor = 2,
           ndays = 3,
           spar = 0.5,
           data2=NULL,
           data3=NULL,
           data4=NULL,
           data5=NULL,
           mincorr=0.6,
           result="wide") {
    # --- argument checks (FIXED) ---
    if (!is.numeric(maxdays) || length(maxdays) != 1L || is.na(maxdays)) {
      stop("maxdays: Please, insert a single numeric value")
    }
    if (maxdays %% 1 != 0 || maxdays <= 1) {
      stop("maxdays: Please, insert an entire number bigger than 1")
    }
    
    if (!is.character(method) || length(method) != 1L || is.na(method)) {
      stop("method: Please, only type 'lineal', 'movingmean', 'spline', 'tseries' or 'neighbour'")
    }
    if(!is.character(method)){stop("method: Please, only type 'lineal' , 'movingmean' or 'spline'")}
    if (method != "lineal" &
        method != "movingmean" &
        method != "spline" & method != "neighbour" & method != "tseries"){
      stop("method: Please, only type 'lineal' , 'movingmean', 'spline', 'tseries' or 'neighbour'")}
    if (result != "wide" &
        result != "long"){
      stop("result: Please, only type 'wide' or 'long'")}
    if (plot != TRUE &
        plot != FALSE){
      stop("plot: Please, only type 'TRUE' or 'FALSE'")}
    if (!is.numeric(factor)){
      stop("factor: Please, insert only a number bigger than 1")}
    if (factor <= 1){
      stop("factor: Please, insert only a number bigger than 1")}
    if (!is.numeric(ndays) || length(ndays) != 1 || is.na(ndays) || ndays %% 1 != 0) {
      stop("ndays: Please, insert a single integer number")
    }
    if (ndays < 2) {
      stop("ndays: Please, insert an entire number bigger than 1")
    }
    if (!is.numeric(spar) | spar <= 0 |
        spar > 1){
      stop("spar: Please, insert only a number between 0 (not included) and 1")}
    if (ndays >= 15){
      warning("WARNING: Results of spline may not be reliable with more than 15 days")}
    if(mincorr<0 | mincorr>1){stop("mincorr: Please insert only a number between 0 and 1 ")}

    data<-data.frame(data)
    colnames(data)[1]<-"date"
    if (!is.data.frame(data)& !is.null(data)){
      stop ("Please, include a data.frame: first column with date, and the rest with pollen types")}
    if (!is.data.frame(data2) & !is.null(data2)){
      stop ("data2: Please, include a data.frame: first column with date, and the rest with pollen types")}
    if (!is.data.frame(data3)& !is.null(data3)){
      stop ("data3: Please, include a data.frame: first column with date, and the rest with pollen types")}
    if (!is.data.frame(data4)& !is.null(data4)){
      stop ("data4: Please, include a data.frame: first column with date, and the rest with pollen types")}
    if (!is.data.frame(data5) & !is.null(data5)){
      stop ("data5: Please, include a data.frame: first column with date, and the rest with pollen types")}
    if (method=="neighbour" & is.null(data2)){stop("You need at least another station loaded in 'data2' to use this method")}
    if(class(data[,1])[1]!="Date" & !is.POSIXt(data[,1])) {stop("Please the first column of your data must be the date in 'Date' format")}
    data[,1]<-as.Date(data[,1])

    if (method == "tseries"){
      warning("WARNING: 'maxdays' argument doesn't work with this method. All gaps will be interpolated.")

      date.st <- min(data[ ,1], na.rm = TRUE)
      date.en <- max(data[ ,1], na.rm = TRUE)
      date.seq <- seq(from = date.st, to = date.en, "days")

      data1 <- data.frame(matrix(data = NA, nrow = length(date.seq), ncol = length(colnames(data))))
      colnames(data1) <- colnames(data)
      data1[ ,1] <- as.Date(date.seq)
      data1[data1[ ,1] %in% data[ ,1], -1] <- data[data[ ,1] %in% data1[ ,1], -1]
      data <- data1

      data.full <- data

      type.name <- colnames(data)


      for (cols in 2: length(type.name)){

        ma.data <- data.frame(date = data[ ,1],
                              year = strftime(data[ ,1], "%Y"),
                              ma = ma(data[ ,type.name[cols]], man = 15))

        ag.data <- aggregate(ma ~ year, data = ma.data, max)

        ag.data$peak <- as.Date("2017-01-01")

        for (r in 1:nrow(ag.data)){
          ag.data$peak[r] <- ma.data$date[which(ma.data$year == ag.data$year[r] & ma.data$ma == ag.data$ma[r])][1]
        }

        ag.data$st <- ag.data$peak - 182
        ag.data$en <- ag.data$peak + 182

        for (d in 1:nrow(ag.data)){
          if (d == 1) {
            date.ps <- seq(from = ag.data$st[d], to = ag.data$en[d], "days")
          } else {
            date.ps <- c(date.ps, seq(from = ag.data$st[d], to = ag.data$en[d], "days"))
          }

        }

        ps.df <- data.frame(date = date.ps, pollen = NA)
        for (p in 1:nrow(ps.df)){
          if (ps.df$date[p] %in% data[ ,1] == TRUE) {ps.df$pollen[p] <- data[data[ ,1] == ps.df$date[p], type.name[cols]]}
        }

        stl.df <- (stl(ts(ps.df$pollen, frequency = 365), s.window = "periodic", na.action=na.approx)$time.series[,1])

        if(min(as.numeric(window(stl.df, start=c(2,1), end=c(2,365)))) < 0){
          pollen.year <- floor(as.numeric(window(stl.df, start=c(2,1), end=c(2,365))) + abs(min(as.numeric(window(stl.df, start=c(2,1), end=c(2,365))))))
        } else {
          pollen.year <- floor(as.numeric(window(stl.df, start=c(2,1), end=c(2,365))))
        }

        par(mfrow = c(ceiling(length(unique(ag.data$year))/4),4), mar = c(0.5,0.5,1,0.5))
        for (y in 1:nrow(ag.data)){
          date.pred <- seq(from = ag.data$st[y], to = ag.data$en[y], "days")
          pollen.sel <- data.frame(date = date.pred, pollen = NA)
          pollen.sel$pollen[pollen.sel$date %in% data[, 1]] <- data[data[ ,1] %in% pollen.sel$date, type.name[cols]]
          pollen.pred <- pollen.year * summary(lm(pollen.sel$pollen ~ pollen.year + 0))$coefficients[1]

          data.full[which(data.full$date %in% date.pred & is.na(data.full[, type.name[cols]])), type.name[cols]] <- pollen.pred[which(date.pred %in% data.full$date[is.na(data.full[, type.name[cols]])])]

          pollen.full <- pollen.sel
          pollen.full$pollen <- NA

          pollen.full$pollen[pollen.full$date %in% data.full[ ,1]] <- data.full[data.full[ ,1] %in% pollen.full$date, type.name[cols]]
          if(plot==TRUE){
          plot(pollen.year, col = "gray", lwd = 2, type = "l", xaxt = "n", yaxt = "n", main = paste(toupper(type.name[cols]), ag.data$year[y]))
          lines(pollen.full$pollen, col = 2)
          lines(pollen.sel$pollen, type = "l", col = 1, lwd = 2)
          legend("topleft", legend = c("original data", "interpolation", "seasonality"), col = c("black", "red", "gray"), pch = 19, cex = 0.8, bty = "n")
        }}
      }

      Interpolated <- gather(data.full, "type", "pollen", colnames(data.full)[-1], factor_key = TRUE)
      Non.interpolated <- gather (data, "type", "pollen", colnames(data.full)[-1], factor_key = TRUE)


      Interpolated$Interpolated <- 1
      Interpolated$Interpolated[which(Interpolated$pollen == Non.interpolated$pollen)] <- 0
      colnames(Interpolated) <- c("Date", "Type", "Pollen", "Interpolated")
      if(result=="long"){
        return(Interpolated)
        print(paste(
          "Process completed: If the data has been interpolated it is marked with 1"
        ))
      }else{return(data.full)}

    }else{


    ######CONVERSION DE DATOS WIDE-LONG
    ConvertData1 <- function(Dataf) {
      cols <- ncol(Dataf)
      Nombres <- colnames(Dataf)
      idvariables <- Nombres[1]
      Tipos <- Nombres[2:cols]
      Result <- gather(Dataf, "Type", "Pollen", Tipos, factor_key = TRUE)
      return(Result)
    }

    Long <- ConvertData1(data)
    Warning <- FALSE
    RawData <- na.omit(Long)
    Interpolated <- rep(0, nrow(RawData))
    RawData <- data.frame(RawData, Interpolated)
    RawData[, 1] <- as.Date(RawData[, 1], origin = "1970-01-01")
    First <- min(RawData[, 1])
    Last <- max(RawData[, 1])
    PollenTypes <- unique(RawData[, 2])
    nPollenTypes <- length(PollenTypes)
    for (a in 1:nPollenTypes) {
      Active_Pollen <- as.character(PollenTypes[a])
      Datatemp <- RawData[RawData[, 2] == Active_Pollen, ]
      Days <- nrow(Datatemp)
      Interpolate <- data.frame()
      for (c in 1:(Days - 1)) {
        if ((Datatemp[c, 1]) != (Datatemp[c + 1, 1] - 1)) {
          Interpolate <-
            rbind(Interpolate, Datatemp[c, 1:4], Datatemp[c + 1, 1:4])
        }
      }
      nInterpolate <- nrow(Interpolate)
      if (nInterpolate >= 2) {
        pares <- seq(1, nInterpolate, by = 2)
        npares <- length(pares)
        #Bucle que va cogiendo todos los pares de fechas que definen el hueco que hay. Va dando saltos de 2 en 2.

        for (d in 1:npares) {
          Active_InterpolStart <-
            pares[d] #Posicion en la que empieza el salto
          Active_InterpolEnd <-
            pares[d] + 1#Posicion en la que acaba el salto
          Datatemp2 <-
            Interpolate[Active_InterpolStart:Active_InterpolEnd, 1:3]#Dataframe que contiene las dos lineas del salto.
          colnames(Datatemp2) <- c("Date", "Type", "Pollen")
          ncasos <-
            as.numeric(Datatemp2[nrow(Datatemp2), 1] - Datatemp2[1, 1])#Numero de dias que faltan
          ncasos <- ncasos - 1 #Numero de datos a introducir.
          Date <- c()
          if (ncasos <= maxdays) {
            #No interpola si los datos que faltan son mas de 30.
            Type <- as.character(c())
            prediccion <- data.frame()
            for (l in 1:ncasos) {
              ##Va creando los datos vacios para rellenar con el metodo
              Active_Date <-
                as.Date((as.numeric(Datatemp2[1, 1]) + l), origin = "1970-01-01")
              Date <-
                as.Date(c(Date, Active_Date), origin = "1970-01-01")
              Type <- as.character(c(Type, Active_Pollen))
            }
            Pollen <- rep(NA, ncasos)
            prediccion <- data.frame(Date, Type, Pollen)
            #######METER AQUi TODOS LOS MeTODOS
            #LINEAL

            if (method == "lineal") {
              modelo <- lm(Pollen ~ Date, data = Datatemp2)#Modelo lineal
              prediccion$Pollen <- predict.lm(modelo, prediccion)

            }

            #MEDIA MoVIL

            if (method == "movingmean") {
              ma1 <- function(arr, n = 10) {
                if (n %% 2 == 0) {
                  n = n + 1
                  try(warning (paste("WARNING! moving average is calculated for n:", n)))
                }
                temp  <-  arr
                for (i in 1:length(arr)) {
                  if (i  <=  (n  -  1)  /  2) {
                    init  <-  1
                  } else{
                    init <- i - (n - 1) / 2
                  }
                  if (i > length(arr) - (n - 1) / 2) {
                    end <- length(arr)
                  } else{
                    end <- i + (n - 1) / 2
                  }

                  temp[i] = mean(arr[init:end], na.rm = T)
                }
                return(temp)
              }

              ftr <- (ncasos + 1) * factor
              Dt <-
                Datatemp[Datatemp[, 1] >= as.Date(Datatemp2[1, 1] - ftr) &
                           Datatemp[, 1] <= as.Date(Datatemp2[2, 1] + ftr), 1:3]
              colnames(Dt) <- colnames(prediccion)
              prediccion[, 3] <- as.numeric(prediccion[, 3])
              Dt <- rbind.data.frame(Dt, prediccion)
              Dt <- Dt[order(Dt[, 1]), ]
              Dt$Interpolated <- ifelse(is.na(Dt[, 3]), 1, 0)
              Dt[, 3] <- ma1(Dt[, 3], ftr)
              solution <- Dt[which(Dt[, 4] == 1), 3]
              prediccion$Pollen <- solution

            }

            #SPLINE
            if (method == "spline") {
              Df <-
                Datatemp[which(Datatemp[, 1] >= (Datatemp2[1, 1] - ndays) &
                                 Datatemp[, 1] <= (Datatemp2[2, 1] + ndays)), ]
              modelo <-
                smooth.spline(x = as.numeric(Df[, 1]),
                              y = Df[, 3],
                              spar = spar)
              prediccion$Pollen <-
                predict(modelo, x = as.numeric(prediccion[, 1]))$y
              prediccion[which(prediccion$Pollen < 0), 3] <- 0
            }

            ########Near Station
            if(method=="neighbour"){
              tryCatch({
                mother<-data[,c(1,which(colnames(data)==Active_Pollen))]
                mother[,1]<-as.Date(mother[,1])
                nmother<-nrow(mother)
                emptiness<-data.frame(as.Date(seq(mother[1,1],mother[nmother,1], by="days")))
                colnames(emptiness)<-colnames(mother)[1]
                motherframe<-merge(emptiness, mother, by.x=c(colnames(emptiness)[1]), all.x = TRUE)
                data2[,1]<-as.Date(data2[,1])
                colnames(data2)[1]<-colnames(data)[1]
                nameneigh<-colnames(data)[1]
                neighbours<-merge(motherframe, data2[,c(nameneigh,Active_Pollen)], by= colnames(Datatemp)[1], all.x=T)
                colnames(neighbours)<-c(colnames(neighbours)[1], "station1", "station2")
                if(!is.null(data3)){
                  data3[,1]<-as.Date(data3[,1])
                  colnames(data3)[1]<-colnames(data)[1]
                  neighbours<-merge(neighbours, data3[,c(nameneigh, Active_Pollen)], by= colnames(Datatemp)[1], all.x=T)
                  colnames(neighbours)<-c(colnames(neighbours)[1], "station1", "station2", "station3")
                }
                if(!is.null(data4)){
                  data4[,1]<-as.Date(data4[,1])
                  colnames(data4)[1]<-colnames(data)[1]
                  neighbours<-merge(neighbours, data4[,c(nameneigh, Active_Pollen)], by= colnames(Datatemp)[1], all.x=T)
                  colnames(neighbours)<-c(colnames(neighbours)[1], "station1", "station2", "station3", "station4")
                }
                if(!is.null(data5)){
                  data5[,1]<-as.Date(data5[,1])
                  colnames(data5)[1]<-colnames(data)[1]
                  neighbours<-merge(neighbours, data5[,c(nameneigh,Active_Pollen)], by= colnames(Datatemp)[1], all.x=T)
                  colnames(neighbours)<-c(colnames(neighbours)[1], "station1", "station2", "station3", "station4", "station5")
                }
                neighbourscomplete<-neighbours#Guardo una copia de los datos sin filtrar
                neighbours[neighbours<=5]<-NA#Quito todos los datos que tengan menos de 5 granos. No son fiables para hacer regresiones
                ncolsneig<-ncol(neighbours)
                for(q in 3:ncolsneig){
                  Correlval<-cor.test(neighbours[,2], neighbours[,q], method = "spearman")#Hago correlaciones para ver si las estaciones se relacionan lo suficiente como para aplicar el metodo
                  if(as.numeric(Correlval$estimate)<mincorr){neighbourscomplete[,-q]}#Quito las correlaciones que no llegan al minimo
                }
                #Si no hay estaciones que tengan suficiente indice de correlacion te imprime un error
                if(ncol(neighbourscomplete)==2){stop(paste("ERROR: None of the neighbour stations have enough correlation with your station to use this method for a mincorr=", mincorr))}
                regresion<-neighbours[,-1]
                ###Hago las regresiones
                regresion<-na.omit(regresion)#Datos para entrenar que sean >5 y sin NA
                npred<-nrow(prediccion)#Numero de datos a predecir
                #Datos originales de todas las estaciones
                gooddata<-neighbourscomplete[which(neighbourscomplete[,1]>=prediccion[1,1] & neighbourscomplete[,1]<=prediccion[npred,1]),]
                columnas<-colnames(regresion)
                ncolumn<-length(columnas)
                for(x in 2:ncolumn){
                  Active_column<-columnas[x]
                  if(anyNA(gooddata[,Active_column])){regresion<-regresion[,-which(colnames(regresion)==Active_column)]}
                }
                if(is.data.frame(regresion)){
                  modelo<-lm(station1~.+0, data = regresion)
                  prediccion$Pollen<- predict.lm(modelo, gooddata[,-1])
                }
              }, error = function(e){
                print("Warning: Some of the gaps may not be interpolated due to lack of data")

              })}







            ########FIN MeTODO
            Interpolated <- rep(1, ncasos)
            prediccion <- data.frame(prediccion, Interpolated)
            prediccion<-na.omit(prediccion)
            colnames(prediccion) <- colnames(RawData)
            RawData <- rbind(RawData, prediccion)
          } else{
            Warning <- TRUE
          }
        }
      }

      if (plot == TRUE) {
        Years <- as.numeric(unique(strftime(Datatemp[, 1], "%Y")))
        nyears <- length(Years)
        par(mfrow = c(ceiling(nyears / 4), 4), mar = c(1, 1, 1, 0))
        for (f in 1:nyears) {
          Active_Year <- Years[f]
          Dataplot <-
            RawData[which(as.numeric(strftime(RawData[, 1], "%Y")) == Active_Year &
                            RawData[, 2] == Active_Pollen), ]
          Dataplot <- Dataplot[order(Dataplot[, 1]), ]
          ndataplot<-nrow(Dataplot)
          date<-as.Date(as.Date(Dataplot[1,1]):as.Date(Dataplot[ndataplot,1]), origin = "1970-01-01")
          Emptydata<-data.frame(date, Type=Active_Pollen)
          colnames(Emptydata)<-colnames(Dataplot)[c(1:2)]
          Dataplot1<-merge(Emptydata,
                           Dataplot,
                           by.x = c(colnames(Emptydata)[1], colnames(Emptydata)[2]),
                           all.x = TRUE)
          Dataplot1<-Dataplot1[,1:3]
          Predicted <- Dataplot[which(Dataplot[, 4] == 1), 1:3]
          Prediplot <-
            merge(
              Emptydata,
              Predicted,
              by.x = c(colnames(Predicted)[1], colnames(Predicted)[2]),
              all.x = TRUE
            )

          plot(y=Dataplot1[,3], x=1:nrow(Dataplot1), type = "l", col="black", lwd=1, main = paste(toupper(Active_Pollen) , Active_Year),
               xaxt = "n",
               yaxt = "n")
          lines(
            x = 1:nrow(Dataplot1),
            y = Prediplot[, 3],
            col = "red",
            lwd = 2,
            type = "l"
          )
          points(
            x = 1:nrow(Dataplot1),
            y = Prediplot[, 3],
            col = "red",
            cex = 0.7,
            pch = 19
          )
        }

      }
    }
    colnames(RawData) <- c("Date", "Type", "Pollen", "Interpolated")
    RawData <- RawData[order(RawData$Type, RawData$Date), ]
    Date <- seq.Date(First, Last, by = "day")
    n <- length(Date)
    #Creo una matriz de datos vacia sobre la que meter los otros datos para que no elimine los NA interestacionales
    CompleteData <- data.frame()
    for (a in 1:nPollenTypes) {
      Active_Type <- as.character(PollenTypes[a])
      Type <- rep(Active_Type, n)
      Complet <- cbind.data.frame(Date, Type)
      CompleteData <- rbind.data.frame(CompleteData, Complet)
    }
    colnames(CompleteData) <- colnames(RawData)[c(1, 2)]
    #####OUTPUT
    DataINTER <-
      merge(CompleteData,
            RawData,
            by.x = c(colnames(RawData)[1], colnames(RawData)[2]),
            all = TRUE)
    if (Warning == TRUE){
      warning (paste("WARNING: Gaps with more than", maxdays, "missing data have not been interpolated"))}
    if(result=="long"){
    return(DataINTER)
      print(paste(
        "Process completed: If the data has been interpolated it is marked with 1"
      ))
    }else{
      DataINTER2<-spread(DataINTER[,1:3], "Type", "Pollen")
      return(DataINTER2)}
    }}

#' Calculating and Plotting Trends of Pollen Data (summary plot).
#'
#' Function to calculate the main seasonal indexes of the pollen season (\emph{Start Date}, \emph{Peak Date}, \emph{End Date} and \emph{Pollen Integral}). Trends analysis of the parameters over the seasons. Summary dot plot showing the distribution of the main seasonal indexes over the years.
#'
#' @param data A \code{data.frame} object. This \code{data.frame} should include a first column in format \code{Date} and the rest of columns in format \code{numeric} belonging to each pollen type by column.
#' @param interpolation A \code{logical} value specifying if the visualization shows the gaps in the inputs data (\code{interpolation = FALSE}) or if an interpolation method is used for filling the gaps (\code{interpolation = TRUE}). By default, \code{interpolation = TRUE}.
#' @param int.method A \code{character} string with the name of the interpolation method to be used. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"tseries"} or \code{"spline"}. By default, \code{int.method = "lineal"}.
#' @param export.plot A \code{logical} value specifying if a plot will be exported or not. If \code{FALSE} graphical results will only be displayed in the active graphics window. If \code{TRUE} graphical results will be displayed in the active graphics window and also one pdf/png file will be saved within the \emph{plot_AeRobiology} directory automatically created in the working directory. By default, \code{export.plot = TRUE}.
#' @param export.format A \code{character} string specifying the format selected to save the plot. The implemented formats that may be used are: \code{"pdf"} or \code{"png"}. By default, \code{export.format = "pdf"}.
#' @param export.result A \code{logical} value. If \code{export.result = TRUE}, a table is exported with the extension \emph{.xlsx}, in the directory \emph{table_AeRobiology}. This table has the information about the \code{slope} \emph{"beta coefficient of a lineal model using as predictor the year and as dependent variable one of the main pollen season indexes"}. The information is referred to the main pollen season indexes: \emph{Start Date}, \emph{Peak Date}, \emph{End Date} and \emph{Pollen Integral}.
#' @param method A \code{character} string specifying the method applied to calculate the pollen season and the main seasonal parameters. The implemented methods that can be used are: \code{"percentage"}, \code{"logistic"}, \code{"moving"}, \code{"clinical"} or \code{"grains"}. By default, \code{method = "percentage"} (\code{perc = 95}\%). A more detailed information about the different methods for defining the pollen season may be consulted in the function \code{\link{calculate_ps}}.
#' @param quantil A \code{numeric} value (between 0 and 1) indicating the quantile of data to be displayed in the graphical output of the function. \code{quantil = 1} would show all the values, however a lower quantile will exclude the most extreme values of the sample. To split the parameters using a different sampling units (e.g. dates and pollen concentrations) can be used low vs high values of \code{quantil} argument (e.g. 0.5 vs 1). Also can be used an extra argument: \code{split}. By default, \code{quantil = 0.75}. \code{quantil} argument can only be applyed when \code{split = FALSE}.
#' @param significant A \code{numeric} value indicating the significant level to be considered in the linear trends analysis. This \emph{p} level is displayed in the graphical output of the function. By default, \code{significant = 0.05}.
#' @param split A \code{logical} argument. If \code{split = TRUE}, the plot is separated in two according to the nature of the variables (i.e. dates or pollen concentrations). By default, \code{split = TRUE}.
#'@param result A \code{character} object with the definition of the object to be produced by the function. If \code{result == "plot"}, the function returns a list of objects of class \pkg{ggplot2}; if \code{result == "table"}, the function returns a \pkg{data.frame}. By default, \code{result = "table"}.
#' @param ... Additional arguments for the function \code{\link{calculate_ps}} are also accepted.
#' @details This function allows to study time series trends of the pollen season. Even though the package was originally designed to treat aeropalynological data, it can be used to study many other atmospheric components (e.g., bacteria in the air, fungi, insects ...) \emph{(Buters et al., 2018; Oteros et al., 2019)}. The study of trends in pollen time series is a common approach to study the impact of climate change or other environmental factors on vegetation (Galan et al., 2016; Garcia_Mozo et al., 2016;  Recio et al., 2018). This tool can also be useful for studying trends in other fields (Oteros et al., 2015).
#' @return If \code{result == "plot"}, the function returns a list of objects of class \pkg{ggplot2}; if \code{result == "table"}, the function returns a \pkg{data.frame} with the hourly patterns.
#' The plot is of the class \pkg{ggplot2} or a list of plots of the class \pkg{ggplot2} (depending on the argument \code{split}). This is a combined dot plot showing the trends (\emph{slope} and \emph{p} value) of the main seasonal features.\cr
#' The object of the class \code{data.frame} has the information about the \code{slope} \emph{(beta coefficient of a lineal model using as predictor the year and as dependent variable one of the main pollen season indexes)}. The information is referred to the main pollen season indexes: \emph{Start Date}, \emph{Peak Date}, \emph{End Date} and \emph{Pollen Integral}.
#'
#' @references Buters, J. T. M., Antunes, C., Galveias, A., Bergmann, K. C., Thibaudon, M., Galan, C., ... & Oteros, J. (2018). Pollen and spore monitoring in the world. \emph{Clinical and translational allergy}, 8(1), 9.
#' @references Galan, C., Alcazar, P., Oteros, J., Garcia_Mozo, H., Aira, M. J., Belmonte, J., ... & Perez_Badia, R. (2016). Airborne pollen trends in the Iberian Peninsula. \emph{Science of the Total Environment}, 550, 53_59.
#' @references Garcia_Mozo, H., Oteros, J. A., & Galan, C. (2016). Impact of land cover changes and climate on the main airborne pollen types in Southern Spain. \emph{Science of the Total Environment}, 548, 221_228.
#' @references Oteros, J., Garcia_Mozo, H., Botey, R., Mestre, A., & Galan, C. (2015). Variations in cereal crop phenology in Spain over the last twenty_six years (1986_2012). \emph{Climatic Change}, 130(4), 545_558.
#' @references Oteros, J., Bartusel, E., Alessandrini, F., Nunez, A., Moreno, D. A., Behrendt, H., ... & Buters, J. (2019). Artemisia pollen is the main vector for airborne endotoxin. \emph{Journal of Allergy and Clinical Immunology}.
#' @references Recio, M., Picornell, A., Trigo, M. M., Gharbi, D., Garcia_Sanchez, J., & Cabezudo, B. (2018). Intensity and temporality of airborne Quercus pollen in the southwest Mediterranean area: Correlation with meteorological and phenoclimatic variables, trends and possible adaptation to climate change. \emph{Agricultural and Forest Meteorology}, 250, 308_318.
#' @seealso \code{\link{calculate_ps}}; \code{\link{plot_trend}}
#' @examples data("munich_pollen")
#' @examples analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE)
#' @importFrom graphics plot
#' @importFrom utils data
#' @importFrom ggplot2 aes element_blank element_text geom_point geom_vline ggplot guide_legend guides labs scale_colour_manual scale_fill_discrete scale_fill_gradientn scale_x_continuous theme theme_bw
#' @importFrom grDevices dev.off pdf png rainbow
#' @importFrom grid grid.layout pushViewport viewport
#' @importFrom lubridate is.POSIXt
#' @importFrom stats as.formula complete.cases lm pf quantile
#' @importFrom writexl write_xlsx
#' @importFrom tidyr %>%
#' @export
analyse_trend  <-   function   (data,
                            interpolation = TRUE,
                            int.method = "lineal",
                            export.plot = TRUE,
                            export.format = "pdf",# pdf, png
                            export.result=TRUE,
                            method="percentage",
                            quantil=0.75,
                            significant=0.05,
                            split=TRUE, result="table",
                            ...){

  # Sys.setlocale(category = "LC_ALL", locale="english")

  base_dir <- if (nzchar(Sys.getenv("_R_CHECK_PACKAGE_NAME_"))) tempdir() else "."
  plot_dir <- file.path(base_dir, "plot_AeRobiology")
  table_dir <- file.path(base_dir, "table_AeRobiology")
  
  if (isTRUE(export.plot)) {
    dir.create(plot_dir, recursive = TRUE, showWarnings = FALSE)
  }
  
  if (isTRUE(export.result)) {
    dir.create(table_dir, recursive = TRUE, showWarnings = FALSE)
  }
  
  #############################################    CHECK THE ARGUMENTS       #############################

  if (isTRUE(export.plot)) {
    base_dir  <- if (nzchar(Sys.getenv("_R_CHECK_PACKAGE_NAME_"))) tempdir() else "."
    plot_dir  <- file.path(base_dir, "plot_AeRobiology")
    if (!dir.exists(plot_dir)) dir.create(plot_dir, recursive = TRUE)
  }

   data<-data.frame(data)
  if(!is.data.frame(data)) stop ("Please include a data.frame: first column with date, and the rest with pollen types")

  if(!is.logical(export.plot)) stop ("Please include only logical values for export.plot argument")

  if(export.format != "pdf" & export.format != "png") stop ("Please export.format only accept values: 'pdf' or 'png'")

  if(class(data[,1])[1]!="Date" & !is.POSIXt(data[,1])) {stop("Please the first column of your data must be the date in 'Date' format")}
  data[,1]<-as.Date(data[,1])

  if(!is.logical(interpolation)) stop ("Please include only logical values for interpolation argument")

  if(!is.logical(split)) stop ("Please include only logical values for split argument")

  if(!is.numeric(quantil)) stop ("Please include only logical values for quantil argument")

  if(!is.numeric(significant)) stop ("Please include only logical values for significant argument")

  if(method != "percentage" & method != "logistic" & method != "moving" & method != "clinical" & method != "grains") stop ("Please method only accept values: 'percentage', 'logistic', 'moving', 'clinical' or 'grains'")

  # if(interpolation == TRUE){data <- interpollen(data, method = int.method)}


  colnames(data)[1]<-"Date"

  ## Function for p value
  lmp <- function (modelobject) {
    if (!inherits(modelobject, "lm")) stop("Not an object of class 'lm' ")
    f <- summary(modelobject)$fstatistic
    p <- pf(f[1],f[2],f[3],lower.tail=F)
    attributes(p) <- NULL
    return(p)
  }

  datafram<-calculate_ps(data,method=method, interpolation =  interpolation, int.method=int.method,plot=FALSE,...)

  variables<-c("st.jd","pk.jd","en.jd","sm.ps")

  trendtime<-data.frame()

  data_summary<-
    for (t in 1:length(unique(datafram$type))){

      type<-unique(as.character(datafram$type))[t]



          for (v in 1:length(variables)){
            tryCatch({
            variable<-variables[v]

            temp<-datafram[which(datafram$type==type),c(1:2,which( colnames(datafram)==variable))]

            lm <- lm (as.formula(paste(variable,"~ seasons")), data= temp, x = TRUE, y = TRUE)

            tempframe<-data.frame(type=type,variable=variable,coef=summary(lm)$coefficients[2,1],p=lmp(lm))

            trendtime<-rbind(trendtime,tempframe)

            }, error=function(e){
              print(paste(type, variable, ": Error, linear model not calculated. Probably due to insufficient amount of years"))
            })

            }
      print(type)
      }



trendtimeresult<-trendtime


### Now start the rock and roll

trendtime$variable<-as.factor(trendtime$variable)

  trendtime2<-trendtime
  trendtime2<-trendtime2[complete.cases(trendtime2),]
  sig<-paste("Significant (p<",significant,")", sep="")
  trendtime2$significant<-sig
  #trendtime2[which(trendtime2$p<=significant),"significant"]<-sig
  trendtime2[which(trendtime2$p>significant),"significant"]<-"Non Significant"
  trendtime2[which(trendtime2$p>significant),"p"]<-0.99
  trendtime2[which(trendtime2$p!=0.99),"p"]<-0.01

trendtime2$variable<-as.character(trendtime2$variable)

trendtime2[which(trendtime2$variable=="st.jd"),"variable"]  <- "Start Date"
trendtime2[which(trendtime2$variable=="pk.jd"),"variable"]  <- "Peak Date"
trendtime2[which(trendtime2$variable=="en.jd"),"variable"]  <- "End Date"
trendtime2[which(trendtime2$variable=="sm.ps"),"variable"]  <- "Total Pollen"

trendtime2$variable<-as.factor(as.character(trendtime2$variable))

trend_p1 <- ggplot(trendtime2, aes(x=coef, y=type))+
   theme_bw()+
   geom_vline(aes(xintercept=0), colour="red", linetype = "dashed", size=1)+
   geom_point(aes(fill=as.numeric(variable), colour=trendtime2$significant, stroke=2-trendtime2$p*2),size=6, alpha=0.9,shape=21)+
   scale_fill_gradientn(colours = rainbow(6), labels = levels(trendtime2$variable))+
   scale_colour_manual(values = c("gray80","black"))+
   scale_x_continuous(limits=c(-quantile(abs(trendtime2$coef),quantil),quantile(abs(trendtime2$coef),quantil)))+
   labs(x= "slope", y="")+
   guides(fill=guide_legend(title=NULL))+
   theme(legend.position="top", legend.title = element_blank(), axis.text.y = element_text(face="italic"))


 filtertrend<-trendtime2[which(trendtime2$variable!="Total Pollen"),]
 filtertrend$variable<-as.factor(as.character(filtertrend$variable))
 filtertrend$type<-as.factor(as.character(filtertrend$type))

 trend_p2 <- ggplot(filtertrend, aes(x=coef, y=type))+
   theme_bw()+
   geom_vline(aes(xintercept=0), colour="red", linetype = "dashed", size=1)+
   geom_point(aes(fill=filtertrend$variable, colour=filtertrend$significant, stroke=2-filtertrend$p*2),size=6, alpha=0.9,shape=21)+
   scale_colour_manual(values = c("gray80","black"))+
   scale_x_continuous(limits=c(-max(abs(filtertrend$coef), na.rm=T),max(abs(filtertrend$coef), na.rm=T)))+
   labs(x= "slope", y="")+
   guides(fill=guide_legend(title=NULL))+
   theme(legend.position="top", legend.title = element_blank(), axis.text.y = element_text(face="italic"))


 filtertrend2<-trendtime2[which(trendtime2$variable=="Total Pollen"),]
 filtertrend2$variable<-as.factor(as.character(filtertrend2$variable))
 filtertrend2$type<-as.factor(as.character(filtertrend2$type))

 trend_p3 <- ggplot(filtertrend2, aes(x=coef, y=type))+
   theme_bw()+
   geom_vline(aes(xintercept=0), colour="red", linetype = "dashed", size=1)+
   geom_point(aes( colour=filtertrend2$significant, stroke=2-filtertrend2$p*2),size=6, alpha=0.9,shape=21,fill="lightpink")+
   scale_colour_manual(values = c("gray80","black"), name = "Total Pollen: ")+
   scale_x_continuous(limits=c(-max(abs(filtertrend2$coef), na.rm=T),max(abs(filtertrend2$coef), na.rm=T)))+
   labs(x= "slope", y="")+
   theme(legend.position="top", axis.text.y = element_text(face="italic"))+
   guides(fill=guide_legend(title=""))


 if (split == F){
   analyse_trend<-trend_p1
   if(export.plot == TRUE  & export.format == "png") {
     png(file.path(plot_dir, "analyse_trend.png"), ...)
     plot(analyse_trend)
     dev.off()

   }

   if(export.plot == TRUE  & export.format == "pdf") {
     pdf(file.path(plot_dir, "analyse_trend.pdf"))
     plot(analyse_trend)

     dev.off()
   }

 }else{
   analyse_trend<-list()
   analyse_trend[[1]]<-trend_p2
   analyse_trend[[2]]<-trend_p3


   if(export.plot == TRUE  & export.format == "png") {
     png(file.path(plot_dir, "analyse_trend_split.png"))
     pushViewport(viewport(layout=grid.layout(2,1)))
     vplayout<-function(x,y) viewport(layout.pos.row = x, layout.pos.col=y)
     print(trend_p2, vp = vplayout(1,1))
     print(trend_p3, vp = vplayout(2,1))
     dev.off()

   }

   if(export.plot == TRUE  & export.format == "pdf") {
     pdf(file.path(plot_dir, "analyse_trend_split.pdf"), ...)
     pushViewport(viewport(layout=grid.layout(2,1)))
     vplayout<-function(x,y) viewport(layout.pos.row = x, layout.pos.col=y)
     print(trend_p2, vp = vplayout(1,1))
     print(trend_p3, vp = vplayout(2,1))

     dev.off()
   }
   }

 lista<-list()
 lista[["trends"]]<-trendtime


 lista [["Information"]] <- data.frame(
   Attributes = c("st.jd", "pk.jd", "en.jd", "sm.ps", "coef", "p", "", "", "Package", "Authors"),
   Description = c("Start-date (day of the year)","Peak-date (day of year)",  "End-date (day of the year)", "Pollen integral", "Slope of the linear trend", "Significance level of the linear trend",  "", "", "AeRobiology", "Jesus Rojo, Antonio Picornell & Jose Oteros"))

 if (isTRUE(export.result)) {
   write_xlsx(lista, file.path(table_dir, "summary_of_trends.xlsx"))
 }

 if (result=="table"){
   return(trendtimeresult)
 }else if (result=="plot"){
   return(analyse_trend)
 }
}

#'Plotting hourly patterns
#'
#'Function to plot pollen data expressed in concentrations with time resolution higher than 1 day (e.g. hourly, bi-hourly concentrations).
#'
#'@param data A \code{data.frame} object with the structure \code{long}. Where the first two columns are \code{factors} indicating the \code{pollen} and the \code{location}. The 3 and 4 columns are \code{POSIXct}, showing the hour. Where the third column is the beguinning of the concentration \code{from} and the fourth column is the end time of the concentrtion data \code{to}. The fifth column shows the concentrations of the different pollen types as \code{numeric}. Please see the example 3-hourly data from the automatic pollen monitor BAA500 from Munich and Viechtach in Bavaria (Germany) \code{data("POMO_pollen")}, supplied by ePIN Network supported by the Bavarian Government.
#'@param result A \code{character} object with the definition of the object to be produced by the function. If \code{result == "plot"}, the function returns a list of objects of class \pkg{ggplot2}; if \code{result == "table"}, the function returns a \pkg{data.frame} with the hourly patterns. By default, \code{result = "plot"}.
#'@param locations A \code{logical} object with the specification if the different locations will be displayed in the plot. Argument only used when \code{result == "plot"}. By default, \code{locations = FALSE}.
#'@return If \code{result == "plot"}, the function returns a list of objects of class \pkg{ggplot2}; if \code{result == "table"}, the function returns a \pkg{data.frame} with the hourly patterns.
#'@references Oteros, J., Pusch, G., Weichenmeier, I., Heimann, U., Mueller, R., Roeseler, S., ... & Buters, J. T. (2015). Automatic and online pollen monitoring. \emph{International archives of allergy and immunology}, 167(3), 158-166.
#'@examples data("POMO_pollen")
#'@examples plot_hour(POMO_pollen, result="plot", locations = FALSE)
#'@examples plot_hour(POMO_pollen, result="plot", locations = TRUE)
#'@importFrom stats aggregate
#'@importFrom data.table data.table
#'@importFrom lubridate hour yday
#'@importFrom dplyr group_by summarise
#'@importFrom tidyr spread
#'@importFrom ggplot2 ggplot scale_fill_brewer
#'@export
plot_hour <-
  function (data, result="plot", locations = FALSE) {
    data<-data.frame(data)
    if(!is.data.frame(data)) stop ("Please include a data.frame: first column with factor indicating the pollen, second column with factor indicating the locaiton, third column with POSIXct indicating the (from), fourth column with POSIXct indicating the (to) and fifth column with numbers indicating the concentration")
    if(result != "plot" & result != "table") stop ("Please result only accept values: 'table' or 'plot'")
    if(!is.logical(locations)) stop ("Please include only logical values for locations argument")

    colnames(data)<-c("pollen","location","from","to","value")
# HOUR = percent = location = NULL
    data$date<-as.Date(as.character(data$from),"%Y-%m-%d")
    data$hour<-hour(strptime(as.character(data$from), format = '%Y-%m-%d %H:%M', 'GMT'))
    data$hour2<-hour(strptime(as.character(data$to), format = '%Y-%m-%d %H:%M', 'GMT'))
    data$Hour<-paste0(data$hour,"-",data$hour2)
    # data$Hour<-factor(data$Hour,levels = c("0-3","3-6","6-9","9-12","12-15","15-18","18-21","21-0"))

    ### Data to 24h concentrations AND POLLENS selection ###

    dayconc<-data.table(data)
    colnames(dayconc)[1]<-"pollen"

    table<-aggregate( value ~ date+pollen+location, data=dayconc, FUN=mean)
    table2<-aggregate( value ~ date+pollen+location, data=dayconc, FUN=max)
    table$max<-table2$value

    mainpollen<-data%>%group_by(pollen)%>%summarise(total=sum(value, na.rm=TRUE))
    mainpollen<-as.data.frame(mainpollen)

    pollens <-mainpollen[,"pollen"]


    pollens<-as.character(pollens)

    table<-table[which(as.character(table$pollen) %in% pollens),]
    table$location<-as.character(table$location)
    table$location<-as.factor(table$location)
    ##### Calculate hourly frames
    frame3<-data.frame()
    data_end<-data.frame()
    if (locations == TRUE){
    for (loc in levels(table$location)){

      tabletemp<-dayconc[which(dayconc$location==loc),]
      tabletemp$location<-as.character(tabletemp$location)
      data_wide <- spread(tabletemp, pollen, value)
      data_wide$location<-loc
      data_end<-rbind(data_end,data_wide)
      tabletemp<-as.data.frame(tabletemp)
      for ( a in 1:length(pollens)){
        tempo<-tabletemp[which(tabletemp$pollen==pollens[a]),]

        if(nrow(tempo)==0){next}
        for ( b in 1:nrow(tempo)){

          tempo[b,"percent"]<-tempo[b,"value"]*100/table[which(table$pollen==pollens[a] & table$date==tempo[b,"date"] & table$location==tempo[b,"location"]),"value"]
        }
        tempo$percent<-tempo$percent/length(unique(data$Hour))

        frame3<-rbind(frame3,tempo)
      }

      frame3<-frame3[complete.cases(frame3),]
    }
   }else {

      tabletemp<-dayconc

      data_wide <- spread(tabletemp, pollen, value)
      data_wide$location<-"All"
      data_end<-data_wide
      tabletemp<-as.data.frame(tabletemp)
      for ( a in 1:length(pollens)){
        tempo<-tabletemp[which(tabletemp$pollen==pollens[a]),]

        if(nrow(tempo)==0){next}
        for ( b in 1:nrow(tempo)){

          tempo[b,"percent"]<-tempo[b,"value"]*100/table[which(table$pollen==pollens[a] & table$date==tempo[b,"date"] & table$location==tempo[b,"location"]),"value"]
        }
        tempo$percent<-tempo$percent/length(unique(data$Hour))

        frame3<-rbind(frame3,tempo)
      }

      frame3<-frame3[complete.cases(frame3),]

  }

    # frame3<-frame3[which(yday(frame3$date)%in%summerseries),]

    frame3 = frame3[order(frame3$hour), ]

    frame3$Hour = factor(frame3$Hour, levels = unique(frame3$Hour))

if (result == "plot" & locations==FALSE) {
  plottotal<-ggplot(frame3,aes(x=as.factor(Hour),y=percent))+
    geom_bar(stat = "summary", fun.y = "mean", color="black", fill="gray")+
    theme_bw()+
    labs(x="hour", y="daily pollen (%)", title="Total pollen")+
    theme(axis.text.x = element_text(angle = 45, hjust = 1))

  pollenlist<-list()
  pollenlist[[1]]<-plottotal
  for ( a in 1:length(pollens)){
    tempo<-frame3[which(frame3$pollen==pollens[a]),]
    pollenlist[[a+1]]<- ggplot(tempo,aes(x=as.factor(Hour),y=percent))+
      geom_bar(stat = "summary", fun.y = "mean", color="black", fill="gray")+
      theme_bw()+
      labs(x="hour", y="daily pollen (%)", title=pollens[a])+
      theme(axis.text.x = element_text(angle = 45, hjust  = 1))


  }
  pollenlist
}else if (result == "plot" & locations==TRUE){
  plottotal<-ggplot(frame3,aes(x=as.factor(Hour),y=percent,fill=location))+
    geom_bar(stat = "summary", fun.y = "mean", color="black",position='dodge')+
    theme_bw()+
    labs(x="hour", y="daily pollen (%)", title="Total pollen")+
    theme(axis.text.x = element_text(angle = 45, hjust = 1))+
    scale_fill_brewer(palette="Set1")

  pollenlist<-list()
  pollenlist[[1]]<-plottotal
  for ( a in 1:length(pollens)){
    tempo<-frame3[which(frame3$pollen==pollens[a]),]
    pollenlist[[a+1]]<- ggplot(tempo,aes(x=as.factor(Hour),y=percent, fill=location))+
      geom_bar(stat = "summary", fun.y = "mean", color="black",position='dodge')+
      theme_bw()+
      labs(x="hour", y="daily pollen (%)", title=pollens[a])+
      theme(axis.text.x = element_text(angle = 45, hjust = 1))+
      scale_fill_brewer(palette="Set1")


  }
  pollenlist
}

    if (result=="plot"){
      return(pollenlist)
    } else if (result=="table"){
      return(frame3)
    }


  }

#' Interactive Plotting Pollen Data (one season).
#'
#' Function to plot the pollen data during one season. The plots are fully interactive.
#'
#' @param data A \code{data.frame} object. This \code{data.frame} should include a first column in format \code{Date} and the rest of columns in format \code{numeric} belonging to each pollen type by column.
#' @param year An \code{integer} value specifying the year to display. This is a mandatory argument.
#' @return An interactive plot of the class \pkg{ggvis}.
#' @seealso \code{\link{iplot_years}}
#' @examples data("munich_pollen")
#' @examples iplot_pollen(data = munich_pollen, year = 2012)
#' @importFrom dplyr filter
#' @importFrom ggvis add_axis axis_props ggvis input_checkboxgroup input_slider layer_lines layer_points scale_numeric %>%
#' @importFrom lubridate is.POSIXt yday year
#' @importFrom tidyr gather
#' @importFrom stats complete.cases
#' @export
iplot_pollen<-function(data, year){

  data<-data.frame(data)
  if(!is.data.frame(data)) stop ("Please include a data.frame: first column with date, and the rest with pollen types")

  if(!is.numeric(year)) stop ("Please include only numeric values for 'year' (including only years in your database)")
  if(!inherits(data[,1], "Date") & !is.POSIXt(data[,1])) {stop("Please the first column of your data must be the date in 'Date' format")}
  colnames(data)[1]<-"date"
  data[,1]<-as.Date(data[,1])

  datalong <-
    gather(
      data,
      colnames(data[2:length(data)]),
      key = "variable",
      value = "value"
    )

## Compare_pollen
datalong_pollen <- datalong[which(year(datalong[, 1]) == year), ]
datalong_pollen$date <- yday(datalong_pollen$date)
datalong_pollen <-
  datalong_pollen[which(complete.cases(datalong_pollen)), ]

iplot_pollen <- datalong_pollen %>%
  ggvis(x =  ~ date,
        y =  ~ value,
        stroke = ~ variable) %>%
  filter(variable %in% eval(input_checkboxgroup(unique(
    datalong_pollen$variable
  )))) %>%
  layer_lines(opacity := 0.6, strokeWidth := 1) %>%
  layer_points(size := 20, opacity := 0.8, strokeWidth := 5) %>%
  add_axis("y", title = "Pollen concentration", title_offset = 50) %>%
  scale_numeric("x", domain = input_slider(1, 365, c(1, 365)), clamp = T) %>%
  add_axis("x", title = "Day of the year") %>%
  add_axis("x", orient = "top", ticks = 0, title = paste("Year",year),
           properties = axis_props(
             axis = list(stroke = "white"),
             labels = list(fontSize = 0)))

return(iplot_pollen)

}

#' Calculating and Plotting Trends of Pollen Data.
#'
#' Function to calculate the main seasonal indexes of the pollen season (\emph{Start Date}, \emph{Peak Date}, \emph{End Date} and \emph{Pollen Integral}). Trends analysis of the parameters over the seasons. Plots showing the distribution of the main seasonal indexes over the years.
#'
#' @param data A \code{data.frame} object. This \code{data.frame} should include a first column in format \code{Date} and the rest of columns in format \code{numeric} belonging to each pollen type by column.
#' @param base_dir Character. Base directory where output tables are stored.
#' @param table_dir Character. Directory where tables are exported.
#' @param interpolation A \code{logical} value specifying if the visualization shows the gaps in the inputs data (\code{interpolation = FALSE}) or if an interpolation method is used for filling the gaps (\code{interpolation = TRUE}). By default, \code{interpolation = TRUE}.
#' @param int.method A \code{character} string with the name of the interpolation method to be used. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"tseries"} or \code{"spline"}. By default, \code{int.method = "lineal"}.
#' @param export.plot A \code{logical} value specifying if a plot will be exported or not. If \code{FALSE} graphical results will only be displayed in the active graphics window. If \code{TRUE} graphical results will be displayed in the active graphics window and also one pdf/png file will be saved within the \emph{plot_AeRobiology} directory automatically created in the working directory. By default, \code{export.plot = TRUE}.
#' @param export.format A \code{character} string specifying the format selected to save the plot. The implemented formats that may be used are: \code{"pdf"} or \code{"png"}. By default, \code{export.format = "pdf"}.
#' @param export.result A \code{logical} value. If \code{export.result = TRUE}, a table is exported with the extension \emph{.xlsx}, in the directory \emph{table_AeRobiology}. This table has the information about the \code{slope} \emph{"beta coefficient of a lineal model using as predictor the year and as dependent variable one of the main pollen season indexes"}. The information is referred to the main pollen season indexes: \emph{Start Date}, \emph{Peak Date}, \emph{End Date} and \emph{Pollen Integral}.
#' @param method A \code{character} string specifying the method applied to calculate the pollen season and the main seasonal parameters. The implemented methods that can be used are: \code{"percentage"}, \code{"logistic"}, \code{"moving"}, \code{"clinical"} or \code{"grains"}. By default, \code{method = "percentage"} (\code{perc = 95}\%). A more detailed information about the different methods for defining the pollen season may be consulted in the function \code{\link{calculate_ps}}.
#' @param ... Additional arguments for the function \code{\link{calculate_ps}} are also accepted.
#' @return This function returns several plots in the directory \emph{plot_AeRobiology/trend_plots} with the extension \emph{.pdf} or \emph{.png}.Also produces an object of the class \code{data.frame} and export a table with the extension \emph{.xlsx}, in the directory \emph{table_AeRobiology}.\cr
#'These tables have the information about the \code{slope} \emph{(beta coefficient of a lineal model using as predictor the year and as dependent variable one of the main pollen season indexes)}. The information is referred to the main pollen season indexes: \emph{Start Date}, \emph{Peak Date}, \emph{End Date} and \emph{Pollen Integral}.
#' @seealso \code{\link{calculate_ps}}; \code{\link{analyse_trend}}
#' @examples  data("munich_pollen")
#' @examples  plot_trend(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = TRUE)
#' @importFrom graphics plot
#' @importFrom utils data
#' @importFrom ggplot2 aes element_text geom_point geom_smooth ggplot labs theme theme_classic theme_set scale_x_continuous
#' @importFrom grDevices dev.off pdf png
#' @importFrom grid grid.layout pushViewport viewport
#' @importFrom lubridate is.POSIXt
#' @importFrom stats as.formula complete.cases lm pf
#' @importFrom scales pretty_breaks
#' @importFrom writexl write_xlsx
#' @importFrom tidyr %>%
#' @export

plot_trend  <-   function   (data,
              base_dir = getwd(),
              table_dir = file.path(base_dir, "table_AeRobiology"),
              interpolation = TRUE,
              int.method = "lineal",
              export.plot = TRUE,
              export.format = "pdf",
              export.result=TRUE,
              method="percentage",
              ...){

  # Sys.setlocale(category = "LC_ALL", locale="english")
  
  # Base directory: during R CMD check, write into a temp folder, not the package/check dir
  base_dir <- if (nzchar(Sys.getenv("_R_CHECK_PACKAGE_NAME_"))) tempdir() else "."
  plot_dir <- file.path(base_dir, "plot_AeRobiology")
  trend_plot_dir <- file.path(plot_dir, "trend_plots")

  #############################################    CHECK THE ARGUMENTS       #############################

  if(export.plot == TRUE){ifelse(!dir.exists(file.path("plot_AeRobiology")), dir.create(file.path("plot_AeRobiology")), FALSE)}
  if (isTRUE(export.plot)) {
    dir.create(trend_plot_dir, recursive = TRUE, showWarnings = FALSE)
  }
  if (isTRUE(export.result)) { if (!dir.exists(table_dir)) dir.create(table_dir, recursive = TRUE) }
  data<-data.frame(data)
  if(!is.data.frame(data)) stop ("Please include a data.frame: first column with date, and the rest with pollen types")

  if(!is.logical(export.plot)) stop ("Please include only logical values for export.plot argument")

  if(export.format != "pdf" & export.format != "png") stop ("Please export.format only accept values: 'pdf' or 'png'")

  if(class(data[,1])[1]!="Date" & !is.POSIXt(data[,1])) {stop("Please the first column of your data must be the date in 'Date' format")}
  data[,1]<-as.Date(data[,1])

  if(!is.logical(interpolation)) stop ("Please include only logical values for interpolation argument")

  # if(int.method != "lineal" & int.method != "movingmean" & int.method != "spline" & int.method != "tseries") stop ("Please int.method only accept values: 'lineal', 'movingmean', 'tseries' or 'spline'")

  # if(interpolation == TRUE){data <- interpollen(data, method = int.method)}


  colnames(data)[1]<-"Date"

  ## Function for p value
  lmp <- function (modelobject) {
    if (!inherits(modelobject, "lm")) stop("Not an object of class 'lm' ")
    f <- summary(modelobject)$fstatistic
    p <- pf(f[1],f[2],f[3],lower.tail=F)
    attributes(p) <- NULL
    return(p)
  }

  datafram<-calculate_ps(data, method=method, interpolation = interpolation, int.method=int.method,plot=FALSE,...)

  variables<-c("st.jd","pk.jd","en.jd","sm.ps")

  trendtime<-data.frame()

  data_summary<-
    for (t in 1:length(unique(datafram$type))){

      type<-unique(as.character(datafram$type))[t]



          for (v in 1:length(variables)){
            tryCatch({
            variable<-variables[v]

            temp<-datafram[which(datafram$type==type),c(1:2,which( colnames(datafram)==variable))]

            lm <- lm (as.formula(paste(variable,"~ seasons")), data= temp, x = TRUE, y = TRUE)

            tempframe<-data.frame(type=type,variable=variable,coef=summary(lm)$coefficients[2,1],p=lmp(lm))

            trendtime<-rbind(trendtime,tempframe)
            }, error=function(e){
              print(paste(type, variable, ": Error, linear model not calculated. Probably due to insufficient amount of years"))
            })
          }
      }




datafram<-datafram[complete.cases(datafram),]


### Now start the rock and roll

  for (p in 1:length(unique(as.character(datafram$type)))){
      pollen<-unique(as.character(datafram$type))[p]
      dataframtemp<-datafram[which(datafram$type==pollen),]

      dataframtemp$seasons<-as.integer(dataframtemp$seasons)

  slope<-trendtime[which(trendtime$type==pollen & trendtime$variable=="st.jd"),"coef"]
  slope<-round(slope, 1)
  slope<-paste0("slope: ",slope)
  p<-trendtime[which(trendtime$type==pollen & trendtime$variable=="st.jd"),"p"]
  p<-round(p, 3)
  if (p < 0.001) {
    pvalue <- "p<0.001"
  } else if (p < 0.01) {
    pvalue <- "p<0.01"
  } else if (p < 0.05) {
    pvalue <- "p<0.05"
  } else {
    pvalue <- "p>0.05"
  }
  p<-pvalue
  comb<-paste0(slope,", ",p)

  p1 <- ggplot(dataframtemp, aes(x=seasons, y=st.jd)) +
    theme_set(theme_classic()) +
    geom_smooth(method="loess", size=1, colour="blue", fill="light blue") +
    geom_smooth(method="lm", size=1, se=FALSE, colour="red", linetype="dashed")  +
    geom_point(shape=21, stroke=1.5,size = 3.5, fill="darkgrey", colour="black") +
    labs(x="", y="Day of the Year (DOY)", title= paste("Start Date", pollen), subtitle=comb)+
    theme(axis.text=element_text(size=10), axis.title=element_text(size=10)) +
    theme(plot.title=element_text(size=13, face = "bold.italic"))+
    scale_x_continuous(breaks=pretty_breaks())

  p1 <- ggplot(dataframtemp, aes(x=seasons, y=st.jd)) +
    theme_set(theme_classic()) +
    geom_smooth(method="loess", size=1, colour="blue", fill="light blue") +
    geom_smooth(method="lm", size=1, se=FALSE, colour="red", linetype="dashed")  +
    geom_point(shape=21, stroke=1.5,size = 3.5, fill="darkgrey", colour="black") +
    labs(x="", y="Day of the Year (DOY)", title= paste("Start Date", pollen), subtitle=comb)+
    theme(axis.text=element_text(size=10), axis.title=element_text(size=10)) +
    theme(plot.title=element_text(size=13, face = "bold.italic"))+
    scale_x_continuous(breaks=pretty_breaks())


  slope<-trendtime[which(trendtime$type==pollen & trendtime$variable=="pk.jd"),"coef"]
  slope<-round(slope, 1)
  slope<-paste0("slope: ",slope)
  p<-trendtime[which(trendtime$type==pollen & trendtime$variable=="pk.jd"),"p"]
  p<-round(p, 3)
  if (p < 0.001) {
    pvalue <- "p<0.001"
  } else if (p < 0.01) {
    pvalue <- "p<0.01"
  } else if (p < 0.05) {
    pvalue <- "p<0.05"
  } else {
    pvalue <- "p>0.05"
  }
  p<-pvalue
  comb<-paste0(slope,", ",p)
  p2 <- ggplot(dataframtemp, aes(x=seasons, y=pk.jd)) +
    theme_set(theme_classic()) +
    geom_smooth(method="loess",size=1, colour="blue", fill="light blue") +
    geom_smooth(method="lm", size=1, se=FALSE, colour="red", linetype="dashed")  +
    geom_point(shape=21, stroke=1.5,size = 3.5,  fill="darkgrey", colour="black") +
    labs(x="", y="Day of the Year (DOY)", title=paste("Peak Date", pollen), subtitle=comb)+
    theme(axis.text=element_text(size=10), axis.title=element_text(size=10)) +
    theme(plot.title=element_text(size=13, face = "bold.italic"))+
    scale_x_continuous(breaks=pretty_breaks())

  slope<-trendtime[which(trendtime$type==pollen & trendtime$variable=="en.jd"),"coef"]
  slope<-round(slope, 1)
  slope<-paste0("slope: ",slope)
  p<-trendtime[which(trendtime$type==pollen & trendtime$variable=="en.jd"),"p"]
  p<-round(p, 3)
  if (p < 0.001) {
    pvalue <- "p<0.001"
  } else if (p < 0.01) {
    pvalue <- "p<0.01"
  } else if (p < 0.05) {
    pvalue <- "p<0.05"
  } else {
    pvalue <- "p>0.05"
  }
  p<-pvalue
  comb<-paste0(slope,", ",p)
  p3 <- ggplot(dataframtemp, aes(x=seasons, y=en.jd)) +
    theme_set(theme_classic()) +
    geom_smooth(method="loess",size=1, colour="blue", fill="light blue") +
    geom_smooth(method="lm", size=1, se=FALSE, colour="red", linetype="dashed")  +
    geom_point(shape=21, stroke=1.5,size = 3.5,  fill="darkgrey", colour="black") +
    labs(x="", y="Day of the Year (DOY)", title= paste("End Date", pollen), subtitle=comb)+
    theme(axis.text=element_text(size=10), axis.title=element_text(size=10)) +
    theme(plot.title=element_text(size=13, face = "bold.italic"))+
    scale_x_continuous(breaks=pretty_breaks())

  slope<-trendtime[which(trendtime$type==pollen & trendtime$variable=="sm.ps"),"coef"]
  slope<-round(slope, 1)
  slope<-paste0("slope: ",slope)
  p<-trendtime[which(trendtime$type==pollen & trendtime$variable=="sm.ps"),"p"]
  p<-round(p, 3)
  if (p < 0.001) {
    pvalue <- "p<0.001"
  } else if (p < 0.01) {
    pvalue <- "p<0.01"
  } else if (p < 0.05) {
    pvalue <- "p<0.05"
  } else {
    pvalue <- "p>0.05"
  }
  p<-pvalue
  comb<-paste0(slope,", ",p)
  p4 <- ggplot(dataframtemp, aes(x=seasons, y=sm.ps)) +
    theme_set(theme_classic()) +
    geom_smooth(method="loess", size=1, colour="blue", fill="light blue") +
    geom_smooth(method="lm", size=1, se=FALSE, colour="red", linetype="dashed")  +
    geom_point(shape=21, stroke=1.5,size = 3.5,  fill="darkgrey", colour="black") +
    labs(x="", y="Pollen grains", title=paste("Total Pollen", pollen),subtitle=comb)+
    theme(axis.text=element_text(size=10), axis.title=element_text(size=10)) +
    theme(plot.title=element_text(size=13, face = "bold.italic"))+
    scale_x_continuous(breaks=pretty_breaks())


 if(export.plot == TRUE  & export.format == "png") {
   png(file.path(trend_plot_dir, paste0("plot_trend_", pollen, ".png")))
   pushViewport(viewport(layout=grid.layout(2,2)))
   vplayout<-function(x,y) viewport(layout.pos.row = x, layout.pos.col=y)
   print(p1, vp = vplayout(1,1))
   print(p2, vp = vplayout(1,2))
   print(p3, vp = vplayout(2,1))
   print(p4, vp = vplayout(2,2))
   dev.off()

 }

 if(export.plot == TRUE  & export.format == "pdf") {
   pdf(file.path(trend_plot_dir, paste0("plot_trend_", pollen, ".pdf")))
   pushViewport(viewport(layout=grid.layout(2,2)))
   vplayout<-function(x,y) viewport(layout.pos.row = x, layout.pos.col=y)
   print(p1, vp = vplayout(1,1))
   print(p2, vp = vplayout(1,2))
   print(p3, vp = vplayout(2,1))
   print(p4, vp = vplayout(2,2))

   dev.off()
 }

}

lista<-list()
lista[["plot_trend"]]<-trendtime


lista [["Information"]] <- data.frame(
  Attributes = c("st.jd", "pk.jd", "en.jd", "sm.ps", "coef", "p", "", "", "Package", "Authors"),
  Description = c("Start-date (day of the year)","Peak-date (day of year)",  "End-date (day of the year)", "Pollen integral", "Slope of the linear trend", "Significance level of the linear trend",  "", "", "AeRobiology", "Jesus Rojo, Antonio Picornell & Jose Oteros"))





if (export.result == TRUE) {
  write_xlsx(lista, file.path(table_dir, "summary_of_plot_trend.xlsx"))
}
return(trendtime)
}

---
title: "Vignette of AeRobiology"
subtitle: "A Computational Tool for Aerobiological Data"
author: Jesus Rojo^[University of Castilla-La Mancha & ZAUM (TUM/Helmholtz Zentrum)]
        Antonio Picornell^[University of Malaga]
        Jose Oteros^[Zentrum Allergie und Umwelt - ZAUM (TUM/Helmholtz Zentrum)]
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Vignette of AeRobiology}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r include = FALSE}
knitr::opts_chunk$set(echo = FALSE, warning = FALSE, fig.width = 7)
Sys.setlocale(locale="english")
```

<style>
p.comment {
background-color: #DBDBDB;
padding: 5px;
margin-left: 3px;
border-radius: 5px;
font-style: italic;
}

</style>

  ![AeRobiology R package](logo_aerobiology.jpg)
  
This package gathers different tools for managing aerobiological databases, elaborating the main calculations and visualization of results. In a first step, data may be checked using tools for quality control and all missing gaps can be completed. Then, the main parameters of the pollen season can be calculated and represented graphically. Multiple graphical tools are available: pollen calendars, phenological plots, time series, tendencies, interactive plots, abundance plots...
  
<div class="alert alert-info">**Please, take into account that not all the arguments of each function are explained in this document. This is a quick guide and further details can be consulted in the [official document](https://CRAN.R-project.org/package=AeRobiology) of the package.**</div>
  
  The first thing you have to do is to install from CRAN repository and to load the package <font size="2" face="verdana">AeRobiology</font>.<div/>  

```{r echo=FALSE}
library ("knitr")
```
  
```{r}
library ("AeRobiology")
```
  
```{r eval=FALSE, echo = TRUE}
install.packages("AeRobiology")
library (AeRobiology)
```
  
    
    
# Using the attached data

During this tutorial we are going to use the **pollen data from Munich** which are **integrated in the package**. This will allow you to follow the tutorial obtaining the same results. If you want to follow the tutorial by using your own data, check the next section.

  <p class="comment">**`munich_pollen`** is a data set containing information of daily concentrations of pollen in the atmosphere of Munich during the years 2010_2015. Pollen types included: "Alnus", "Betula", "Taxus", "Fraxinus", "Poaceae", "Quercus", "Ulmus" and "Urtica".  
Data were obtained at Munich (Zentrum Allergie und Umwelt, ZAUM) using a Hirst_type volumetric pollen trap (Hirst, 1952) following the standard methodology (VDI4252_4_2016). Some gaps have been added to test some functions of the package (e.g. <font size="2" face="verdana">quality_control()</font>, <font size="2" face="verdana">interpollen()</font>). <br>
The data were obtained by the research team of Prof. Jeroen Buters (Christine Weil & Ingrid Weichenmeier). At the Zentrum Allergie und Umwelt (ZAUM, directed by Prof. Carsten B. Schmidt_Weber). </p> 

You can **load the data** in your working environment by typing:

```{r echo = TRUE}
data("munich_pollen")
```
  
    
    
# Loading your database from Excel
This section has been developed for people who are not familiar with R. **If you have experience in loading databases in R, you might not be interested in this section and you can skip it.**

There are several functions to import data from Excel. Arbitrarily, we are going to use the package **<font size="3" face="verdana">readxl</font>**.
```{r eval=FALSE, echo = TRUE}
install.packages("readxl")
library (readxl)
```

Now we can import the data with the function **<font size="3" face="verdana">read_xlsx()</font>**. I strongly recommend you to **have your Excel file in the same folder in which you are working with R**. This will avoid long paths to your files and also will prevent broken paths when some files have been moved. If you are working with an old database, you might be interested in the **<font size="3" face="verdana">read_xls()</font>** function.

```{r eval=FALSE, echo = TRUE}
Mydata<-read_xlsx("C:/Users/Antonio/Desktop/Prueba Markdown/mydata.xlsx")

```
You can also **select the sheet** you want to import:

```{r eval=FALSE, echo = TRUE}
Mydata<-read_xlsx("C:/Users/Antonio/Desktop/Prueba Markdown/mydata.xlsx", sheet=2)

```

<div class="alert alert-info">**IMPORTANT**: You must remove all the symbols or letters from your database. **If you have missing gaps within your database don't put "-" or "No Data" or any letter in the gaps**, keep the cell empty or remove the cell. The dates should be in a complete format (E.g.:"14/02/2019"). There must be a first column with the date followed by as many columns as pollen types with only numeric values (**check decimal separation: commas must be replaced by dots**).</div>

Now you should have loaded your data in the object `Mydata`. Let's check if there is any mistake:

```{r echo=TRUE, results='hold'}
str(munich_pollen)
```

**Note**: I'm using `munich_pollen` database as example but you should use `Mydata`.

As you can see, the object is a `data.frame`, the first column is "Date" type and the rest are "num", which means numeric. This is the format you database **must** have. Normally it is automatically recognized by the import function, but if not, check the functions: <font size="3" face="verdana">**as.Date()**</font>, <font size="3" face="verdana">**as.numeric()**</font> and <font size="3" face="verdana">**as.data.frame()**</font>.

<div class="alert alert-info"><p>**Your database must have this format to start working with the package**. The functions are designed to warn you in case the format is not correct but there may be some exceptions. **This is the most important step when using the package and some strange errors reported by the functions can be solved by doing this**. Sometimes the date column has 2 different types simultaneously ("POSIXlt" and "POSIXct") and it might cause mistakes. You can use one or another, but not both. Furthermore, it is strongly recommended to use "Date" format instead of "POSIXlt" or "POSIXct" despite theoretically there may not be problems by using them.</p><br>

<p>**Please, don`t exasperate**. This is the **slowest step of using the package and the most important**. Once you have your data loaded, you only have to spend a few minutes in each function to have your results. If you have some unsolving problems, search on the internet. Some other people must have had your same problem and it should be solved in some forums. If not, write us and we will help you as soon as possible: aerobiology.package@gmail.com </p></div>

<p class="comment">If you want to import your data from **csv files**, you might be interested in **<font size="3" face="verdana">read.csv()</font>** function.</p>
  
    
    
# Function <font face="verdana">quality_control()</font>

**This function was designed to check the quality of an historical database of several pollen types**. Since many of the quality requirements depend on the criteria selected to establish the main pollen season, this function has the **<font size="3" face="verdana">calculate_ps()</font> function integrated**. You can insert arguments of calculate_ps() in this function to select the method you want for calculating the main pollen season. calculate_ps() details can be consulted later in this same manuscript.

<p class="comment">If **result = "plot"**, this function returns a **graphical resume** of the quality of the database marking with different red intensities the "weak-points" of it, and if **result = "table"** a `data.frame` with the detailed reasons of their "weakness".</p>

**It establishes the quality according to 5 different criteria**:

* **It checks if the main pollen season cannot be calculated according to the minimal requirements:** lack of data for this pollen type and year. This criteria appears as **"Complete"** in the generated data.frame.

* **If the start, end or peak dates of the main pollen season have been interpolated** (or a date near them specified by **`int.window`** argument). It is based on the following premise: If this day or a nearby date is missing/interpolated, the selected date as start/peak/end might not be the real one. These criteria appear as **"Start"**, **"Peak"** and **"End"** in the generated data.frame.

* **The percentage of missing data within the main pollen season.** It calculates the number of days which have been interpolated by interpollen() function and their percentage of the main pollen season. If a high percentage of the main pollen season has been interpolated, the information of this season might not be reliable. The maximal percentage allowed can be specified by the **`perc.miss`** argument. This filter appears as **"Comp.MPS"** in the generated data.frame.

When running the function, it gives you a **graphical resume** with different color intensity depending on the risk of including each pollen/spore type for a concrete year and a **data.frame** with detailed information about the reasons of this evaluation.

<div class="alert alert-info"> If **result = "plot"**, the function returns a list of objects of class *ggplot2*; if **result = "table"**, the function returns a *data.frame*. By default, **result = "table"**.</div>

```{r echo=TRUE, results='hide', fig.keep='first'}
QualityControl<-quality_control(munich_pollen, result = "table")
```


If the filter has been successfully passed, it appears as `TRUE` in the generated `data.frame`. If not, it appears as `FALSE`.


```{r echo=TRUE, results='hold'}

head(QualityControl)
```


```{r echo=TRUE,  fig.keep='first', results='hide'}
quality_control(munich_pollen, result = "plot")
```


There are lots of arguments for this function. You can consult them in the "help" section of the function in R or in the [official document](https://CRAN.R-project.org/package=AeRobiology) of the package.

Let's suppose we want to check the quality of our database, but we want to calculate it for a **80% defined Main Pollen Season** (arguments **`ps.method`** and **`perc`**). We don't want to take into account years with a missing data less than **4 days** away from the start, peak or end dates (argument **`int.window`**). Furthermore, we only want to exclude years with more than **50% of interpolated data** within the main pollen season (argument **`perc.miss`**):

```{r echo=TRUE, results='hide', fig.keep='first'}
quality_control(munich_pollen, int.window = 4, perc.miss = 50, ps.method = "percentage", perc = 80)
```

**As you would have noticed, there are several differences between this result and the previous one.**

<div class="alert alert-info">**<font size="3" face="verdana">interpollen()</font> function** is integrated in this function. Consult the "help" section of this function to use it.</div>
  
    
    
# Function <font face="verdana">interpollen()</font>
The function **<font size="3" face="verdana">interpollen()</font>** was designed to complete all the missing gaps within a database in just one step. All the gaps of each pollen/spore type are completed simultaneously. **There are different methods to do so which may be more or less appropriate according to the particularities of your database.** The arguments are:

* **data**: A `data.frame` object. This data.frame should include a first column in "Date" format and the rest of the columns in "numeric" format belonging to each pollen/spore type by column.
* **method**: A `character` string specifying the method applied to calculate and generate the pollen missing data. The implemented methods that can be used are: **"lineal"**, **"movingmean"**, **"spline"**, **"tseries"** or **"neighbour"**. The method argument will be "lineal" by default.
* **maxdays**: A `numeric (integer)` value specifying the maximum number of consecutive days with missing data that the algorithm is going to interpolate. If the gap is bigger than the argument value, the gap will not be interpolated. Not valid with <font size="2" face="verdana">"tseries"</font> method. The <font size="2" face="verdana">maxdays</font> argument will be 30 by default. This argument might be very interesting to avoid long interpolated gaps.
* **plot**: A `logical (integer)` argument. If `TRUE`, graphical previews of the input database will be plot at the end of the interpolation process. All the interpolated gaps will be marked in red. The `plot` argument will be `TRUE` by default.
* Others...

```{r echo=TRUE, results='hide', fig.keep='first'}
Interpolated<-interpollen(munich_pollen[,c(1,6)], method="lineal", plot = TRUE, result = "long")

```

As you can see above, when **result = "long"**, **the missing gaps which have been completed by the algorithm are marked in red.** It displays similar graphs for each pollen/spore type within your database. Furthermore, the **"Interpolated"** data.frame is produced as "long" with another new column indicating if each data has been interpolated or not (1 means interpolated and 0 means original data).

```{r echo=TRUE, results='hold'}
head(Interpolated)
```


If you want to integrate all the new data in your database, **you can assign the function to a new object** and specify the argument **result = "wide"**:

```{r echo=TRUE, results='hide'}
CompleteData<-interpollen(munich_pollen[,c(1,6)], method="lineal", plot = FALSE, result = "wide")
```

Now your database without gaps appears as "CompleteData".

**As you might have noticed, if you add `plot=FALSE`, the graphs are not shown.**

You don't have to do this before applying another function of this package. **<font size="3" face="verdana">"interpollen"</font> function has been integrated in the main functions of the package** so you can choose whether you want your data to be completed or not by a specific argument in each function.E.g.:

```{r echo=TRUE, eval=FALSE}
calculate_ps(munich_pollen, method="percentage", interpolation=TRUE, int.method = "lineal", plot = F)
```

<div class="alert alert-info">**FREQUENT ERROR:** Sometimes when applying interpollen you receive the following error: **"Error in rep(NA, ncasos): invalid 'times' argument"**. This is due to a mistake in your database: **you have some dates repeated or disorganized**. The algorithm of `interpollen()` searches for correlative dates and, when they are not consecutive natural days, it carries out the interpolation. When the second date is an earlier date than the previous one, it reports an error. You have to correct these issues in your database before applying the interpollen function. </div>
  
  
## Methods of interpolation

In this function there are **5 different methods to interpolate missing gaps**. Each method can be more appropriate than the others under some specific circumstances. Interpolated data are not real data, but including such estimations can reduce the error of some calculations such as the main pollen season by percentage or a pollen calendar, i.e.: if you keep the gap, these days would count as 0 for the calculations and this would suppose a bigger error than estimating pollen concentrations for these days. Obviously, this will also suppose a bigger error than having the real data.

### <font face="verdana">"lineal"</font> method
As mentioned above, there are many methods to interpolate your missing data. The simplest one was the showed in the previous example: "lineal". **It traces a straight line between each extreme of the gap.** The pollen/spore concentration of the missing days is calculated according to this line. This method may be appropriate for dates without pollen/spores or for small gaps.

**Nevertheless, there are other method which can be more effective during the pollen season.**

### <font face="verdana">"movingmean"</font> method
This method calculates the moving mean of the pollen daily concentrations. The gaps are fulfilled by **calculating the moving mean of the concentrations for this particular day.** The window of the moving mean is centered on this day and its size is the result of multiplicating the gap size by the **`factor` argument**. E.g.: If you have a gap of 3 days and your factor is 2, the gaps are replaced by the value of a moving mean of 6 days (3 x 2) centered in this particular day and not taking into account the missing days for the mean value. Furthermore, it is a dynamic function: **for each gap of the database the window size of the moving mean changes depending of each gap size.**

```{r echo=TRUE, results='hide', fig.keep='first'}
i<-interpollen(munich_pollen[,c(1,6)], method="movingmean", factor = 2, plot = TRUE)
```


### <font face="verdana">"spline"</font> method
This method carries out the interpolation by tracing a **polinomic function to link both extremes of the gap.** The polinomic function is chosen according to the best fitting equation to the previous and posterior days of the gap (second, third, fourth degree...). The number of days of each side of the gap which will be taken into account for calculating the spline regression are specified by **`ndays` argument**. The smoothness of the adjustment can be specified by the **`spar` argument**.

```{r echo=TRUE, results='hide', fig.keep='first'}
i2<-interpollen(munich_pollen[,c(1,6)], method="spline", ndays=3, spar=0.7, plot = FALSE)
```

**Note**: By changing the `ndays` and `spar` argument, very different results can be obtained. E.g.:

```{r echo=TRUE, results='hide', fig.keep='first'}
i3<-interpollen(munich_pollen[,c(1,6)], method="spline", ndays=5, spar=0.2, plot = TRUE)
```

### <font face="verdana">"tseries"</font> method
If you have long time series of data, this might be the most suitable method for you. This method **analyses the time series of the pollen/spore database and performs a seasonal-trend decomposition based on LOESS** ([Cleveland et al., 1990](https://www.scirp.org/reference/referencespapers?referenceid=1891917)). It extracts the **seasonality of the historical database** and uses it to predict the missing data by performing a linear regression with the target year.

```{r echo=TRUE, results='hide', fig.keep='last'}
i4<-interpollen(munich_pollen, method="tseries", plot = TRUE)
```

**Seasonality is represented in grey, real data in black and interpolated data in red.** This method improves with long time series of years. Strange results may be caused by lack of years or small sampling periods.

### <font face="verdana">"neighbour"</font> method

**Other near stations provided by the user are used to interpolate the missing data of the target station.** First of all, a Spearman correlation is performed between the target station and the neighbour stations to discard the neighbour stations with a correlation coefficient smaller than **`mincorr` value**. For each gap, a linear regression is performed between the neighbour stations and the target stations to determine the equation which converts the pollen concentrations of the neighbour stations into the pollen concentration of the target station. Only neighbour stations without any missing data during the gap period are taken into account for each gap.

<p class="comment">You can include 4 different databases of neighbour stations with the arguments **`data2`, `data3`, `data4` and `data5`.** **The format of these databases must be the same than the original one and the name of the pollen/spore types must be exactly the same.**</p>

With the **`mincorr` argument** you can specify the minimal correlation coefficient (Spearman correlation) that the neighbour stations must have with the target station to be taken into account for a concrete gap. This process is completely independent for each gap of each pollen type.
  
    
    
# Function <font face="verdana">calculate_ps()</font>

The function **<font size="3" face="verdana">calculate_ps()</font>** is one of the core functions of the AeRobiology package. It was designed to **calculate the main parameters of the pollen season** with regard to phenology and pollen intensity from a historical database of several pollen types. The function can use the most common methods to define the main pollen season. 

<div class="alert alert-info">**Please, be patient:** This function has tons of arguments. Some of them are only useful for specific situations. You can use the function without knowing all of them. Nevertheless, **we decided to include all the possible arguments in order to provide specific tools for the advanced users**.</div>


**This function has several arguments, but don't worry, we are going to perform examples later**. The main arguments are:

* **data**: A `data.frame` object including the general database where calculation of the pollen season must be applied. This data.frame must include a first column in "Date" format and the rest of columns in "numeric" format belonging to each pollen type by column.
* **method**: A `character` string specifying the method applied to calculate the pollen season and the main parameters. The implemented methods that can be used are: "percentage", "logistic", "moving", "clinical" or "grains". A more detailed information about the different methods for defining the pollen season may be consulted [here](https://CRAN.R-project.org/package=AeRobiology)) or later in this same document.
* **th.day**: A `numeric` value. The number of days whose pollen concentration is bigger than this threshold is calculated for each year and pollen type. This value will be obtained in the results of the function. The `th.day` argument will be 100 by default.
* **perc**: A `numeric` value ranging 0_100. This argument is valid only for `method = "percentage"`. This value represents the percentage of the total annual pollen included in the pollen season, removing (100_perc)/2% of the total pollen before and after of the pollen season. The `perc` argument will be 95 by default.
* **def.season**: A `character` string specifying the method for selecting the best annual period to calculate the pollen season. The pollen seasons may occur within the natural year between two years. The implemented options that can be used are: "natural", "interannual" or "peak". The `def.season` argument will be "natural" by default. A more detailed information about the different methods for selecting the best annual period to calculate the pollen season may be consulted [here](https://CRAN.R-project.org/package=AeRobiology).
* **reduction**: A `logical` value. This argument is valid only for the "logistic" method. If `FALSE` the reduction of the pollen data is not applicable. If `TRUE` a reduction of the peaks above a certain level (`red.level` argument) will be carried out before the definition of the pollen season. The reduction argument will be `FALSE` by default. A more detailed information about the reduction process may be consulted [here](https://CRAN.R-project.org/package=AeRobiology).
* **red.level**: A `numeric` value ranging 0_1 specifying the percentile used as level to reduce the peaks of the pollen series before the definition of the pollen season. This argument is valid only for the "logistic" method. The `red.level` argument will be 0.90 by default, specifying the percentile 90.
* **derivative**: A `numeric (integer)` value belonging to options of 4, 5 or 6 specifying the derivative that will be applied to calculate the asymptotes which determines the pollen season using the "logistic" method. This argument is valid only for the "logistic" method. The `derivative` argument will be 5 by default. More information may be consulted [here](https://CRAN.R-project.org/package=AeRobiology).
* **man**: A `numeric (integer)` value specifying the order of the moving average applied to calculate the pollen season using the "moving" method. This argument is valid only for the "moving" method. The `man` argument will be 11 by default.
* **th.ma**: A `numeric` value specifying the threshold used for the "moving" method for defining the beginning and the end of the pollen season. This argument is valid only for the "moving" method. The `th.ma` argument will be 5 by default.
* **n.clinical**: A `numeric (integer)` value specifying the number of days which must exceed a given threshold (th.pollen argument) for defining the beginning and the end of the pollen season. This argument is valid only for the "clinical" method. The `n.clinical` argument will be 5 by default.
* **window.clinical**: A `numeric (integer)` value specifying the time window during which the conditions must be evaluated for defining the beginning and the end of the pollen season using the "clinical" method. This argument is valid only for the "clinical" method. The `window.clinical` argument will be 7 by default.
* **window.grains**: A `numeric (integer)` value specifying the time window during which the conditions must be evaluated for defining the beginning and the end of the pollen season using the "grains" method. This argument is valid only for the "grains" method. The `window.grains` argument will be 5 by default.
* **th.pollen**: A `numeric` value specifying the threshold that must be exceeded during a given number of days (n.clinical or window.grains arguments) for defining the beginning and the end of the pollen season using the "clinical" or "grains" methods. This argument is valid only for the "clinical" or "grains" methods. The `th.pollen` argument will be 10 by default.
* **th.sum**: A `numeric` value specifying the pollen threshold that must be exceeded by the sum of daily pollen during a given number of days (`n.clinical` argument) exceeding a given daily threshold (`th.pollen` argument) for defining the beginning and the end of the pollen season using the "clinical" method. This argument is valid only for the "clinical" method. The `th.sum` argument will be 100 by default.
* **type**: A `character` string specifying the parameters considered according to a specific pollen type for calculating the pollen season using the "clinical" method. The implemented pollen types that may be used are: "birch", "grasses", "cypress", "olive" or "ragweed". As result for selecting any of these pollen types the parameters `n.clinical`, `window.clinical`, `th.pollen` and `th.sum` will be automatically adjusted for the "clinical" method. If no pollen types are specified (`type = "none"`), these parameters will be considered by the user. This argument is valid only for the "clinical" method. The `type` argument will be "none" by default.
* **interpolation**: A `logical` value. If `FALSE` the interpolation of the pollen data is not applicable. If `TRUE` an interpolation of the pollen series will be applied to complete the gaps with no data before the calculation of the pollen season. The `interpolation` argument will be `TRUE` by default. A more detailed information about the interpolation method may be consulted [here](https://CRAN.R-project.org/package=AeRobiology).
* **int.method**: A `character` string specifying the method selected to apply the interpolation method in order to complete the pollen series. The implemented methods that may be used are: "lineal", "movingmean", "spline" or "tseries". The `int.method` argument will be "lineal" by default.
* **maxdays**: A `numeric` (integer value) specifying the maximum number of consecutive days with missing data that the algorithm is going to interpolate. If the gap is bigger than the argument value, the gap will not be interpolated. Not valid with `int.method = "tseries"`. The `maxdays` argument will be 30 by default.
* **export.plot**: A `logical` value specifying if a set of plots based on the definition of the pollen season and saved in the working directory will be required or not. If `FALSE` graphical results will not be saved. If `TRUE` a pdf file for each pollen type showing graphically the definition of the pollen season for each studied year will be saved within the plot_AeRobiology directory created in the working directory. The `export.plot` argument will be `FALSE` by default.
* **export.result**: A `logical` value specifying if a excel file including all parameters for the definition of the pollen season saved in the working directory will be required or not. If `FALSE` the results will not exported. If `TRUE` the results will be exported as xlsx file including all parameters calculated from the definition of the pollen season within the table_AeRobiology directory created in the working directory. The `export.result` argument will be `FALSE` by default.
* **plot**: A `logical` value specifying if the plots are generated in the plot history. The `plot` argument will be `TRUE` by default.
* **result**: A `character` string specifying the output for the function. The implemented outputs that may be obtained are: `"table"` and `"list"`. The argument `result` will be `"table"` by default.

<div class="alert alert-info">**IMPORTANT :** if `export.plot = FALSE`, the plots are **EXPORTED** in "plot_AeRobiology" folder.</div>
  
  
## Methods of calculating the Main Pollen Season

This function allows to calculate the pollen season using **five different methods** which are described below. After calculating the **start_date**, **end_date** and **peak_date** for the pollen season all rest of **parameters** are calculated:

* **type**: pollen type
* **seasons**: year of the beginning of the season
* **st.dt**: start_date (date)
* **st.jd**: start_date (day of the year)
* **en.dt**: end_date (date)
* **en.jd**: end_date (day of the year)
* **ln.ps**: length of the season
* **sm.tt**: total sum
* **sm.ps**: pollen integral
* **pk.val**: peak value
* **pk.dt**: peak_date (date)
* **pk.jd**: peak_date (day of year)
* **ln.prpk**: length of the pre_peak period
* **sm.prpk**: pollen integral of the pre_peak period
* **ln.pspk**: length of the post_peak period
* **sm.pspk**: pollen integral of the post_peak period
* **daysth**: number of days with more than 100 pollen grains
* **st.dt.hs**: start_date of the High pollen season (date, only for clinical method)
* **st.jd.hs**: start_date of the High pollen season (day of the year, only for clinical method)
* **en.dt.hs**: end_date of the High pollen season (date, only for clinical method)
* **en.jd.hs**: end_date of the High pollen season (day of the year, only for clinical method)

<div class="alert alert-info">**IMPORTANT :** If `export.result = FALSE`, these objects will be exported as xlsx file within the "table_AeRobiology" directory created in your working directory. This Excel file will have a sheet for each pollen type and a last sheet with the legend of all the abbreviations and the method selected to calculate them. **We strongly recommend to use `export.result = FALSE`**</div>

Although the results can be extracted in the working directory in a xlsx file, **they can also be assigned to an object, and visualized**, for example (an extract):

```{r echo = TRUE, results='hide', fig.keep='last', warning=FALSE}
pollen_season <- calculate_ps(munich_pollen)
```

```{r echo = FALSE, fig.keep='all', warning=FALSE}
knitr::kable(pollen_season[24:31, ] , format = "html", booktabs = TRUE)
```

The result is also plotted by default (*plot = TRUE*).

```{r echo = TRUE, fig.keep='last', warning=FALSE}
calculate_ps(munich_pollen[,c(1,6)], plot = TRUE)
```

### "percentage" method

This is a commonly used method for defining the pollen season based on the **elimination of a certain percentage in the beginning and the end of the pollen season** ( [Nilsson and Persson, 1981](https://doi.org/10.1080/00173138109427661); [Andersen, 1991](https://doi.org/10.1080/00173139109427810). For example, if the pollen season is based on the 95% of the total annual pollen (`perc = 95`), the start_date of the pollen season is marked as the day in which 2.5% of the total pollen is registered and the end_date of the pollen season is marked as the day in which 97.5% of the total pollen is registered.

```{r echo=TRUE, results='hide', fig.keep='first', eval=FALSE}
calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc = 90, export.result = FALSE)
```

In this case we have calculated the main pollen season based on the 90% of the total annual pollen. **Results are stored in the "table_AeRobiology" folder since `export.result = FALSE`**.

You can select different methods of interpolation or even to not interpolate gaps:

```{r echo=TRUE, results='hide', fig.keep='first'}
calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc = 90, export.result = FALSE, int.method = "spline")
```

```{r echo=TRUE, results='hide', fig.keep='first'}
calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc = 75, export.result = FALSE, interpolation = FALSE)
```

<div class="alert alert-info">**IMPORTANT :** if `export.plot = FALSE`, the plots are **EXPORTED** in "plot_AeRobiology" folder.</div>


### "logistic" method

This method was developed by Ribeiro et al. (2007) and modified by Cunha et al. (2015). It is based on fitting annually a **non-linear logistic regression model** to the daily accumulated curve for each pollen type. This logistic function and the **different derivatives** were considered to calculate the **start_date** and **end_date** of the pollen season, based on the **asymptotes when pollen amounts are stabilized on the beginning and the end of the accumulated curve**. For more information about the method, see [Ribeiro et al. (2007)](https://pubmed.ncbi.nlm.nih.gov/18247462/) and [Cunha et al. (2015)](https://link.springer.com/article/10.1007/s10453-014-9345-3). **Three different derivatives** may be used (`derivative` argument) 4, 5 or 6 that represent **from higher to lower restrictive criterion** for defining the pollen season. 

This method may be **complemented with an optional method for reduction the peaks values** (`reduction = TRUE`), thus avoiding the effect of the great influence of extreme peaks. In this sense, **peaks values will be cut below a certain level** that the user may select based on a percentile analysis of peaks. For example, `red.level = 0.90` will cut all peaks above the percentile 90.

```{r echo=TRUE, results='hide', fig.keep='first', warning=FALSE}
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "logistic", derivative = 5, reduction=FALSE)
```

```{r echo = FALSE, fig.keep='all', warning=FALSE}
knitr::kable(pollen_season, format = "html", booktabs = TRUE )
```

In the previous case, the reduction wasn't carried out (`reduction=FALSE`) and all the peaks were conserved. We can cut some peaks and change the `derivative`:

```{r echo=TRUE, results='hide', fig.keep='first', warning=FALSE}
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "logistic", derivative = 6, reduction=FALSE, red.level = 0.8)
```

```{r echo = FALSE, fig.keep='all', warning=FALSE}
knitr::kable(pollen_season, format = "html", booktabs = TRUE)
```

As you can observe, results are a bit different.

<div class="alert alert-info">**IMPORTANT :** if `export.plot = FALSE`, the plots are **EXPORTED** in "plot_AeRobiology" folder.</div>

### "clinical" method

This method was proposed by [Pfaar et al. (2017)](https://pubmed.ncbi.nlm.nih.gov/27874202/). It is based on the expert consensus in relation to pollen exposure and the **relationship with allergic symptoms** derived of the literature. 

Different periods may be defined by this method: the **pollen season**, the **high pollen season** and the **high pollen days**: 

1) The **start_date** and **end_date** of the **pollen season** were defined as a **certain number of days (`n.clinical` argument) within a time window period (`window.clinical` argument) exceeding a certain pollen threshold (`th.pollen` argument) which summation is above a certain pollen sum (`th.sum` argument)**. <br> All these parameters are established for each pollen type according to Pfaar et al. (2017) and using the **`type`** argument these parameters may be automatically adjusted for the specific pollen types ("birch", "grasses", "cypress", "olive" or "ragweed"). Furthermore, **the user may change all parameters to do a customized definition of the pollen season**.

2) The **start_date** and **end_date** of the **high pollen season** were defined as **three consecutive days exceeding a certain pollen threshold (`th.day` argument)**. 

3) The number of **high pollen days** will also be calculated exceeding this pollen threshold (`th.day`). For more information about the method, see [Pfaar et al. (2017)](https://pubmed.ncbi.nlm.nih.gov/27874202/).

Running the following example, the main pollen season will be established according to the birch requirements: more than 5 days within a week in which more than 10 pollen grains/m3 are registered and whose sum exceeds 100 pollen grains/m3. The high pollen days are those which exceed 100 pollen grains/m3 (`n.clinical=5, window.clinical=7, th.pollen=10, th.sum=100, th.day=100`)

```{r echo=TRUE, results='hide', fig.keep='first', warning=FALSE}
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "clinical", type = "birch")
```

```{r echo = FALSE, fig.keep='all', warning=FALSE}
knitr::kable(pollen_season, format = "html", booktabs = TRUE)
```

The code above returns the same result than:

```{r echo=TRUE, results='hide', fig.keep='first', warning=FALSE}
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "clinical", n.clinical = 5, window.clinical = 7, th.pollen = 10, th.sum = 100, th.day = 100)
```

```{r echo = FALSE, fig.keep='all', warning=FALSE}
knitr::kable(pollen_season, format = "html", booktabs = TRUE)
```

We have resumed all these parameters under the argument `type=birch` to facilitate its application.

<div class="alert alert-info">**IMPORTANT :** if **`export.plot = FALSE`**, the plots are **EXPORTED** in "plot_AeRobiology" folder.</div>

### "grains" method

This method was proposed by Galan et al. (2001) originally in olive pollen but after also applied in other pollen types. 

The **start_date** and **end_date** of the pollen season were defined as a **certain number of days (`window.grains` argument) exceeding a certain pollen threshold (`th.pollen` argument)**. For more information about the method, see [Galan et al. (2001)](https://link.springer.com/article/10.1007/s004840000081).

We want to establish the main pollen season start in the first day when more than 3 consecutive days have more than 2 pollen grains/m3, and the end in the last day in which these conditions are fulfilled:

```{r echo=TRUE, results='hide', fig.keep='first'}
calculate_ps(munich_pollen[,c(1,6)], method = "grains", window.grains = 3, th.pollen = 2 )
```

### "moving" method

<div class="alert alert-info">**This method is proposed the first time by the authors of this package. We are developing a research paper explaining the method in detail.**</div>

The definition of the pollen season is based on the application of a **moving average** to the pollen series in order to obtain the general seasonality of the pollen curve avoiding the great variability of the daily fluctuations. Thus, **the start_date and the end_date will be established when the curve of the moving average reaches a given pollen threshold** (**`th.ma`** argument). Also the order of the moving average may be customized by the user (**`man`** argument). By default, `man = 11` and `th.ma = 5`.

<p class="comment"> The idea of this method is to be able to calculate the start of the main pollen season when the season has not finished yet. Moreover, it allows to establish the start and end even if there is a huge amount of lacking data within the main pollen season. Its similar to the "grains" method but taking into account the moving mean to avoid daily variability.</p>

You might understand it better by consulting the plots obtained.

<div class="alert alert-info">**IMPORTANT :** if **`export.plot = FALSE`**, the plots are **EXPORTED** in "plot_AeRobiology" folder.</div>

Let's calculate it with a moving average of 7 days. We are going to establish the start and end of the main pollen season when the moving average reaches 4 pollen grains/m3:

```{r echo=TRUE, results='hide', fig.keep='first'}
calculate_ps(munich_pollen[,c(1,6)], method = "moving", man = 7, th.ma = 4)
```
  
  
## Advanced examples

### Southern Hemisphere & interannual types

As you may have noticed, we have been using the function under an "European" point of view: the calculations are from 1st January to 31th December. The researchers of the **Southern Hemisphere** are used to work with **interanual pollen seasons**. Don't worry, we haven't forgotten you!

1) You can work **from 1st June to 31th May** by means of the argument **`def.season="interannual"`**:

```{r echo=TRUE, results='hide', fig.keep='first'}
calculate_ps(munich_pollen[,c(1,3)], method = "moving", man = 7, th.ma = 4, def.season = "interannual")
```

<p class="comment"> In this method, the season belongs to the first year of the pair of years, i.e: from June 2017 to May 2018 -> season "2017".</p>

2) You can **center the main pollen season in the average peak day** (182 days before and after the average date of the peak):

```{r echo=TRUE, results='hide', fig.keep='first'}
calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc=95, def.season = "peak")
```

<p class="comment"> In this last method, the season belongs to the year in which the average peak date - 182 days is located, i.e.: if the average peak date is in January 2013, the season is called "2012" in the data.frames.</p>

### Interpolation in detail

Pollen time series frequently have different gaps with no data and this fact could be a problem for the calculation of specific methods for defining the pollen season even providing incorrect results. In this sense **by default a linear interpolation will be carried out to complete these gaps before to define the pollen season (`interpolation = TRUE`)**. Additionally, the users may select other interpolation methods using the **`int.method` argument**, as "lineal", "movingmean", "spline" or "tseries".

Some advanced users may have noticed that you can't use directly all the arguments of **<font size="3" face="verdana">interpollen()</font>** through **<font size="3" face="verdana">calculate_ps()</font>**. You only are able to select the interpolation method. Nevertheless, it is not impossible to use them:

1) **Use <font size="3" face="verdana">interpollen()</font>** with all the arguments you want and **overwrite your interpolated database in an object**:

```{r echo=TRUE, results='hide', fig.keep='first'}
CompleteData<-interpollen(munich_pollen, method="spline", ndays=3, spar=0.7, plot = TRUE, maxdays = 3, result = "wide")
```

2) Then, **use "CompleteData" instead of "munich_pollen" (or your database) in the following steps**:

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_ps(CompleteData, pollen.type="Alnus", year=2013, fill.col = "orange", axisname = "AeRobiology custom units")
```

<p class="comment"> **Note**: You might select **`interpolation=FALSE`** in the other functions you use after interpolating manually. In some cases it doesn't matter, but if you want to interpolate only gaps with less than 3 days and you did in the first step, if you don't use `interpolation=FALSE` in calculate_ps function, a second interpolation will be carried out by using the default method (gaps with less than 30 days and lineal interpolation). You will obtain a database with the gaps of less than 3 days interpolated by "spline" method and the rest with the "lineal" method. </p>
  
    
    
# Function <font face="verdana">pollen_calendar</font>

This function **calculates the pollen calendar from a historical database** of several pollen types using different designs. The main arguments are:  

* **data**: A `data.frame` with the first column in "Date" format and the rest of the columns in "numeric" format (pollen types).
* **method**: for choosing the method to generate the pollen calendar. The options are "heatplot", "violinplot" and "phenological".
* **n.types**: indicating the number of the most abundant pollen types showed in the pollen calendar
* **start.month**: ranging 1-12 indicates the number of the month (January-December) when the beginning of the pollen calendar must be considered, see more details [here](https://CRAN.R-project.org/package=AeRobiology).
* **export.plot**: specifying if a plot with the pollen calendar saved in the working directory will be required or not. Other arguments have been incorporated in relation to the format to export the plot (`export.format`).
* **result**: **"plot"** or **"table"**.

**Data exportation:**

- If `export.plot = FALSE` this plot displaying the pollen calendar will be exported within the **Plot_AeRobiology** directory created in the working directory.
- If `export.plot = FALSE` and `export.format = pdf`, a pdf file with the pollen calendar will be saved within the **plot_AeRobiology** directory, created in the working directory. Additional characteristics
may be incorporated to the exportation as pdf file.
- If `export.plot = FALSE` and `export.format = png`, a png file with the pollen calendar will be saved within the **plot_AeRobiology** directory, created in the working directory. Additional characteristics may be incorporated to the exportation as png file.

**Exclusive arguments** for pollen calendars generated as **"heatplot"**:

* **period**: specifying the interval time considered to generate the pollen calendar. The options are "weekly" and "daily."
* **method.classes**: indicating the method to define the classes used for classifying the average pollen concentrations. The options are "exponential" and "custom".
* **n.classes**: specifying the number of classes that will be used when `method.classes = custom`.
* **classes**: specifying a numeric vector with the desired thresholds to define the different classes.
* **color**: choosing different options such as "green", "red", "blue", "purple"or "black".

**Exclusive arguments** for pollen calendars generated as **"phenological"**:

* **perc1, perc2**: both ranging 0-100. These values represent the percentage of the total annual pollen included in the pollen season, removing (100-percentage)/2% of the total pollen before and after the pollen season. Two percentages must be specified to define the "main pollination period" (`perc1`) and the "early/late pollination" (`perc2`) based on the "phenological" method proposed by [Werchan
et al. (2018)](https://link.springer.com/article/10.1007/s40629-018-0055-1).
* **th.pollen**: specifying the minimum threshold of the average pollen concentration which will be used to generate the pollen calendar. Days below this threshold will not be considered and days above this threshold will be considered as "possible occurrence" as proposed by [Werchan
et al. (2018)](https://link.springer.com/article/10.1007/s40629-018-0055-1). This argument also works for "violinplot" pollen calendar

<div class="alert alert-info">By default the database will be interpolated according to the **<font size="3" face="verdana">interpollen</font>** function, and also other arguments for this function are incorporated in the **<font size="3" face="verdana">pollen_calendar</font>** function.</div>

## "heatplot" method

This pollen calendar is constructed based on the **daily or weekly average of pollen concentrations** (depending on the preferences of the user, who may select "daily" or "weekly" as **`period` argument**). Then, these averages may be classified in different categories following different methods selected by the user. An example of this pollen calendar may be consulted in [Rojo et al. (2016)](https://link.springer.com/article/10.1007/s10661-016-5129-2). This method to design pollen calendars is an **adaptation from the pollen calendar proposed by Spieksma (1991)**, who considered 10-day periods instead of daily or weekly periods.

First, we are going to generate a pollen calendar based on the **heatplot**, designed with **green** color and constructed with **daily** averages:

```{r echo = TRUE, results='hide',fig.keep='all', warning=FALSE}
pollen_calendar(munich_pollen, method = "heatplot", period = "daily", color = "green", interpolation = FALSE)
```

In all cases, the table used by the pollen calendar with the averaged values will be created. This table can be visualized. To do that we have to set the argument **result = "table"** For example (an extract):

```{r echo = TRUE, fig.keep='all', warning=FALSE}
average_values<-pollen_calendar(munich_pollen, method = "heatplot", period = "daily", color = "green", interpolation = FALSE, result = "table")
knitr::kable(average_values[82:90, ], format = "html", booktabs = TRUE)
```

By default the method for defining the classes for the pollen calendar is according to the **exponential** method. Nevertheless, the classes can be customized by **`classes` argument**:

```{r echo = TRUE, results='hide',fig.keep='all', warning=FALSE}
pollen_calendar(data = munich_pollen, method = "heatplot", period = "daily", color = "red", method.classes = "custom", n.classes = 5, classes = c(5, 25, 50, 200), interpolation = FALSE)
```

In addition, for species with their pollen season occurring between two natural years, the start of the pollen calendar can be selected by the **`start.month` argument**:

```{r echo = TRUE, results='hide',fig.keep='all', warning=FALSE}
pollen_calendar(data = munich_pollen, method = "heatplot", period = "daily", color = "purple", method.classes = "custom", n.classes = 5, classes = c(5, 25, 50, 200), start.month = 11, na.remove = FALSE, interpolation = FALSE)
```

<p class="comment">**`NA` (no data) can be removed by using `na.remove` argument.**</p>

Also we can generate a pollen calendar based on the **heatplot** design with **weekly** averages. 

```{r echo = TRUE, results='hide',fig.keep='all', warning=FALSE}
pollen_calendar(data = munich_pollen, method = "heatplot", period = "weekly", color = "blue", method.classes = "exponential", n.types = 4, y.start = 2011, y.end = 2014, interpolation = FALSE)
```

In this case, we have included other restrictive arguments as **`n.types`** limiting the number of pollen types and **`y.start`** and **`y.end`**, limiting the period to be considered for the pollen calendar.

## Monthly heatmap

The function **<font face="verdana">plot_monthly_heatmap()</font>** produces a simple heatmap of the **monthly sums of daily pollen concentrations** for one selected pollen type. Months are represented in the x axis and years in the y axis. The main arguments are:

* **data**: a `data.frame` with the first column in "Date" format and pollen types in numeric columns.
* **pollen.type**: the pollen type to be represented.
* **start.month**: the first month shown in the x axis. January is used by default.
* **color.A, color.B**: colors used to build the gradient palette. By default, yellow and red are used.
* **location**: if the database includes several locations in a column such as `location`, `city` or `station`, the selected location can be specified. If it is not specified, the first location in the database is used.

```{r echo = TRUE, results='hide', fig.keep='all', warning=FALSE}
plot_monthly_heatmap(munich_pollen, pollen.type = "Betula")
```

The first month of the heatmap can be changed when the pollen season is better represented between two natural years:

```{r echo = TRUE, results='hide', fig.keep='all', warning=FALSE}
plot_monthly_heatmap(munich_pollen, pollen.type = "Poaceae", start.month = 6, color.A = "white", color.B = "darkgreen")
```

## "phenological" method

This pollen calendar is based on the phenological definition of the pollen season and adapted from the methodology proposed by [Werchan et al. (2018)](https://link.springer.com/article/10.1007/s40629-018-0055-1). 

After obtaining the **daily average pollen concentrations** for the most abundant pollen types, different pollination periods are calculated. The **main pollination period** is calculated according to the percentage defined by `perc1` argument (selected by the user, 80% by default; red) of the annual total pollen. For example, if `perc1 = 80`, the beginning of the high season is marked when the 10% of the annual value is reached; the end is selected when 90% is reached. The **early/late pollination period** is defined with the `perc2` argument (selected by the user, 99% of the total annual pollen by default; orange), i.e.: the start of this period will be when the 0.5% is reached and the end when the 99.5% is reached. For this kind of pollen calendar the `th.pollen` argument defines the **possible occurrence** period as adapted by [Werchan et al. (2018)](https://link.springer.com/article/10.1007/s40629-018-0055-1), considering the entire period between the first and the last day when this pollen level is reached (yellow).

```{r echo = TRUE, results='hide',fig.keep='all', warning=FALSE}
pollen_calendar(data = munich_pollen, method = "phenological", n.types = 5, y.start = 2011, y.end = 2014, interpolation = FALSE)
```

Furthermore, different criteria can be customized:

```{r echo = TRUE, results='hide',fig.keep='all', warning=FALSE}
pollen_calendar(data = munich_pollen,  method = "phenological", perc1 = 90, perc2 = 95, th.pollen = 5, interpolation = FALSE)
```

In this last case, the pollen calendar has been generated with more restrictive criteria for `perc1`, `perc2` and `th.pollen`.  

## "violinplot" method

This pollen calendar is based on the **pollen intensity**, and adapted from the pollen calendar published by [ORourke (1990)](https://link.springer.com/article/10.1007/BF02539105). At first, the daily averages of the pollen concentrations are calculated and then, these averages are represented by using the violin plot graph. 

<div class="alert alert-info">The shape of the violin plot represents the pollen intensity of the pollen types in a relative way, i.e.: the values will be calculated as **relative measurements** regarding to the most abundant pollen type in annual amounts. Therefore, this pollen calendar shows a relative comparison between the pollen intensity of the pollen types but **without scales and units**.</div>

```{r echo = TRUE, results='hide', fig.keep='all', warning=FALSE}
pollen_calendar(data = munich_pollen, method = "violinplot", y.start = 2012, y.end = 2015, interpolation = FALSE)
```

In addition, **`th.pollen`** can be established, specifying the minimum pollen concentration considered (E.g.: 10 pollen grains/m3):

```{r echo = TRUE, results='hide', fig.keep='all', warning=FALSE}
pollen_calendar(data = munich_pollen, method = "violinplot", th.pollen = 10, na.rm = FALSE, interpolation = FALSE)
```
  
    
    
# Functions <font face="verdana">iplot_pollen()</font> and <font face="verdana">iplot_years()</font>  

These functions have been designed for a **quick view** of your data for discussions or interpretations of them. **Interactive plots are displayed**. It might be interesting for group meetings or real time exposition of results. The functions create a emergent screen in which you can select the pollen/spore type or the years you want to plot. 

<div class="alert alert-info">**IMPORTANT :** To stop the real time visualization and continue using the package you must click in the **"Stop" signal.**</div>

The function **<font size="3" face="verdana">iplot_pollen()</font>** is to plot the pollen data during one season. The arguments are:  

* **data**: A `data.frame` object. This data.frame should include a first column in "Date" format and the rest of columns in format "numeric" belonging to each pollen type by column.  
* **year:** An `integer` value specifying the year to display. This is a mandatory argument. 

The function **<font size="3" face="verdana">iplot_years()</font>** is to plot the pollen data during one season. The arguments are:  

* **data**: A `data.frame` object. This data.frame should include a first column in "Date" format and the rest of columns in format "numeric" belonging to each pollen type by column.    
* **pollen:** A `character` string with the name of the particle to show. This character must match with the name of a column in the input database. This is a mandatory argument.


```{r echo = TRUE, results='hide',fig.keep='all', eval=FALSE}
iplot_pollen(munich_pollen, year = 2012)
iplot_years(munich_pollen, pollen = "Betula")
```

<p class="comment">**Note:** We are not able to plot interactive figures in this document. Please, run the codes above in your R session.</p>


# Function <font face="verdana">plot_summary()</font>  

The function **<font size="3" face="verdana">plot_summary()</font>** is to plot the pollen data during several seasons. Also to plot the averaged pollen season over the study period. It is possible to plot the relative abundance per day and smoothing the pollen season by calculating a moving average. The main arguments are:  

* **data**: A `data.frame` object. This data.frame should include a first column in "Date" format and the rest of columns in "numeric" format belonging to each pollen type by column.  
* **pollen:** A `character` string with the name of the particle to show. This character must match with the name of a column in the input database. This is a mandatory argument.  
* **mave:** An `integer` value specifying the order of the moving average applied to the data. By default, `mave = 1`.  
* **normalized:** A `logical` value specifying if the visualization shows real pollen data (`normalized = FALSE`) or the percentage of every day over the whole pollen season (`normalized = TRUE`). By default, `normalized = FALSE`.  
* **axisname:** A `character` string specifying the title of the y axis. By default, `axisname = "Pollen grains / m3"`  
* Others...

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_summary(munich_pollen, pollen = "Betula")
```

In some cases the user may want to reduce the "noise" of the daily values by **calculating moving means** (E.g.: 5 days moving mean; `mave = 5`):

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_summary(munich_pollen, pollen = "Betula", mave = 5)
```

You might be also interested in representing as background the **percentage** each day suppose to the main pollen season (`normalized = TRUE`):

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_summary(munich_pollen, pollen = "Betula", mave = 5, normalized = TRUE)
```

<div class="alert alert-info">**<font size="3" face="verdana">interpollen()</font> function** is integrated in this function. Consult the "help" section of this function to use it.</div>


# Function <font face="verdana">plot_normsummary()</font>  

The function **<font face="verdana">plot_normsummary()</font>** has been designed to plot the pollen data amplitude during several seasons: daily average pollen concentration over the study period, maximum pollen concentration of each day over the study period and minimum pollen concentration of each day value over the study period. It is possible to plot the relative abundance per day and smoothing the pollen season by calculating a moving average. The main arguments similar to **<font size="3" face="verdana">plot_summary()</font>**, but as a result **you will obtain the the max-min range of the study period** instead of the values for every year.  

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_normsummary(munich_pollen, pollen = "Betula", color.plot = "red")
```

The **maximum values** are marked in **red** and the **minimum values in white**. The **average** is the **black line**.

Of course, you can change the color (`color.plot` argument):

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_normsummary(munich_pollen, pollen = "Betula", color.plot = "green", mave = 5, normalized = TRUE)
```

<div class="alert alert-info">**<font size="3" face="verdana">interpollen()</font> function** is integrated in this function. Consult the "help" section of this function to use it.</div>
  
    
    
# Function <font face="verdana">analyse_trend()</font>  

The function **<font size="3" face="verdana">analyse_trend()</font>** has been created to calculate the main seasonal indexes of the pollen season ("Start Date", "Peak Date", "End Date" and "Pollen Integral"), as well as **trends analysis** of those parameters over the seasons. It is a summary dot plot showing the distribution of the main seasonal indexes over the years.  

The results can also be stored in two folders termed **"plot_AeRobiology"** and **"table_AeRobiology"**, which will be created in your working directory (only if `export.result = FALSE` & `export.plot = FALSE`). You can decide which result to be returned from the function by setting the argument **result**: *result = "table"* or *result = "plot"*.

The function allows you to decide if you want to interpolate the data or not, by the argument **`interpolation`**, it also allows you to select the interpolation method by the argument **`int.method`**. Furthermore, it allows you to select the pollen season definition method, by the argument **`method`** and additional arguments for the function **<font size="3" face="verdana">calculate_ps()</font>**. Some arguments about the visualization are:  

* **split**: A `logical` argument. If `split = TRUE`, the plot is separated in two according to the nature of the variables (i.e. dates or pollen concentrations). **This argument was a solution to reduce the scale of the x-axis when "total pollen"" variable has a very high/low slope**. By default, `split = TRUE`.
* **quantil**: A `numeric` value (between 0 and 1) indicating the quantile of data to be displayed in the graphical output of the function. `quantil = 1` would show all the values, however a lower quantile will exclude the most extreme values of the sample. **This argument was designed after realizing of a common problem: when plotting the results with `split=FALSE`, some "outlier" results increased a lot the scale of the x-axis, making unreadable the rest of results**. Our solution was to create an argument to exclude these outliers results and to be able to observe the main results in an appropriate scale. Furthermore, this argument may be used to split the parameters using a different sampling units (e.g. dates and pollen concentrations) can be used low vs high values of quantil argument (e.g. 0.5 vs 1). Also can be used an extra argument: `split`. By default, `quantil = 0.75`. **This argument only works when `split=FALSE`.**
* **significant**: A `numeric` value indicating the significant level to be considered in the linear trends analysis. This p level is displayed in the graphical output of the function (as a number in the legend and as a black ring in the graphical representation). By default, `significant = 0.05`.  

```{r echo = TRUE, results='hide',fig.keep='all'}
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, result="plot")
```

Lets see what happen if we don't split the graphics:

```{r echo = TRUE, results='hide',fig.keep='all'}
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, split = FALSE, quantil = 1, result="plot")
```

Now the results are less readable, but this kind of graphical representation may be interesting for some people. When plotting all the results together, it might be useful to exclude some outliers:

```{r echo = TRUE, results='hide',fig.keep='all'}
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, split=FALSE, quantil = 0.5, result="plot")
```

As you can appreciate, a lot of points have been omitted.

You can also change the significance level as mentioned above. Why don`t we try?:

```{r echo = TRUE, results='hide',fig.keep='all'}
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, significant = 1, result = "plot")
```

Now everything is significant!

Have a look to the numbers by setting *result = "table"* (the default output).


```{r echo = TRUE, results='hide',fig.keep='all'}
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, significant = 1, result="table")
```


<div class="alert alert-info">**<font size="3" face="verdana">interpollen()</font> function** is integrated in this function. Consult the "help" section of this function to use it.</div>

<div class="alert alert-info"> If **result = "plot"**, the function returns a list of objects of class *ggplot2*; if **result = "table"**, the function returns a *data.frame*. By default, **result = "table"**.</div>
  
    
    
# Function <font face="verdana">plot_trend()</font>  

The function **<font size="3" face="verdana">plot_trend()</font>** has been created to calculate the main seasonal indexes of the pollen season ("Start Date", "Peak Date", "End Date" and "Pollen Integral") and their trends analysis over the seasons. It produces plots showing the distribution of the main seasonal indexes over the years.  

The **results are stored in two folders termed "plot_AeRobiology" and "table_AeRobiology"** which will be located in your working directory (only if `export.result = FALSE` & `export.plot = FALSE`).

```{r echo = TRUE, results='hide',fig.keep='all', eval=FALSE}
plot_trend(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE)
```

<div class="alert alert-info">**NOTE:** The plots are not shown in your R environment. Because of the high amount of graphs, they are stored in new folders created in your working directory (search were you have saved the R project and you will find the folders).</div>


<p class="comment">The **interval of confidence** only appears if more than 6 dots are plotted. If not, a line crossing all the dots is plotted.</p>

<div class="alert alert-info">**<font size="3" face="verdana">interpollen()</font> function** is integrated in this function. Consult the "help" section of this function to use it.</div>
  
    
    
# Function <font face="verdana">iplot_abundance()</font> 

The function **<font size="3" face="verdana">iplot_abundance()</font>** generates a barplot based on the relative abundance in the air (as percentage) of each pollen/spore type with respect to the total amounts.

The main arguments are:

* **n.types:** A `numeric` (integer) value specifying the number of the most abundant pollen types that must be represented in the plot of the relative abundance. A more detailed information about the selection of the considered pollen types may be consulted [here](https://CRAN.R-project.org/package=AeRobiology). The `n.types` argument will be 15 types by default.
* **y.start/y.end:** A `numeric` (integer) value specifying the period selected to calculate relative abundances of the pollen types (start year - end year). If `y.start` and `y.end` are not specified (`NULL`), the entire database will be used to generate the pollen calendar. The `y.start` and `y.end` arguments will be `NULL` by default.
* **col.bar:** A `character` string specifying the color of the bars to generate the graph showing the relative abundances of the pollen types. The `color` argument will be #E69F00 by default, but any color may be selected.
* **type.plot: ** A `character` string specifying the type of plot selected to show the plot showing the relative abundance of the pollen types. The implemented types that may be used are: "static" (generates a static ggplot object) and "dynamic" (generates a dynamic plotly object).
* **exclude:** A character string vector with the names of the pollen types to be excluded from the plot.
* Others...

```{r echo = TRUE, results='hide',fig.keep='all'}
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE)
```

Now we are going to reduce the number of types:

```{r echo = TRUE, results='hide',fig.keep='all'}
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE, n.types = 3)
```

We can also select the abundance for only one year and change the color: 

```{r echo = TRUE, results='hide',fig.keep='all'}
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE, n.types = 3, y.start = 2011, y.end = 2011, col.bar = "#d63131")
```

Furthermore, we can make it interactive:

```{r echo = TRUE, results='hide',fig.keep='all'}
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE, n.types = 3, y.start = 2011, y.end = 2011, col.bar = "#d63131", type.plot = "dynamic")
```

<div class="alert alert-info">**<font size="3" face="verdana">interpollen()</font> function** is integrated in this function. Consult the "help" section of this function to use it.</div>
  
    
    
# Function <font face="verdana">iplot_pheno()</font>

The function **<font size="3" face="verdana">iplot_pheno()</font>** generates a boxplot based on phenological parameters (start_dates and end_dates) which are calculated by the estimation of the main parameters of the pollen season. The main arguments are:

* **data**: A `data.frame` object including the general database where calculation of the pollen season must be applied in order to generate the phenological plot based on the start_dates and end_dates. This data.frame must include a first column in "Date" format and the rest of columns in "numeric" format belonging to each pollen type by column.
* **method**: A `character` string specifying the method applied to calculate the pollen season and the main parameters. The implemented methods that can be used are: "percentage", "logistic", "moving", "clinical" or "grains". A more detailed information about the different methods for defining the pollen season may be consulted in calculate_ps function.
* **n.types**: A `numeric` (integer) value specifying the number of the most abundant pollen types that must be represented. A more detailed information about the selection of the considered pollen types may be consulted [here](https://CRAN.R-project.org/package=AeRobiology). The `n.types` argument will be 15 by default.
* **type.plot**: A `character` string specifying the type of plot selected to show the phenological plot. The implemented types that may be used are: "static" (generates a static ggplot object) and "dynamic" (generates a dynamic plotly object).
* Other arguments related to **<font size="3" face="verdana">calculate_ps()</font> function**

```{r echo = TRUE, results='hide',fig.keep='all'}
iplot_pheno(munich_pollen, method= "percentage", perc=80, int.method="spline", n.types = 8)
```

We can change the method to establish the main pollen season and the number of pollen types to show:

```{r echo = TRUE, results='hide',fig.keep='all'}
iplot_pheno(munich_pollen, method= "clinical", n.clinical = 3, int.method="spline", n.types = 4)
```

Furthermore, we can make the plot interactive to obtain more information by clicking in each object:

```{r echo = TRUE, results='hide',fig.keep='all', eval=FALSE}
iplot_pheno(munich_pollen, method= "clinical", n.clinical = 3, int.method="spline", n.types = 4, type.plot = "dynamic")
```
  
    
    
# Function <font face="verdana">plot_ps()</font> 

The function **<font size="3" face="verdana">plot_ps()</font> function** was designed to plot the main pollen season of a single pollen type and year. Some of the arguments are:

* **data**: A `data.frame` object including the general database where interpolation must be performed. This data.frame must include a first column in "Date" format and the rest of the columns in "numeric" format. Each column must contain information of one pollen type. It is not necessary to insert missing gaps, the function will automatically detect them.
* **pollen.type**: A `character` string specifying the name of the pollen type which will be plotted. The name must be exactly the same that appears in the column name. Mandatory argument with no default.
* **year**: A `numeric` (integer) value specifying the season to be plotted. The season does not necessary fit a natural year. See calculate_ps for more details. Mandatory argument with no default.
* **days**: A `numeric` (integer) specifying the number of days beyond each side of the main pollen season that will be represented. The `days` argument will be 30 by default.
* **fill.col**: A `character` string specifying the name of the color to fill the main pollen season in the plot. See ggplot function for more details. The `fill.col` argument will be "turquoise4" by default. It uses the ggplot color codes.
* **axisname**:A `character` string specifying the title of the y axis. By default, `axisname = expression(paste("Pollen grains / m"^"3"))`  
* Others...

<div class="alert alert-info">**<font size="3" face="verdana">calculate_ps</font> function** is integrated in this function. Consult [here](https://CRAN.R-project.org/package=AeRobiology) for more information. **Interpolation is mandatory** for this function. Due to technical encoding, you must use interpollen function through calculate_ps function. Consult calculate_ps for more information.</div>

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_ps(munich_pollen, pollen.type="Alnus", year=2011)
```

If you misspell some pollen type name, the function will tell you:

```{r echo = TRUE, results='hold', error=TRUE}
plot_ps(munich_pollen, pollen.type="Alnuscdscscr", year=2011)
```

**Let`s test more arguments:**

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, method= "percentage", perc=95 ,int.method = "lineal")
```

As you have noticed, the arguments `method`, `perc` and `int.method` are from **<font size="3" face="verdana">calculate_ps</font> function**.

What about changing the interpolation method?

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, method= "percentage", perc=95 ,int.method = "movingmean")
```

Do you want a larger scale?

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, days = 90)
```

Maybe a different color and y-axis name?

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, fill.col = "orange", axisname = "AeRobiology custom units")
```
  
  
  
    
    
# Function <font face="verdana">plot_hour()</font> 
  
  Please keep in mind that the function *plot_hour()* is only available after package **version 2.0**.  
  
  The input data must be a data.frame object with the structure long. Where the first two columns are factors indicating the pollen and the location. The 3 and 4 columns are POSIXct, showing the date with the hour. Where the third column is the beginning of the concentration *from* and the fourth column is the end time of the concentration data *to*. The fifth column shows the concentrations of the different pollen types as numeric. Please see the example 3-hourly data from the automatic pollen monitor BAA500 from Munich and Viechtach in Bavaria (Germany) data("POMO_pollen"), supplied by ePIN Network supported by the Bavarian Government.
  
  We will load an example dataset about 3-hourly data from the ePIN network in Bavaria (Germany). The dataset contains information of 3-hourly concentrations of pollen in the atmosphere of Munich (DEBIED) and Viechtach (DEVIEC) during the year 2018. Pollen types included: "Poaceae" and "Pinus".
  
  The data were obtained by the automatic pollen monitor BAA500 from Munich and Viechtach in Bavaria (Germany) data("POMO_pollen"), supplied by the public ePIN Network supported by the Bavarian Government. The ePIN Network was built by Das Bayerische Landesamt für Gesundheit und Lebensmittelsicherheit (LGL) in collaboration with Zentrum Allergie und Umwelt (ZAUM).
  
```{r echo = FALSE, warning=FALSE, message=FALSE}
library(ggplot2)
library(dplyr)
```
  
 
  
```{r echo = TRUE}
data("POMO_pollen")
```

  The function plots pollen data expressed in concentrations with time resolution higher than 1 day (e.g. hourly, bi-hourly concentrations). If the argument *result = "plot"*, the function returns a list of objects of class **ggplot2**; if *result = "table"*, the function returns a **data.frame** with the hourly patterns.
  

```{r echo = TRUE, message=FALSE}
plot_hour(POMO_pollen)
```

  To display a table we have to set the argument *result = "table"*.
  
```{r message=FALSE}
TO<-plot_hour(POMO_pollen, result ="table")
knitr::kable(TO[1:10,], caption = "3-Hourly patterns", row.names = FALSE, digits = 1, format = "html", booktabs = TRUE)
```
  
  We can also split the different stations by setting the argument *locations = TRUE*.
  
```{r, message=FALSE, echo=TRUE}
plot_hour(POMO_pollen, locations = TRUE)
```
  
    
      
# Function <font face="verdana">plot_heathour()</font> 

An alternative to *plot_hour()* is *plot_heathour()*, which shows a summary of all particles with a heatplot. The input data should have the same format as for *plot_hour()*.

```{r, message=FALSE, echo=TRUE}
plot_heathour(POMO_pollen)
```
  
  You can also set the colors by the arguments: *low.col*, *mid.col* and *high.col*. E.g.
  
```{r, message=FALSE, echo=TRUE}
plot_heathour(POMO_pollen, low.col = "darkgreen", mid.col = "moccasin", high.col = "brown")
```

By setting *locations = TRUE* you can split the result by locations:

```{r, message=FALSE, echo=TRUE}
plot_heathour(POMO_pollen, locations = TRUE)
```
  

---
title: "Vignette of AeRobiology"
subtitle: "A Computational Tool for Aerobiological Data"
author: Jesus Rojo^[University of Castilla-La Mancha & ZAUM (TUM/Helmholtz Zentrum)]
        Antonio Picornell^[University of Malaga]
        Jose Oteros^[Zentrum Allergie und Umwelt - ZAUM (TUM/Helmholtz Zentrum)]
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Vignette of AeRobiology}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r include = FALSE}
knitr::opts_chunk$set(echo = FALSE, warning = FALSE, fig.width = 7)
Sys.setlocale(locale="english")
```

<style>
p.comment {
background-color: #DBDBDB;
padding: 5px;
margin-left: 3px;
border-radius: 5px;
font-style: italic;
}

</style>

  ![AeRobiology R package](logo_aerobiology.jpg)
  
This package gathers different tools for managing aerobiological databases, elaborating the main calculations and visualization of results. In a first step, data may be checked using tools for quality control and all missing gaps can be completed. Then, the main parameters of the pollen season can be calculated and represented graphically. Multiple graphical tools are available: pollen calendars, phenological plots, time series, tendencies, interactive plots, abundance plots...
  
<div class="alert alert-info">**Please, take into account that not all the arguments of each function are explained in this document. This is a quick guide and further details can be consulted in the [official document](https://CRAN.R-project.org/package=AeRobiology) of the package.**</div>
  
  The first thing you have to do is to install from CRAN repository and to load the package <font size="2" face="verdana">AeRobiology</font>.<div/>  

```{r echo=FALSE}
library ("knitr")
```
  
```{r}
library ("AeRobiology")
```
  
```{r eval=FALSE, echo = TRUE}
install.packages("AeRobiology")
library (AeRobiology)
```
  
    
    
# Using the attached data

During this tutorial we are going to use the **pollen data from Munich** which are **integrated in the package**. This will allow you to follow the tutorial obtaining the same results. If you want to follow the tutorial by using your own data, check the next section.

  <p class="comment">**`munich_pollen`** is a data set containing information of daily concentrations of pollen in the atmosphere of Munich during the years 2010_2015. Pollen types included: "Alnus", "Betula", "Taxus", "Fraxinus", "Poaceae", "Quercus", "Ulmus" and "Urtica".  
Data were obtained at Munich (Zentrum Allergie und Umwelt, ZAUM) using a Hirst_type volumetric pollen trap (Hirst, 1952) following the standard methodology (VDI4252_4_2016). Some gaps have been added to test some functions of the package (e.g. <font size="2" face="verdana">quality_control()</font>, <font size="2" face="verdana">interpollen()</font>). <br>
The data were obtained by the research team of Prof. Jeroen Buters (Christine Weil & Ingrid Weichenmeier). At the Zentrum Allergie und Umwelt ([ZAUM](https://www.zaum-online.de/), directed by Prof. Carsten B. Schmidt_Weber). </p> 

You can **load the data** in your working environment by typing:

```{r echo = TRUE}
data("munich_pollen")
```
  
    
    
# Loading your database from Excel
This section has been developed for people who are not familiar with R. **If you have experience in loading databases in R, you might not be interested in this section and you can skip it.**

There are several functions to import data from Excel. Arbitrarily, we are going to use the package **<font size="3" face="verdana">readxl</font>**.
```{r eval=FALSE, echo = TRUE}
install.packages("readxl")
library (readxl)
```

Now we can import the data with the function **<font size="3" face="verdana">read_xlsx()</font>**. I strongly recommend you to **have your Excel file in the same folder in which you are working with R**. This will avoid long paths to your files and also will prevent broken paths when some files have been moved. If you are working with an old database, you might be interested in the **<font size="3" face="verdana">read_xls()</font>** function.

```{r eval=FALSE, echo = TRUE}
Mydata<-read_xlsx("C:/Users/Antonio/Desktop/Prueba Markdown/mydata.xlsx")

```
You can also **select the sheet** you want to import:

```{r eval=FALSE, echo = TRUE}
Mydata<-read_xlsx("C:/Users/Antonio/Desktop/Prueba Markdown/mydata.xlsx", sheet=2)

```

<div class="alert alert-info">**IMPORTANT**: You must remove all the symbols or letters from your database. **If you have missing gaps within your database don't put "-" or "No Data" or any letter in the gaps**, keep the cell empty or remove the cell. The dates should be in a complete format (E.g.:"14/02/2019"). There must be a first column with the date followed by as many columns as pollen types with only numeric values (**check decimal separation: commas must be replaced by dots**).</div>

Now you should have loaded your data in the object `Mydata`. Let's check if there is any mistake:

```{r echo=TRUE, results='hold'}
str(munich_pollen)
```

**Note**: I'm using `munich_pollen` database as example but you should use `Mydata`.

As you can see, the object is a `data.frame`, the first column is "Date" type and the rest are "num", which means numeric. This is the format you database **must** have. Normally it is automatically recognized by the import function, but if not, check the functions: <font size="3" face="verdana">**as.Date()**</font>, <font size="3" face="verdana">**as.numeric()**</font> and <font size="3" face="verdana">**as.data.frame()**</font>.

<div class="alert alert-info"><p>**Your database must have this format to start working with the package**. The functions are designed to warn you in case the format is not correct but there may be some exceptions. **This is the most important step when using the package and some strange errors reported by the functions can be solved by doing this**. Sometimes the date column has 2 different types simultaneously ("POSIXlt" and "POSIXct") and it might cause mistakes. You can use one or another, but not both. Furthermore, it is strongly recommended to use "Date" format instead of "POSIXlt" or "POSIXct" despite theoretically there may not be problems by using them.</p><br>

<p>**Please, don`t exasperate**. This is the **slowest step of using the package and the most important**. Once you have your data loaded, you only have to spend a few minutes in each function to have your results. If you have some unsolving problems, search on the internet. Some other people must have had your same problem and it should be solved in some forums. If not, write us and we will help you as soon as possible: aerobiology.package@gmail.com </p></div>

<p class="comment">If you want to import your data from **csv files**, you might be interested in **<font size="3" face="verdana">read.csv()</font>** function.</p>
  
    
    
# Function <font face="verdana">quality_control()</font>

**This function was designed to check the quality of an historical database of several pollen types**. Since many of the quality requirements depend on the criteria selected to establish the main pollen season, this function has the **<font size="3" face="verdana">calculate_ps()</font> function integrated**. You can insert arguments of calculate_ps() in this function to select the method you want for calculating the main pollen season. calculate_ps() details can be consulted later in this same manuscript.

<p class="comment">If **result = "plot"**, this function returns a **graphical resume** of the quality of the database marking with different red intensities the "weak-points" of it, and if **result = "table"** a `data.frame` with the detailed reasons of their "weakness".</p>

**It establishes the quality according to 5 different criteria**:

* **It checks if the main pollen season cannot be calculated according to the minimal requirements:** lack of data for this pollen type and year. This criteria appears as **"Complete"** in the generated data.frame.

* **If the start, end or peak dates of the main pollen season have been interpolated** (or a date near them specified by **`int.window`** argument). It is based on the following premise: If this day or a nearby date is missing/interpolated, the selected date as start/peak/end might not be the real one. These criteria appear as **"Start"**, **"Peak"** and **"End"** in the generated data.frame.

* **The percentage of missing data within the main pollen season.** It calculates the number of days which have been interpolated by interpollen() function and their percentage of the main pollen season. If a high percentage of the main pollen season has been interpolated, the information of this season might not be reliable. The maximal percentage allowed can be specified by the **`perc.miss`** argument. This filter appears as **"Comp.MPS"** in the generated data.frame.

When running the function, it gives you a **graphical resume** with different color intensity depending on the risk of including each pollen/spore type for a concrete year and a **data.frame** with detailed information about the reasons of this evaluation.

<div class="alert alert-info"> If **result = "plot"**, the function returns a list of objects of class *ggplot2*; if **result = "table"**, the function returns a *data.frame*. By default, **result = "table"**.</div>

```{r echo=TRUE, results='hide', fig.keep='first'}
QualityControl<-quality_control(munich_pollen, result = "table")
```


If the filter has been successfully passed, it appears as `TRUE` in the generated `data.frame`. If not, it appears as `FALSE`.


```{r echo=TRUE, results='hold'}

head(QualityControl)
```


```{r echo=TRUE,  fig.keep='first', results='hide'}
quality_control(munich_pollen, result = "plot")
```


There are lots of arguments for this function. You can consult them in the "help" section of the function in R or in the [official document](https://CRAN.R-project.org/package=AeRobiology) of the package.

Let's suppose we want to check the quality of our database, but we want to calculate it for a **80% defined Main Pollen Season** (arguments **`ps.method`** and **`perc`**). We don't want to take into account years with a missing data less than **4 days** away from the start, peak or end dates (argument **`int.window`**). Furthermore, we only want to exclude years with more than **50% of interpolated data** within the main pollen season (argument **`perc.miss`**):

```{r echo=TRUE, results='hide', fig.keep='first'}
quality_control(munich_pollen, int.window = 4, perc.miss = 50, ps.method = "percentage", perc = 80)
```

**As you would have noticed, there are several differences between this result and the previous one.**

<div class="alert alert-info">**<font size="3" face="verdana">interpollen()</font> function** is integrated in this function. Consult the "help" section of this function to use it.</div>
  
    
    
# Function <font face="verdana">interpollen()</font>
The function **<font size="3" face="verdana">interpollen()</font>** was designed to complete all the missing gaps within a database in just one step. All the gaps of each pollen/spore type are completed simultaneously. **There are different methods to do so which may be more or less appropriate according to the particularities of your database.** The arguments are:

* **data**: A `data.frame` object. This data.frame should include a first column in "Date" format and the rest of the columns in "numeric" format belonging to each pollen/spore type by column.
* **method**: A `character` string specifying the method applied to calculate and generate the pollen missing data. The implemented methods that can be used are: **"lineal"**, **"movingmean"**, **"spline"**, **"tseries"** or **"neighbour"**. The method argument will be "lineal" by default.
* **maxdays**: A `numeric (integer)` value specifying the maximum number of consecutive days with missing data that the algorithm is going to interpolate. If the gap is bigger than the argument value, the gap will not be interpolated. Not valid with <font size="2" face="verdana">"tseries"</font> method. The <font size="2" face="verdana">maxdays</font> argument will be 30 by default. This argument might be very interesting to avoid long interpolated gaps.
* **plot**: A `logical (integer)` argument. If `TRUE`, graphical previews of the input database will be plot at the end of the interpolation process. All the interpolated gaps will be marked in red. The `plot` argument will be `TRUE` by default.
* Others...

```{r echo=TRUE, results='hide', fig.keep='first'}
Interpolated<-interpollen(munich_pollen[,c(1,6)], method="lineal", plot = TRUE, result = "long")

```

As you can see above, when **result = "long"**, **the missing gaps which have been completed by the algorithm are marked in red.** It displays similar graphs for each pollen/spore type within your database. Furthermore, the **"Interpolated"** data.frame is produced as "long" with another new column indicating if each data has been interpolated or not (1 means interpolated and 0 means original data).

```{r echo=TRUE, results='hold'}
head(Interpolated)
```


If you want to integrate all the new data in your database, **you can assign the function to a new object** and specify the argument **result = "wide"**:

```{r echo=TRUE, results='hide'}
CompleteData<-interpollen(munich_pollen[,c(1,6)], method="lineal", plot = FALSE, result = "wide")
```

Now your database without gaps appears as "CompleteData".

**As you might have noticed, if you add `plot=FALSE`, the graphs are not shown.**

You don't have to do this before applying another function of this package. **<font size="3" face="verdana">"interpollen"</font> function has been integrated in the main functions of the package** so you can choose whether you want your data to be completed or not by a specific argument in each function.E.g.:

```{r echo=TRUE, eval=FALSE}
calculate_ps(munich_pollen, method="percentage", interpolation=TRUE, int.method = "lineal", plot = F)
```

<div class="alert alert-info">**FREQUENT ERROR:** Sometimes when applying interpollen you receive the following error: **"Error in rep(NA, ncasos): invalid 'times' argument"**. This is due to a mistake in your database: **you have some dates repeated or disorganized**. The algorithm of `interpollen()` searches for correlative dates and, when they are not consecutive natural days, it carries out the interpolation. When the second date is an earlier date than the previous one, it reports an error. You have to correct these issues in your database before applying the interpollen function. </div>
  
  
## Methods of interpolation

In this function there are **5 different methods to interpolate missing gaps**. Each method can be more appropriate than the others under some specific circumstances. Interpolated data are not real data, but including such estimations can reduce the error of some calculations such as the main pollen season by percentage or a pollen calendar, i.e.: if you keep the gap, these days would count as 0 for the calculations and this would suppose a bigger error than estimating pollen concentrations for these days. Obviously, this will also suppose a bigger error than having the real data.

### <font face="verdana">"lineal"</font> method
As mentioned above, there are many methods to interpolate your missing data. The simplest one was the showed in the previous example: "lineal". **It traces a straight line between each extreme of the gap.** The pollen/spore concentration of the missing days is calculated according to this line. This method may be appropriate for dates without pollen/spores or for small gaps.

**Nevertheless, there are other method which can be more effective during the pollen season.**

### <font face="verdana">"movingmean"</font> method
This method calculates the moving mean of the pollen daily concentrations. The gaps are fulfilled by **calculating the moving mean of the concentrations for this particular day.** The window of the moving mean is centered on this day and its size is the result of multiplicating the gap size by the **`factor` argument**. E.g.: If you have a gap of 3 days and your factor is 2, the gaps are replaced by the value of a moving mean of 6 days (3 x 2) centered in this particular day and not taking into account the missing days for the mean value. Furthermore, it is a dynamic function: **for each gap of the database the window size of the moving mean changes depending of each gap size.**

```{r echo=TRUE, results='hide', fig.keep='first'}
i<-interpollen(munich_pollen[,c(1,6)], method="movingmean", factor = 2, plot = TRUE)
```


### <font face="verdana">"spline"</font> method
This method carries out the interpolation by tracing a **polinomic function to link both extremes of the gap.** The polinomic function is chosen according to the best fitting equation to the previous and posterior days of the gap (second, third, fourth degree...). The number of days of each side of the gap which will be taken into account for calculating the spline regression are specified by **`ndays` argument**. The smoothness of the adjustment can be specified by the **`spar` argument**.

```{r echo=TRUE, results='hide', fig.keep='first'}
i2<-interpollen(munich_pollen[,c(1,6)], method="spline", ndays=3, spar=0.7, plot = FALSE)
```

**Note**: By changing the `ndays` and `spar` argument, very different results can be obtained. E.g.:

```{r echo=TRUE, results='hide', fig.keep='first'}
i3<-interpollen(munich_pollen[,c(1,6)], method="spline", ndays=5, spar=0.2, plot = TRUE)
```

### <font face="verdana">"tseries"</font> method
If you have long time series of data, this might be the most suitable method for you. This method **analyses the time series of the pollen/spore database and performs a seasonal-trend decomposition based on LOESS** ([Cleveland et al., 1990](https://www.scirp.org/reference/referencespapers?referenceid=1891917)). It extracts the **seasonality of the historical database** and uses it to predict the missing data by performing a linear regression with the target year.

```{r echo=TRUE, results='hide', fig.keep='last'}
i4<-interpollen(munich_pollen, method="tseries", plot = TRUE)
```

**Seasonality is represented in grey, real data in black and interpolated data in red.** This method improves with long time series of years. Strange results may be caused by lack of years or small sampling periods.

### <font face="verdana">"neighbour"</font> method

**Other near stations provided by the user are used to interpolate the missing data of the target station.** First of all, a Spearman correlation is performed between the target station and the neighbour stations to discard the neighbour stations with a correlation coefficient smaller than **`mincorr` value**. For each gap, a linear regression is performed between the neighbour stations and the target stations to determine the equation which converts the pollen concentrations of the neighbour stations into the pollen concentration of the target station. Only neighbour stations without any missing data during the gap period are taken into account for each gap.

<p class="comment">You can include 4 different databases of neighbour stations with the arguments **`data2`, `data3`, `data4` and `data5`.** **The format of these databases must be the same than the original one and the name of the pollen/spore types must be exactly the same.**</p>

With the **`mincorr` argument** you can specify the minimal correlation coefficient (Spearman correlation) that the neighbour stations must have with the target station to be taken into account for a concrete gap. This process is completely independent for each gap of each pollen type.
  
    
    
# Function <font face="verdana">calculate_ps()</font>

The function **<font size="3" face="verdana">calculate_ps()</font>** is one of the core functions of the AeRobiology package. It was designed to **calculate the main parameters of the pollen season** with regard to phenology and pollen intensity from a historical database of several pollen types. The function can use the most common methods to define the main pollen season. 

<div class="alert alert-info">**Please, be patient:** This function has tons of arguments. Some of them are only useful for specific situations. You can use the function without knowing all of them. Nevertheless, **we decided to include all the possible arguments in order to provide specific tools for the advanced users**.</div>


**This function has several arguments, but don't worry, we are going to perform examples later**. The main arguments are:

* **data**: A `data.frame` object including the general database where calculation of the pollen season must be applied. This data.frame must include a first column in "Date" format and the rest of columns in "numeric" format belonging to each pollen type by column.
* **method**: A `character` string specifying the method applied to calculate the pollen season and the main parameters. The implemented methods that can be used are: "percentage", "logistic", "moving", "clinical" or "grains". A more detailed information about the different methods for defining the pollen season may be consulted [here](https://CRAN.R-project.org/package=AeRobiology)) or later in this same document.
* **th.day**: A `numeric` value. The number of days whose pollen concentration is bigger than this threshold is calculated for each year and pollen type. This value will be obtained in the results of the function. The `th.day` argument will be 100 by default.
* **perc**: A `numeric` value ranging 0_100. This argument is valid only for `method = "percentage"`. This value represents the percentage of the total annual pollen included in the pollen season, removing (100_perc)/2% of the total pollen before and after of the pollen season. The `perc` argument will be 95 by default.
* **def.season**: A `character` string specifying the method for selecting the best annual period to calculate the pollen season. The pollen seasons may occur within the natural year between two years. The implemented options that can be used are: "natural", "interannual" or "peak". The `def.season` argument will be "natural" by default. A more detailed information about the different methods for selecting the best annual period to calculate the pollen season may be consulted [here](https://CRAN.R-project.org/package=AeRobiology).
* **reduction**: A `logical` value. This argument is valid only for the "logistic" method. If `FALSE` the reduction of the pollen data is not applicable. If `TRUE` a reduction of the peaks above a certain level (`red.level` argument) will be carried out before the definition of the pollen season. The reduction argument will be `FALSE` by default. A more detailed information about the reduction process may be consulted [here](https://CRAN.R-project.org/package=AeRobiology).
* **red.level**: A `numeric` value ranging 0_1 specifying the percentile used as level to reduce the peaks of the pollen series before the definition of the pollen season. This argument is valid only for the "logistic" method. The `red.level` argument will be 0.90 by default, specifying the percentile 90.
* **derivative**: A `numeric (integer)` value belonging to options of 4, 5 or 6 specifying the derivative that will be applied to calculate the asymptotes which determines the pollen season using the "logistic" method. This argument is valid only for the "logistic" method. The `derivative` argument will be 5 by default. More information may be consulted [here](https://CRAN.R-project.org/package=AeRobiology).
* **man**: A `numeric (integer)` value specifying the order of the moving average applied to calculate the pollen season using the "moving" method. This argument is valid only for the "moving" method. The `man` argument will be 11 by default.
* **th.ma**: A `numeric` value specifying the threshold used for the "moving" method for defining the beginning and the end of the pollen season. This argument is valid only for the "moving" method. The `th.ma` argument will be 5 by default.
* **n.clinical**: A `numeric (integer)` value specifying the number of days which must exceed a given threshold (th.pollen argument) for defining the beginning and the end of the pollen season. This argument is valid only for the "clinical" method. The `n.clinical` argument will be 5 by default.
* **window.clinical**: A `numeric (integer)` value specifying the time window during which the conditions must be evaluated for defining the beginning and the end of the pollen season using the "clinical" method. This argument is valid only for the "clinical" method. The `window.clinical` argument will be 7 by default.
* **window.grains**: A `numeric (integer)` value specifying the time window during which the conditions must be evaluated for defining the beginning and the end of the pollen season using the "grains" method. This argument is valid only for the "grains" method. The `window.grains` argument will be 5 by default.
* **th.pollen**: A `numeric` value specifying the threshold that must be exceeded during a given number of days (n.clinical or window.grains arguments) for defining the beginning and the end of the pollen season using the "clinical" or "grains" methods. This argument is valid only for the "clinical" or "grains" methods. The `th.pollen` argument will be 10 by default.
* **th.sum**: A `numeric` value specifying the pollen threshold that must be exceeded by the sum of daily pollen during a given number of days (`n.clinical` argument) exceeding a given daily threshold (`th.pollen` argument) for defining the beginning and the end of the pollen season using the "clinical" method. This argument is valid only for the "clinical" method. The `th.sum` argument will be 100 by default.
* **type**: A `character` string specifying the parameters considered according to a specific pollen type for calculating the pollen season using the "clinical" method. The implemented pollen types that may be used are: "birch", "grasses", "cypress", "olive" or "ragweed". As result for selecting any of these pollen types the parameters `n.clinical`, `window.clinical`, `th.pollen` and `th.sum` will be automatically adjusted for the "clinical" method. If no pollen types are specified (`type = "none"`), these parameters will be considered by the user. This argument is valid only for the "clinical" method. The `type` argument will be "none" by default.
* **interpolation**: A `logical` value. If `FALSE` the interpolation of the pollen data is not applicable. If `TRUE` an interpolation of the pollen series will be applied to complete the gaps with no data before the calculation of the pollen season. The `interpolation` argument will be `TRUE` by default. A more detailed information about the interpolation method may be consulted [here](https://CRAN.R-project.org/package=AeRobiology).
* **int.method**: A `character` string specifying the method selected to apply the interpolation method in order to complete the pollen series. The implemented methods that may be used are: "lineal", "movingmean", "spline" or "tseries". The `int.method` argument will be "lineal" by default.
* **maxdays**: A `numeric` (integer value) specifying the maximum number of consecutive days with missing data that the algorithm is going to interpolate. If the gap is bigger than the argument value, the gap will not be interpolated. Not valid with `int.method = "tseries"`. The `maxdays` argument will be 30 by default.
* **export.plot**: A `logical` value specifying if a set of plots based on the definition of the pollen season and saved in the working directory will be required or not. If `FALSE` graphical results will not be saved. If `TRUE` a pdf file for each pollen type showing graphically the definition of the pollen season for each studied year will be saved within the plot_AeRobiology directory created in the working directory. The `export.plot` argument will be `FALSE` by default.
* **export.result**: A `logical` value specifying if a excel file including all parameters for the definition of the pollen season saved in the working directory will be required or not. If `FALSE` the results will not exported. If `TRUE` the results will be exported as xlsx file including all parameters calculated from the definition of the pollen season within the table_AeRobiology directory created in the working directory. The `export.result` argument will be `FALSE` by default.
* **plot**: A `logical` value specifying if the plots are generated in the plot history. The `plot` argument will be `TRUE` by default.
* **result**: A `character` string specifying the output for the function. The implemented outputs that may be obtained are: `"table"` and `"list"`. The argument `result` will be `"table"` by default.

<div class="alert alert-info">**IMPORTANT :** if `export.plot = FALSE`, the plots are **EXPORTED** in "plot_AeRobiology" folder.</div>
  
  
## Methods of calculating the Main Pollen Season

This function allows to calculate the pollen season using **five different methods** which are described below. After calculating the **start_date**, **end_date** and **peak_date** for the pollen season all rest of **parameters** are calculated:

* **type**: pollen type
* **seasons**: year of the beginning of the season
* **st.dt**: start_date (date)
* **st.jd**: start_date (day of the year)
* **en.dt**: end_date (date)
* **en.jd**: end_date (day of the year)
* **ln.ps**: length of the season
* **sm.tt**: total sum
* **sm.ps**: pollen integral
* **pk.val**: peak value
* **pk.dt**: peak_date (date)
* **pk.jd**: peak_date (day of year)
* **ln.prpk**: length of the pre_peak period
* **sm.prpk**: pollen integral of the pre_peak period
* **ln.pspk**: length of the post_peak period
* **sm.pspk**: pollen integral of the post_peak period
* **daysth**: number of days with more than 100 pollen grains
* **st.dt.hs**: start_date of the High pollen season (date, only for clinical method)
* **st.jd.hs**: start_date of the High pollen season (day of the year, only for clinical method)
* **en.dt.hs**: end_date of the High pollen season (date, only for clinical method)
* **en.jd.hs**: end_date of the High pollen season (day of the year, only for clinical method)

<div class="alert alert-info">**IMPORTANT :** If `export.result = FALSE`, these objects will be exported as xlsx file within the "table_AeRobiology" directory created in your working directory. This Excel file will have a sheet for each pollen type and a last sheet with the legend of all the abbreviations and the method selected to calculate them. **We strongly recommend to use `export.result = FALSE`**</div>

Although the results can be extracted in the working directory in a xlsx file, **they can also be assigned to an object, and visualized**, for example (an extract):

```{r echo = TRUE, results='hide', fig.keep='last', warning=FALSE}
pollen_season <- calculate_ps(munich_pollen)
```

```{r echo = FALSE, fig.keep='all', warning=FALSE}
knitr::kable(pollen_season[24:31, ] , format = "html", booktabs = TRUE)
```

The result is also plotted by default (*plot = TRUE*).

```{r echo = TRUE, fig.keep='last', warning=FALSE}
calculate_ps(munich_pollen[,c(1,6)], plot = TRUE)
```

### "percentage" method

This is a commonly used method for defining the pollen season based on the **elimination of a certain percentage in the beginning and the end of the pollen season** ( [Nilsson and Persson, 1981](https://doi.org/10.1080/00173138109427661); [Andersen, 1991](https://doi.org/10.1080/00173139109427810). For example, if the pollen season is based on the 95% of the total annual pollen (`perc = 95`), the start_date of the pollen season is marked as the day in which 2.5% of the total pollen is registered and the end_date of the pollen season is marked as the day in which 97.5% of the total pollen is registered.

```{r echo=TRUE, results='hide', fig.keep='first', eval=FALSE}
calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc = 90, export.result = FALSE)
```

In this case we have calculated the main pollen season based on the 90% of the total annual pollen. **Results are stored in the "table_AeRobiology" folder since `export.result = FALSE`**.

You can select different methods of interpolation or even to not interpolate gaps:

```{r echo=TRUE, results='hide', fig.keep='first'}
calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc = 90, export.result = FALSE, int.method = "spline")
```

```{r echo=TRUE, results='hide', fig.keep='first'}
calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc = 75, export.result = FALSE, interpolation = FALSE)
```

<div class="alert alert-info">**IMPORTANT :** if `export.plot = FALSE`, the plots are **EXPORTED** in "plot_AeRobiology" folder.</div>


### "logistic" method

This method was developed by Ribeiro et al. (2007) and modified by Cunha et al. (2015). It is based on fitting annually a **non-linear logistic regression model** to the daily accumulated curve for each pollen type. This logistic function and the **different derivatives** were considered to calculate the **start_date** and **end_date** of the pollen season, based on the **asymptotes when pollen amounts are stabilized on the beginning and the end of the accumulated curve**. For more information about the method, see [Ribeiro et al. (2007)](https://pubmed.ncbi.nlm.nih.gov/18247462/) and [Cunha et al. (2015)](https://link.springer.com/article/10.1007/s10453-014-9345-3). **Three different derivatives** may be used (`derivative` argument) 4, 5 or 6 that represent **from higher to lower restrictive criterion** for defining the pollen season. 

This method may be **complemented with an optional method for reduction the peaks values** (`reduction = TRUE`), thus avoiding the effect of the great influence of extreme peaks. In this sense, **peaks values will be cut below a certain level** that the user may select based on a percentile analysis of peaks. For example, `red.level = 0.90` will cut all peaks above the percentile 90.

```{r echo=TRUE, results='hide', fig.keep='first', warning=FALSE}
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "logistic", derivative = 5, reduction=FALSE)
```

```{r echo = FALSE, fig.keep='all', warning=FALSE}
knitr::kable(pollen_season, format = "html", booktabs = TRUE )
```

In the previous case, the reduction wasn't carried out (`reduction=FALSE`) and all the peaks were conserved. We can cut some peaks and change the `derivative`:

```{r echo=TRUE, results='hide', fig.keep='first', warning=FALSE}
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "logistic", derivative = 6, reduction=FALSE, red.level = 0.8)
```

```{r echo = FALSE, fig.keep='all', warning=FALSE}
knitr::kable(pollen_season, format = "html", booktabs = TRUE)
```

As you can observe, results are a bit different.

<div class="alert alert-info">**IMPORTANT :** if `export.plot = FALSE`, the plots are **EXPORTED** in "plot_AeRobiology" folder.</div>

### "clinical" method

This method was proposed by [Pfaar et al. (2017)](https://pubmed.ncbi.nlm.nih.gov/27874202/). It is based on the expert consensus in relation to pollen exposure and the **relationship with allergic symptoms** derived of the literature. 

Different periods may be defined by this method: the **pollen season**, the **high pollen season** and the **high pollen days**: 

1) The **start_date** and **end_date** of the **pollen season** were defined as a **certain number of days (`n.clinical` argument) within a time window period (`window.clinical` argument) exceeding a certain pollen threshold (`th.pollen` argument) which summation is above a certain pollen sum (`th.sum` argument)**. <br> All these parameters are established for each pollen type according to Pfaar et al. (2017) and using the **`type`** argument these parameters may be automatically adjusted for the specific pollen types ("birch", "grasses", "cypress", "olive" or "ragweed"). Furthermore, **the user may change all parameters to do a customized definition of the pollen season**.

2) The **start_date** and **end_date** of the **high pollen season** were defined as **three consecutive days exceeding a certain pollen threshold (`th.day` argument)**. 

3) The number of **high pollen days** will also be calculated exceeding this pollen threshold (`th.day`). For more information about the method, see [Pfaar et al. (2017)](https://pubmed.ncbi.nlm.nih.gov/27874202/).

Running the following example, the main pollen season will be established according to the birch requirements: more than 5 days within a week in which more than 10 pollen grains/m3 are registered and whose sum exceeds 100 pollen grains/m3. The high pollen days are those which exceed 100 pollen grains/m3 (`n.clinical=5, window.clinical=7, th.pollen=10, th.sum=100, th.day=100`)

```{r echo=TRUE, results='hide', fig.keep='first', warning=FALSE}
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "clinical", type = "birch")
```

```{r echo = FALSE, fig.keep='all', warning=FALSE}
knitr::kable(pollen_season, format = "html", booktabs = TRUE)
```

The code above returns the same result than:

```{r echo=TRUE, results='hide', fig.keep='first', warning=FALSE}
pollen_season<-calculate_ps(munich_pollen[,c(1,6)], method = "clinical", n.clinical = 5, window.clinical = 7, th.pollen = 10, th.sum = 100, th.day = 100)
```

```{r echo = FALSE, fig.keep='all', warning=FALSE}
knitr::kable(pollen_season, format = "html", booktabs = TRUE)
```

We have resumed all these parameters under the argument `type=birch` to facilitate its application.

<div class="alert alert-info">**IMPORTANT :** if **`export.plot = FALSE`**, the plots are **EXPORTED** in "plot_AeRobiology" folder.</div>

### "grains" method

This method was proposed by Galan et al. (2001) originally in olive pollen but after also applied in other pollen types. 

The **start_date** and **end_date** of the pollen season were defined as a **certain number of days (`window.grains` argument) exceeding a certain pollen threshold (`th.pollen` argument)**. For more information about the method, see [Galan et al. (2001)](https://link.springer.com/article/10.1007/s004840000081).

We want to establish the main pollen season start in the first day when more than 3 consecutive days have more than 2 pollen grains/m3, and the end in the last day in which these conditions are fulfilled:

```{r echo=TRUE, results='hide', fig.keep='first'}
calculate_ps(munich_pollen[,c(1,6)], method = "grains", window.grains = 3, th.pollen = 2 )
```

### "moving" method

<div class="alert alert-info">**This method is proposed the first time by the authors of this package. We are developing a research paper explaining the method in detail.**</div>

The definition of the pollen season is based on the application of a **moving average** to the pollen series in order to obtain the general seasonality of the pollen curve avoiding the great variability of the daily fluctuations. Thus, **the start_date and the end_date will be established when the curve of the moving average reaches a given pollen threshold** (**`th.ma`** argument). Also the order of the moving average may be customized by the user (**`man`** argument). By default, `man = 11` and `th.ma = 5`.

<p class="comment"> The idea of this method is to be able to calculate the start of the main pollen season when the season has not finished yet. Moreover, it allows to establish the start and end even if there is a huge amount of lacking data within the main pollen season. Its similar to the "grains" method but taking into account the moving mean to avoid daily variability.</p>

You might understand it better by consulting the plots obtained.

<div class="alert alert-info">**IMPORTANT :** if **`export.plot = FALSE`**, the plots are **EXPORTED** in "plot_AeRobiology" folder.</div>

Let's calculate it with a moving average of 7 days. We are going to establish the start and end of the main pollen season when the moving average reaches 4 pollen grains/m3:

```{r echo=TRUE, results='hide', fig.keep='first'}
calculate_ps(munich_pollen[,c(1,6)], method = "moving", man = 7, th.ma = 4)
```
  
  
## Advanced examples

### Southern Hemisphere & interannual types

As you may have noticed, we have been using the function under an "European" point of view: the calculations are from 1st January to 31th December. The researchers of the **Southern Hemisphere** are used to work with **interanual pollen seasons**. Don't worry, we haven't forgotten you!

1) You can work **from 1st June to 31th May** by means of the argument **`def.season="interannual"`**:

```{r echo=TRUE, results='hide', fig.keep='first'}
calculate_ps(munich_pollen[,c(1,3)], method = "moving", man = 7, th.ma = 4, def.season = "interannual")
```

<p class="comment"> In this method, the season belongs to the first year of the pair of years, i.e: from June 2017 to May 2018 -> season "2017".</p>

2) You can **center the main pollen season in the average peak day** (182 days before and after the average date of the peak):

```{r echo=TRUE, results='hide', fig.keep='first'}
calculate_ps(munich_pollen[,c(1,6)], method = "percentage", perc=95, def.season = "peak")
```

<p class="comment"> In this last method, the season belongs to the year in which the average peak date - 182 days is located, i.e.: if the average peak date is in January 2013, the season is called "2012" in the data.frames.</p>

### Interpolation in detail

Pollen time series frequently have different gaps with no data and this fact could be a problem for the calculation of specific methods for defining the pollen season even providing incorrect results. In this sense **by default a linear interpolation will be carried out to complete these gaps before to define the pollen season (`interpolation = TRUE`)**. Additionally, the users may select other interpolation methods using the **`int.method` argument**, as "lineal", "movingmean", "spline" or "tseries".

Some advanced users may have noticed that you can't use directly all the arguments of **<font size="3" face="verdana">interpollen()</font>** through **<font size="3" face="verdana">calculate_ps()</font>**. You only are able to select the interpolation method. Nevertheless, it is not impossible to use them:

1) **Use <font size="3" face="verdana">interpollen()</font>** with all the arguments you want and **overwrite your interpolated database in an object**:

```{r echo=TRUE, results='hide', fig.keep='first'}
CompleteData<-interpollen(munich_pollen, method="spline", ndays=3, spar=0.7, plot = TRUE, maxdays = 3, result = "wide")
```

2) Then, **use "CompleteData" instead of "munich_pollen" (or your database) in the following steps**:

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_ps(CompleteData, pollen.type="Alnus", year=2013, fill.col = "orange", axisname = "AeRobiology custom units")
```

<p class="comment"> **Note**: You might select **`interpolation=FALSE`** in the other functions you use after interpolating manually. In some cases it doesn't matter, but if you want to interpolate only gaps with less than 3 days and you did in the first step, if you don't use `interpolation=FALSE` in calculate_ps function, a second interpolation will be carried out by using the default method (gaps with less than 30 days and lineal interpolation). You will obtain a database with the gaps of less than 3 days interpolated by "spline" method and the rest with the "lineal" method. </p>
  
    
    
# Function <font face="verdana">pollen_calendar</font>

This function **calculates the pollen calendar from a historical database** of several pollen types using different designs. The main arguments are:  

* **data**: A `data.frame` with the first column in "Date" format and the rest of the columns in "numeric" format (pollen types).
* **method**: for choosing the method to generate the pollen calendar. The options are "heatplot", "violinplot" and "phenological".
* **n.types**: indicating the number of the most abundant pollen types showed in the pollen calendar
* **start.month**: ranging 1-12 indicates the number of the month (January-December) when the beginning of the pollen calendar must be considered, see more details [here](https://CRAN.R-project.org/package=AeRobiology).
* **export.plot**: specifying if a plot with the pollen calendar saved in the working directory will be required or not. Other arguments have been incorporated in relation to the format to export the plot (`export.format`).
* **result**: **"plot"** or **"table"**.

**Data exportation:**

- If `export.plot = FALSE` this plot displaying the pollen calendar will be exported within the **Plot_AeRobiology** directory created in the working directory.
- If `export.plot = FALSE` and `export.format = pdf`, a pdf file with the pollen calendar will be saved within the **plot_AeRobiology** directory, created in the working directory. Additional characteristics
may be incorporated to the exportation as pdf file.
- If `export.plot = FALSE` and `export.format = png`, a png file with the pollen calendar will be saved within the **plot_AeRobiology** directory, created in the working directory. Additional characteristics may be incorporated to the exportation as png file.

**Exclusive arguments** for pollen calendars generated as **"heatplot"**:

* **period**: specifying the interval time considered to generate the pollen calendar. The options are "weekly" and "daily."
* **method.classes**: indicating the method to define the classes used for classifying the average pollen concentrations. The options are "exponential" and "custom".
* **n.classes**: specifying the number of classes that will be used when `method.classes = custom`.
* **classes**: specifying a numeric vector with the desired thresholds to define the different classes.
* **color**: choosing different options such as "green", "red", "blue", "purple"or "black".

**Exclusive arguments** for pollen calendars generated as **"phenological"**:

* **perc1, perc2**: both ranging 0-100. These values represent the percentage of the total annual pollen included in the pollen season, removing (100-percentage)/2% of the total pollen before and after the pollen season. Two percentages must be specified to define the "main pollination period" (`perc1`) and the "early/late pollination" (`perc2`) based on the "phenological" method proposed by [Werchan
et al. (2018)](https://link.springer.com/article/10.1007/s40629-018-0055-1).
* **th.pollen**: specifying the minimum threshold of the average pollen concentration which will be used to generate the pollen calendar. Days below this threshold will not be considered and days above this threshold will be considered as "possible occurrence" as proposed by [Werchan
et al. (2018)](https://link.springer.com/article/10.1007/s40629-018-0055-1). This argument also works for "violinplot" pollen calendar

<div class="alert alert-info">By default the database will be interpolated according to the **<font size="3" face="verdana">interpollen</font>** function, and also other arguments for this function are incorporated in the **<font size="3" face="verdana">pollen_calendar</font>** function.</div>

## "heatplot" method

This pollen calendar is constructed based on the **daily or weekly average of pollen concentrations** (depending on the preferences of the user, who may select "daily" or "weekly" as **`period` argument**). Then, these averages may be classified in different categories following different methods selected by the user. An example of this pollen calendar may be consulted in [Rojo et al. (2016)](https://link.springer.com/article/10.1007/s10661-016-5129-2). This method to design pollen calendars is an **adaptation from the pollen calendar proposed by Spieksma (1991)**, who considered 10-day periods instead of daily or weekly periods.

First, we are going to generate a pollen calendar based on the **heatplot**, designed with **green** color and constructed with **daily** averages:

```{r echo = TRUE, results='hide',fig.keep='all', warning=FALSE}
pollen_calendar(munich_pollen, method = "heatplot", period = "daily", color = "green", interpolation = FALSE)
```

In all cases, the table used by the pollen calendar with the averaged values will be created. This table can be visualized. To do that we have to set the argument **result = "table"** For example (an extract):

```{r echo = TRUE, fig.keep='all', warning=FALSE}
average_values<-pollen_calendar(munich_pollen, method = "heatplot", period = "daily", color = "green", interpolation = FALSE, result = "table")
knitr::kable(average_values[82:90, ], format = "html", booktabs = TRUE)
```

By default the method for defining the classes for the pollen calendar is according to the **exponential** method. Nevertheless, the classes can be customized by **`classes` argument**:

```{r echo = TRUE, results='hide',fig.keep='all', warning=FALSE}
pollen_calendar(data = munich_pollen, method = "heatplot", period = "daily", color = "red", method.classes = "custom", n.classes = 5, classes = c(5, 25, 50, 200), interpolation = FALSE)
```

In addition, for species with their pollen season occurring between two natural years, the start of the pollen calendar can be selected by the **`start.month` argument**:

```{r echo = TRUE, results='hide',fig.keep='all', warning=FALSE}
pollen_calendar(data = munich_pollen, method = "heatplot", period = "daily", color = "purple", method.classes = "custom", n.classes = 5, classes = c(5, 25, 50, 200), start.month = 11, na.remove = FALSE, interpolation = FALSE)
```

<p class="comment">**`NA` (no data) can be removed by using `na.remove` argument.**</p>

Also we can generate a pollen calendar based on the **heatplot** design with **weekly** averages. 

```{r echo = TRUE, results='hide',fig.keep='all', warning=FALSE}
pollen_calendar(data = munich_pollen, method = "heatplot", period = "weekly", color = "blue", method.classes = "exponential", n.types = 4, y.start = 2011, y.end = 2014, interpolation = FALSE)
```

In this case, we have included other restrictive arguments as **`n.types`** limiting the number of pollen types and **`y.start`** and **`y.end`**, limiting the period to be considered for the pollen calendar.

## "phenological" method

This pollen calendar is based on the phenological definition of the pollen season and adapted from the methodology proposed by [Werchan et al. (2018)](https://link.springer.com/article/10.1007/s40629-018-0055-1). 

After obtaining the **daily average pollen concentrations** for the most abundant pollen types, different pollination periods are calculated. The **main pollination period** is calculated according to the percentage defined by `perc1` argument (selected by the user, 80% by default; red) of the annual total pollen. For example, if `perc1 = 80`, the beginning of the high season is marked when the 10% of the annual value is reached; the end is selected when 90% is reached. The **early/late pollination period** is defined with the `perc2` argument (selected by the user, 99% of the total annual pollen by default; orange), i.e.: the start of this period will be when the 0.5% is reached and the end when the 99.5% is reached. For this kind of pollen calendar the `th.pollen` argument defines the **possible occurrence** period as adapted by [Werchan et al. (2018)](https://link.springer.com/article/10.1007/s40629-018-0055-1), considering the entire period between the first and the last day when this pollen level is reached (yellow).

```{r echo = TRUE, results='hide',fig.keep='all', warning=FALSE}
pollen_calendar(data = munich_pollen, method = "phenological", n.types = 5, y.start = 2011, y.end = 2014, interpolation = FALSE)
```

Furthermore, different criteria can be customized:

```{r echo = TRUE, results='hide',fig.keep='all', warning=FALSE}
pollen_calendar(data = munich_pollen,  method = "phenological", perc1 = 90, perc2 = 95, th.pollen = 5, interpolation = FALSE)
```

In this last case, the pollen calendar has been generated with more restrictive criteria for `perc1`, `perc2` and `th.pollen`.  

## "violinplot" method

This pollen calendar is based on the **pollen intensity**, and adapted from the pollen calendar published by [ORourke (1990)](https://link.springer.com/article/10.1007/BF02539105). At first, the daily averages of the pollen concentrations are calculated and then, these averages are represented by using the violin plot graph. 

<div class="alert alert-info">The shape of the violin plot represents the pollen intensity of the pollen types in a relative way, i.e.: the values will be calculated as **relative measurements** regarding to the most abundant pollen type in annual amounts. Therefore, this pollen calendar shows a relative comparison between the pollen intensity of the pollen types but **without scales and units**.</div>

```{r echo = TRUE, results='hide', fig.keep='all', warning=FALSE}
pollen_calendar(data = munich_pollen, method = "violinplot", y.start = 2012, y.end = 2015, interpolation = FALSE)
```

In addition, **`th.pollen`** can be established, specifying the minimum pollen concentration considered (E.g.: 10 pollen grains/m3):

```{r echo = TRUE, results='hide', fig.keep='all', warning=FALSE}
pollen_calendar(data = munich_pollen, method = "violinplot", th.pollen = 10, na.rm = FALSE, interpolation = FALSE)
```
  
    
    
# Functions <font face="verdana">iplot_pollen()</font> and <font face="verdana">iplot_years()</font>  

These functions have been designed for a **quick view** of your data for discussions or interpretations of them. **Interactive plots are displayed**. It might be interesting for group meetings or real time exposition of results. The functions create a emergent screen in which you can select the pollen/spore type or the years you want to plot. 

<div class="alert alert-info">**IMPORTANT :** To stop the real time visualization and continue using the package you must click in the **"Stop" signal.**</div>

The function **<font size="3" face="verdana">iplot_pollen()</font>** is to plot the pollen data during one season. The arguments are:  

* **data**: A `data.frame` object. This data.frame should include a first column in "Date" format and the rest of columns in format "numeric" belonging to each pollen type by column.  
* **year:** An `integer` value specifying the year to display. This is a mandatory argument. 

The function **<font size="3" face="verdana">iplot_years()</font>** is to plot the pollen data during one season. The arguments are:  

* **data**: A `data.frame` object. This data.frame should include a first column in "Date" format and the rest of columns in format "numeric" belonging to each pollen type by column.    
* **pollen:** A `character` string with the name of the particle to show. This character must match with the name of a column in the input database. This is a mandatory argument.


```{r echo = TRUE, results='hide',fig.keep='all', eval=FALSE}
iplot_pollen(munich_pollen, year = 2012)
iplot_years(munich_pollen, pollen = "Betula")
```

<p class="comment">**Note:** We are not able to plot interactive figures in this document. Please, run the codes above in your R session.</p>


# Function <font face="verdana">plot_summary()</font>  

The function **<font size="3" face="verdana">plot_summary()</font>** is to plot the pollen data during several seasons. Also to plot the averaged pollen season over the study period. It is possible to plot the relative abundance per day and smoothing the pollen season by calculating a moving average. The main arguments are:  

* **data**: A `data.frame` object. This data.frame should include a first column in "Date" format and the rest of columns in "numeric" format belonging to each pollen type by column.  
* **pollen:** A `character` string with the name of the particle to show. This character must match with the name of a column in the input database. This is a mandatory argument.  
* **mave:** An `integer` value specifying the order of the moving average applied to the data. By default, `mave = 1`.  
* **normalized:** A `logical` value specifying if the visualization shows real pollen data (`normalized = FALSE`) or the percentage of every day over the whole pollen season (`normalized = TRUE`). By default, `normalized = FALSE`.  
* **axisname:** A `character` string specifying the title of the y axis. By default, `axisname = "Pollen grains / m3"`  
* Others...

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_summary(munich_pollen, pollen = "Betula")
```

In some cases the user may want to reduce the "noise" of the daily values by **calculating moving means** (E.g.: 5 days moving mean; `mave = 5`):

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_summary(munich_pollen, pollen = "Betula", mave = 5)
```

You might be also interested in representing as background the **percentage** each day suppose to the main pollen season (`normalized = TRUE`):

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_summary(munich_pollen, pollen = "Betula", mave = 5, normalized = TRUE)
```

<div class="alert alert-info">**<font size="3" face="verdana">interpollen()</font> function** is integrated in this function. Consult the "help" section of this function to use it.</div>


# Function <font face="verdana">plot_normsummary()</font>  

The function **<font face="verdana">plot_normsummary()</font>** has been designed to plot the pollen data amplitude during several seasons: daily average pollen concentration over the study period, maximum pollen concentration of each day over the study period and minimum pollen concentration of each day value over the study period. It is possible to plot the relative abundance per day and smoothing the pollen season by calculating a moving average. The main arguments similar to **<font size="3" face="verdana">plot_summary()</font>**, but as a result **you will obtain the the max-min range of the study period** instead of the values for every year.  

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_normsummary(munich_pollen, pollen = "Betula", color.plot = "red")
```

The **maximum values** are marked in **red** and the **minimum values in white**. The **average** is the **black line**.

Of course, you can change the color (`color.plot` argument):

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_normsummary(munich_pollen, pollen = "Betula", color.plot = "green", mave = 5, normalized = TRUE)
```

<div class="alert alert-info">**<font size="3" face="verdana">interpollen()</font> function** is integrated in this function. Consult the "help" section of this function to use it.</div>
  
    
    
# Function <font face="verdana">analyse_trend()</font>  

The function **<font size="3" face="verdana">analyse_trend()</font>** has been created to calculate the main seasonal indexes of the pollen season ("Start Date", "Peak Date", "End Date" and "Pollen Integral"), as well as **trends analysis** of those parameters over the seasons. It is a summary dot plot showing the distribution of the main seasonal indexes over the years.  

The results can also be stored in two folders termed **"plot_AeRobiology"** and **"table_AeRobiology"**, which will be created in your working directory (only if `export.result = FALSE` & `export.plot = FALSE`). You can decide which result to be returned from the function by setting the argument **result**: *result = "table"* or *result = "plot"*.

The function allows you to decide if you want to interpolate the data or not, by the argument **`interpolation`**, it also allows you to select the interpolation method by the argument **`int.method`**. Furthermore, it allows you to select the pollen season definition method, by the argument **`method`** and additional arguments for the function **<font size="3" face="verdana">calculate_ps()</font>**. Some arguments about the visualization are:  

* **split**: A `logical` argument. If `split = TRUE`, the plot is separated in two according to the nature of the variables (i.e. dates or pollen concentrations). **This argument was a solution to reduce the scale of the x-axis when "total pollen"" variable has a very high/low slope**. By default, `split = TRUE`.
* **quantil**: A `numeric` value (between 0 and 1) indicating the quantile of data to be displayed in the graphical output of the function. `quantil = 1` would show all the values, however a lower quantile will exclude the most extreme values of the sample. **This argument was designed after realizing of a common problem: when plotting the results with `split=FALSE`, some "outlier" results increased a lot the scale of the x-axis, making unreadable the rest of results**. Our solution was to create an argument to exclude these outliers results and to be able to observe the main results in an appropriate scale. Furthermore, this argument may be used to split the parameters using a different sampling units (e.g. dates and pollen concentrations) can be used low vs high values of quantil argument (e.g. 0.5 vs 1). Also can be used an extra argument: `split`. By default, `quantil = 0.75`. **This argument only works when `split=FALSE`.**
* **significant**: A `numeric` value indicating the significant level to be considered in the linear trends analysis. This p level is displayed in the graphical output of the function (as a number in the legend and as a black ring in the graphical representation). By default, `significant = 0.05`.  

```{r echo = TRUE, results='hide',fig.keep='all'}
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, result="plot")
```

Lets see what happen if we don't split the graphics:

```{r echo = TRUE, results='hide',fig.keep='all'}
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, split = FALSE, quantil = 1, result="plot")
```

Now the results are less readable, but this kind of graphical representation may be interesting for some people. When plotting all the results together, it might be useful to exclude some outliers:

```{r echo = TRUE, results='hide',fig.keep='all'}
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, split=FALSE, quantil = 0.5, result="plot")
```

As you can appreciate, a lot of points have been omitted.

You can also change the significance level as mentioned above. Why don`t we try?:

```{r echo = TRUE, results='hide',fig.keep='all'}
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, significant = 1, result = "plot")
```

Now everything is significant!

Have a look to the numbers by setting *result = "table"* (the default output).


```{r echo = TRUE, results='hide',fig.keep='all'}
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE, significant = 1, result="table")
```


<div class="alert alert-info">**<font size="3" face="verdana">interpollen()</font> function** is integrated in this function. Consult the "help" section of this function to use it.</div>

<div class="alert alert-info"> If **result = "plot"**, the function returns a list of objects of class *ggplot2*; if **result = "table"**, the function returns a *data.frame*. By default, **result = "table"**.</div>
  
    
    
# Function <font face="verdana">plot_trend()</font>  

The function **<font size="3" face="verdana">plot_trend()</font>** has been created to calculate the main seasonal indexes of the pollen season ("Start Date", "Peak Date", "End Date" and "Pollen Integral") and their trends analysis over the seasons. It produces plots showing the distribution of the main seasonal indexes over the years.  

The **results are stored in two folders termed "plot_AeRobiology" and "table_AeRobiology"** which will be located in your working directory (only if `export.result = FALSE` & `export.plot = FALSE`).

```{r echo = TRUE, results='hide',fig.keep='all', eval=FALSE}
plot_trend(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE)
```

<div class="alert alert-info">**NOTE:** The plots are not shown in your R environment. Because of the high amount of graphs, they are stored in new folders created in your working directory (search were you have saved the R project and you will find the folders).</div>


<p class="comment">The **interval of confidence** only appears if more than 6 dots are plotted. If not, a line crossing all the dots is plotted.</p>

<div class="alert alert-info">**<font size="3" face="verdana">interpollen()</font> function** is integrated in this function. Consult the "help" section of this function to use it.</div>
  
    
    
# Function <font face="verdana">iplot_abundance()</font> 

The function **<font size="3" face="verdana">iplot_abundance()</font>** generates a barplot based on the relative abundance in the air (as percentage) of each pollen/spore type with respect to the total amounts.

The main arguments are:

* **n.types:** A `numeric` (integer) value specifying the number of the most abundant pollen types that must be represented in the plot of the relative abundance. A more detailed information about the selection of the considered pollen types may be consulted [here](https://CRAN.R-project.org/package=AeRobiology). The `n.types` argument will be 15 types by default.
* **y.start/y.end:** A `numeric` (integer) value specifying the period selected to calculate relative abundances of the pollen types (start year - end year). If `y.start` and `y.end` are not specified (`NULL`), the entire database will be used to generate the pollen calendar. The `y.start` and `y.end` arguments will be `NULL` by default.
* **col.bar:** A `character` string specifying the color of the bars to generate the graph showing the relative abundances of the pollen types. The `color` argument will be #E69F00 by default, but any color may be selected.
* **type.plot: ** A `character` string specifying the type of plot selected to show the plot showing the relative abundance of the pollen types. The implemented types that may be used are: "static" (generates a static ggplot object) and "dynamic" (generates a dynamic plotly object).
* **exclude:** A character string vector with the names of the pollen types to be excluded from the plot.
* Others...

```{r echo = TRUE, results='hide',fig.keep='all'}
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE)
```

Now we are going to reduce the number of types:

```{r echo = TRUE, results='hide',fig.keep='all'}
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE, n.types = 3)
```

We can also select the abundance for only one year and change the color: 

```{r echo = TRUE, results='hide',fig.keep='all'}
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE, n.types = 3, y.start = 2011, y.end = 2011, col.bar = "#d63131")
```

Furthermore, we can make it interactive:

```{r echo = TRUE, results='hide',fig.keep='all'}
iplot_abundance(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = FALSE, n.types = 3, y.start = 2011, y.end = 2011, col.bar = "#d63131", type.plot = "dynamic")
```

<div class="alert alert-info">**<font size="3" face="verdana">interpollen()</font> function** is integrated in this function. Consult the "help" section of this function to use it.</div>
  
    
    
# Function <font face="verdana">iplot_pheno()</font>

The function **<font size="3" face="verdana">iplot_pheno()</font>** generates a boxplot based on phenological parameters (start_dates and end_dates) which are calculated by the estimation of the main parameters of the pollen season. The main arguments are:

* **data**: A `data.frame` object including the general database where calculation of the pollen season must be applied in order to generate the phenological plot based on the start_dates and end_dates. This data.frame must include a first column in "Date" format and the rest of columns in "numeric" format belonging to each pollen type by column.
* **method**: A `character` string specifying the method applied to calculate the pollen season and the main parameters. The implemented methods that can be used are: "percentage", "logistic", "moving", "clinical" or "grains". A more detailed information about the different methods for defining the pollen season may be consulted in calculate_ps function.
* **n.types**: A `numeric` (integer) value specifying the number of the most abundant pollen types that must be represented. A more detailed information about the selection of the considered pollen types may be consulted [here](https://CRAN.R-project.org/package=AeRobiology). The `n.types` argument will be 15 by default.
* **type.plot**: A `character` string specifying the type of plot selected to show the phenological plot. The implemented types that may be used are: "static" (generates a static ggplot object) and "dynamic" (generates a dynamic plotly object).
* Other arguments related to **<font size="3" face="verdana">calculate_ps()</font> function**

```{r echo = TRUE, results='hide',fig.keep='all'}
iplot_pheno(munich_pollen, method= "percentage", perc=80, int.method="spline", n.types = 8)
```

We can change the method to establish the main pollen season and the number of pollen types to show:

```{r echo = TRUE, results='hide',fig.keep='all'}
iplot_pheno(munich_pollen, method= "clinical", n.clinical = 3, int.method="spline", n.types = 4)
```

Furthermore, we can make the plot interactive to obtain more information by clicking in each object:

```{r echo = TRUE, results='hide',fig.keep='all', eval=FALSE}
iplot_pheno(munich_pollen, method= "clinical", n.clinical = 3, int.method="spline", n.types = 4, type.plot = "dynamic")
```
  
    
    
# Function <font face="verdana">plot_ps()</font> 

The function **<font size="3" face="verdana">plot_ps()</font> function** was designed to plot the main pollen season of a single pollen type and year. Some of the arguments are:

* **data**: A `data.frame` object including the general database where interpolation must be performed. This data.frame must include a first column in "Date" format and the rest of the columns in "numeric" format. Each column must contain information of one pollen type. It is not necessary to insert missing gaps, the function will automatically detect them.
* **pollen.type**: A `character` string specifying the name of the pollen type which will be plotted. The name must be exactly the same that appears in the column name. Mandatory argument with no default.
* **year**: A `numeric` (integer) value specifying the season to be plotted. The season does not necessary fit a natural year. See calculate_ps for more details. Mandatory argument with no default.
* **days**: A `numeric` (integer) specifying the number of days beyond each side of the main pollen season that will be represented. The `days` argument will be 30 by default.
* **fill.col**: A `character` string specifying the name of the color to fill the main pollen season in the plot. See ggplot function for more details. The `fill.col` argument will be "turquoise4" by default. It uses the ggplot color codes.
* **axisname**:A `character` string specifying the title of the y axis. By default, `axisname = expression(paste("Pollen grains / m"^"3"))`  
* Others...

<div class="alert alert-info">**<font size="3" face="verdana">calculate_ps</font> function** is integrated in this function. Consult [here](https://CRAN.R-project.org/package=AeRobiology) for more information. **Interpolation is mandatory** for this function. Due to technical encoding, you must use interpollen function through calculate_ps function. Consult calculate_ps for more information.</div>

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_ps(munich_pollen, pollen.type="Alnus", year=2011)
```

If you misspell some pollen type name, the function will tell you:

```{r echo = TRUE, results='hold', error=TRUE}
plot_ps(munich_pollen, pollen.type="Alnuscdscscr", year=2011)
```

**Let`s test more arguments:**

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, method= "percentage", perc=95 ,int.method = "lineal")
```

As you have noticed, the arguments `method`, `perc` and `int.method` are from **<font size="3" face="verdana">calculate_ps</font> function**.

What about changing the interpolation method?

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, method= "percentage", perc=95 ,int.method = "movingmean")
```

Do you want a larger scale?

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, days = 90)
```

Maybe a different color and y-axis name?

```{r echo = TRUE, results='hide',fig.keep='all'}
plot_ps(munich_pollen, pollen.type="Alnus", year=2013, fill.col = "orange", axisname = "AeRobiology custom units")
```
  
  
  
    
    
# Function <font face="verdana">plot_hour()</font> 
  
  Please keep in mind that the function *plot_hour()* is only available after package **version 2.0**.  
  
  The input data must be a data.frame object with the structure long. Where the first two columns are factors indicating the pollen and the location. The 3 and 4 columns are POSIXct, showing the date with the hour. Where the third column is the beginning of the concentration *from* and the fourth column is the end time of the concentration data *to*. The fifth column shows the concentrations of the different pollen types as numeric. Please see the example 3-hourly data from the automatic pollen monitor BAA500 from Munich and Viechtach in Bavaria (Germany) data("POMO_pollen"), supplied by ePIN Network supported by the Bavarian Government.
  
  We will load an example dataset about 3-hourly data from the ePIN network in Bavaria (Germany). The dataset contains information of 3-hourly concentrations of pollen in the atmosphere of Munich (DEBIED) and Viechtach (DEVIEC) during the year 2018. Pollen types included: "Poaceae" and "Pinus".
  
  The data were obtained by the automatic pollen monitor BAA500 from Munich and Viechtach in Bavaria (Germany) data("POMO_pollen"), supplied by the public ePIN Network supported by the Bavarian Government. The ePIN Network was built by Das Bayerische Landesamt für Gesundheit und Lebensmittelsicherheit (LGL) in collaboration with Zentrum Allergie und Umwelt (ZAUM).
  
```{r echo = FALSE, warning=FALSE, message=FALSE}
library(ggplot2)
library(dplyr)
```
  
 
  
```{r echo = TRUE}
data("POMO_pollen")
```

  The function plots pollen data expressed in concentrations with time resolution higher than 1 day (e.g. hourly, bi-hourly concentrations). If the argument *result = "plot"*, the function returns a list of objects of class **ggplot2**; if *result = "table"*, the function returns a **data.frame** with the hourly patterns.
  

```{r echo = TRUE, message=FALSE}
plot_hour(POMO_pollen)
```

  To display a table we have to set the argument *result = "table"*.
  
```{r message=FALSE}
TO<-plot_hour(POMO_pollen, result ="table")
knitr::kable(TO[1:10,], caption = "3-Hourly patterns", row.names = FALSE, digits = 1, format = "html", booktabs = TRUE)
```
  
  We can also split the different stations by setting the argument *locations = TRUE*.
  
```{r, message=FALSE, echo=TRUE}
plot_hour(POMO_pollen, locations = TRUE)
```
  
    
      
# Function <font face="verdana">plot_heathour()</font> 

An alternative to *plot_hour()* is *plot_heathour()*, which shows a summary of all particles with a heatplot. The input data should have the same format as for *plot_hour()*.

```{r, message=FALSE, echo=TRUE}
plot_heathour(POMO_pollen)
```
  
  You can also set the colors by the arguments: *low.col*, *mid.col* and *high.col*. E.g.
  
```{r, message=FALSE, echo=TRUE}
plot_heathour(POMO_pollen, low.col = "darkgreen", mid.col = "moccasin", high.col = "brown")
```

By setting *locations = TRUE* you can split the result by locations:

```{r, message=FALSE, echo=TRUE}
plot_heathour(POMO_pollen, locations = TRUE)
```
  

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_ps.R
\name{plot_ps}
\alias{plot_ps}
\title{Pollen Season Plot}
\usage{
plot_ps(
  data,
  pollen.type = NULL,
  year = NULL,
  days = 30,
  fill.col = "turquoise4",
  int.method = "lineal",
  axisname = expression(paste("Pollen grains / m"^"3")),
  ...
)
}
\arguments{
\item{data}{A \code{data.frame} object including the general database where interpollation must be performed. This \code{data.frame} must include a first column in \code{Date} format and the rest of columns in \code{numeric} format. Each column must contain information of one pollen type. It is not necessary to insert missing gaps; the function will automatically detect them.}

\item{pollen.type}{A \code{character} string specifying the name of the pollen type which will be plotted. The name must be exactly the same that appears in the column name. Mandatory argument with no default.}

\item{year}{A \code{numeric (interger)} value specifying the season to be plotted. The season does not necessary fit a natural year. See \code{\link{calculate_ps}} for more details. Mandatory argument with no default.}

\item{days}{A \code{numeric (interger)} specifying the number of days beyond each side of the main pollen season that will be represented. The \code{days} argument will be \code{30} by default.}

\item{fill.col}{A \code{character} string specifying the name of the color to fill the main pollen season (Galan et al., 2017) in the plot. See \code{\link[ggplot2]{ggplot}} function for more details. The \code{fill.col} argument will be \code{"turquoise4"} by default.}

\item{int.method}{A \code{character} string specifying the method selected to apply the interpolation method in order to complete the pollen series. The implemented methods that may be used are: \code{"lineal"},  \code{"movingmean"}, \code{"spline"} or  \code{"tseries"}. See \code{\link{interpollen}} function for more details. The \code{int.method} argument will be \code{"lineal"} by default.}

\item{axisname}{A \code{character} string or an expression specifying the y axis title of the plot. The \code{axisname} argument will be \code{expression(paste("Pollen grains / m" ^ "3"))} by default.}

\item{...}{Other arguments passed on to the pollen season calculation as specified in \code{\link{calculate_ps}} function.}
}
\value{
The function returns an object of class \code{\link[ggplot2]{ggplot}} with a graphical representation of the main pollen season of the selected pollen type. The pre_peak and post_peak periods are marked with different color intensity.
}
\description{
Function to plot the main pollen season of a single pollen type.
}
\details{
\code{plot_ps} function is designed to easily plot the main pollen season (Galan et al., 2017). The pre_peak period and the post_peak period are marked with different color intensity in the graph. The user must choose a single pollen type and season to plot.
}
\examples{
data("munich_pollen")
plot_ps(munich_pollen, year = 2013, pollen.type = "Betula")
}
\references{
Galan, C., Ariatti, A., Bonini, M., Clot, B., Crouzy, B., Dahl, A., Fernandez_Gonzalez, D., Frenguelli, G., Gehrig, R., Isard, S., Levetin, E., Li, D.W., Mandrioli, P., Rogers, C.A., Thibaudon, M., Sauliene, I., Skjoth, C., Smith, M., Sofiev, M., 2017. Recommended terminology for aerobiological studies. Aerobiologia (Bologna). 293_295.
}
\seealso{
\code{\link{calculate_ps}}, \code{\link{interpollen}}, \code{\link[ggplot2]{ggplot}}.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/quality_control.R
\name{quality_control}
\alias{quality_control}
\title{Quality Control of a Pollen Database}
\usage{
quality_control(
  data,
  int.window = 2,
  perc.miss = 20,
  ps.method = "percentage",
  result = "plot",
  th.day = 100,
  perc = 95,
  def.season = "natural",
  reduction = FALSE,
  red.level = 0.9,
  derivative = 5,
  man = 11,
  th.ma = 5,
  n.clinical = 5,
  window.clinical = 7,
  window.grains = 5,
  th.pollen = 10,
  th.sum = 100,
  type = "none",
  int.method = "lineal",
  ...
)
}
\arguments{
\item{data}{A \code{data.frame} object including the general database where quality must be checked. This data.frame must include a first column in \code{Date} format and the rest of columns in \code{numeric} format belonging to each pollen type by column. It is not necessary to insert the missing gaps; the function will automatically detect them.}

\item{int.window}{A  \code{numeric (interger)}value bigger or equal to \code{1}. The argument specifies the number of days of each side of the start, peak or end date of the main pollen season which will be checked during the quality control. If any of these days has been interpolated, the current season will not pass the quality control. The \code{int.window} argument will be \code{2} by default.}

\item{perc.miss}{A \code{numeric (interger)} value between \code{0} and \code{100}. The argument specifies the maximal percentage of interpolated days which is allowed inside the main pollen season to pass the quality control. The \code{perc.miss} argument will be \code{20} by default.}

\item{ps.method}{A \code{character} string specifying the method applied to calculate the pollen season and the main parameters. The implemented methods that can be used are: \code{"percentage"}, \code{"logistic"}, \code{"moving"}, \code{"clinical"} or \code{"grains"}. A more detailed information about the different methods for defining the pollen season may be consulted in \code{\link{calculate_ps}} function. The \code{ps.method} argument will be \code{"percentage"} by default.}

\item{result}{A \code{character} string specifying the format of the results. Only \code{"plot"} or \code{"table"} available. If \code{"plot"}, graphical resume of the quality control will be plotted. If \code{"table"}, a \code{data.frame} will be created indicating the filters passed by each pollen type and season. Consult 'Return' for more information .The \code{result} argument will be \code{"plot"} by default.}

\item{th.day}{See \code{\link{calculate_ps}} for more details.}

\item{perc}{See \code{\link{calculate_ps}} for more details.}

\item{def.season}{See \code{\link{calculate_ps}} for more details.}

\item{reduction}{See \code{\link{calculate_ps}} for more details.}

\item{red.level}{See \code{\link{calculate_ps}} for more details.}

\item{derivative}{See \code{\link{calculate_ps}} for more details.}

\item{man}{See \code{\link{calculate_ps}} for more details.}

\item{th.ma}{See \code{\link{calculate_ps}} for more details.}

\item{n.clinical}{See \code{\link{calculate_ps}} for more details.}

\item{window.clinical}{See \code{\link{calculate_ps}} for more details.}

\item{window.grains}{See \code{\link{calculate_ps}} for more details.}

\item{th.pollen}{See \code{\link{calculate_ps}} for more details.}

\item{th.sum}{See \code{\link{calculate_ps}} for more details.}

\item{type}{See \code{\link{calculate_ps}} for more details.}

\item{int.method}{See \code{\link{calculate_ps}} for more details.}

\item{...}{Other arguments passed on to the pollen season calculation as specified in \code{\link{calculate_ps}} function.}
}
\value{
This function can return different results: \cr
\itemize{
\item If \code{result = "plot"}: Graphical resume of the Quality Control results showing the seasons of each pollen type and their quality (the risk assumed if they are included in further studies). The legend indicates the number of filter that have been unsuccessfully passed for each case. Object of class \code{\link[ggplot2]{ggplot}}. For graphical customization, see \code{\link[ggplot2]{ggplot}} function.
\item If \code{result = "table"}: \code{data.frame} with \code{logical} values for each pollen type and season. If \code{TRUE}, the filter has been successfully passed for this case. If FALSE, this case does not fit the minimal requirements of this filter.
}
}
\description{
Function to check the quality of an historical database of several pollen types.
}
\details{
Quality control is a relevant topic for aerobiology (Oteros et al., 2013). This function is another approach to improve the quality control management in the field. \cr\code{quality_control} function checks the quality of the pollen data of each pollen type and season. The filters applied by the function are: \cr
\itemize{
\item If the main pollen season (Galan et al., 2017) cannot be calculated according to \code{\link{calculate_ps}} function minimal requirements (lack of data for these pollen type and year). Filter named \code{"Complete"} in the \code{"quality_control"} \code{data.frame}.
\item If the start, end or peak date of the main pollen season has been interpolated or a day near to it (number of days specified by \code{int.window} argument). If a day near to these dates is missing, the selected date could not be the right one. Filters named \code{"Start"}, \code{"Peak"} and \code{"End"} in the \code{"quality_control"} \code{data.frame}.
\item The percentage of missing data inside the main pollen season. It calculates the number of days which have been interpolated by the algorithm and their percentage inside the main pollen season. If a high percentage of the main pollen season has been interpolated, the information of these season could not be reliable. Filter named \code{"Comp.MPS"} in the \code{"quality_control"} \code{data.frame}.
}
}
\examples{
data("munich_pollen")
quality_control(munich_pollen[,c(1:4)])
}
\references{
Galan, C., Ariatti, A., Bonini, M., Clot, B., Crouzy, B., Dahl, A., Fernandez_Gonzalez, D., Frenguelli, G., Gehrig, R., Isard, S., Levetin, E., Li, D.W., Mandrioli, P., Rogers, C.A., Thibaudon, M., Sauliene, I., Skjoth, C., Smith, M., Sofiev, M., 2017. Recommended terminology for aerobiological studies. Aerobiologia (Bologna). 293_295.

Oteros, J., Galan, C., Alcazar, P., & Dominguez_Vilches, E. (2013). Quality control in bio_monitoring networks, Spanish Aerobiology Network. Science of the Total Environment, 443, 559_565.
}
\seealso{
\code{\link{calculate_ps}}, \code{\link{interpollen}}, \code{\link[ggplot2]{ggplot}}, \code{\link[ggplot2]{ggsave}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/iplot_years.R
\name{iplot_years}
\alias{iplot_years}
\title{Interactive Plotting Pollen Data (one pollen type).}
\usage{
iplot_years(data, pollen)
}
\arguments{
\item{data}{A \code{data.frame} object. This \code{data.frame} should include a first column in format \code{Date} and the rest of columns in format \code{numeric} belonging to each pollen type by column.}

\item{pollen}{A \code{character} string with the name of the particle to show. This \code{character} must match with the name of a column in the input database. This is a mandatory argument.}
}
\value{
An interactive plot of the class \pkg{ggvis}.
}
\description{
Function to plot the pollen data of a pollen type during several seasons. The plots are fully interactive.
}
\examples{
data("munich_pollen")
iplot_years(data = munich_pollen, pollen = "Betula")
}
\seealso{
\code{\link{iplot_pollen}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ma.R
\name{ma}
\alias{ma}
\title{Moving Average Calculator}
\usage{
ma(data, man = 10, warnings = FALSE)
}
\arguments{
\item{data}{A \code{numeric} vector (e.g. a \code{numeric} column of a \code{dataframe}).}

\item{man}{An \code{integer} value specifying the order of the moving average applied to the data. By default, \code{man = 10}.}

\item{warnings}{A \code{logical} value specifying the show of warning messages. By default, \code{warnings = FALSE}.}
}
\value{
This function returns a vector with the moving average of the input data.
}
\description{
Function to calculate the moving average of a given numeric vector. The order of the moving average may be customized by the user (\code{man} argument).
}
\examples{
data("munich_pollen")
ma(data = munich_pollen$Betula, man = 10, warnings = FALSE)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analyse_trend.R
\name{analyse_trend}
\alias{analyse_trend}
\title{Calculating and Plotting Trends of Pollen Data (summary plot).}
\usage{
analyse_trend(
  data,
  interpolation = TRUE,
  int.method = "lineal",
  export.plot = TRUE,
  export.format = "pdf",
  export.result = TRUE,
  method = "percentage",
  quantil = 0.75,
  significant = 0.05,
  split = TRUE,
  result = "table",
  ...
)
}
\arguments{
\item{data}{A \code{data.frame} object. This \code{data.frame} should include a first column in format \code{Date} and the rest of columns in format \code{numeric} belonging to each pollen type by column.}

\item{interpolation}{A \code{logical} value specifying if the visualization shows the gaps in the inputs data (\code{interpolation = FALSE}) or if an interpolation method is used for filling the gaps (\code{interpolation = TRUE}). By default, \code{interpolation = TRUE}.}

\item{int.method}{A \code{character} string with the name of the interpolation method to be used. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"tseries"} or \code{"spline"}. By default, \code{int.method = "lineal"}.}

\item{export.plot}{A \code{logical} value specifying if a plot will be exported or not. If \code{FALSE} graphical results will only be displayed in the active graphics window. If \code{TRUE} graphical results will be displayed in the active graphics window and also one pdf/png file will be saved within the \emph{plot_AeRobiology} directory automatically created in the working directory. By default, \code{export.plot = TRUE}.}

\item{export.format}{A \code{character} string specifying the format selected to save the plot. The implemented formats that may be used are: \code{"pdf"} or \code{"png"}. By default, \code{export.format = "pdf"}.}

\item{export.result}{A \code{logical} value. If \code{export.result = TRUE}, a table is exported with the extension \emph{.xlsx}, in the directory \emph{table_AeRobiology}. This table has the information about the \code{slope} \emph{"beta coefficient of a lineal model using as predictor the year and as dependent variable one of the main pollen season indexes"}. The information is referred to the main pollen season indexes: \emph{Start Date}, \emph{Peak Date}, \emph{End Date} and \emph{Pollen Integral}.}

\item{method}{A \code{character} string specifying the method applied to calculate the pollen season and the main seasonal parameters. The implemented methods that can be used are: \code{"percentage"}, \code{"logistic"}, \code{"moving"}, \code{"clinical"} or \code{"grains"}. By default, \code{method = "percentage"} (\code{perc = 95}\%). A more detailed information about the different methods for defining the pollen season may be consulted in the function \code{\link{calculate_ps}}.}

\item{quantil}{A \code{numeric} value (between 0 and 1) indicating the quantile of data to be displayed in the graphical output of the function. \code{quantil = 1} would show all the values, however a lower quantile will exclude the most extreme values of the sample. To split the parameters using a different sampling units (e.g. dates and pollen concentrations) can be used low vs high values of \code{quantil} argument (e.g. 0.5 vs 1). Also can be used an extra argument: \code{split}. By default, \code{quantil = 0.75}. \code{quantil} argument can only be applyed when \code{split = FALSE}.}

\item{significant}{A \code{numeric} value indicating the significant level to be considered in the linear trends analysis. This \emph{p} level is displayed in the graphical output of the function. By default, \code{significant = 0.05}.}

\item{split}{A \code{logical} argument. If \code{split = TRUE}, the plot is separated in two according to the nature of the variables (i.e. dates or pollen concentrations). By default, \code{split = TRUE}.}

\item{result}{A \code{character} object with the definition of the object to be produced by the function. If \code{result == "plot"}, the function returns a list of objects of class \pkg{ggplot2}; if \code{result == "table"}, the function returns a \pkg{data.frame}. By default, \code{result = "table"}.}

\item{...}{Additional arguments for the function \code{\link{calculate_ps}} are also accepted.}
}
\value{
If \code{result == "plot"}, the function returns a list of objects of class \pkg{ggplot2}; if \code{result == "table"}, the function returns a \pkg{data.frame} with the hourly patterns.
The plot is of the class \pkg{ggplot2} or a list of plots of the class \pkg{ggplot2} (depending on the argument \code{split}). This is a combined dot plot showing the trends (\emph{slope} and \emph{p} value) of the main seasonal features.\cr
The object of the class \code{data.frame} has the information about the \code{slope} \emph{(beta coefficient of a lineal model using as predictor the year and as dependent variable one of the main pollen season indexes)}. The information is referred to the main pollen season indexes: \emph{Start Date}, \emph{Peak Date}, \emph{End Date} and \emph{Pollen Integral}.
}
\description{
Function to calculate the main seasonal indexes of the pollen season (\emph{Start Date}, \emph{Peak Date}, \emph{End Date} and \emph{Pollen Integral}). Trends analysis of the parameters over the seasons. Summary dot plot showing the distribution of the main seasonal indexes over the years.
}
\details{
This function allows to study time series trends of the pollen season. Even though the package was originally designed to treat aeropalynological data, it can be used to study many other atmospheric components (e.g., bacteria in the air, fungi, insects ...) \emph{(Buters et al., 2018; Oteros et al., 2019)}. The study of trends in pollen time series is a common approach to study the impact of climate change or other environmental factors on vegetation (Galan et al., 2016; Garcia_Mozo et al., 2016;  Recio et al., 2018). This tool can also be useful for studying trends in other fields (Oteros et al., 2015).
}
\examples{
data("munich_pollen")
analyse_trend(munich_pollen, interpolation = FALSE, export.result = FALSE, export.plot = FALSE)
}
\references{
Buters, J. T. M., Antunes, C., Galveias, A., Bergmann, K. C., Thibaudon, M., Galan, C., ... & Oteros, J. (2018). Pollen and spore monitoring in the world. \emph{Clinical and translational allergy}, 8(1), 9.

Galan, C., Alcazar, P., Oteros, J., Garcia_Mozo, H., Aira, M. J., Belmonte, J., ... & Perez_Badia, R. (2016). Airborne pollen trends in the Iberian Peninsula. \emph{Science of the Total Environment}, 550, 53_59.

Garcia_Mozo, H., Oteros, J. A., & Galan, C. (2016). Impact of land cover changes and climate on the main airborne pollen types in Southern Spain. \emph{Science of the Total Environment}, 548, 221_228.

Oteros, J., Garcia_Mozo, H., Botey, R., Mestre, A., & Galan, C. (2015). Variations in cereal crop phenology in Spain over the last twenty_six years (1986_2012). \emph{Climatic Change}, 130(4), 545_558.

Oteros, J., Bartusel, E., Alessandrini, F., Nunez, A., Moreno, D. A., Behrendt, H., ... & Buters, J. (2019). Artemisia pollen is the main vector for airborne endotoxin. \emph{Journal of Allergy and Clinical Immunology}.

Recio, M., Picornell, A., Trigo, M. M., Gharbi, D., Garcia_Sanchez, J., & Cabezudo, B. (2018). Intensity and temporality of airborne Quercus pollen in the southwest Mediterranean area: Correlation with meteorological and phenoclimatic variables, trends and possible adaptation to climate change. \emph{Agricultural and Forest Meteorology}, 250, 308_318.
}
\seealso{
\code{\link{calculate_ps}}; \code{\link{plot_trend}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/munich_pollen.R
\docType{data}
\name{munich_pollen}
\alias{munich_pollen}
\title{Pollen data of Munich (2010_2015)}
\format{
Time series of daily pollen concentrations expressed as pollen grains / m3 of air.
}
\source{
Zentrum Allergie und Umwelt (ZAUM).
}
\usage{
munich_pollen
}
\description{
A dataset containing information of daily concentrations of pollen in the atmosphere of Munich during the years 2010_2015. Pollen types included: \emph{"Alnus"}, \emph{"Betula"}, \emph{"Taxus"}, \emph{"Fraxinus"}, \emph{"Poaceae"}, \emph{"Quercus"}, \emph{"Ulmus"} and \emph{"Urtica"}.
}
\details{
Data were obtained at Munich (Zentrum Allergie und Umwelt, ZAUM) using a Hirst_type volumetric pollen trap (Hirst, 1952) following the standard methodology (VDI4252_4_2016). Some gaps have been added to test some functions of the package (e.g. \code{\link{quality_control}}, \code{\link{interpollen}}).

The data were obtained by the research team of Prof. Jeroen Buters (Christine Weil & Ingrid Weichenmeier). We specially acknowledge this team and the Zentrum Allergie und Umwelt (ZAUM, directed by Prof. Carsten B. Schmidt_Weber) for their support.
}
\references{
Hirst, J.M., 1952. AN AUTOMATIC VOLUMETRIC SPORE TRAP. Ann. Appl. Biol. 39, 257_265.

VDI 4252_4. (2016). Bioaerosole und biologische Agenzien_Ermittlung von Pollen und Sporen in der Aussenluft unterVerwendung  einer volumetrischen  Methode  fuer  einMessnetz zu allergologischen Zwecken. VDI_Richtlinie4252 Blatt 4, Entwurf. VDI/DIN_Handbuch Reinhaltungder Luft, Band 1a: Beuth, Berlin
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_summary.R
\name{plot_summary}
\alias{plot_summary}
\title{Plotting Several Pollen Seasons.}
\usage{
plot_summary(
  data,
  pollen,
  mave = 1,
  normalized = FALSE,
  interpolation = TRUE,
  int.method = "lineal",
  export.plot = FALSE,
  export.format = "pdf",
  axisname = "Pollen grains / m3",
  ...
)
}
\arguments{
\item{data}{A \code{data.frame} object. This \code{data.frame} should include a first column in format \code{Date} and the rest of columns in format \code{numeric} belonging to each pollen type by column.}

\item{pollen}{A \code{character} string with the name of the particle to show. This \code{character} must match with the name of a column in the input database. This is a mandatory argument.}

\item{mave}{An \code{integer} value specifying the order of the moving average applied to the data. By default, \code{mave = 1}.}

\item{normalized}{A \code{logical} value specifying if the visualization shows real pollen data (\code{normalized = FALSE}) or the percentage of every day over the whole pollen season (\code{normalized = TRUE}). By default, \code{normalized = FALSE}.}

\item{interpolation}{A \code{logical} value specifying if the visualization shows the gaps in the inputs data (\code{interpolation = FALSE}) or if an interpolation method is used for filling the gaps (\code{interpolation = TRUE}). By default, \code{interpolation = TRUE}.}

\item{int.method}{A \code{character} string with the name of the interpolation method to be used. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"tseries"} or \code{"spline"}. By default, \code{int.method = "lineal"}.}

\item{export.plot}{A \code{logical} value specifying if a plot will be exported or not. If \code{FALSE} graphical results will only be displayed in the active graphics window. If \code{TRUE} graphical results will be displayed in the active graphics window and also one pdf/png file will be saved within the \emph{plot_AeRobiology} directory automatically created in the working directory. By default, \code{export.plot = FALSE}.}

\item{export.format}{A \code{character} string specifying the format selected to save the plot. The implemented formats that may be used are: \code{"pdf"} or \code{"png"}. By default, \code{export.format = "pdf"}.}

\item{axisname}{A \code{character} string specifying the title of the y axis. By default, \code{axisname =  "Pollen grains / m3"}.}

\item{...}{Other additional arguments may be used to customize the exportation of the plots using \code{"pdf"} or \code{"png"} files and therefore arguments from functions \code{\link[grDevices]{pdf}} and \code{\link[grDevices]{png}} may be implemented. For example, for pdf files the user may custom the arguments: width, height, family, title, fonts, paper, bg, fg, pointsize...; and for png files the user may custom the arguments: width, height, units, pointsize, bg, res...}
}
\value{
This function returns plot of class \pkg{ggplot2}. User are able to customize the output as a \pkg{ggplot2} object.
}
\description{
Function to plot the pollen data during several seasons. Also plots the averaged pollen season over the study period. It is possible to plot the relative abundance per day and smoothing the pollen season by calculating a moving average.
}
\details{
This function allows to summarize the pollen season by a simple plot. Even though the package was originally designed to treat aeropalynological data, it can be used to study many other atmospheric components (e.g., bacteria in the air, fungi, insects ...) \emph{(Buters et al., 2018; Oteros et al., 2019)}.
}
\examples{
 data("munich_pollen")
 plot_summary(munich_pollen, pollen = "Betula", export.plot = FALSE, interpolation = FALSE)
}
\references{
Buters, J. T. M., Antunes, C., Galveias, A., Bergmann, K. C., Thibaudon, M., Galan, C. & Oteros, J. (2018). Pollen and spore monitoring in the world. \emph{Clinical and translational allergy}, 8(1), 9.

Oteros, J., Bartusel, E., Alessandrini, F., Nunez, A., Moreno, D. A., Behrendt, H., ... & Buters, J. (2019). Artemisia pollen is the main vector for airborne endotoxin. \emph{Journal of Allergy and Clinical Immunology}.
}
\seealso{
\code{\link{calculate_ps}}; \code{\link{plot_normsummary}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_hour.R
\name{plot_hour}
\alias{plot_hour}
\title{Plotting hourly patterns}
\usage{
plot_hour(data, result = "plot", locations = FALSE)
}
\arguments{
\item{data}{A \code{data.frame} object with the structure \code{long}. Where the first two columns are \code{factors} indicating the \code{pollen} and the \code{location}. The 3 and 4 columns are \code{POSIXct}, showing the hour. Where the third column is the beguinning of the concentration \code{from} and the fourth column is the end time of the concentrtion data \code{to}. The fifth column shows the concentrations of the different pollen types as \code{numeric}. Please see the example 3-hourly data from the automatic pollen monitor BAA500 from Munich and Viechtach in Bavaria (Germany) \code{data("POMO_pollen")}, supplied by ePIN Network supported by the Bavarian Government.}

\item{result}{A \code{character} object with the definition of the object to be produced by the function. If \code{result == "plot"}, the function returns a list of objects of class \pkg{ggplot2}; if \code{result == "table"}, the function returns a \pkg{data.frame} with the hourly patterns. By default, \code{result = "plot"}.}

\item{locations}{A \code{logical} object with the specification if the different locations will be displayed in the plot. Argument only used when \code{result == "plot"}. By default, \code{locations = FALSE}.}
}
\value{
If \code{result == "plot"}, the function returns a list of objects of class \pkg{ggplot2}; if \code{result == "table"}, the function returns a \pkg{data.frame} with the hourly patterns.
}
\description{
Function to plot pollen data expressed in concentrations with time resolution higher than 1 day (e.g. hourly, bi-hourly concentrations).
}
\examples{
data("POMO_pollen")
plot_hour(POMO_pollen, result="plot", locations = FALSE)
plot_hour(POMO_pollen, result="plot", locations = TRUE)
}
\references{
Oteros, J., Pusch, G., Weichenmeier, I., Heimann, U., Mueller, R., Roeseler, S., ... & Buters, J. T. (2015). Automatic and online pollen monitoring. \emph{International archives of allergy and immunology}, 167(3), 158-166.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AeRobiology.R
\docType{package}
\name{AeRobiology}
\alias{AeRobiology-package}
\alias{AeRobiology}
\title{\code{AeRobiology} package}
\description{
AeRobiology computational tool
}
\author{
\strong{Maintainer}: Jose Oteros \email{OterosJose@gmail.com}

Authors:
\itemize{
  \item Jesus Rojo \email{Jesus.Rojo@uclm.es}
  \item Antonio Picornell \email{picornell@uma.es}
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/iplot_pollen.R
\name{iplot_pollen}
\alias{iplot_pollen}
\title{Interactive Plotting Pollen Data (one season).}
\usage{
iplot_pollen(data, year)
}
\arguments{
\item{data}{A \code{data.frame} object. This \code{data.frame} should include a first column in format \code{Date} and the rest of columns in format \code{numeric} belonging to each pollen type by column.}

\item{year}{An \code{integer} value specifying the year to display. This is a mandatory argument.}
}
\value{
An interactive plot of the class \pkg{ggvis}.
}
\description{
Function to plot the pollen data during one season. The plots are fully interactive.
}
\examples{
data("munich_pollen")
iplot_pollen(data = munich_pollen, year = 2012)
}
\seealso{
\code{\link{iplot_years}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/interpollen.R
\name{interpollen}
\alias{interpollen}
\title{Interpolation of Missing Data in a Pollen Database by Different Methods}
\usage{
interpollen(
  data,
  method = "lineal",
  maxdays = 30,
  plot = TRUE,
  factor = 2,
  ndays = 3,
  spar = 0.5,
  data2 = NULL,
  data3 = NULL,
  data4 = NULL,
  data5 = NULL,
  mincorr = 0.6,
  result = "wide"
)
}
\arguments{
\item{data}{A \code{data.frame} object including the general database where interpollation must be performed. This \code{data.frame} must include a first column in \code{Date} format and the rest of columns in \code{numeric} format. Each column must contain information of one pollen type. It is not necessary to insert missing gaps; the function will automatically detect them.}

\item{method}{A \code{character} string specifying the method applied to calculate and generate the pollen missing data. The implemented methods that can be used are: \code{"lineal"}, \code{"movingmean"}, \code{"spline"}, \code{"tseries"} or \code{"neighbour"}. A more detailed information about the different methods may be consulted in Details. The \code{method} argument will be \code{"lineal"} by default.}

\item{maxdays}{A \code{numeric (interger)} value specifying the maximum number of consecutive days with missing data that the algorithm is going to interpolate. If the gap is bigger than the argument value, the gap will not be interpolated. Not valid with \code{"tseries"} method. The \code{maxdays} argument will be \code{30} by default.}

\item{plot}{A \code{logical} argument. If \code{TRUE}, graphical previews of the input database will be plot at the end of the interpolation process. All the interpolated gaps will be marked in red. The \code{plot} argument will be \code{TRUE} by default.}

\item{factor}{A \code{numeric (interger)} value bigger than \code{1}. Only valid if the \code{"movingmean"} method is chosen. The argument specifies the factor which will multiply the gap size to stablish the range of the moving mean that will fulfill the gap. A more detailed information about the selection of the factor may be consulted in Details. The argument \code{factor} will be \code{1} by default.}

\item{ndays}{A \code{numeric (interger)} value bigger than \code{1}. Only valid if the \code{"spline"} method is chosen. Specifies the number of days beyond each side of the gap which are used to perform the spline regression. The argument \code{ndays} will be \code{3} by default.}

\item{spar}{A \code{numeric (double)} value ranging \code{0_1} specifying the degree of smoothness of the spline regression adjustment. As smooth as the adjustment is, more data are considered as outliers for the spline regression. Only valid if the \code{"spline"} method is chosen. The argument \code{"spar"} will be \code{0.5} by default.}

\item{data2, data3, data4, data5}{A \code{data.frame} object (each one) including database of a neighbour pollen station which will be used to interpolate missing data in the target station. Only valid if the "neighbour" method is chosen. This \code{data.frame} must include a first column in \code{Date} format and the rest of columns in \code{numeric} format belonging to each pollen type by column. It is not necessary to insert the missing gaps; the function will automatically detect them. The arguments will be \code{NULL} by default.}

\item{mincorr}{A \code{numeric (double)} value ranging \code{0_1}. It specifies the minimal correlation coefficient (Spearman correlations) that neighbour stations must have with the target station to be taken into account for the interpolation. Only valid if the \code{"neighbour"} method is chosen. The argument \code{"mincorr"} will be \code{0.6} by default.}

\item{result}{A \code{character} string specifying the format of the resulting \code{data.frame}. Only \code{"wide"} or \code{"long"}. The \code{result} argument will be \code{"wide"} by default.}
}
\value{
This function returns different results:
\itemize{
\item If \code{result = "wide"}, returns a \code{data.frame} including the original data and completed with the interpolated data.
\item If \code{result = "long"}, returns a \code{data.frame} containing your data in long format (the first column for date, the second for pollen type, the third for concentration and an additional fourth column with \code{1} if this data has been interpolated or \code{0} if not).
\item If \code{plot = TRUE}, plots for each year and pollen type with daily values are represented in the active graphic window. Interpolated values are marked in red. If \code{method} argument is \code{"tseries"}, the seasonality is also represented in grey.
}
}
\description{
Function to simultaneously replace all missing data of an historical database of several pollen types by using different methods of interpolation.
}
\details{
This function allows to interpolate missing data in a pollen database using 4 different methods which are described below. Interpolation for each pollen type will be automatically done for gaps smaller than the \code{"maxdays"} argument. \cr
\itemize{
\item \code{"lineal"} method. The interpolation will be carried out by tracing a straight line between the gap extremes.
\item \code{"movingmean"} method. It calculates the moving mean of the pollen daily concentrations with a window size of the gap size multiplicated by the \code{factor} argument and replace the missing data with the moving mean for these days. It is a dynamic function and for each gap of the database, the window size of the moving mean changes depending of each gap size.
\item \code{"spline"} method. The interpolation will be carried out by performing a spline regression with the previous and following days to the gap. The number of days of each side of the gap that will be taken into account for calculating the spline regression are specified by \code{ndays} argument. The smoothness of the adjustment of the spline regression can be specified by the \code{spar} argument.
\item \code{"tseries"} method. The interpolation will be carried out by analysing the time series of pollen database. It performs a seasonal_trend decomposition based on LOESS (Cleveland et al., 1990). The seasonality of the historical database is extracted and used to predict the missing data by performing a linear regression with the target year.
\item \code{"neighbour"} method. Other near stations provided by the user are used to interpolate the missing data of the target station. First of all, a Spearman correlation is performed between the target station and the neighbour stations to discard the neighbour stations with a correlation coefficient smaller than \code{mincorr} value. For each gap, a linear regression is performed between the neighbour stations and the target stations to determine the equation which converts the pollen concentrations of the neighbour stations into the pollen concentration of the target station. Only neighbour stations without any missing data during the gap period are taken into account for each gap.
}
}
\examples{
data("munich_pollen")
interpollen(munich_pollen, method = "lineal", plot = FALSE)
}
\references{
Cleveland RB, Cleveland WS, McRae JE, Terpenning I (1990) STL: a seasonal_trend decomposition procedure based on loess. J Off Stat 6(1):3_33.
}
\seealso{
\code{\link{ma}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/POMO_pollen.R
\docType{data}
\name{POMO_pollen}
\alias{POMO_pollen}
\title{3-hourly pollen data of Munich and Viechtach (2018), obtained automatically by BAA500}
\format{
Time series of 3-hours pollen concentrations expressed as pollen grains / m3 of air.
}
\source{
Bavarian State Office for Health and Food Safety (LGL) and Zentrum Allergie
und Umwelt (ZAUM).
}
\usage{
POMO_pollen
}
\description{
A dataset containing information of 3-hourly concentrations of pollen in the atmosphere of Munich (DEBIED) and Viechtach (DEVIEC) during the year 2018. Pollen types included: \emph{"Poaceae"} and \emph{"Pinus"}.
}
\details{
Data were obtained by the automatic pollen monitor BAA500 from Munich and Viechtach in Bavaria (Germany) \code{data("POMO_pollen")}, supplied by the public ePIN Network supported by the Bavarian Government. The ePIN Network was built by Das Bayerische Landesamt für Gesundheit und Lebensmittelsicherheit (LGL) in collaboration with Zentrum Allergie und Umwelt (ZAUM).
}
\references{
Oteros, J., et al., ... & Buters, J. T. (2019). Building an automatic Pollen Monitoring Network (ePIN): Selection of optimal sites by clustering pollen stations.

Oteros, J., Pusch, G., Weichenmeier, I., Heimann, U., Mueller, R., Roeseler, S., ... & Buters, J. T. (2015). Automatic and online pollen monitoring.

Hirst, J.M., 1952. AN AUTOMATIC VOLUMETRIC SPORE TRAP. Ann. Appl. Biol. 39, 257_265.

VDI 4252_4. (2016). Bioaerosole und biologische Agenzien_Ermittlung von Pollen und Sporen in der Aussenluft unterVerwendung  einer volumetrischen  Methode  fuer  einMessnetz zu allergologischen Zwecken. VDI_Richtlinie4252 Blatt 4, Entwurf. VDI/DIN_Handbuch Reinhaltungder Luft, Band 1a: Beuth, Berlin
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_normsummary.R
\name{plot_normsummary}
\alias{plot_normsummary}
\title{Plotting the Amplitude of Several Pollen Seasons.}
\usage{
plot_normsummary(
  data,
  pollen,
  mave = 1,
  normalized = FALSE,
  interpolation = TRUE,
  int.method = "lineal",
  export.plot = FALSE,
  export.format = "pdf",
  color.plot = "orange2",
  axisname = "Pollen grains / m3",
  ...
)
}
\arguments{
\item{data}{A \code{data.frame} object. This \code{data.frame} should include a first column in format \code{Date} and the rest of columns in format \code{numeric} belonging to each pollen type by column.}

\item{pollen}{A \code{character} string with the name of the particle to show. This \code{character} must match with the name of a column in the input database. This is a mandatory argument.}

\item{mave}{An \code{integer} value specifying the order of the moving average applied to the data. By default, \code{mave = 1}.}

\item{normalized}{A \code{logical} value specifying if the visualization shows real pollen data (\code{normalized = FALSE}) or the percentage of every day over the whole pollen season (\code{normalized = TRUE}). By default, \code{normalized = FALSE}.}

\item{interpolation}{A \code{logical} value specifying if the visualization shows the gaps in the inputs data (\code{interpolation = FALSE}) or if an interpolation method is used for filling the gaps (\code{interpolation = TRUE}). By default, \code{interpolation = TRUE}.}

\item{int.method}{A \code{character} string with the name of the interpolation method to be used. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"tseries"} or \code{"spline"}. By default, \code{int.method = "lineal"}.}

\item{export.plot}{A \code{logical} value specifying if a plot will be exported or not. If \code{FALSE} graphical results will only be displayed in the active graphics window. If \code{TRUE} graphical results will be displayed in the active graphics window and also one pdf/png file will be saved within the \emph{plot_AeRobiology} directory automatically created in the working directory. By default, \code{export.plot = FALSE}.}

\item{export.format}{A \code{character} string specifying the format selected to save the plot. The implemented formats that may be used are: \code{"pdf"} or \code{"png"}. By default, \code{export.format = "pdf"}.}

\item{color.plot}{A \code{character} string. The argument defines the color to fill the plot. Will be \code{"orange2"} by default.}

\item{axisname}{A \code{character} string specifying the title of the y axis. By default, \code{axisname =  "Pollen grains / m3"}.}

\item{...}{Other additional arguments may be used to customize the exportation of the plots using \code{"pdf"} or \code{"png"} files and therefore arguments from functions \code{\link[grDevices]{pdf}} and  \code{\link[grDevices]{png}} may be implemented. For example, for pdf files the user may custom the arguments: width, height, family, title, fonts, paper, bg, fg, pointsize...; and for png files the user may custom the arguments: width, height, units, pointsize, bg, res...}
}
\value{
This function returns plot of class \pkg{ggplot2}. User are able to customize the output as a \pkg{ggplot2} object.
}
\description{
Function to plot the pollen data amplitude during several seasons: daily average pollen concentration over the study period, maximum pollen concentration of each day over the study period and minimum pollen concentration of each day value over the study period. It is possible to plot the relative abundance per day and smoothing the pollen season by calculating a moving average.
}
\examples{
data("munich_pollen")
plot_normsummary(munich_pollen, pollen = "Betula", interpolation = FALSE, export.plot = FALSE)
}
\seealso{
\code{\link{calculate_ps}}; \code{\link{plot_summary}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculate_ps.R
\name{calculate_ps}
\alias{calculate_ps}
\title{Estimation of the Main Parameters of the Pollen Season}
\usage{
calculate_ps(
  data,
  method = "percentage",
  th.day = 100,
  perc = 95,
  def.season = "natural",
  reduction = FALSE,
  red.level = 0.9,
  derivative = 5,
  man = 11,
  th.ma = 5,
  n.clinical = 5,
  window.clinical = 7,
  window.grains = 5,
  th.pollen = 10,
  th.sum = 100,
  type = "none",
  interpolation = TRUE,
  int.method = "lineal",
  maxdays = 30,
  result = "table",
  plot = TRUE,
  export.plot = FALSE,
  export.result = FALSE
)
}
\arguments{
\item{data}{A \code{data.frame} object including the general database where calculation of the pollen season must be applied. This \code{data.frame} must include a first column in \code{Date} format and the rest of columns in \code{numeric} format belonging to each pollen type by column.}

\item{method}{A \code{character} string specifying the method applied to calculate the pollen season and the main parameters. The implemented methods that can be used are: \code{"percentage"}, \code{"logistic"}, \code{"moving"}, \code{"clinical"} or \code{"grains"}. A more detailed information about the different methods for defining the pollen season may be consulted in \strong{Details}.}

\item{th.day}{A \code{numeric} value. The number of days whose pollen concentration is bigger than this threshold is calculated for each year and pollen type. This value will be obtained in the results of the function. The \code{th.day} argument will be \code{100} by default.}

\item{perc}{A \code{numeric} value ranging \code{0_100}. This argument is valid only for \code{method = "percentage"}. This value represents the percentage of the total annual pollen included in the pollen season, removing \code{(100_perc)/2\%} of the total pollen before and after of the pollen season. The \code{perc} argument will be \code{95} by default.}

\item{def.season}{A \code{character} string specifying the method for selecting the best annual period to calculate the pollen season. The pollen seasons may occur within the natural year between two years. The implemented options that can be used are: \code{"natural"}, \code{"interannual"} or \code{"peak"}. The \code{def.season} argument will be \code{"natural"} by default. A more detailed information about the different methods for selecting the best annual period to calculate the pollen season may be consulted in \strong{Details}.}

\item{reduction}{A \code{logical} value. This argument is valid only for the \code{"logistic"} method. If \code{FALSE} the reduction of the pollen data is not applicable. If \code{TRUE} a reduction of the peaks above a certain level (\code{red.level} argument) will be carried out before the definition of the pollen season. The \code{reduction} argument will be \code{FALSE} by default. A more detailed information about the reduction process may be consulted in \strong{Details}.}

\item{red.level}{A \code{numeric} value ranging \code{0_1} specifying the percentile used as level to reduce the peaks of the pollen series before the definition of the pollen season. This argument is valid only for the \code{"logistic"} method. The \code{red.level} argument will be \code{0.90} by default, specifying the percentile 90.}

\item{derivative}{A \code{numeric} (\code{integer}) value belonging to options of \code{4}, \code{5} or \code{6} specifying the derivative that will be applied to calculate the asymptotes which determines the pollen season using the \code{"logistic"} method. This argument is valid only for the \code{"logistic"} method. The \code{derivative} argument will be \code{5} by default. More information may be consulted in \strong{Details}.}

\item{man}{A \code{numeric} (\code{integer}) value specifying the order of the moving average applied to calculate the pollen season using the \code{"moving"} method. This argument is valid only for the \code{"moving"} method. The \code{man} argument will be \code{11} by default.}

\item{th.ma}{A \code{numeric} value specifying the threshold used for the \code{"moving"} method for defining the beginning and the end of the pollen season. This argument is valid only for the \code{"moving"} method. The \code{th.ma} argument will be \code{5} by default.}

\item{n.clinical}{A \code{numeric} (\code{integer}) value specifying the number of days which must exceed a given threshold (\code{th.pollen} argument) for defining the beginning and the end of the pollen season. This argument is valid only for the \code{"clinical"} method. The \code{n.clinical} argument will be \code{5} by default.}

\item{window.clinical}{A \code{numeric} (\code{integer}) value specifying the time window during which the conditions must be evaluated for defining the beginning and the end of the pollen season using the \code{"clinical"} method. This argument is valid only for the \code{"clinical"} method. The \code{window.clinical} argument will be \code{7} by default.}

\item{window.grains}{A \code{numeric} (\code{integer}) value specifying the time window during which the conditions must be evaluated for defining the beginning and the end of the pollen season using the \code{"grains"} method. This argument is valid only for the \code{"grains"} method. The \code{window.grains} argument will be \code{5} by default.}

\item{th.pollen}{A \code{numeric} value specifying the threshold that must be exceeded during a given number of days (\code{n.clinical} or \code{window.grains} arguments) for defining the beginning and the end of the pollen season using the \code{"clinical"} or \code{"grains"} methods. This argument is valid only for the \code{"clinical"} or \code{"grains"} methods. The \code{th.pollen} argument will be \code{10} by default.}

\item{th.sum}{A \code{numeric} value specifying the pollen threshold that must be exceeded by the sum of daily pollen during a given number of days (\code{n.clinical} argument) exceeding a given daily threshold (\code{th.pollen} argument) for defining the beginning and the end of the pollen season using the \code{"clinical"} method. This argument is valid only for the \code{"clinical"} method. The \code{th.sum} argument will be \code{100} by default.}

\item{type}{A \code{character} string specifying the parameters considered according to a specific pollen type for calculating the pollen season using the \code{"clinical"} method. The implemented pollen types that may be used are: \code{"birch"}, \code{"grasses"}, \code{"cypress"}, \code{"olive"} or \code{"ragweed"}. As result for selecting any of these pollen types the parameters \code{n.clinical}, \code{window.clinical}, \code{th.pollen} and \code{th.sum} will be automatically adjusted for the \code{"clinical"} method. If no pollen types are specified (\code{type = "none"}), these parameters will be considered by the user. This argument is valid only for the \code{"clinical"} method. The \code{type} argument will be \code{"none"} by default.}

\item{interpolation}{A \code{logical} value. If \code{FALSE} the interpolation of the pollen data is not applicable. If \code{TRUE} an interpolation of the pollen series will be applied to complete the gaps with no data before the calculation of the pollen season. The \code{interpolation} argument will be \code{TRUE} by default. A more detailed information about the interpolation method may be consulted in \strong{Details}.}

\item{int.method}{A \code{character} string specifying the method selected to apply the interpolation method in order to complete the pollen series. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"spline"} or \code{"tseries"}. The \code{int.method} argument will be \code{"lineal"} by default.}

\item{maxdays}{A \code{numeric} (\code{integer} value) specifying the maximum number of consecutive days with missing data that the algorithm is going to interpolate. If the gap is bigger than the argument value, the gap will not be interpolated. Not valid with \code{int.method = "tseries"}. The \code{maxdays} argument will be \code{30} by default.}

\item{result}{A \code{character} string specifying the output for the function. The implemented outputs that may be obtained are: \code{"table"} and \code{"list"}. The argument \code{result} will be \code{"table"} by default.}

\item{plot}{A \code{logical} value specifying if a set of plots based on the definition of the pollen season will be shown in the plot history or not. If \code{FALSE} graphical results will not be shown. If \code{TRUE} a set of plots will be shown in the plot history. The \code{plot} argument will be \code{TRUE} by default.}

\item{export.plot}{A \code{logical} value specifying if a set of plots based on the definition of the pollen season will be saved in the workspace. If \code{TRUE} a \emph{pdf} file for each pollen type showing graphically the definition of the pollen season for each studied year will be saved within the \emph{plot_AeRobiology} directory created in the working directory. The \code{plot} argument will be \code{FALSE} by default.}

\item{export.result}{A \code{logical} value specifying if a excel file including all parameters for the definition of the pollen season saved in the working directoty will be required or not. If \code{FALSE} the results will not exported. If \code{TRUE} the results will be exported as \emph{xlsx} file including all parameters calculated from the definition of the pollen season within the \emph{table_AeRobiology} directory created in the working directory. The \code{export.result} argument will be \code{FALSE} by default.}
}
\value{
This function returns different results:\cr
\code{data.frame} when \code{result = "table"} including the main parameters of the pollen season with regard to phenology and pollen intensity as:
\itemize{
   \item \strong{type}: pollen type
   \item \strong{seasons}: year of the beginning of the season
   \item \strong{st.dt}: start_date (date)
   \item \strong{st.jd}: start_date (day of the year)
   \item \strong{en.dt}: end_date (date)
   \item \strong{en.jd}: end_date (day of the year)
   \item \strong{ln.ps}: length of the season
   \item \strong{sm.tt}: total sum
   \item \strong{sm.ps}: pollen integral
   \item \strong{pk.val}: peak value
   \item \strong{pk.dt}: peak_date (date)
   \item \strong{pk.jd}: peak_date (day of year)
   \item \strong{ln.prpk}: length of the pre_peak period
   \item \strong{sm.prpk}: pollen integral of the pre_peak period
   \item \strong{ln.pspk}: length of the post_peak period
   \item \strong{sm.pspk}: pollen integral of the post_peak period
   \item \strong{daysth}: number of days with more than 100 pollen grains
   \item \strong{st.dt.hs}: start_date of the High pollen season (date, only for clinical method)
   \item \strong{st.jd.hs}: start_date of the High pollen season (day of the year, only for clinical method)
   \item \strong{en.dt.hs}: end_date of the High pollen season (date, only for clinical method)
   \item \strong{en.jd.hs}: end_date of the High pollen season (day of the year, only for clinical method)
}
\code{list} when \code{result = "list"} including the main parameters of the pollen season, one pollen type by element
\code{plots} when \code{plot = TRUE} showing graphically the definition of the pollen season for each studied year in the plot history.
If \code{export.result = TRUE} this \code{data.frame} will also be exported as \emph{xlsx} file within the \emph{table_AeRobiology} directory created in the working directory. If \code{export.result = FALSE} the results will also be showed as list object named \code{list.ps}. \cr
If \code{export.plot = TRUE} a \emph{pdf} file for each pollen type showing graphically the definition of the pollen season for each studied year will be saved within the \emph{plot_AeRobiology} directory created in the working directory.
}
\description{
Function to calculate the main parameters of the pollen season with regard to phenology and pollen intensity from a historical database of several pollen types. The function can use the most common methods in the definition of the pollen season.
}
\details{
This function allows to calculate the pollen season using five different methods which are described below. After calculating the start_date, end_date and peak_date for the pollen season all rest of parameters have been calculated as detailed in \strong{Value} section.
\itemize{
  \item \code{"percentage"} method. This is a commonly used method for defining the pollen season based on the elimination of a certain percentage in the beginning and the end of the pollen season \emph{(Nilsson and Persson, 1981; Andersen, 1991)}. For example if the pollen season is based on the 95\% of the total annual pollen (\code{"perc" = 95}), the start_date of the pollen season is marked as the day in which 2.5\% of the total pollen is registered and the end_date of the pollen season is marked as the day in which 97.5\% of the total pollen is registered.
  \item \code{"logistic"} method. This method was developed by \emph{Ribeiro et al. (2007)} and modified by \emph{Cunha et al. (2015)}. It is based on fitting annually a non_linear logistic regression model to the daily accumulated curve for each pollen type. This logistic function and the different derivatives were considered to calculate the start_date and end_date of the pollen season, based on the asymptotes when pollen amounts are stabilized on the beginning and the end of the accumulated curve. For more information about the method to see \emph{Ribeiro et al. (2007)} and \emph{Cunha et al. (2015)}. Three different derivatives may be used (\code{derivative} argument) \code{4}, \code{5} or \code{6} that represent from higher to lower restrictive criterion for defining the pollen season. This method may be complemented with an optional method for reduction the peaks values (\code{reduction = TRUE}), thus avoiding the effect of the great influence of extreme peaks. In this sense, peaks values will be cut below a certain level that the user may select based on a percentile analysis of peaks. For example, \code{red.level = 0.90} will cut all peaks above the percentile \code{90}.
  \item \code{"moving"} method. This method is proposed the first time by the authors of this package. The definition of the pollen season is based on the application of a moving average to the pollen series in order to obtain the general seasonality of the pollen curve avoiding the great variability of the daily fluctuations. Thus, the start_date and the end_date will be established when the curve of the moving average reaches a given pollen threshold (\code{th.ma} argument). Also the order of the moving average may be customized by the user (\code{man} argument). By default, \code{man} = 11 and \code{th.ma} = 5.
  \item \code{"clinical"} method. This method was proposed by \emph{Pfaar et al. (2017)}. It is based on the expert consensus in relation to pollen exposure and the relationship with allergic symptoms derived of the literature. Different periods may be defined by this method: the pollen season, the high pollen season and the high pollen days. The start_date and end_date of the pollen season were defined as a certain number of days (\code{n.clinical} argument) within a time window period (\code{window.clinical} argument) exceeding a certain pollen threshold (\code{th.pollen} argument) which summation is above a certain pollen sum (\code{th.sum} argument). All these parameters are established for each pollen type according to \emph{Pfaar et al. (2017)} and using the \code{type} argument these parameters may be automatically adjusted for the specific pollen types (\code{"birch"}, \code{"grasses"}, \code{"cypress"}, \code{"olive"} or \code{"ragweed"}). Furthermore, the user may change all parameters to do a customized definition of the pollen season. The start_date and end_date of the high pollen season were defined as three consecutive days exceeding a certain pollen threshold (\code{th.day} argument). The number of high pollen days will also be calculated exceeding this pollen threshold (\code{th.day}). For more information about the method to see \emph{Pfaar et al. (2017)}.
\item \code{"grains"} method. This method was proposed by \emph{Galan et al. (2001)} originally in olive pollen but after also applied in other pollen types. The start_date and end_date of the pollen season were defined as a certain number of days (\code{window.grains} argument) exceeding a certain pollen threshold (\code{th.pollen} argument). For more information about the method to see \emph{Galan et al. (2001)}.
}
The pollen season of the species may occur during the natural year (Calendar year: from 1. January to 31. December) or the start_date and the end_date of the pollen season may happen in two different natural years (or calendar years). This consideration has been taken into account and in this package different method for defining the period for calculating the pollen season have been implemented. In this sense, the \code{def.season} argument has been incorporated in three options:
\itemize{
\item \code{"natural"}: considering the pollination year as natural year from 1st January to 31th December for defining the start_dates and end_dates of the pollen season for each pollen types.
\item \code{"interannual"}: considering the pollination year from 1st June to 31th May for defining the start_dates and end_dates of the pollen season for each pollen types.
\item \code{"peak"}: considering a customized pollination year for each pollen types calculated as 6 previous months and 6 later months from the average peak_date.
}
Pollen time series frequently have different gaps with no data and this fact could be a problem for the calculation of specific methods for defining the pollen season even providing incorrect results. In this sense by default a linear interpolation will be carried out to complete these gaps before to define the pollen season (\code{interpolation = TRUE}). Additionally, the users may select other interpolation methods using the \code{int.method} argument, as \code{"lineal"}, \code{"movingmean"}, \code{"spline"} or \code{"tseries"}. For more information to see the \code{\link{interpollen}} function.
}
\examples{
data("munich_pollen")
calculate_ps(munich_pollen, plot = TRUE, result = "table")
}
\references{
Andersen, T.B., 1991. A model to predict the beginning of the pollen season. \emph{Grana}, 30(1), pp.269_275.

Cunha, M., Ribeiro, H., Costa, P. and Abreu, I., 2015. A comparative study of vineyard phenology and pollen metrics extracted from airborne pollen time series. \emph{Aerobiologia}, 31(1), pp.45_56.

Galan, C., Garcia_Mozo, H., Carinanos, P., Alcazar, P. and Dominguez_Vilches, E., 2001. The role of temperature in the onset of the \emph{Olea europaea} L. pollen season in southwestern Spain. \emph{International Journal of Biometeorology}, 45(1), pp.8_12.

Nilsson, S. and Persson, S., 1981. Tree pollen spectra in the Stockholm region (Sweden), 1973_1980. \emph{Grana}, 20(3), pp.179_182.

Pfaar, O., Bastl, K., Berger, U., Buters, J., Calderon, M.A., Clot, B., Darsow, U., Demoly, P., Durham, S.R., Galan, C., Gehrig, R., Gerth van Wijk, R., Jacobsen, L., Klimek, L., Sofiev, M., Thibaudon, M. and Bergmann, K.C., 2017. Defining pollen exposure times for clinical trials of allergen immunotherapy for pollen_induced rhinoconjunctivitis_an EAACI position paper. \emph{Allergy}, 72(5), pp.713_722.

Ribeiro, H., Cunha, M. and Abreu, I., 2007. Definition of main pollen season using logistic model. \emph{Annals of Agricultural and Environmental Medicine}, 14(2), pp.259_264.
}
\seealso{
\code{\link{interpollen}}, \code{\link{plot_ps}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_trend.R
\name{plot_trend}
\alias{plot_trend}
\title{Calculating and Plotting Trends of Pollen Data.}
\usage{
plot_trend(
  data,
  base_dir = getwd(),
  table_dir = file.path(base_dir, "table_AeRobiology"),
  interpolation = TRUE,
  int.method = "lineal",
  export.plot = TRUE,
  export.format = "pdf",
  export.result = TRUE,
  method = "percentage",
  ...
)
}
\arguments{
\item{data}{A \code{data.frame} object. This \code{data.frame} should include a first column in format \code{Date} and the rest of columns in format \code{numeric} belonging to each pollen type by column.}

\item{base_dir}{Character. Base directory where output tables are stored.}

\item{table_dir}{Character. Directory where tables are exported.}

\item{interpolation}{A \code{logical} value specifying if the visualization shows the gaps in the inputs data (\code{interpolation = FALSE}) or if an interpolation method is used for filling the gaps (\code{interpolation = TRUE}). By default, \code{interpolation = TRUE}.}

\item{int.method}{A \code{character} string with the name of the interpolation method to be used. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"tseries"} or \code{"spline"}. By default, \code{int.method = "lineal"}.}

\item{export.plot}{A \code{logical} value specifying if a plot will be exported or not. If \code{FALSE} graphical results will only be displayed in the active graphics window. If \code{TRUE} graphical results will be displayed in the active graphics window and also one pdf/png file will be saved within the \emph{plot_AeRobiology} directory automatically created in the working directory. By default, \code{export.plot = TRUE}.}

\item{export.format}{A \code{character} string specifying the format selected to save the plot. The implemented formats that may be used are: \code{"pdf"} or \code{"png"}. By default, \code{export.format = "pdf"}.}

\item{export.result}{A \code{logical} value. If \code{export.result = TRUE}, a table is exported with the extension \emph{.xlsx}, in the directory \emph{table_AeRobiology}. This table has the information about the \code{slope} \emph{"beta coefficient of a lineal model using as predictor the year and as dependent variable one of the main pollen season indexes"}. The information is referred to the main pollen season indexes: \emph{Start Date}, \emph{Peak Date}, \emph{End Date} and \emph{Pollen Integral}.}

\item{method}{A \code{character} string specifying the method applied to calculate the pollen season and the main seasonal parameters. The implemented methods that can be used are: \code{"percentage"}, \code{"logistic"}, \code{"moving"}, \code{"clinical"} or \code{"grains"}. By default, \code{method = "percentage"} (\code{perc = 95}\%). A more detailed information about the different methods for defining the pollen season may be consulted in the function \code{\link{calculate_ps}}.}

\item{...}{Additional arguments for the function \code{\link{calculate_ps}} are also accepted.}
}
\value{
This function returns several plots in the directory \emph{plot_AeRobiology/trend_plots} with the extension \emph{.pdf} or \emph{.png}.Also produces an object of the class \code{data.frame} and export a table with the extension \emph{.xlsx}, in the directory \emph{table_AeRobiology}.\cr
These tables have the information about the \code{slope} \emph{(beta coefficient of a lineal model using as predictor the year and as dependent variable one of the main pollen season indexes)}. The information is referred to the main pollen season indexes: \emph{Start Date}, \emph{Peak Date}, \emph{End Date} and \emph{Pollen Integral}.
}
\description{
Function to calculate the main seasonal indexes of the pollen season (\emph{Start Date}, \emph{Peak Date}, \emph{End Date} and \emph{Pollen Integral}). Trends analysis of the parameters over the seasons. Plots showing the distribution of the main seasonal indexes over the years.
}
\examples{
 data("munich_pollen")
 plot_trend(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = TRUE)
}
\seealso{
\code{\link{calculate_ps}}; \code{\link{analyse_trend}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pollen_calendar.R
\name{pollen_calendar}
\alias{pollen_calendar}
\title{Pollen Calendar by Different Methods from a Historical Pollen Database}
\usage{
pollen_calendar(
  data,
  method = "heatplot",
  n.types = 15,
  start.month = 1,
  y.start = NULL,
  y.end = NULL,
  perc1 = 80,
  perc2 = 99,
  th.pollen = 1,
  average.method = "avg_before",
  period = "daily",
  method.classes = "exponential",
  n.classes = 5,
  classes = c(25, 50, 100, 300),
  color = "green",
  interpolation = TRUE,
  int.method = "lineal",
  na.remove = TRUE,
  result = "plot",
  export.plot = FALSE,
  export.format = "pdf",
  legendname = "Pollen grains / m3",
  ...
)
}
\arguments{
\item{data}{A \code{data.frame} object including the general database where calculation of the pollen calendar must be applied. This \code{data.frame} must include a first column in \code{Date} format and the rest of columns in \code{numeric} format belonging to each pollen type by column.}

\item{method}{A \code{character} string specifying the method applied to calculate and generate the pollen calendar. The implemented methods that can be used are: \code{"heatplot"}, \code{"violinplot"} or \code{"phenological"}. A more detailed information about the different methods for defining the pollen season may be consulted in \strong{Details}. The \code{method} argument will be \code{heatplot} by default.}

\item{n.types}{A \code{numeric} (\code{integer}) value specifying the number of the most abundant pollen types that must be represented in the pollen calendar. A more detailed information about the selection of the considered pollen types may be consulted in \strong{Details}. The \code{n.types} argument will be \code{15} types by default.}

\item{start.month}{A \code{numeric} (\code{integer}) value ranging \code{1_12} specifying the number of the month (January_December) when the beginning of the pollen calendar must be considered. This argument is only applicable for the \code{"heatplot"} method with \code{"daily"} period, for the \code{"phenological"} method with \code{"avg_before"} \code{average.method}, and for the \code{"violinplot"} method, and the rest of methods only may be generated from the January (\code{start.month = 1}). The \code{start.month} argument will be \code{1} (month of January) by default.}

\item{y.start, y.end}{A \code{numeric} (\code{integer}) value specifying the period selected to calculate the pollen calendar (start year _ end year). If \code{y.start} and \code{y.end} are not specified (\code{NULL}), the entire database will be used to generate the pollen calendar. The \code{y.start} and \code{y.end} arguments will be \code{NULL} by default.}

\item{perc1, perc2}{A \code{numeric} value ranging \code{0_100}. These arguments are valid only for the \code{"phenological"} method. These values represent the percentage of the total annual pollen included in the pollen season, removing \code{(100_percentage)/2\%} of the total pollen before and after of the pollen season. Two percentages must be specified because of the definition of the "main pollination period" (\code{perc1}) and "early/late pollination" (\code{perc2}) based on the \code{"phenological"} method proposed by \emph{Werchan et al. (2018)}. The \code{perc1} argument will be \code{80} and \code{perc2} argument will be \code{99} by default. A more detailed information about the \code{phenological} method to generate the pollen calendar may be consulted in \strong{Details}.}

\item{th.pollen}{A \code{numeric} value specifying the minimum threshold of the average pollen concentration which will be used to generate the pollen calendar. Days below this threshold will not be considered. For the \code{"phenological"} method this value limits the "possible occurrence" period as proposed by \emph{Werchan et al. (2018)}. The \code{th.pollen} argument will be \code{1} by default. A more detailed information about the methods to generate the pollen calendar may be consulted in \emph{Details}.}

\item{average.method}{A \code{character} string specifying the moment of the application of the average. This argument is valid only for the \code{"phenological"} method. The implemented methods that can be used are: \code{"avg_before"} or \code{"avg_after"}. \code{"avg_before"} produces the average to the daily concentrations and then pollen season are calculated for all pollen types, this method is recommended as it is a more concordant method with respect to the rest of implemented methods. Otherwise, \code{"avg_after"} determines the pollen season for all years and all pollen types, and then a circular average is calculated for the start_dates and end_dates. The \code{average.method} argument will be \code{"avg_before"} by default.}

\item{period}{A \code{character} string specifying the interval time considered to generate the pollen calendar. This argument is valid only for the \code{"heatplot"} method. The implemented periods that can be used are: \code{"daily"} or \code{"weekly"}. \code{"daily"} selection produces a pollen calendar using daily averages during the year and \code{"weekly"} selection produces a pollen calendar using weekly averages during the year. The \code{period} argument will be \code{"daily"} by default.}

\item{method.classes}{A  \code{character} string specifying the method to define the classes used for classifying the average pollen concentrations to generate the pollen calendar. This argument is valid only for the  \code{"heatplot"} method. The implemented methods for defining classes are:  \code{"exponential"} and  \code{"custom"}. The  \code{method.classes} argument will be  \code{"exponential"} by default. A more detailed information about the methods to classify the average pollen concentrations to generate the pollen calendar may be consulted in \strong{Details}.}

\item{n.classes}{A \code{numeric} (\code{integer}) value specifying the number of classes that will be used for classifying the average pollen concentrations to generate the pollen calendar. This argument is valid only for the \code{"heatplot"} method and the classification by \code{method.classes = "custom"}. The \code{n.classes} argument will be \code{5} by default. A more detailed information about the methods to classify the average pollen concentrations to generate the pollen calendar may be consulted in \strong{Details}.}

\item{classes}{A \code{numeric} vector specifying the threshold established to define the different classes that will be used for classifying the average pollen concentrations to generate the pollen calendar. This argument is valid only for the \code{"heatplot"} method and the classification by \code{method.classes = "custom"}. The \code{classes} argument will be \code{c(25, 50, 100, 300)} by default. The number of specified classes must be equal to \code{n.classes _ 1} because of the maximum threshold will be automatically specified by the maximum value. A more detailed information about the methods to classify the average pollen concentrations to generate the pollen calendar may be consulted in \strong{Details}.}

\item{color}{A \code{character} string specifying the color to generate the graph showing the pollen calendar. This argument is valid only for the \code{"heatplot"} method. The implemented color palettes to generate the pollen calendar are: \code{"green"}, \code{"red"}, \code{"blue"}, \code{"purple"} or \code{"black"}. The \code{color} argument will be \code{"green"} by default.}

\item{interpolation}{A \code{logical} value. If \code{FALSE} the interpolation of the pollen data is not applicable. If \code{TRUE} an interpolation of the pollen series will be applied to complete the gaps before the calculation of the pollen calendar. The \code{interpolation} argument will be \code{TRUE} by default. A more detailed information about the interpolation method may be consulted in \strong{Details}.}

\item{int.method}{A \code{character} string specifying the method selected to apply the interpolation method in order to complete the pollen series. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"spline"} or \code{"tseries"}. The \code{int.method} argument will be \code{"lineal"} by default.}

\item{na.remove}{A \code{logical} value specifying if \code{na} values must be remove for the pollen calendar or not. \code{n.remove = TRUE} by default.}

\item{result}{A \code{character} string specifying the output for the function. The implemented outputs that may be obtained are: \code{"plot"} and \code{"table"}. The argument \code{result} will be \code{"plot"} by default.}

\item{export.plot}{A \code{logical} value specifying if a plot with the pollen calendar saved in the working directory will be required or not. If \code{FALSE} graphical results will only be displayed in the active graphics window. If \code{TRUE} graphical results will be displayed in the active graphics window and also a \emph{pdf} file will be saved within the \emph{plot_AeRobiology} directory automatically created in the working directory. The \code{export.plot} will be \code{FALSE} by default.}

\item{export.format}{A \code{character} string specifying the format selected to save the pollen calendar plot. The implemented formats that may be used are: \code{"pdf"} and \code{"png"}. The \code{export.format} will be \code{"pdf"} by default.}

\item{legendname}{A \code{character} string specifying the title of the legend. By default is \code{"Pollen / m3"}.}

\item{...}{Other additional arguments may be used to customize the exportation of the plots using \code{"pdf"} or \code{"png"} files and therefore arguments from \emph{pdf} and \emph{png} functions (\pkg{grDevices} package) may be implemented. For example, for \emph{pdf} files the user may custom the arguments: \code{width}, \code{height}, \code{family}, \code{title}, \code{fonts}, \code{paper}, \code{bg}, \code{fg}, \code{pointsize...}; and for \emph{png} files the user may custom the arguments: \code{width}, \code{height}, \code{units}, \code{pointsize}, \code{bg}, \code{res...}}
}
\value{
This function returns different results:\cr
\code{plot} in the active graphics window displaying the pollen calendar generated by the user when \code{result = "plot"}. This plot may be included in an object by assignment operators.\cr
\code{data.frame} including the daily or weekly average pollen concentrations (according to the selection of the user) used to generate the pollen calendar. This \code{data.frame} will be returned when \code{result = "table"}.\cr
If \code{export.plot = TRUE} this plot displaying the pollen calendar will also be exported as file within the \emph{Plot_AeRobiology}" directory created in the working directory.\cr
If \code{export.plot = TRUE} and \code{export.format = pdf} a \emph{pdf} file of the pollen calendar will be saved within the \emph{plot_AeRobiology} directory created in the working directory. Additional characteristics may be incorporated to the exportation as \emph{pdf} file (see \pkg{grDevices} package)\cr
If \code{export.plot = TRUE} and \code{export.format = png} a \emph{png} file of the pollen calendar will be saved within the \emph{plot_AeRobiology} directory created in the working directory. Additional characteristics may be incorporated to the exportation as \emph{png} file (see \pkg{grDevices} package).
}
\description{
Function to calculate the pollen calendar from a historical database of several pollen types and using the most commonly used methods in the generation of the pollen calendars in the aerobiology field.
}
\details{
This function allows to calculate and generate the pollen calendar using three different methods which are described below. The pollen calendar will be calculated and generated only for the period specified by the user using the \code{y.start} and \code{y.end} arguments, and for the specified number of the most abundant pollen types using the \code{n.types} argument by the user. The most abundant pollen types will be selected according to the highest average annual amounts of pollen registered by the pollen types during the considered period.
\itemize{
\item \code{"heatplot"} method. This pollen calendar is constructed based on the daily or weekly average of pollen concentrations, depending of the preferences of the user that may select \code{"daily"} or \code{"weekly"} as \code{period} argument. Then, these averages may be classified in different categories following different methods selected by the user according to the \code{method.classes} argument. If \code{method.classes = "exponential"} the user will apply the classification based on exponential classes proposed by \emph{Stix and Ferreti (1974)}, which has been commonly used in aerobiology for the generation of pollen calendars. The classification based on exponential method considers 11 classes (\code{1_2, 3_5, 6_11, 12_24, 25_49, 50_99, 100_199, 200_399, 400_799, 800_1600, >1600}). An example of this pollen calendar may be consulted in \emph{Rojo et al. (2016)}. This method to design pollen calendars is an adaptation from the pollen calendar proposed by \emph{Spieksma (1991)} who considered 10_day periods instead of daily or weekly periods. Otherwise, if \code{method.classes  = "custom"} the user may customize the classification according to the number of classes selected (\code{n.classes} argument) and the thresholds of the pollen concentrations used to define the classes (\code{classes} argument). Average values below the level of the \code{th.pollen} argument will be removed from the pollen calendar.
\item \code{"phenological"} method. This pollen calendar is based on phenological definition of the pollen season and adapted from the methodology proposed by \emph{Werchan et al. (2018)}. After to obtain daily average pollen concentrations for the most abundant pollen types different pollination periods were calculated using the daily averages. The main pollination period was calculated based on the percentage defined by \code{perc1} argument (selected by the user, 80\% by default) of the annual total pollen. For example, if \code{perc1 = 80} the beginning of the high season was marked when 10\% of the annual value was reached and the end was selected when 90\% was reached. In the case of the early/late pollination a total of the percentage defined by \code{perc2} argument (selected by the user, 99\% by default) of the annual total pollen will be registered during this period. For this kind of pollen calendar the \code{th.pollen} argument will define the "possible occurrence" period as adapted by \emph{Werchan et al. (2018)}, considering the entire period between the first and the last day when this pollen level is reached. In an alternative way the average may be carried out after to define the pollen seasons using \code{method_average = "avg_after"} (instead of \code{"avg_before"} by default). \code{"avg_after"} determines the pollen season for all years and all pollen types, and then an average for circular data is calculated from the start_dates and end_dates.
\item \code{"violinplot"} method. This pollen calendar is based on the pollen intensity and adapted from the pollen calendar published by \emph{ORourke (1990)}. In first time the daily averages of the pollen concentrations are calculated and then these averages are represented using the \emph{violin plot} graph. The shape of the \emph{violin plot} display the pollen intensity of the pollen types in a relative way i.e. the values will be calculated as relative measurements regarding to the most abundant pollen type in annual amounts. Therefore, this pollen calendar shows a relative comparison between the pollen intensity of the pollen types but without scales and units. Average values below the level of the \code{th.pollen} argument will be removed from the pollen calendar.
}
Pollen time series frequently have different gaps with no data and this fact could be a problem for the calculation of specific methods for defining the pollen season even providing incorrect results. In this sense by default a linear interpolation will be carried out to complete these gaps before to generate the pollen calendar. For more information to see the \code{\link{interpollen}} function.
}
\examples{
data("munich_pollen")
pollen_calendar(munich_pollen, method = "heatplot", interplation = FALSE)
}
\references{
ORourke, M.K., 1990. Comparative pollen calendars from Tucson, Arizona: Durhamvs. Burkard samplers. \emph{Aerobiologia}, 6(2), p.136_140.

Rojo, J., Rapp, A., Lara, B., Sabariego, S., Fernandez_Gonzalez, F. and Perez_Badia, R., 2016. Characterisation of the airborne pollen spectrum in Guadalajara (central Spain) and estimation of the potential allergy risk. \emph{Environmental Monitoring and Assessment}, 188(3), p.130.

Spieksma, F.T.M., 1991. \emph{Regional European pollen calendars. Allergenic pollen and pollinosis in Europe}, pp.49_65.

Stix, E. and Ferretti, M.L., 1974. \emph{Pollen calendars of three locations in Western Germany. Atlas European des Pollens Allergisants}, pp.85_94.

Werchan, M., Werchan, B. and Bergmann, K.C., 2018. German pollen calendar 4.0_update based on 2011_2016 pollen data. \emph{Allergo Journal International}, 27, pp.69_71.
}
\seealso{
\code{\link{interpollen}}, \code{\link{calculate_ps}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_heathour.R
\name{plot_heathour}
\alias{plot_heathour}
\title{Plotting hourly patterns with heatplot}
\usage{
plot_heathour(
  data,
  locations = FALSE,
  low.col = "blue",
  mid.col = "white",
  high.col = "red"
)
}
\arguments{
\item{data}{A \code{data.frame} object with the structure \code{long}. Where the first two columns are \code{factors} indicating the \code{pollen} and the \code{location}. The 3 and 4 columns are \code{POSIXct}, showing the hour. Where the third column is the beguinning of the concentration \code{from} and the fourth column is the end time of the concentrtion data \code{to}. The fifth column shows the concentrations of the different pollen types as \code{numeric}. Please see the example 3-hourly data from the automatic pollen monitor BAA500 from Munich and Viechtach in Bavaria (Germany) \code{data("POMO_pollen")}, supplied by ePIN Network supported by the Bavarian Government.}

\item{locations}{A \code{logical} object with the specification if the different locations will be displayed in the plot. Argument only used when \code{result == "plot"}. By default, \code{locations = FALSE}.}

\item{low.col}{A \code{character} object with the specification of the color of the lowest value for the scale. By default, \code{low.col = "blue"}.}

\item{mid.col}{A \code{character} object with the specification of the color of the medium value for the scale. By default, \code{mid.col = "white"}.}

\item{high.col}{A \code{character} object with the specification object with the specification of the color of the highest value for the scale. By default, \code{high.col = "red"}.}
}
\value{
The function returns an object or a list of objects of class \pkg{ggplot2}.
}
\description{
Function to plot pollen data expressed in concentrations with time resolution higher than 1 day (e.g. hourly, bi-hourly concentrations). As heatplot.
}
\examples{
data("POMO_pollen")
plot_heathour(POMO_pollen)
}
\references{
Oteros, J., Pusch, G., Weichenmeier, I., Heimann, U., Mueller, R., Roeseler, S., ... & Buters, J. T. (2015). Automatic and online pollen monitoring. \emph{International archives of allergy and immunology}, 167(3), 158-166.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/iplot_abundance.R
\name{iplot_abundance}
\alias{iplot_abundance}
\title{Plot of the Relative Abundance of the Pollen Types}
\usage{
iplot_abundance(
  data,
  n.types = 15,
  y.start = NULL,
  y.end = NULL,
  interpolation = TRUE,
  int.method = "lineal",
  col.bar = "#E69F00",
  type.plot = "static",
  result = "plot",
  export.plot = FALSE,
  export.format = "pdf",
  exclude = NULL,
  ...
)
}
\arguments{
\item{data}{A \code{data.frame} object including the general database where calculation of the pollen season must be applied. This \code{data.frame} must include a first column in \code{Date} format and the rest of columns in \code{numeric} format belonging to each pollen type by column.}

\item{n.types}{A \code{numeric} (\code{integer}) value specifying the number of the most abundant pollen types that must be represented in the plot of the relative abundance. A more detailed information about the selection of the considered pollen types may be consulted in \strong{Details}. The \code{n.types} argument will be \code{15} types by default.}

\item{y.start, y.end}{A \code{numeric} (\code{integer}) value specifying the period selected to calculate relative abundances of the pollen types (\code{start year _ end year}). If \code{y.start} and \code{y.end} are not specified (\code{NULL}), the entire database will be used to generate the pollen calendar. The \code{y.start} and \code{y.end} arguments will be \code{NULL} by default.}

\item{interpolation}{A \code{logical} value. If \code{FALSE} the interpolation of the pollen data is not applicable. If \code{TRUE} an interpolation of the pollen series will be applied to complete the gaps with no data before the calculation of the pollen season. The \code{interpolation} argument will be \code{TRUE} by default. A more detailed information about the interpolation method may be consulted in \strong{Details}.}

\item{int.method}{A \code{character} string specifying the method selected to apply the interpolation method in order to complete the pollen series. The implemented methods that may be used are: \code{"lineal"}, \code{"movingmean"}, \code{"spline"} or \code{"tseries"}. The \code{int.method} argument will be \code{"lineal"} by default.}

\item{col.bar}{A \code{character} string specifying the color of the bars to generate the graph showing the relative abundances of the pollen types. The \code{color} argument will be \code{#E69F00} by default, but any color may be selected.}

\item{type.plot}{A \code{character} string specifying the type of plot selected to show the plot showing the relative abundance of the pollen types. The implemented types that may be used are: \code{static} generates a static \strong{ggplot} object and \code{dynamic} generates a dynamic \strong{plotly} object.}

\item{result}{A \code{character} string specifying the output for the function. The implemented outputs that may be obtained are: \code{"plot"} and \code{"table"}. The argument \code{result} will be \code{"plot"} by default.}

\item{export.plot}{A \code{logical} value specifying if a plot saved in the working directory will be required or not. If \code{FALSE} graphical results will only be displayed in the active graphics window. If \code{TRUE} graphical results will be displayed in the active graphics window and also a \emph{pdf} or \emph{png} file (according to the \code{export.format} argument) will be saved within the \emph{plot_AeRobiology} directory automatically created in the working directory. This argument is applicable only for \code{"static"} plots. The \code{export.plot} will be \code{FALSE} by default.}

\item{export.format}{A \code{character} string specifying the format selected to save the plot showing the relative abundance of the pollen types. The implemented formats that may be used are: \code{"pdf"} and \code{"png"}. This argument is applicable only for \code{"static"} plots. The \code{export.format} will be \code{"pdf"} by default.}

\item{exclude}{A \code{character} string vector with the names of the pollen types to be excluded from the plot.}

\item{...}{Other additional arguments may be used to customize the exportation of the plots using \code{"pdf"} or \code{"png"} files and therefore arguments from \code{\link[grDevices]{pdf}} and \code{\link[grDevices]{png}} functions (\pkg{grDevices} package) may be implemented. For example, for \emph{pdf} files the user may custom the arguments: \code{width}, \code{height}, \code{family}, \code{title}, \code{fonts}, \code{paper}, \code{bg}, \code{fg}, \code{pointsize...}; and for \emph{png} files the user may custom the arguments: \code{width}, \code{height}, \code{units}, \code{pointsize}, \code{bg}, \code{res...}}
}
\value{
This function returns different results:\cr
\cr
\code{plot} in the active graphics window displaying the pollen calendar generated by the user when \code{result = "plot"}. This \code{plot} may be included in an object by assignment operators.\cr
\cr
\code{data.frame} including the yearly average pollen amounts for each pollen types used to generate the pollen of the relative abundance when \code{result = "table"}. This \code{data.frame} will be included in an object named \code{annual.sum.data}.\cr
\cr
If \code{export.plot = FALSE} graphical results will only be displayed in the active graphics window as \strong{ggplot} graph. Additional characteristics may be incorporated to the plot by \code{\link[ggplot2]{ggplot}} syntax (see \pkg{ggplot2} package).\cr
\cr
If \code{export.plot = TRUE} and \code{export.format = pdf} a \emph{pdf} file with the plot will be saved within the \emph{plot_AeRobiology} directory created in the working directory. This option is applicable only for \code{"static"} plots. Additional characteristics may be incorporated to the exportation as \emph{pdf} file (see \pkg{grDevices} package).\cr
\cr
If \code{export.plot = TRUE} and \code{export.format = png} a \emph{png} file with the plot will be saved within the \emph{plot_AeRobiology} directory created in the working directory. This option is applicable only for \code{"static"} plots. Additional characteristics may be incorporated to the exportation as \emph{png} file (see \pkg{grDevices} package).\cr
\cr
If \code{type.plot = dynamic} graphical results will be displayed in the active Viewer window as \strong{plotly} graph. Additional characteristics may be incorporated to the plot by \code{\link[plotly]{plotly}} syntax (see \pkg{plotly} package).
}
\description{
Generates a barplot based on the relative abundance (as percentage) in the air of the pollen types with respect to the total amounts
}
\details{
This function allows to calculate the relative abundance of the pollen types in the air from a database and to display a barplot with the percentage representation of the main pollen types as the graph reported by \emph{Rojo et al. (2016)}. This plot will be generated only for the specified number of the most abundant pollen types using the \code{n.types} argument by the user.\cr
\cr
Pollen time series frequently have different gaps with no data and this fact could be a problem for the calculation of specific methods for defining the pollen season even providing incorrect results. In this sense by default a linear interpolation will be carried out to complete these gaps before to define the pollen season (\code{interpolation = TRUE}). Additionally, the users may select other interpolation methods using the \code{int.method} argument, as \code{"lineal"}, \code{"movingmean"}, \code{"spline"} or \code{"tseries"}. For more information to see the \code{\link{interpollen}} function.
}
\examples{
data("munich_pollen")
iplot_abundance (munich_pollen, interpolation = FALSE, export.plot = FALSE)
}
\references{
Rojo, J., Rapp, A., Lara, B., Sabariego, S., Fernandez_Gonzalez, F. and Perez_Badia, R., 2016. Characterisation of the airborne pollen spectrum in Guadalajara (central Spain) and estimation of the potential allergy risk. \emph{Environmental Monitoring and Assessment}, 188(3), p.130.
}
\seealso{
\code{\link{interpollen}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_monthly_heatmap.R
\name{plot_monthly_heatmap}
\alias{plot_monthly_heatmap}
\title{Monthly Pollen Heatmap}
\usage{
plot_monthly_heatmap(
  data,
  pollen.type,
  location = NULL,
  location.col = NULL,
  start.month = 1,
  color.A = "yellow",
  color.B = "red",
  result = "plot"
)
}
\arguments{
\item{data}{A \code{data.frame} object. The first column must be in \code{Date}
format and pollen types must be provided as numeric columns. If the data include
several locations, one column can identify the location.}

\item{pollen.type}{A \code{character} string with the name of the pollen type to
be plotted. This name must match one numeric column in \code{data}.}

\item{location}{A \code{character} string with the location to be selected. If
\code{NULL} and a location column is detected, the first location in the data is
used. If the data do not include a location column, this argument is ignored.}

\item{location.col}{A \code{character} string with the name of the column
containing the locations. If \code{NULL}, common names such as \code{"location"},
\code{"city"} or \code{"station"} are automatically detected.}

\item{start.month}{A \code{numeric} value ranging \code{1_12} specifying the
first month shown in the x axis. The \code{start.month} argument will be
\code{1} by default.}

\item{color.A}{A \code{character} object with the specification of the color of
the lowest value for the scale. By default, \code{color.A = "yellow"}.}

\item{color.B}{A \code{character} object with the specification of the color of
the highest value for the scale. By default, \code{color.B = "red"}.}

\item{result}{A \code{character} object with the definition of the object to be
produced by the function. If \code{result == "plot"}, the function returns an
object of class \pkg{ggplot2}; if \code{result == "table"}, the function returns
a \pkg{data.frame} with the monthly sums. By default, \code{result = "plot"}.}
}
\value{
If \code{result == "plot"}, the function returns an object of class
\pkg{ggplot2}; if \code{result == "table"}, the function returns a
\pkg{data.frame} with the monthly sums.
}
\description{
Function to plot monthly sums of daily pollen concentrations as a heatmap. Months
are displayed in the x axis and years in the y axis for one selected pollen type.
}
\examples{
data("munich_pollen")
plot_monthly_heatmap(munich_pollen, pollen.type = "Betula")
plot_monthly_heatmap(munich_pollen, pollen.type = "Poaceae", start.month = 6)
}
